@@ -62,11 +62,11 @@ static BOOLEAN cla_lookdown(NODEPROTO*);
 /* command completion table for this constraint solver */
 static KEYWORD layconopt[] =
 {
-	{"debug-toggle",      0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
+	{x_("debug-toggle"),      0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
 	TERMKEY
 };
 COMCOMP cla_layconp = {layconopt, NOTOPLIST, NONEXTLIST, NOPARAMS,
-	0, " \t", M_("layout constraint system option"), 0};
+	0, x_(" \t"), M_("layout constraint system option"), 0};
 
 INTBIG cla_changeclock;
 #ifdef CLA_DEBUG
@@ -89,18 +89,18 @@ void cla_layconinit(CONSTRAINT *con)
 
 void cla_layconterm(void)
 {
-	if (cla_workingarccount > 0) efree((char *)cla_workingarcs);
+	if (cla_workingarccount > 0) efree((CHAR *)cla_workingarcs);
 	cla_workingarccount = 0;
 }
 
-void cla_layconsetmode(INTBIG count, char *par[])
+void cla_layconsetmode(INTBIG count, CHAR *par[])
 {
 	REGISTER INTBIG l;
-	REGISTER char *pp;
+	REGISTER CHAR *pp;
 
 	if (count == 0)
 	{
-		ttyputusage("constraint tell layout OPTION");
+		ttyputusage(x_("constraint tell layout OPTION"));
 		return;
 	}
 
@@ -110,10 +110,10 @@ void cla_layconsetmode(INTBIG count, char *par[])
 		return;
 	}
 
-	l = strlen(pp = par[0]);
+	l = estrlen(pp = par[0]);
 
 	/* debugging switch */
-	if (namesamen(pp, "debug-toggle", l) == 0 && l >= 1)
+	if (namesamen(pp, x_("debug-toggle"), l) == 0 && l >= 1)
 	{
 #ifdef CLA_DEBUG
 		cla_conlaydebug = !cla_conlaydebug;
@@ -124,22 +124,22 @@ void cla_layconsetmode(INTBIG count, char *par[])
 #endif
 		return;
 	}
-	ttyputbadusage("constraint tell layout");
+	ttyputbadusage(x_("constraint tell layout"));
 }
 
 /*
  * the valid "command" is "describearc" which returns a string that describes
  * the constraints on the arc in "arg1".
  */
-INTBIG cla_layconrequest(char *command, INTBIG arg1)
+INTBIG cla_layconrequest(CHAR *command, INTBIG arg1)
 {
 	REGISTER ARCINST *ai;
 	REGISTER INTBIG l;
 	REGISTER void *infstr;
 
-	l = strlen(command);
+	l = estrlen(command);
 
-	if (namesamen(command, "describearc", l) == 0)
+	if (namesamen(command, x_("describearc"), l) == 0)
 	{
 		ai = (ARCINST *)arg1;
 		infstr = initinfstr();
@@ -148,7 +148,7 @@ INTBIG cla_layconrequest(char *command, INTBIG arg1)
 			switch (ai->userbits&(FIXANG|CANTSLIDE))
 			{
 				case 0:                addtoinfstr(infstr, 'S');         break;
-				case FIXANG:           addstringtoinfstr(infstr, "FS");  break;
+				case FIXANG:           addstringtoinfstr(infstr, x_("FS"));  break;
 				case CANTSLIDE:        addtoinfstr(infstr, 'X');         break;
 				case FIXANG|CANTSLIDE: addtoinfstr(infstr, 'F');         break;
 			}
@@ -187,22 +187,22 @@ void cla_layconsolve(NODEPROTO *np)
 		case NODEINSTNEW:
 		case NODEINSTKILL:
 		case NODEINSTMOD:
-			((NODEINST *)c->entryaddr)->changeaddr = (char *)NOCHANGE;
+			((NODEINST *)c->entryaddr)->changeaddr = (CHAR *)NOCHANGE;
 			break;
 		case ARCINSTNEW:
 		case ARCINSTKILL:
 		case ARCINSTMOD:
-			((ARCINST *)c->entryaddr)->changeaddr = (char *)NOCHANGE;
+			((ARCINST *)c->entryaddr)->changeaddr = (CHAR *)NOCHANGE;
 			break;
 		case PORTPROTONEW:
 		case PORTPROTOKILL:
 		case PORTPROTOMOD:
-			((PORTPROTO *)c->entryaddr)->changeaddr = (char *)NOCHANGE;
+			((PORTPROTO *)c->entryaddr)->changeaddr = (CHAR *)NOCHANGE;
 			break;
 		case NODEPROTONEW:
 		case NODEPROTOKILL:
 		case NODEPROTOMOD:
-			((NODEPROTO *)c->entryaddr)->changeaddr = (char *)NOCHANGE;
+			((NODEPROTO *)c->entryaddr)->changeaddr = (CHAR *)NOCHANGE;
 			break;
 	}
 }
@@ -258,7 +258,7 @@ void cla_layconkillobject(INTBIG addr, INTBIG type)
  */
 void cla_layconnewvariable(INTBIG addr, INTBIG type, INTBIG skey, INTBIG stype)
 {
-	char *name;
+	CHAR *name;
 	REGISTER NODEPROTO *np;
 	REGISTER PORTPROTO *pp;
 	REGISTER NODEINST *ni;
@@ -268,7 +268,7 @@ void cla_layconnewvariable(INTBIG addr, INTBIG type, INTBIG skey, INTBIG stype)
 		if ((stype&VCREF) != 0)
 		{
 			name = changedvariablename(type, skey, stype);
-			if (strcmp(name, "protoname") == 0)
+			if (estrcmp(name, x_("protoname")) == 0)
 			{
 				pp = (PORTPROTO *)addr;
 				np = pp->parent;
@@ -301,27 +301,27 @@ BOOLEAN cla_layconsetobject(INTBIG addr, INTBIG type, INTBIG changetype,
 	{
 		case CHANGETYPERIGID:				/* arc rigid */
 			if ((ai->userbits & FIXED) != 0) return(TRUE);
-			(void)setval((INTBIG)ai, VARCINST, "userbits", ai->userbits|FIXED, VINTEGER);
+			(void)setval((INTBIG)ai, VARCINST, x_("userbits"), ai->userbits|FIXED, VINTEGER);
 			break;
 		case CHANGETYPEUNRIGID:				/* arc un-rigid */
 			if ((ai->userbits & FIXED) == 0) return(TRUE);
-			(void)setval((INTBIG)ai, VARCINST, "userbits", ai->userbits & ~FIXED, VINTEGER);
+			(void)setval((INTBIG)ai, VARCINST, x_("userbits"), ai->userbits & ~FIXED, VINTEGER);
 			break;
 		case CHANGETYPEFIXEDANGLE:			/* arc fixed-angle */
 			if ((ai->userbits & FIXANG) != 0) return(TRUE);
-			(void)setval((INTBIG)ai, VARCINST, "userbits", ai->userbits|FIXANG, VINTEGER);
+			(void)setval((INTBIG)ai, VARCINST, x_("userbits"), ai->userbits|FIXANG, VINTEGER);
 			break;
 		case CHANGETYPENOTFIXEDANGLE:		/* arc not fixed-angle */
 			if ((ai->userbits & FIXANG) == 0) return(TRUE);
-			(void)setval((INTBIG)ai, VARCINST, "userbits", ai->userbits & ~FIXANG, VINTEGER);
+			(void)setval((INTBIG)ai, VARCINST, x_("userbits"), ai->userbits & ~FIXANG, VINTEGER);
 			break;
 		case CHANGETYPESLIDABLE:			/* arc slidable */
 			if ((ai->userbits & CANTSLIDE) == 0) return(TRUE);
-			(void)setval((INTBIG)ai, VARCINST, "userbits", ai->userbits & ~CANTSLIDE, VINTEGER);
+			(void)setval((INTBIG)ai, VARCINST, x_("userbits"), ai->userbits & ~CANTSLIDE, VINTEGER);
 			break;
 		case CHANGETYPENOTSLIDABLE:			/* arc nonslidable */
 			if ((ai->userbits & CANTSLIDE) != 0) return(TRUE);
-			(void)setval((INTBIG)ai, VARCINST, "userbits", ai->userbits|CANTSLIDE, VINTEGER);
+			(void)setval((INTBIG)ai, VARCINST, x_("userbits"), ai->userbits|CANTSLIDE, VINTEGER);
 			break;
 		case CHANGETYPETEMPRIGID:			/* arc temporarily rigid */
 			if (ai->changed == cla_changeclock + 2) return(TRUE);
@@ -405,7 +405,7 @@ void cla_layconmodifyvariable(INTBIG addr, INTBIG type, INTBIG key, INTBIG stype
 	INTBIG aindex, INTBIG oldval)
 {
 #ifdef TEXTPARTOFOBJECTBOUNDS
-	REGISTER char *name;
+	REGISTER CHAR *name;
 	REGISTER PORTPROTO *pp;
 	REGISTER NODEINST *ni;
 
@@ -415,7 +415,7 @@ void cla_layconmodifyvariable(INTBIG addr, INTBIG type, INTBIG key, INTBIG stype
 		if ((stype&VCREF) != 0)
 		{
 			name = changedvariablename(type, key, stype);
-			if (strcmp(name, "textdescript") == 0)
+			if (estrcmp(name, x_("textdescript")) == 0)
 			{
 				if (aindex == 1)
 				{
@@ -519,7 +519,7 @@ BOOLEAN cla_modifynodeinst(NODEINST *ni, INTBIG deltalx, INTBIG deltaly, INTBIG
 	/* mark that this nodeinst has changed */
 	if (ni->changed < cla_changeclock-1)
 	{
-		ni->changeaddr = (char *)db_change((INTBIG)ni, NODEINSTMOD, oldlx,
+		ni->changeaddr = (CHAR *)db_change((INTBIG)ni, NODEINSTMOD, oldlx,
 			oldly, oldhx, oldhy, oldang, oldtrans);
 		if (announce)
 			(void)db_change((INTBIG)ni, OBJECTEND, VNODEINST, 0, 0, 0, 0, 0);
@@ -584,7 +584,7 @@ void cla_modwithin(NODEINST *ni, INTBIG dangle, INTBIG dtrans)
 	if (total == 0) return;
 	if (total > cla_workingarccount)
 	{
-		if (cla_workingarccount > 0) efree((char *)cla_workingarcs);
+		if (cla_workingarccount > 0) efree((CHAR *)cla_workingarcs);
 		cla_workingarccount = 0;
 		cla_workingarcs = (ARCINST **)emalloc(total * (sizeof (ARCINST *)), db_cluster);
 		if (cla_workingarcs == 0) return;
@@ -800,7 +800,7 @@ BOOLEAN cla_modrigid(NODEINST *ni, INTBIG dangle, INTBIG dtrans)
 			nextangle = (3600 - nextangle) % 3600;
 		if (cla_modnodearcs(ono, nextangle, dtrans)) examinefacet = TRUE;
 	}
-	efree((char *)arclist);
+	efree((CHAR *)arclist);
 	return(examinefacet);
 }
 
@@ -1053,7 +1053,7 @@ BOOLEAN cla_modflex(NODEINST *ni, INTBIG dangle, INTBIG dtrans)
 #endif
 		cla_domovearcinst(ai, ax[0],ay[0], ax[1],ay[1], 1);
 	}
-	efree((char *)arclist);
+	efree((CHAR *)arclist);
 	return(examinefacet);
 }
 
@@ -1215,7 +1215,7 @@ void cla_updatearc(ARCINST *ai, INTBIG fx, INTBIG fy, INTBIG tx, INTBIG ty, INTB
 	if (((CHANGE *)ai->changeaddr) == NOCHANGE)
 	{
 		/* announce new arcinst change */
-		ai->changeaddr = (char *)db_change((INTBIG)ai, ARCINSTMOD, oldxA,
+		ai->changeaddr = (CHAR *)db_change((INTBIG)ai, ARCINSTMOD, oldxA,
 			oldyA, oldxB, oldyB, ai->width, oldlen);
 		ai->changed = cla_changeclock + arctyp;
 	}
@@ -1558,7 +1558,7 @@ void cla_computefacet(NODEPROTO *facet, BOOLEAN forcedlook)
 	/* update the facet size */
 	facet->lowx = nlx;   facet->highx = nhx;
 	facet->lowy = nly;   facet->highy = nhy;
-	facet->changeaddr = (char *)db_change((INTBIG)facet, NODEPROTOMOD, flx, fhx, fly, fhy, 0, 0);
+	facet->changeaddr = (CHAR *)db_change((INTBIG)facet, NODEPROTOMOD, flx, fhx, fly, fhy, 0, 0);
 
 	/* see if all instances of this facet are in the same location */
 	mixed = FALSE;
@@ -1749,7 +1749,7 @@ BOOLEAN cla_lookdown(NODEPROTO *start)
 	}
 
 	/* update the facet size */
-	start->changeaddr = (char *)db_change((INTBIG)start, NODEPROTOMOD,
+	start->changeaddr = (CHAR *)db_change((INTBIG)start, NODEPROTOMOD,
 		start->lowx, start->highx, start->lowy, start->highy, 0, 0);
 	start->lowx = nlx;  start->highx = nhx;
 	start->lowy = nly;  start->highy = nhy;
