@@ -34,34 +34,34 @@
 
 /* command completion table for this constraint solver */
 static COMCOMP cli_linconsp = {NOKEYWORD, topoffacets, nextfacets, NOPARAMS,
-	INPUTOPT, " \t", M_("facet to solve for linear inequalities"), 0};
+	INPUTOPT, x_(" \t"), M_("facet to solve for linear inequalities"), 0};
 static KEYWORD linconiopt[] =
 {
-	{"on",                   0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
-	{"off",                  0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
+	{x_("on"),                   0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
+	{x_("off"),                  0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
 	TERMKEY
 };
 static COMCOMP cli_linconip = {linconiopt, NOTOPLIST, NONEXTLIST, NOPARAMS,
-	INPUTOPT, " \t", M_("mode that assumes manhattan wires"), 0};
+	INPUTOPT, x_(" \t"), M_("mode that assumes manhattan wires"), 0};
 static KEYWORD lincontopt[] =
 {
-	{"go",                   0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
-	{"name-nodes",           0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
-	{"highlight-equivalent", 0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
+	{x_("go"),                   0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
+	{x_("name-nodes"),           0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
+	{x_("highlight-equivalent"), 0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
 	TERMKEY
 };
 static COMCOMP cli_lincontp = {lincontopt, NOTOPLIST, NONEXTLIST, NOPARAMS,
-	INPUTOPT, " \t", M_("text-equivalent mode"), 0};
+	INPUTOPT, x_(" \t"), M_("text-equivalent mode"), 0};
 static KEYWORD linconopt[] =
 {
-	{"solve",                1,{&cli_linconsp,NOKEY,NOKEY,NOKEY,NOKEY}},
-	{"debug-toggle",         0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
-	{"implicit-manhattan",   1,{&cli_linconip,NOKEY,NOKEY,NOKEY,NOKEY}},
-	{"text-equivalence",     1,{&cli_lincontp,NOKEY,NOKEY,NOKEY,NOKEY}},
+	{x_("solve"),                1,{&cli_linconsp,NOKEY,NOKEY,NOKEY,NOKEY}},
+	{x_("debug-toggle"),         0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
+	{x_("implicit-manhattan"),   1,{&cli_linconip,NOKEY,NOKEY,NOKEY,NOKEY}},
+	{x_("text-equivalence"),     1,{&cli_lincontp,NOKEY,NOKEY,NOKEY,NOKEY}},
 	TERMKEY
 };
 COMCOMP cli_linconp = {linconopt, NOTOPLIST, NONEXTLIST, NOPARAMS,
-	0, " \t", M_("linear constraint system option"), 0};
+	0, x_(" \t"), M_("linear constraint system option"), 0};
 
 /* global data in linear constraints */
        CONSTRAINT *cli_constraint;	/* the constraint object for this solver */
@@ -71,7 +71,7 @@ COMCOMP cli_linconp = {linconopt, NOTOPLIST, NONEXTLIST, NOPARAMS,
        BOOLEAN     cli_ownchanges;	/* true if changes are internally generated */
        INTBIG      cli_textlines;	/* number of declaration/connection lines */
        BOOLEAN     cli_texton;		/* true if text/graphics system is on */
-static char       *cli_linconops[] = {">=", "==", "<="};
+static CHAR       *cli_linconops[] = {x_(">="), x_("=="), x_("<=")};
 
 static BOOLEAN cli_conlindebug;
 static BOOLEAN cli_didsolve;
@@ -117,7 +117,7 @@ static BOOLEAN cli_solveconstraints(CONNODE*, BOOLEAN);
 static BOOLEAN cli_satisfy(CONNODE*, CONARC*);
 static void cli_applyconstraints(NODEPROTO*, CONNODE*, BOOLEAN);
 static void cli_deleteconstraints(CONNODE*);
-static void cli_printconstraints(CONNODE*, char*, char*);
+static void cli_printconstraints(CONNODE*, CHAR*, CHAR*);
 static void cli_nameallnodes(NODEPROTO*);
 
 /****************************** ALLOCATION ******************************/
@@ -193,7 +193,7 @@ void cli_linconinit(CONSTRAINT *con)
 		cli_manhattan = TRUE;
 
 		/* get the primary key for the properties variable */
-		cli_properties_key = makekey("CONLIN_properties");
+		cli_properties_key = makekey(x_("CONLIN_properties"));
 
 		/* initialize the text/graphics equivalence system */
 		cli_ownchanges = FALSE;
@@ -203,16 +203,16 @@ void cli_linconinit(CONSTRAINT *con)
 
 void cli_linconterm(void) {}
 
-void cli_linconsetmode(INTBIG count, char *par[])
+void cli_linconsetmode(INTBIG count, CHAR *par[])
 {
 	REGISTER INTBIG l;
-	REGISTER char *pp;
+	REGISTER CHAR *pp;
 	REGISTER NODEPROTO *np;
 	REGISTER GEOM *geom;
 
 	if (count == 0)
 	{
-		ttyputusage("constraint tell linear OPTION");
+		ttyputusage(x_("constraint tell linear OPTION"));
 		return;
 	}
 
@@ -222,9 +222,9 @@ void cli_linconsetmode(INTBIG count, char *par[])
 		return;
 	}
 
-	l = strlen(pp = par[0]);
+	l = estrlen(pp = par[0]);
 
-	if (namesamen(pp, "debug-toggle", l) == 0 && l >= 1)
+	if (namesamen(pp, x_("debug-toggle"), l) == 0 && l >= 1)
 	{
 		cli_conlindebug = !cli_conlindebug;
 		if (cli_conlindebug) ttyputverbose(M_("Linear constraint debugging on")); else
@@ -232,15 +232,15 @@ void cli_linconsetmode(INTBIG count, char *par[])
 		return;
 	}
 
-	if (namesamen(pp, "text-equivalence", l) == 0 && l >= 1)
+	if (namesamen(pp, x_("text-equivalence"), l) == 0 && l >= 1)
 	{
 		if (count < 2)
 		{
-			ttyputusage("constraint tell linear text-equivalence OPTION");
+			ttyputusage(x_("constraint tell linear text-equivalence OPTION"));
 			return;
 		}
-		l = strlen(pp = par[1]);
-		if (namesamen(pp, "name-nodes", l) == 0 && l >= 1)
+		l = estrlen(pp = par[1]);
+		if (namesamen(pp, x_("name-nodes"), l) == 0 && l >= 1)
 		{
 			np = getcurfacet();
 			if (np == NONODEPROTO)
@@ -251,7 +251,7 @@ void cli_linconsetmode(INTBIG count, char *par[])
 			cli_nameallnodes(np);
 			return;
 		}
-		if (namesamen(pp, "go", l) == 0 && l >= 1)
+		if (namesamen(pp, x_("go"), l) == 0 && l >= 1)
 		{
 			np = getcurfacet();
 			if (np == NONODEPROTO) ttyputverbose(M_("Enabling text/graphics association")); else
@@ -266,9 +266,9 @@ void cli_linconsetmode(INTBIG count, char *par[])
 			cli_maketextfacet(np);
 			return;
 		}
-		if (namesamen(pp, "highlight-equivalent", l) == 0 && l >= 1)
+		if (namesamen(pp, x_("highlight-equivalent"), l) == 0 && l >= 1)
 		{
-			geom = (GEOM *)asktool(us_tool, "get-object");
+			geom = (GEOM *)asktool(us_tool, x_("get-object"));
 			if (geom == NOGEOM)
 			{
 				ttyputerr(M_("Find a single object first"));
@@ -277,30 +277,30 @@ void cli_linconsetmode(INTBIG count, char *par[])
 			cli_highlightequivalent(geom);
 			return;
 		}
-		ttyputbadusage("constraint tell linear text-equivalence");
+		ttyputbadusage(x_("constraint tell linear text-equivalence"));
 		return;
 	}
 
-	if (namesamen(pp, "implicit-manhattan", l) == 0 && l >= 1)
+	if (namesamen(pp, x_("implicit-manhattan"), l) == 0 && l >= 1)
 	{
-		if (count < 2) l = strlen(pp = "X"); else l = strlen(pp = par[1]);
-		if (namesame(pp, "on") == 0)
+		if (count < 2) l = estrlen(pp = x_("X")); else l = estrlen(pp = par[1]);
+		if (namesame(pp, x_("on")) == 0)
 		{
 			cli_manhattan = TRUE;
 			ttyputverbose(M_("Manhattan arcs will be kept that way"));
 			return;
 		}
-		if (namesamen(pp, "off", l) == 0 && l >= 2)
+		if (namesamen(pp, x_("off"), l) == 0 && l >= 2)
 		{
 			cli_manhattan = FALSE;
 			ttyputverbose(M_("No assumptions will be made about Manhattan arcs"));
 			return;
 		}
-		ttyputusage("constraint tell linear implicit-manhattan (on|off)");
+		ttyputusage(x_("constraint tell linear implicit-manhattan (on|off)"));
 		return;
 	}
 
-	if (namesamen(pp, "solve", l) == 0 && l >= 1)
+	if (namesamen(pp, x_("solve"), l) == 0 && l >= 1)
 	{
 		if (count < 2)
 		{
@@ -330,23 +330,23 @@ void cli_linconsetmode(INTBIG count, char *par[])
 		cli_didsolve = TRUE;
 		return;
 	}
-	ttyputbadusage("constraint tell linear");
+	ttyputbadusage(x_("constraint tell linear"));
 }
 
 /*
  * the valid "command"s are:
  *    "describearc"  return a string that describes constraints on arc in "arg1".
  */
-INTBIG cli_linconrequest(char *command, INTBIG arg1)
+INTBIG cli_linconrequest(CHAR *command, INTBIG arg1)
 {
 	REGISTER INTBIG i, len, l;
 	REGISTER VARIABLE *var;
 	REGISTER LINCON *conptr;
 	REGISTER void *infstr;
 
-	l = strlen(command);
+	l = estrlen(command);
 
-	if (namesamen(command, "describearc", l) == 0)
+	if (namesamen(command, x_("describearc"), l) == 0)
 	{
 		infstr = initinfstr();
 		var = getvalkey(arg1, VARCINST, VINTEGER|VISARRAY, cli_properties_key);
@@ -356,8 +356,8 @@ INTBIG cli_linconrequest(char *command, INTBIG arg1)
 			for(i=0; i<len; i++)
 			{
 				conptr = &((LINCON *)var->addr)[i];
-				if (i != 0) addstringtoinfstr(infstr, ", ");
-				addtoinfstr(infstr, (char)(conptr->variable<=1 ? 'X' : 'Y'));
+				if (i != 0) addstringtoinfstr(infstr, x_(", "));
+				addtoinfstr(infstr, (CHAR)(conptr->variable<=1 ? 'X' : 'Y'));
 				addstringtoinfstr(infstr, cli_linconops[conptr->oper]);
 				addstringtoinfstr(infstr, frtoa(conptr->value));
 			}
@@ -406,7 +406,7 @@ void cli_dosolve(NODEPROTO *facet)
 	if (dlx == 0 && dhx == 0 && dly == 0 && dhy == 0) return;
 
 	/* update the facet size */
-	facet->changeaddr = (char *)db_change((INTBIG)facet, NODEPROTOMOD,
+	facet->changeaddr = (CHAR *)db_change((INTBIG)facet, NODEPROTOMOD,
 		facet->lowx, facet->lowy, facet->highx, facet->highy, 0, 0);
 	facet->lowx = nlx;  facet->highx = nhx;
 	facet->lowy = nly;  facet->highy = nhy;
@@ -485,7 +485,7 @@ void cli_linconmodifynodeinst(NODEINST *ni, INTBIG dlx, INTBIG dly, INTBIG dhx,
 	updategeom(ni->geom, ni->parent);
 
 	/* mark that this nodeinst has changed */
-	ni->changeaddr = (char *)db_change((INTBIG)ni, NODEINSTMOD, oldlx, oldly,
+	ni->changeaddr = (CHAR *)db_change((INTBIG)ni, NODEINSTMOD, oldlx, oldly,
 		oldhx, oldhy, oldang, oldtrans);
 
 	/* look at all of the arcs on this nodeinst */
@@ -553,7 +553,7 @@ void cli_linconmodifynodeinst(NODEINST *ni, INTBIG dlx, INTBIG dly, INTBIG dhx,
 		updategeom(ai->geom, ai->parent);
 
 		/* announce new arcinst change */
-		ai->changeaddr = (char *)db_change((INTBIG)ai, ARCINSTMOD, oldxA,
+		ai->changeaddr = (CHAR *)db_change((INTBIG)ai, ARCINSTMOD, oldxA,
 			oldyA, oldxB, oldyB, ai->width, oldlen);
 		(void)db_change((INTBIG)ai, OBJECTEND, VARCINST, 0, 0, 0, 0, 0);
 		cli_eq_modarc(ai);
@@ -588,7 +588,7 @@ void cli_linconmodifyarcinst(ARCINST *ai, INTBIG oldx0, INTBIG oldy0, INTBIG old
 BOOLEAN cli_linconsetobject(INTBIG addr, INTBIG type, INTBIG changetype, INTBIG changedata)
 {
 	REGISTER ARCINST *ai;
-	REGISTER char *str, *pack, *pt;
+	REGISTER CHAR *str, *pack, *pt;
 	REGISTER BOOLEAN error;
 	REGISTER INTBIG variable, value, len, i, oper;
 	REGISTER LINCON *conptr;
@@ -608,7 +608,7 @@ BOOLEAN cli_linconsetobject(INTBIG addr, INTBIG type, INTBIG changetype, INTBIG
 			for(i=0; i<len; i++)
 			{
 				conptr = &((LINCON *)var->addr)[i];
-				ttyputmsg(M_("Constraint %ld: %s %s %s"), i+1, (conptr->variable<=1 ? "x" : "y"),
+				ttyputmsg(M_("Constraint %ld: %s %s %s"), i+1, (conptr->variable<=1 ? x_("x") : x_("y")),
 					cli_linconops[conptr->oper], frtoa(conptr->value));
 			}
 		}
@@ -633,7 +633,7 @@ BOOLEAN cli_linconsetobject(INTBIG addr, INTBIG type, INTBIG changetype, INTBIG
 	}
 
 	/* adding a new constraint: parse it */
-	str = (char *)changedata;
+	str = (CHAR *)changedata;
 
 	/* eliminate blanks in the string */
 	for(pack = pt = str; *pt != 0; pt++) if (*pt != ' ') *pack++ = *pt;
@@ -644,11 +644,11 @@ BOOLEAN cli_linconsetobject(INTBIG addr, INTBIG type, INTBIG changetype, INTBIG
 	pt = str;
 
 	/* get the variable */
-	if (namesamen(pt, "x", 1) == 0)
+	if (namesamen(pt, x_("x"), 1) == 0)
 	{
 		if (ai->end[0].xpos < ai->end[1].xpos) variable = 1; else
 			variable = 0;
-	} else if (namesamen(pt, "y", 1) == 0)
+	} else if (namesamen(pt, x_("y"), 1) == 0)
 	{
 		if (ai->end[0].ypos < ai->end[1].ypos) variable = 3; else
 			variable = 2;
@@ -661,12 +661,12 @@ BOOLEAN cli_linconsetobject(INTBIG addr, INTBIG type, INTBIG changetype, INTBIG
 
 	/* get the operator */
 	for(i=0; i<3; i++)
-		if (namesamen(pt, cli_linconops[i], strlen(cli_linconops[i])) == 0)
+		if (namesamen(pt, cli_linconops[i], estrlen(cli_linconops[i])) == 0)
 			break;
 	if (i < 3)
 	{
 		oper = i;
-		pt += strlen(cli_linconops[i]);
+		pt += estrlen(cli_linconops[i]);
 	} else
 	{
 		ttyputerr(M_("Cannot parse operator (must be '>=', '==', or '<=')"));
@@ -749,7 +749,7 @@ BOOLEAN cli_addarcconstraint(ARCINST *ai, INTBIG variable, INTBIG oper, INTBIG v
 	(void)setvalkey((INTBIG)ai, VARCINST, cli_properties_key, (INTBIG)conlist,
 		VINTEGER|VISARRAY|((LINCONSIZE*(len+1))<<VLENGTHSH));
 	cli_eq_modarc(ai);
-	efree((char *)conlist);
+	efree((CHAR *)conlist);
 	return(FALSE);
 }
 
@@ -805,7 +805,7 @@ void cli_deletearcconstraint(ARCINST *ai, INTBIG variable, INTBIG oper, INTBIG v
 	}
 	(void)setvalkey((INTBIG)ai, VARCINST, cli_properties_key, (INTBIG)conlist,
 		VINTEGER|VISARRAY|((LINCONSIZE*(len-1))<<VLENGTHSH));
-	efree((char *)conlist);
+	efree((CHAR *)conlist);
 	cli_eq_modarc(ai);
 }
 
@@ -903,9 +903,9 @@ void cli_solvefacet(NODEPROTO *np, BOOLEAN minimum, BOOLEAN noanchors)
 
 	if (cli_conlindebug)
 	{
-		cli_printconstraints(firstx, M_("Horizontal constraints:"), "X");
+		cli_printconstraints(firstx, M_("Horizontal constraints:"), x_("X"));
 		if (!xnotsolved) ttyputmsg(M_("HORIZONTAL CONSTRAINTS ARE ALL MET"));
-		cli_printconstraints(firsty, M_("Vertical constraints:"), "Y");
+		cli_printconstraints(firsty, M_("Vertical constraints:"), x_("Y"));
 		if (!ynotsolved) ttyputmsg(M_("VERTICAL CONSTRAINTS ARE ALL MET"));
 	}
 
@@ -1460,7 +1460,7 @@ void cli_applyconstraints(NODEPROTO *np, CONNODE *first, BOOLEAN axis)
 			ni->lowy += adjust;   ni->highy += adjust;
 		}
 		updategeom(ni->geom, ni->parent);
-		ni->changeaddr = (char *)db_change((INTBIG)ni, NODEINSTMOD, oldlx,
+		ni->changeaddr = (CHAR *)db_change((INTBIG)ni, NODEINSTMOD, oldlx,
 			oldly, oldhx, oldhy, ni->rotation, ni->transpose);
 		(void)db_change((INTBIG)ni, OBJECTEND, VNODEINST, 0, 0, 0, 0, 0);
 		cli_eq_modnode(ni);
@@ -1489,7 +1489,7 @@ void cli_applyconstraints(NODEPROTO *np, CONNODE *first, BOOLEAN axis)
 		updategeom(ai->geom, ai->parent);
 		ai->length = computedistance(ai->end[0].xpos,ai->end[0].ypos,
 			ai->end[1].xpos,ai->end[1].ypos);
-		ai->changeaddr = (char *)db_change((INTBIG)ai, ARCINSTMOD, oldxA,
+		ai->changeaddr = (CHAR *)db_change((INTBIG)ai, ARCINSTMOD, oldxA,
 			oldyA, oldxB, oldyB, ai->width, oldlen);
 		(void)db_change((INTBIG)ai, OBJECTEND, VARCINST, 0, 0, 0, 0, 0);
 		cli_eq_modarc(ai);
@@ -1513,12 +1513,12 @@ void cli_deleteconstraints(CONNODE *first)
 	}
 }
 
-void cli_printconstraints(CONNODE *first, char *message, char *axis)
+void cli_printconstraints(CONNODE *first, CHAR *message, CHAR *axis)
 {
 	REGISTER CONNODE *cn;
 	REGISTER CONARC *ca;
 
-	ttyputmsg("%s", message);
+	ttyputmsg(x_("%s"), message);
 	for(cn = first; cn != NOCONNODE; cn = cn->nextconnode)
 	{
 		ttyputmsg(M_("  Node %s at %ld anchored=%d has these constraints:"),
@@ -1536,7 +1536,7 @@ void cli_printconstraints(CONNODE *first, char *message, char *axis)
 
 typedef struct Iabbrev
 {
-	char   *name;
+	CHAR   *name;
 	INTBIG  aindex;
 	struct Iabbrev *nextabbrev;
 } ABBREV;
@@ -1544,11 +1544,11 @@ typedef struct Iabbrev
 void cli_nameallnodes(NODEPROTO *np)
 {
 	REGISTER NODEINST *ni;
-	REGISTER char *pt;
+	REGISTER CHAR *pt;
 	REGISTER BOOLEAN upper;
 	REGISTER VARIABLE *var;
 	REGISTER ABBREV *firstabbrev, *a, *nexta;
-	char line[20];
+	CHAR line[20];
 	REGISTER void *infstr;
 
 	firstabbrev = NOABBREV;
@@ -1561,7 +1561,7 @@ void cli_nameallnodes(NODEPROTO *np)
 		pt = makeabbrev(ni->proto->cell->cellname, upper);
 
 		/* if the name is null, assign a name */
-		if (strlen(pt) == 0)
+		if (estrlen(pt) == 0)
 		{
 			if (ni->proto->primindex == 0) pt = M_("FACET"); else pt = M_("node");
 		}
@@ -1582,7 +1582,7 @@ void cli_nameallnodes(NODEPROTO *np)
 		/* assign a name to the node */
 		infstr = initinfstr();
 		addstringtoinfstr(infstr, a->name);
-		(void)sprintf(line, "%ld", a->aindex++);
+		(void)esnprintf(line, 20, x_("%ld"), a->aindex++);
 		addstringtoinfstr(infstr, line);
 		var = setvalkey((INTBIG)ni, VNODEINST, el_node_name_key, (INTBIG)returninfstr(infstr), VSTRING|VDISPLAY);
 		if (var != NOVARIABLE)
@@ -1594,6 +1594,6 @@ void cli_nameallnodes(NODEPROTO *np)
 	{
 		nexta = a->nextabbrev;
 		efree(a->name);
-		efree((char *)a);
+		efree((CHAR *)a);
 	}
 }
