@@ -36,13 +36,13 @@ static WINDOWPART *cli_curwindow;
 /* prototypes for local routines */
 static void cli_addequivcon(ARCINST*);
 static INTBIG cli_findtextconn(ARCINST*);
-static char *cli_makearcline(ARCINST*);
-static char *cli_makeportline(PORTPROTO*);
+static CHAR *cli_makearcline(ARCINST*);
+static CHAR *cli_makeportline(PORTPROTO*);
 static BOOLEAN cli_uniquelayer(ARCINST*);
 static INTBIG cli_addcomponentinfo(void*, NODEINST*);
 static void cli_addcomponentdata(void*, COMPONENT*);
-static char *cli_componentname(NODEINST*);
-static void cli_addcomponentline(char*, WINDOWPART*);
+static CHAR *cli_componentname(NODEINST*);
+static void cli_addcomponentline(CHAR*, WINDOWPART*);
 static void cli_addattr(void*, ATTR*);
 static void cli_addnodeprotoname(void*, NODEPROTO*);
 
@@ -57,7 +57,7 @@ void cli_highlightequivalent(GEOM *geom)
 	REGISTER ARCINST *ai;
 	REGISTER NODEINST *ni;
 	REGISTER INTBIG i, cindex, total;
-	REGISTER char *str, *compname;
+	REGISTER CHAR *str, *compname;
 	REGISTER COMPONENTDEC *dec;
 	REGISTER COMPONENT *compo;
 
@@ -69,17 +69,17 @@ void cli_highlightequivalent(GEOM *geom)
 	{
 		ai = geom->entryaddr.ai;
 		cindex = cli_findtextconn(ai);
-		if (cindex != -1) (void)asktool(us_tool, "edit-highlightline", (INTBIG)cli_curwindow, cindex);
+		if (cindex != -1) (void)asktool(us_tool, x_("edit-highlightline"), (INTBIG)cli_curwindow, cindex);
 		return;
 	}
 
 	/* highlight the equivalent node */
 	ni = geom->entryaddr.ni;
 	compname = cli_componentname(ni);
-	total = asktool(us_tool, "edit-totallines", (INTBIG)cli_curwindow);
+	total = asktool(us_tool, x_("edit-totallines"), (INTBIG)cli_curwindow);
 	for(i=0; i<total; i++)
 	{
-		str = (char *)asktool(us_tool, "edit-getline", (INTBIG)cli_curwindow, i);
+		str = (CHAR *)asktool(us_tool, x_("edit-getline"), (INTBIG)cli_curwindow, i);
 		if (str == NOSTRING) break;
 		if (cli_linetype(str) != LINEDECL) continue;
 		dec = cli_parsecomp(str, FALSE);
@@ -93,7 +93,7 @@ void cli_highlightequivalent(GEOM *geom)
 		/* search for the changed node */
 		for(compo = dec->firstcomponent; compo != NOCOMPONENT; compo = compo->nextcomponent)
 			if (namesame(compname, compo->name) == 0) break;
-		if (compo != NOCOMPONENT) (void)asktool(us_tool, "edit-highlightline", (INTBIG)cli_curwindow, i);
+		if (compo != NOCOMPONENT) (void)asktool(us_tool, x_("edit-highlightline"), (INTBIG)cli_curwindow, i);
 		cli_deletecomponentdec(dec);
 		return;
 	}
@@ -107,8 +107,8 @@ void cli_highlightequivalent(GEOM *geom)
  */
 void cli_maketextfacet(NODEPROTO *np)
 {
-	char *name;
-	REGISTER char *pt;
+	CHAR *name;
+	REGISTER CHAR *pt;
 	REGISTER NODEINST *ni, *oni;
 	REGISTER PORTPROTO *pp;
 	REGISTER ARCINST *ai;
@@ -120,7 +120,7 @@ void cli_maketextfacet(NODEPROTO *np)
 	cli_curfacet = np;
 	if (!cli_texton)
 	{
-		(void)asktool(us_tool, "edit-describe", (INTBIG)&name);
+		(void)asktool(us_tool, x_("edit-describe"), (INTBIG)&name);
 		infstr = initinfstr();
 		addstringtoinfstr(infstr, name);
 		addstringtoinfstr(infstr, M_(" Editor equivalence for facet "));
@@ -133,21 +133,21 @@ void cli_maketextfacet(NODEPROTO *np)
 	if (np == NONODEPROTO) return;
 
 	/* convert all components into declarations */
-	(void)asktool(us_tool, "edit-suspendgraphics", (INTBIG)cli_curwindow);
+	(void)asktool(us_tool, x_("edit-suspendgraphics"), (INTBIG)cli_curwindow);
 
 	/* erase the window */
-	len = asktool(us_tool, "edit-totallines", (INTBIG)cli_curwindow);
+	len = asktool(us_tool, x_("edit-totallines"), (INTBIG)cli_curwindow);
 	for(i=0; i<len; i++)
-		(void)asktool(us_tool, "edit-deleteline", (INTBIG)cli_curwindow, i);
+		(void)asktool(us_tool, x_("edit-deleteline"), (INTBIG)cli_curwindow, i);
 
 	/* load the facet */
 	trunclen = chars / 4 * 3;
 	cli_textlines = 0;
 	infstr = initinfstr();
-	addstringtoinfstr(infstr, "BEGINFACET ");
+	addstringtoinfstr(infstr, x_("BEGINFACET "));
 	addstringtoinfstr(infstr, np->cell->cellname);
-	addstringtoinfstr(infstr, ";");
-	(void)asktool(us_tool, "edit-addline", (INTBIG)cli_curwindow, 0, (INTBIG)returninfstr(infstr));
+	addstringtoinfstr(infstr, x_(";"));
+	(void)asktool(us_tool, x_("edit-addline"), (INTBIG)cli_curwindow, 0, (INTBIG)returninfstr(infstr));
 	for(ni = np->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
 		ni->temp1 = 0;
 	for(ni = np->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
@@ -174,16 +174,16 @@ void cli_maketextfacet(NODEPROTO *np)
 			if (first == 0)
 			{
 				infstr = initinfstr();
-				addstringtoinfstr(infstr, "declare ");
+				addstringtoinfstr(infstr, x_("declare "));
 				lensofar = 8;
 				first++;
 			} else
 			{
-				addstringtoinfstr(infstr, ", ");
+				addstringtoinfstr(infstr, x_(", "));
 				lensofar += 2;
 			}
 			pt = cli_componentname(oni);
-			lensofar += strlen(pt);
+			lensofar += estrlen(pt);
 			addstringtoinfstr(infstr, pt);
 			oni->temp1 = 1;
 
@@ -206,8 +206,8 @@ void cli_maketextfacet(NODEPROTO *np)
 	/* now convert the constaints */
 	for(ai = np->firstarcinst; ai != NOARCINST; ai = ai->nextarcinst)
 		cli_addequivcon(ai);
-	cli_replaceendfacet("ENDFACET;", cli_curwindow);
-	(void)asktool(us_tool, "edit-resumegraphics", (INTBIG)cli_curwindow);
+	cli_replaceendfacet(x_("ENDFACET;"), cli_curwindow);
+	(void)asktool(us_tool, x_("edit-resumegraphics"), (INTBIG)cli_curwindow);
 }
 
 /***************************** GRAPHIC CHANGES *****************************/
@@ -219,7 +219,7 @@ void cli_eq_newnode(NODEINST *ni)
 {
 	REGISTER COMPONENTDEC *dec;
 	REGISTER COMPONENT *compo;
-	REGISTER char *str;
+	REGISTER CHAR *str;
 	REGISTER INTBIG i, total;
 	REGISTER void *infstr;
 
@@ -230,10 +230,10 @@ void cli_eq_newnode(NODEINST *ni)
 	if (ni->parent != cli_curfacet) return;
 
 	/* look for a declaration of this type of node */
-	total = asktool(us_tool, "edit-totallines", (INTBIG)cli_curwindow);
+	total = asktool(us_tool, x_("edit-totallines"), (INTBIG)cli_curwindow);
 	for(i=0; i<total; i++)
 	{
-		str = (char *)asktool(us_tool, "edit-getline", (INTBIG)cli_curwindow, i);
+		str = (CHAR *)asktool(us_tool, x_("edit-getline"), (INTBIG)cli_curwindow, i);
 		if (str == NOSTRING) break;
 		if (cli_linetype(str) != LINEDECL) continue;
 		dec = cli_parsecomp(str, FALSE);
@@ -246,12 +246,12 @@ void cli_eq_newnode(NODEINST *ni)
 
 		/* found the declaration, rebuild with existing components */
 		infstr = initinfstr();
-		addstringtoinfstr(infstr, "declare ");
+		addstringtoinfstr(infstr, x_("declare "));
 		for(compo = dec->firstcomponent; compo != NOCOMPONENT; compo = compo->nextcomponent)
 		{
 			addstringtoinfstr(infstr, compo->name);
 			cli_addcomponentdata(infstr, compo);
-			addstringtoinfstr(infstr, ", ");
+			addstringtoinfstr(infstr, x_(", "));
 		}
 
 		/* add in the new component */
@@ -262,14 +262,14 @@ void cli_eq_newnode(NODEINST *ni)
 		/* finish the declaration and replace the line */
 		addstringtoinfstr(infstr, dec->protoname);
 		addtoinfstr(infstr, ';');
-		(void)asktool(us_tool, "edit-replaceline", (INTBIG)cli_curwindow, i, (INTBIG)returninfstr(infstr));
+		(void)asktool(us_tool, x_("edit-replaceline"), (INTBIG)cli_curwindow, i, (INTBIG)returninfstr(infstr));
 		cli_deletecomponentdec(dec);
 		return;
 	}
 
 	/* build a simple declaration for this node */
 	infstr = initinfstr();
-	addstringtoinfstr(infstr, "declare ");
+	addstringtoinfstr(infstr, x_("declare "));
 	addstringtoinfstr(infstr, cli_componentname(ni));
 	(void)cli_addcomponentinfo(infstr, ni);
 	addtoinfstr(infstr, ' ');
@@ -283,7 +283,7 @@ void cli_eq_newnode(NODEINST *ni)
  */
 void cli_eq_killnode(NODEINST *ni)
 {
-	REGISTER char *str, *compname;
+	REGISTER CHAR *str, *compname;
 	REGISTER INTBIG first, i, total;
 	REGISTER COMPONENTDEC *dec;
 	REGISTER COMPONENT *compo, *ocomp;
@@ -297,10 +297,10 @@ void cli_eq_killnode(NODEINST *ni)
 
 	/* look for a declaration of this type of node */
 	compname = cli_componentname(ni);
-	total = asktool(us_tool, "edit-totallines", (INTBIG)cli_curwindow);
+	total = asktool(us_tool, x_("edit-totallines"), (INTBIG)cli_curwindow);
 	for(i=0; i<total; i++)
 	{
-		str = (char *)asktool(us_tool, "edit-getline", (INTBIG)cli_curwindow, i);
+		str = (CHAR *)asktool(us_tool, x_("edit-getline"), (INTBIG)cli_curwindow, i);
 		if (str == NOSTRING) break;
 		if (cli_linetype(str) != LINEDECL) continue;
 		dec = cli_parsecomp(str, FALSE);
@@ -324,7 +324,7 @@ void cli_eq_killnode(NODEINST *ni)
 		if (dec->count == 1 && namesame(dec->firstcomponent->name, compname) == 0)
 		{
 			/* line had only one keyword: delete the line */
-			(void)asktool(us_tool, "edit-deleteline", (INTBIG)cli_curwindow, i);
+			(void)asktool(us_tool, x_("edit-deleteline"), (INTBIG)cli_curwindow, i);
 			cli_textlines--;
 			cli_deletecomponentdec(dec);
 			return;
@@ -332,12 +332,12 @@ void cli_eq_killnode(NODEINST *ni)
 
 		/* rebuild line without the deleted component */
 		infstr = initinfstr();
-		addstringtoinfstr(infstr, "declare ");
+		addstringtoinfstr(infstr, x_("declare "));
 		first = 0;
 		for(ocomp = dec->firstcomponent; ocomp != NOCOMPONENT; ocomp = ocomp->nextcomponent)
 		{
 			if (compo == ocomp) continue;
-			if (first != 0) addstringtoinfstr(infstr, ", ");
+			if (first != 0) addstringtoinfstr(infstr, x_(", "));
 			first++;
 			addstringtoinfstr(infstr, ocomp->name);
 			cli_addcomponentdata(infstr, ocomp);
@@ -345,7 +345,7 @@ void cli_eq_killnode(NODEINST *ni)
 		addtoinfstr(infstr, ' ');
 		addstringtoinfstr(infstr, dec->protoname);
 		addtoinfstr(infstr, ';');
-		(void)asktool(us_tool, "edit-replaceline", (INTBIG)cli_curwindow, i, (INTBIG)returninfstr(infstr));
+		(void)asktool(us_tool, x_("edit-replaceline"), (INTBIG)cli_curwindow, i, (INTBIG)returninfstr(infstr));
 		cli_deletecomponentdec(dec);
 		return;
 	}
@@ -410,7 +410,7 @@ void cli_eq_killarc(ARCINST *ai)
  */
 void cli_eq_modarc(ARCINST *ai)
 {
-	REGISTER char *str;
+	REGISTER CHAR *str;
 	REGISTER INTBIG cindex;
 
 	/* see if arc is in graphics facet that has equivalent text */
@@ -431,7 +431,7 @@ void cli_eq_modarc(ARCINST *ai)
 	str = cli_makearcline(ai);
 
 	/* change the line */
-	(void)asktool(us_tool, "edit-replaceline", (INTBIG)cli_curwindow, cindex, (INTBIG)str);
+	(void)asktool(us_tool, x_("edit-replaceline"), (INTBIG)cli_curwindow, cindex, (INTBIG)str);
 }
 
 /* handle the creation of port "pp" */
@@ -447,7 +447,7 @@ void cli_eq_newport(PORTPROTO *pp)
 void cli_eq_killport(PORTPROTO *pp)
 {
 	REGISTER INTBIG i, total;
-	REGISTER char *str;
+	REGISTER CHAR *str;
 	REGISTER EXPORT *e;
 
 	/* see if port is in graphics facet that has equivalent text */
@@ -455,11 +455,11 @@ void cli_eq_killport(PORTPROTO *pp)
 	if (pp->parent != cli_curfacet) return;
 
 	/* find the export line with this port */
-	total = asktool(us_tool, "edit-totallines", (INTBIG)cli_curwindow);
+	total = asktool(us_tool, x_("edit-totallines"), (INTBIG)cli_curwindow);
 	for(i=0; i<total; i++)
 	{
 		/* get a line of text */
-		str = (char *)asktool(us_tool, "edit-getline", (INTBIG)cli_curwindow, i);
+		str = (CHAR *)asktool(us_tool, x_("edit-getline"), (INTBIG)cli_curwindow, i);
 		if (str == NOSTRING) break;
 		if (cli_linetype(str) != LINEEXPORT) continue;
 
@@ -473,7 +473,7 @@ void cli_eq_killport(PORTPROTO *pp)
 		}
 
 		/* export line found: delete it */
-		(void)asktool(us_tool, "edit-deleteline", (INTBIG)cli_curwindow, i);
+		(void)asktool(us_tool, x_("edit-deleteline"), (INTBIG)cli_curwindow, i);
 		cli_textlines--;
 		cli_deleteexport(e);
 		break;
@@ -483,7 +483,7 @@ void cli_eq_killport(PORTPROTO *pp)
 /* handle the modification of port "pp" */
 void cli_eq_modport(PORTPROTO *pp)
 {
-	REGISTER char *str;
+	REGISTER CHAR *str;
 	REGISTER EXPORT *e;
 	REGISTER INTBIG i, total;
 
@@ -492,11 +492,11 @@ void cli_eq_modport(PORTPROTO *pp)
 	if (pp->parent != cli_curfacet) return;
 
 	/* find the export line with this port */
-	total = asktool(us_tool, "edit-totallines", (INTBIG)cli_curwindow);
+	total = asktool(us_tool, x_("edit-totallines"), (INTBIG)cli_curwindow);
 	for(i=0; i<total; i++)
 	{
 		/* get a line of text */
-		str = (char *)asktool(us_tool, "edit-getline", (INTBIG)cli_curwindow, i);
+		str = (CHAR *)asktool(us_tool, x_("edit-getline"), (INTBIG)cli_curwindow, i);
 		if (str == NOSTRING) break;
 		if (cli_linetype(str) != LINEEXPORT) continue;
 
@@ -510,7 +510,7 @@ void cli_eq_modport(PORTPROTO *pp)
 		}
 
 		/* export line found: rewrite it */
-		(void)asktool(us_tool, "edit-replaceline", (INTBIG)cli_curwindow, i,
+		(void)asktool(us_tool, x_("edit-replaceline"), (INTBIG)cli_curwindow, i,
 			(INTBIG)cli_makeportline(pp));
 		cli_deleteexport(e);
 		break;
@@ -521,7 +521,7 @@ void cli_eq_modport(PORTPROTO *pp)
 void cli_eq_newvar(INTBIG addr, INTBIG type, INTBIG key)
 {
 	REGISTER NODEINST *ni;
-	char line[50];
+	CHAR line[50];
 	REGISTER VARIABLE *var;
 
 	if (cli_ownchanges) return;
@@ -536,12 +536,12 @@ void cli_eq_newvar(INTBIG addr, INTBIG type, INTBIG key)
 		if (key == el_node_name_key)
 		{
 			/* construct the original name */
-			(void)sprintf(line, M_("NODE%ld"), (INTBIG)ni);
+			(void)esnprintf(line, 50, M_("NODE%ld"), (INTBIG)ni);
 
 			/* get the new node name */
 			var = getvalkey((INTBIG)ni, VNODEINST, VSTRING, el_node_name_key);
 			if (var == NOVARIABLE) return;
-			cli_replacename(line, (char *)var->addr);
+			cli_replacename(line, (CHAR *)var->addr);
 			return;
 		}
 
@@ -566,7 +566,7 @@ void cli_eq_newvar(INTBIG addr, INTBIG type, INTBIG key)
 /* handle the deletion of variable type "type", name "key", and value "addr" */
 void cli_eq_killvar(INTBIG addr, INTBIG type, INTBIG key)
 {
-	char line[50];
+	CHAR line[50];
 	REGISTER VARIABLE *var;
 	REGISTER NODEINST *ni;
 
@@ -584,8 +584,8 @@ void cli_eq_killvar(INTBIG addr, INTBIG type, INTBIG key)
 			if (var == NOVARIABLE) return;
 
 			/* construct the new node name */
-			(void)sprintf(line, M_("NODE%ld"), (INTBIG)ni);
-			cli_replacename((char *)var->addr, line);
+			(void)esnprintf(line, 50, M_("NODE%ld"), (INTBIG)ni);
+			cli_replacename((CHAR *)var->addr, line);
 			return;
 		}
 
@@ -621,18 +621,18 @@ void cli_addequivcon(ARCINST *ai)
 {
 	REGISTER INTBIG i, total;
 
-	total = asktool(us_tool, "edit-totallines", (INTBIG)cli_curwindow);
+	total = asktool(us_tool, x_("edit-totallines"), (INTBIG)cli_curwindow);
 
 	/* search for the last line with a valid connection declaration */
 	for(i = total-1; i >= 0; i--)
-		if (cli_linetype((char *)asktool(us_tool, "edit-getline",
+		if (cli_linetype((CHAR *)asktool(us_tool, x_("edit-getline"),
 			(INTBIG)cli_curwindow, i)) == LINECONN) break;
 	if (i < 0)
 	{
 		/* no "connect" lines, take last line anywhere */
 		i = total-1;
 	}
-	(void)asktool(us_tool, "edit-addline", (INTBIG)cli_curwindow, i+1, (INTBIG)cli_makearcline(ai));
+	(void)asktool(us_tool, x_("edit-addline"), (INTBIG)cli_curwindow, i+1, (INTBIG)cli_makearcline(ai));
 	cli_textlines++;
 }
 
@@ -647,7 +647,7 @@ void cli_deleteequivcon(ARCINST *ai)
 	cindex = cli_findtextconn(ai);
 	if (cindex != -1)
 	{
-		(void)asktool(us_tool, "edit-deleteline", (INTBIG)cli_curwindow, cindex);
+		(void)asktool(us_tool, x_("edit-deleteline"), (INTBIG)cli_curwindow, cindex);
 		cli_textlines--;
 	}
 }
@@ -657,7 +657,7 @@ void cli_deleteequivcon(ARCINST *ai)
  */
 void cli_changeequivcomp(NODEINST *ni)
 {
-	REGISTER char *str, *compname;
+	REGISTER CHAR *str, *compname;
 	REGISTER INTBIG i, total;
 	REGISTER COMPONENTDEC *dec;
 	REGISTER COMPONENT *compo, *ocomp;
@@ -665,10 +665,10 @@ void cli_changeequivcomp(NODEINST *ni)
 
 	/* look for a declaration of this type of node */
 	compname = cli_componentname(ni);
-	total = asktool(us_tool, "edit-totallines", (INTBIG)cli_curwindow);
+	total = asktool(us_tool, x_("edit-totallines"), (INTBIG)cli_curwindow);
 	for(i=0; i<total; i++)
 	{
-		str = (char *)asktool(us_tool, "edit-getline", (INTBIG)cli_curwindow, i);
+		str = (CHAR *)asktool(us_tool, x_("edit-getline"), (INTBIG)cli_curwindow, i);
 		if (str == NOSTRING) break;
 		if (cli_linetype(str) != LINEDECL) continue;
 		dec = cli_parsecomp(str, FALSE);
@@ -689,10 +689,10 @@ void cli_changeequivcomp(NODEINST *ni)
 		}
 
 		infstr = initinfstr();
-		addstringtoinfstr(infstr, "declare ");
+		addstringtoinfstr(infstr, x_("declare "));
 		for(ocomp = dec->firstcomponent; ocomp != NOCOMPONENT; ocomp = ocomp->nextcomponent)
 		{
-			if (ocomp != dec->firstcomponent) addstringtoinfstr(infstr, ", ");
+			if (ocomp != dec->firstcomponent) addstringtoinfstr(infstr, x_(", "));
 			if (compo == ocomp)
 			{
 				addstringtoinfstr(infstr, cli_componentname(ni));
@@ -706,7 +706,7 @@ void cli_changeequivcomp(NODEINST *ni)
 		addtoinfstr(infstr, ' ');
 		addstringtoinfstr(infstr, dec->protoname);
 		addtoinfstr(infstr, ';');
-		(void)asktool(us_tool, "edit-replaceline", (INTBIG)cli_curwindow, i, (INTBIG)returninfstr(infstr));
+		(void)asktool(us_tool, x_("edit-replaceline"), (INTBIG)cli_curwindow, i, (INTBIG)returninfstr(infstr));
 		cli_deletecomponentdec(dec);
 		return;
 	}
@@ -717,11 +717,11 @@ void cli_changeequivcomp(NODEINST *ni)
  * routine to replace the name of graphics node "oni" (which used to be called
  * "oldname") with the name "newname"
  */
-void cli_replacename(char *oldname, char *newname)
+void cli_replacename(CHAR *oldname, CHAR *newname)
 {
-	REGISTER char *str;
+	REGISTER CHAR *str;
 	REGISTER INTBIG i, rewrite, total;
-	char line[50];
+	CHAR line[50];
 	REGISTER EXPORT *e;
 	REGISTER COMPONENTDEC *dcl;
 	REGISTER COMPONENT *compo, *ocomp;
@@ -731,10 +731,10 @@ void cli_replacename(char *oldname, char *newname)
 	REGISTER void *infstr;
 
 	/* look through all statements for the old name */
-	total = asktool(us_tool, "edit-totallines", (INTBIG)cli_curwindow);
+	total = asktool(us_tool, x_("edit-totallines"), (INTBIG)cli_curwindow);
 	for(i=0; i<total; i++)
 	{
-		str = (char *)asktool(us_tool, "edit-getline", (INTBIG)cli_curwindow, i);
+		str = (CHAR *)asktool(us_tool, x_("edit-getline"), (INTBIG)cli_curwindow, i);
 		if (str == NOSTRING) break;
 
 		/* search declaration statement */
@@ -752,10 +752,10 @@ void cli_replacename(char *oldname, char *newname)
 
 			/* rewrite the component declaration line */
 			infstr = initinfstr();
-			addstringtoinfstr(infstr, "declare ");
+			addstringtoinfstr(infstr, x_("declare "));
 			for(ocomp = dcl->firstcomponent; ocomp != NOCOMPONENT; ocomp = ocomp->nextcomponent)
 			{
-				if (ocomp != dcl->firstcomponent) addstringtoinfstr(infstr, ", ");
+				if (ocomp != dcl->firstcomponent) addstringtoinfstr(infstr, x_(", "));
 				if (ocomp == compo) addstringtoinfstr(infstr, newname); else
 					addstringtoinfstr(infstr, ocomp->name);
 				cli_addcomponentdata(infstr, ocomp);
@@ -763,7 +763,7 @@ void cli_replacename(char *oldname, char *newname)
 			addtoinfstr(infstr, ' ');
 			addstringtoinfstr(infstr, dcl->protoname);
 			addtoinfstr(infstr, ';');
-			(void)asktool(us_tool, "edit-replaceline", (INTBIG)cli_curwindow, i, (INTBIG)returninfstr(infstr));
+			(void)asktool(us_tool, x_("edit-replaceline"), (INTBIG)cli_curwindow, i, (INTBIG)returninfstr(infstr));
 			cli_deletecomponentdec(dcl);
 			continue;
 		}
@@ -781,12 +781,12 @@ void cli_replacename(char *oldname, char *newname)
 
 			/* rewrite the export line */
 			infstr = initinfstr();
-			addstringtoinfstr(infstr, "export ");
+			addstringtoinfstr(infstr, x_("export "));
 			if ((e->flag&(EXPCHAR|EXPATTR)) != 0)
 			{
 				if ((e->flag&EXPCHAR) != 0)
 				{
-					addstringtoinfstr(infstr, "[type=");
+					addstringtoinfstr(infstr, x_("[type="));
 					switch (e->bits&STATEBITS)
 					{
 						case INPORT :
@@ -817,6 +817,8 @@ void cli_replacename(char *oldname, char *newname)
 							addstringtoinfstr(infstr, M_("refout")); break;
 						case REFINPORT:
 							addstringtoinfstr(infstr, M_("refin")); break;
+						case REFBASEPORT:
+							addstringtoinfstr(infstr, M_("refbase")); break;
 					}
 				}
 				if ((e->flag&EXPATTR) != 0)
@@ -829,10 +831,10 @@ void cli_replacename(char *oldname, char *newname)
 						cli_addattr(infstr, a);
 					}
 				}
-				addstringtoinfstr(infstr, "] ");
+				addstringtoinfstr(infstr, x_("] "));
 			}
 			addstringtoinfstr(infstr, e->portname);
-			addstringtoinfstr(infstr, " is ");
+			addstringtoinfstr(infstr, x_(" is "));
 			addstringtoinfstr(infstr, newname);
 			if (e->subport != 0)
 			{
@@ -840,7 +842,7 @@ void cli_replacename(char *oldname, char *newname)
 				addstringtoinfstr(infstr, e->subport);
 			}
 			addtoinfstr(infstr, ';');
-			(void)asktool(us_tool, "edit-replaceline", (INTBIG)cli_curwindow, i, (INTBIG)returninfstr(infstr));
+			(void)asktool(us_tool, x_("edit-replaceline"), (INTBIG)cli_curwindow, i, (INTBIG)returninfstr(infstr));
 			cli_deleteexport(e);
 			continue;
 		}
@@ -871,19 +873,19 @@ void cli_replacename(char *oldname, char *newname)
 
 			/* rewrite the connetion line */
 			infstr = initinfstr();
-			addstringtoinfstr(infstr, "connect ");
+			addstringtoinfstr(infstr, x_("connect "));
 			if ((dec->flag&(LAYERVALID|WIDTHVALID|ATTRVALID)) != 0)
 			{
 				if ((dec->flag&LAYERVALID) != 0)
 				{
-					addstringtoinfstr(infstr, "[layer=");
+					addstringtoinfstr(infstr, x_("[layer="));
 					addstringtoinfstr(infstr, dec->layer);
 				}
 				if ((dec->flag&WIDTHVALID) != 0)
 				{
 					if ((dec->flag&LAYERVALID) != 0) addtoinfstr(infstr, ','); else
 						addtoinfstr(infstr, '[');
-					(void)sprintf(line, "width=%s", latoa(dec->width, 0));
+					(void)esnprintf(line, 50, x_("width=%s"), latoa(dec->width, 0));
 					addstringtoinfstr(infstr, line);
 				}
 				if ((dec->flag&ATTRVALID) != 0)
@@ -896,7 +898,7 @@ void cli_replacename(char *oldname, char *newname)
 						cli_addattr(infstr, a);
 					}
 				}
-				addstringtoinfstr(infstr, "] ");
+				addstringtoinfstr(infstr, x_("] "));
 			}
 
 			addstringtoinfstr(infstr, dec->end1);
@@ -912,25 +914,25 @@ void cli_replacename(char *oldname, char *newname)
 				addstringtoinfstr(infstr, cons->direction);
 				addtoinfstr(infstr, ' ');
 				addstringtoinfstr(infstr, frtoa(cons->amount));
-				if (cons->flag == 1) addstringtoinfstr(infstr, " or more");
-				if (cons->flag == -1) addstringtoinfstr(infstr, " or less");
+				if (cons->flag == 1) addstringtoinfstr(infstr, x_(" or more"));
+				if (cons->flag == -1) addstringtoinfstr(infstr, x_(" or less"));
 			}
 
 			/* decide whether to print the arc offset */
 			if ((dec->flag&OFFSETVALID) != 0)
 			{
-				(void)sprintf(line, " [%s,%s]", latoa(dec->xoff, 0), latoa(dec->yoff, 0));
+				(void)esnprintf(line, 50, x_(" [%s,%s]"), latoa(dec->xoff, 0), latoa(dec->yoff, 0));
 				addstringtoinfstr(infstr, line);
 			}
-			addstringtoinfstr(infstr, " to ");
+			addstringtoinfstr(infstr, x_(" to "));
 			addstringtoinfstr(infstr, dec->end2);
 			if ((dec->flag&PORT2VALID) != 0)
 			{
 				addtoinfstr(infstr, ':');
 				addstringtoinfstr(infstr, dec->port2);
 			}
-			addstringtoinfstr(infstr, ";");
-			(void)asktool(us_tool, "edit-replaceline", (INTBIG)cli_curwindow, i, (INTBIG)returninfstr(infstr));
+			addstringtoinfstr(infstr, x_(";"));
+			(void)asktool(us_tool, x_("edit-replaceline"), (INTBIG)cli_curwindow, i, (INTBIG)returninfstr(infstr));
 			cli_deleteconnection(dec);
 		}
 	}
@@ -945,14 +947,14 @@ void cli_replacename(char *oldname, char *newname)
 INTBIG cli_findtextconn(ARCINST *ai)
 {
 	REGISTER INTBIG i, total;
-	REGISTER char *str;
+	REGISTER CHAR *str;
 	REGISTER CONNECTION *dec;
 
-	total = asktool(us_tool, "edit-totallines", (INTBIG)cli_curwindow);
+	total = asktool(us_tool, x_("edit-totallines"), (INTBIG)cli_curwindow);
 	for(i=0; i<total; i++)
 	{
 		/* get a valid connection line */
-		str = (char *)asktool(us_tool, "edit-getline", (INTBIG)cli_curwindow, i);
+		str = (CHAR *)asktool(us_tool, x_("edit-getline"), (INTBIG)cli_curwindow, i);
 		if (str == NOSTRING) break;
 		if (cli_linetype(str) != LINECONN) continue;
 		dec = cli_parseconn(str, TRUE);
@@ -997,9 +999,9 @@ INTBIG cli_findtextconn(ARCINST *ai)
 /*
  * routine to convert an arc into a line of text with all constraints
  */
-char *cli_makearcline(ARCINST *ai)
+CHAR *cli_makearcline(ARCINST *ai)
 {
-	char line[50];
+	CHAR line[50];
 	REGISTER VARIABLE *var;
 	REGISTER INTBIG i, len;
 	REGISTER BOOLEAN doit, added;
@@ -1008,18 +1010,18 @@ char *cli_makearcline(ARCINST *ai)
 	REGISTER void *infstr;
 
 	infstr = initinfstr();
-	addstringtoinfstr(infstr, "connect ");
+	addstringtoinfstr(infstr, x_("connect "));
 	added = FALSE;
 	if (!cli_uniquelayer(ai))
 	{
-		addstringtoinfstr(infstr, "[layer=");
+		addstringtoinfstr(infstr, x_("[layer="));
 		addstringtoinfstr(infstr, describearcproto(ai->proto));
 		added = TRUE;
 	}
 	if (ai->width != ai->proto->nominalwidth)
 	{
 		if (!added) addtoinfstr(infstr, '['); else addtoinfstr(infstr, ',');
-		addstringtoinfstr(infstr, "width=");
+		addstringtoinfstr(infstr, x_("width="));
 		addstringtoinfstr(infstr, latoa(ai->width, 0));
 		added = TRUE;
 	}
@@ -1028,12 +1030,12 @@ char *cli_makearcline(ARCINST *ai)
 		var = &ai->firstvar[i];
 		if ((var->type&VISARRAY) != 0) continue;
 		if (!added) addtoinfstr(infstr, '['); else addtoinfstr(infstr, ',');
-		addstringtoinfstr(infstr, (char *)var->key);
+		addstringtoinfstr(infstr, (CHAR *)var->key);
 		addtoinfstr(infstr, '=');
 		addstringtoinfstr(infstr, describevariable(var, -1, 1));
 		added = TRUE;
 	}
-	if (added) addstringtoinfstr(infstr, "] ");
+	if (added) addstringtoinfstr(infstr, x_("] "));
 	addstringtoinfstr(infstr, cli_componentname(ai->end[0].nodeinst));
 	if (!cli_uniqueport(ai->end[0].nodeinst, ai->end[0].portarcinst->proto))
 	{
@@ -1058,27 +1060,27 @@ char *cli_makearcline(ARCINST *ai)
 				case CLLEFT:
 					xcons++;
 					conx = -conptr->value * lambda / WHOLE;
-					(void)sprintf(line, " left %s", latoa(-conx, 0));
+					(void)esnprintf(line, 50, _(" left %s"), latoa(-conx, 0));
 					break;
 				case CLRIGHT:
 					xcons++;
 					conx = conptr->value * lambda / WHOLE;
-					(void)sprintf(line, " right %s", latoa(conx, 0));
+					(void)esnprintf(line, 50, x_(" right %s"), latoa(conx, 0));
 					break;
 				case CLDOWN:
 					ycons++;
 					cony = -conptr->value * lambda / WHOLE;
-					(void)sprintf(line, " down %s", latoa(-cony, 0));
+					(void)esnprintf(line, 50, x_(" down %s"), latoa(-cony, 0));
 					break;
 				case CLUP:
 					ycons++;
 					cony = conptr->value * lambda / WHOLE;
-					(void)sprintf(line, " up %s", latoa(cony, 0));
+					(void)esnprintf(line, 50, x_(" up %s"), latoa(cony, 0));
 					break;
 			}
 			addstringtoinfstr(infstr, line);
-			if (conptr->oper == 0) addstringtoinfstr(infstr, " or more");
-			if (conptr->oper == 2) addstringtoinfstr(infstr, " or less");
+			if (conptr->oper == 0) addstringtoinfstr(infstr, x_(" or more"));
+			if (conptr->oper == 2) addstringtoinfstr(infstr, x_(" or less"));
 		}
 	}
 
@@ -1090,25 +1092,25 @@ char *cli_makearcline(ARCINST *ai)
 		doit = TRUE;
 	if (doit)
 	{
-		(void)sprintf(line, " [%s,%s]", latoa(ai->end[1].xpos - ai->end[0].xpos, 0),
+		(void)esnprintf(line, 50, x_(" [%s,%s]"), latoa(ai->end[1].xpos - ai->end[0].xpos, 0),
 			latoa(ai->end[1].ypos - ai->end[0].ypos, 0));
 		addstringtoinfstr(infstr, line);
 	}
-	addstringtoinfstr(infstr, " to ");
+	addstringtoinfstr(infstr, x_(" to "));
 	addstringtoinfstr(infstr, cli_componentname(ai->end[1].nodeinst));
 	if (!cli_uniqueport(ai->end[1].nodeinst, ai->end[1].portarcinst->proto))
 	{
 		addtoinfstr(infstr, ':');
 		addstringtoinfstr(infstr, ai->end[1].portarcinst->proto->protoname);
 	}
-	addstringtoinfstr(infstr, ";");
+	addstringtoinfstr(infstr, x_(";"));
 	return(returninfstr(infstr));
 }
 
 /*
  * routine to handle the addition of the text associated with new port "pp"
  */
-char *cli_makeportline(PORTPROTO *pp)
+CHAR *cli_makeportline(PORTPROTO *pp)
 {
 	REGISTER BOOLEAN added;
 	REGISTER INTBIG i;
@@ -1116,26 +1118,28 @@ char *cli_makeportline(PORTPROTO *pp)
 	REGISTER void *infstr;
 
 	infstr = initinfstr();
-	addstringtoinfstr(infstr, "export ");
+	addstringtoinfstr(infstr, x_("export "));
 	if ((pp->userbits&STATEBITS) != 0)
 	{
-		addstringtoinfstr(infstr, "[type=");
+		addstringtoinfstr(infstr, x_("[type="));
 		switch (pp->userbits&STATEBITS)
 		{
-			case INPORT:     addstringtoinfstr(infstr, "input");         break;
-			case OUTPORT:    addstringtoinfstr(infstr, "output");        break;
-			case BIDIRPORT:  addstringtoinfstr(infstr, "bidirectional"); break;
-			case PWRPORT:    addstringtoinfstr(infstr, "power");         break;
-			case GNDPORT:    addstringtoinfstr(infstr, "ground");        break;
-			case CLKPORT:    addstringtoinfstr(infstr, "clock");         break;
-			case C1PORT:     addstringtoinfstr(infstr, "clock1");        break;
-			case C2PORT:     addstringtoinfstr(infstr, "clock2");        break;
-			case C3PORT:     addstringtoinfstr(infstr, "clock3");        break;
-			case C4PORT:     addstringtoinfstr(infstr, "clock4");        break;
-			case C5PORT:     addstringtoinfstr(infstr, "clock5");        break;
-			case C6PORT:     addstringtoinfstr(infstr, "clock6");        break;
-			case REFOUTPORT: addstringtoinfstr(infstr, "refout");        break;
-			case REFINPORT:  addstringtoinfstr(infstr, "refin");         break;
+			case INPORT:      addstringtoinfstr(infstr, x_("input"));         break;
+			case OUTPORT:     addstringtoinfstr(infstr, x_("output"));        break;
+			case BIDIRPORT:   addstringtoinfstr(infstr, x_("bidirectional")); break;
+			case PWRPORT:     addstringtoinfstr(infstr, x_("power"));         break;
+			case GNDPORT:     addstringtoinfstr(infstr, x_("ground"));        break;
+			case CLKPORT:     addstringtoinfstr(infstr, x_("clock"));         break;
+			case C1PORT:      addstringtoinfstr(infstr, x_("clock1"));        break;
+			case C2PORT:      addstringtoinfstr(infstr, x_("clock2"));        break;
+			case C3PORT:      addstringtoinfstr(infstr, x_("clock3"));        break;
+			case C4PORT:      addstringtoinfstr(infstr, x_("clock4"));        break;
+			case C5PORT:      addstringtoinfstr(infstr, x_("clock5"));        break;
+			case C6PORT:      addstringtoinfstr(infstr, x_("clock6"));        break;
+			case REFOUTPORT:  addstringtoinfstr(infstr, x_("refout"));        break;
+			case REFINPORT:   addstringtoinfstr(infstr, x_("refin"));         break;
+			case REFBASEPORT: addstringtoinfstr(infstr, x_("refbase"));       break;
+				
 		}
 		added = TRUE;
 	} else added = FALSE;
@@ -1145,15 +1149,15 @@ char *cli_makeportline(PORTPROTO *pp)
 		var = &pp->firstvar[i];
 		if ((var->type&VISARRAY) != 0) continue;
 		if (!added) addtoinfstr(infstr, '['); else addtoinfstr(infstr, ',');
-		addstringtoinfstr(infstr, (char *)var->key);
+		addstringtoinfstr(infstr, (CHAR *)var->key);
 		addtoinfstr(infstr, '=');
 		addstringtoinfstr(infstr, describevariable(var, -1, 1));
 		added = TRUE;
 	}
-	if (added) addstringtoinfstr(infstr, "] ");
+	if (added) addstringtoinfstr(infstr, x_("] "));
 
 	addstringtoinfstr(infstr, pp->protoname);
-	addstringtoinfstr(infstr, " is ");
+	addstringtoinfstr(infstr, x_(" is "));
 	addstringtoinfstr(infstr, cli_componentname(pp->subnodeinst));
 	if (!cli_uniqueport(pp->subnodeinst, pp->subportproto))
 	{
@@ -1237,8 +1241,8 @@ BOOLEAN cli_uniquelayer(ARCINST *ai)
  */
 INTBIG cli_addcomponentinfo(void *infstr, NODEINST *ni)
 {
-	char line[50];
-	REGISTER char *st;
+	CHAR line[50];
+	REGISTER CHAR *st;
 	REGISTER INTBIG added, i;
 	REGISTER VARIABLE *var;
 	INTBIG plx, phx, ply, phy;
@@ -1249,19 +1253,19 @@ INTBIG cli_addcomponentinfo(void *infstr, NODEINST *ni)
 		ni->highy-ni->lowy != ni->proto->highy-ni->proto->lowy)
 	{
 		nodesizeoffset(ni, &plx, &ply, &phx, &phy);
-		(void)sprintf(line, "[size=(%s,%s)", latoa(ni->highx-ni->lowx-plx-phx, 0),
+		(void)esnprintf(line, 50, x_("[size=(%s,%s)"), latoa(ni->highx-ni->lowx-plx-phx, 0),
 			latoa(ni->highy-ni->lowy-ply-phy, 0));
 		addstringtoinfstr(infstr, line);
-		added += strlen(line);
+		added += estrlen(line);
 	}
 
 	/* add in component rotation */
 	if (ni->rotation != 0 || ni->transpose != 0)
 	{
 		if (added != 0) addtoinfstr(infstr, ','); else addtoinfstr(infstr, '[');
-		(void)sprintf(line, "rotation=%s", frtoa(ni->rotation*WHOLE/10));
+		(void)esnprintf(line, 50, x_("rotation=%s"), frtoa(ni->rotation*WHOLE/10));
 		addstringtoinfstr(infstr, line);
-		added += strlen(line) + 1;
+		added += estrlen(line) + 1;
 		if (ni->transpose != 0)
 		{
 			addtoinfstr(infstr, 't');
@@ -1273,10 +1277,10 @@ INTBIG cli_addcomponentinfo(void *infstr, NODEINST *ni)
 	if (ni->firstportarcinst == NOPORTARCINST)
 	{
 		if (added != 0) addtoinfstr(infstr, ','); else addtoinfstr(infstr, '[');
-		(void)sprintf(line, "location=(%s,%s)", latoa((ni->highx+ni->lowx) / 2, 0),
+		(void)esnprintf(line, 50, x_("location=(%s,%s)"), latoa((ni->highx+ni->lowx) / 2, 0),
 			latoa((ni->highy+ni->lowy) / 2, 0));
 		addstringtoinfstr(infstr, line);
-		added += strlen(line) + 1;
+		added += estrlen(line) + 1;
 	}
 
 	/* add additional variables */
@@ -1288,11 +1292,11 @@ INTBIG cli_addcomponentinfo(void *infstr, NODEINST *ni)
 
 		if (added != 0) addtoinfstr(infstr, ','); else addtoinfstr(infstr, '[');
 		added++;
-		addstringtoinfstr(infstr, (char *)var->key);
+		addstringtoinfstr(infstr, (CHAR *)var->key);
 		addtoinfstr(infstr, '=');
-		added += strlen((char *)var->key) + 1;
+		added += estrlen((CHAR *)var->key) + 1;
 		st = describevariable(var, -1, 1);
-		added += strlen(st);
+		added += estrlen(st);
 		addstringtoinfstr(infstr, st);
 	}
 
@@ -1306,7 +1310,7 @@ INTBIG cli_addcomponentinfo(void *infstr, NODEINST *ni)
  */
 void cli_addcomponentdata(void *infstr, COMPONENT *compo)
 {
-	char line[50];
+	CHAR line[50];
 	REGISTER ATTR *a;
 
 	if ((compo->flag&(COMPSIZE|COMPROT|COMPLOC|COMPATTR)) != 0)
@@ -1314,20 +1318,20 @@ void cli_addcomponentdata(void *infstr, COMPONENT *compo)
 		addtoinfstr(infstr, '[');
 		if ((compo->flag&COMPSIZE) != 0)
 		{
-			(void)sprintf(line, "size=(%s,%s)", latoa(compo->sizex, 0), latoa(compo->sizey, 0));
+			(void)esnprintf(line, 50, x_("size=(%s,%s)"), latoa(compo->sizex, 0), latoa(compo->sizey, 0));
 			addstringtoinfstr(infstr, line);
 		}
 		if ((compo->flag&COMPROT) != 0)
 		{
 			if ((compo->flag&COMPSIZE) != 0) addtoinfstr(infstr, ',');
-			(void)sprintf(line, "rotation=%s", frtoa(compo->rot*WHOLE/10));
+			(void)esnprintf(line, 50, x_("rotation=%s"), frtoa(compo->rot*WHOLE/10));
 			addstringtoinfstr(infstr, line);
 			if (compo->trans != 0) addtoinfstr(infstr, 't');
 		}
 		if ((compo->flag&COMPLOC) != 0)
 		{
 			if ((compo->flag&(COMPSIZE|COMPROT)) != 0) addtoinfstr(infstr, ',');
-			(void)sprintf(line, "location=(%s,%s)", latoa(compo->locx, 0), latoa(compo->locy, 0));
+			(void)esnprintf(line, 50, x_("location=(%s,%s)"), latoa(compo->locx, 0), latoa(compo->locy, 0));
 			addstringtoinfstr(infstr, line);
 		}
 		if ((compo->flag&COMPATTR) != 0)
@@ -1346,48 +1350,48 @@ void cli_addcomponentdata(void *infstr, COMPONENT *compo)
 /*
  * routine to return the component name for node "ni"
  */
-char *cli_componentname(NODEINST *ni)
+CHAR *cli_componentname(NODEINST *ni)
 {
-	static char line[50];
+	static CHAR line[50];
 	REGISTER VARIABLE *var;
 
 	var = getvalkey((INTBIG)ni, VNODEINST, VSTRING, el_node_name_key);
 	if (var == NOVARIABLE)
 	{
-		(void)sprintf(line, "NODE%ld", (INTBIG)ni);
+		(void)esnprintf(line, 50, x_("NODE%ld"), (INTBIG)ni);
 		return(line);
 	}
-	return((char *)var->addr);
+	return((CHAR *)var->addr);
 }
 
-void cli_addcomponentline(char *str, WINDOWPART *win)
+void cli_addcomponentline(CHAR *str, WINDOWPART *win)
 {
 	REGISTER INTBIG i, total;
 
-	total = asktool(us_tool, "edit-totallines", (INTBIG)win);
+	total = asktool(us_tool, x_("edit-totallines"), (INTBIG)win);
 
 	/* search for the last line with a valid component declaration */
 	for(i = total-1; i >= 0; i--)
-		if (cli_linetype((char *)asktool(us_tool, "edit-getline", (INTBIG)win, i)) == LINEDECL) break;
+		if (cli_linetype((CHAR *)asktool(us_tool, x_("edit-getline"), (INTBIG)win, i)) == LINEDECL) break;
 	if (i < 0) i = 0;
-	(void)asktool(us_tool, "edit-addline", (INTBIG)win, i+1, (INTBIG)str);
+	(void)asktool(us_tool, x_("edit-addline"), (INTBIG)win, i+1, (INTBIG)str);
 	cli_textlines++;
 }
 
 void cli_addattr(void *infstr, ATTR *a)
 {
-	char line[50];
+	CHAR line[50];
 
 	addstringtoinfstr(infstr, a->name);
 	addtoinfstr(infstr, '=');
 	if ((a->type&VTYPE) == VINTEGER)
 	{
-		(void)sprintf(line, "%ld", a->value);
+		(void)esnprintf(line, 50, x_("%ld"), a->value);
 		addstringtoinfstr(infstr, line);
 	} else
 	{
 		addtoinfstr(infstr, '"');
-		addstringtoinfstr(infstr, (char *)a->value);
+		addstringtoinfstr(infstr, (CHAR *)a->value);
 		addtoinfstr(infstr, '"');
 	}
 }
