@@ -55,25 +55,25 @@
 #include "conlin.h"
 
 /* prototypes for local routines */
-static BOOLEAN cli_doparseexport(char*, BOOLEAN, EXPORT*);
-static BOOLEAN cli_doparseconn(char*, BOOLEAN, CONNECTION*);
-static BOOLEAN cli_doparsecomp(char**, char*, BOOLEAN, COMPONENTDEC*);
-static BOOLEAN cli_parsetwovalue(INTBIG*, INTBIG*, char*, char**, BOOLEAN);
-static ATTR *cli_getattr(char*, char**, char*, BOOLEAN);
+static BOOLEAN cli_doparseexport(CHAR*, BOOLEAN, EXPORT*);
+static BOOLEAN cli_doparseconn(CHAR*, BOOLEAN, CONNECTION*);
+static BOOLEAN cli_doparsecomp(CHAR**, CHAR*, BOOLEAN, COMPONENTDEC*);
+static BOOLEAN cli_parsetwovalue(INTBIG*, INTBIG*, CHAR*, CHAR**, BOOLEAN);
+static ATTR *cli_getattr(CHAR*, CHAR**, CHAR*, BOOLEAN);
 static void cli_freeattr(ATTR*);
 
 /*
  * routine to determine the type of text in "line"
  */
-INTBIG cli_linetype(char *line)
+INTBIG cli_linetype(CHAR *line)
 {
 	while (*line == ' ' || *line == '\t') line++;
 	if (*line == 0 || *line == ';') return(LINECOMM);
-	if (namesamen(line, "declare", 7) == 0) return(LINEDECL);
-	if (namesamen(line, "connect", 4) == 0) return(LINECONN);
-	if (namesamen(line, "export", 6) == 0) return(LINEEXPORT);
-	if (namesamen(line, "beginfacet", 9) == 0) return(LINEBEGIN);
-	if (namesamen(line, "endfacet", 7) == 0) return(LINEEND);
+	if (namesamen(line, x_("declare"), 7) == 0) return(LINEDECL);
+	if (namesamen(line, x_("connect"), 4) == 0) return(LINECONN);
+	if (namesamen(line, x_("export"), 6) == 0) return(LINEEXPORT);
+	if (namesamen(line, x_("beginfacet"), 9) == 0) return(LINEBEGIN);
+	if (namesamen(line, x_("endfacet"), 7) == 0) return(LINEEND);
 	return(LINEUNKN);
 }
 
@@ -82,24 +82,24 @@ INTBIG cli_linetype(char *line)
  * facet name must be deallocated when done.  If "quiet" is true, do not
  * print error messages.  Returns -1 if the line cannot be parsed
  */
-char *cli_parsebeginfacet(char *str, BOOLEAN quiet)
+CHAR *cli_parsebeginfacet(CHAR *str, BOOLEAN quiet)
 {
-	char *pt;
-	REGISTER char *st;
+	CHAR *pt;
+	REGISTER CHAR *st;
 
 	pt = str;
 
 	/* get the "beginfacet" keyword */
-	st = getkeyword(&pt, " \t");
+	st = getkeyword(&pt, x_(" \t"));
 	if (st == NOSTRING) return(NOSTRING);
-	if (namesame(st, "beginfacet") != 0)
+	if (namesame(st, x_("beginfacet")) != 0)
 	{
 		if (!quiet) ttyputerr(M_("Missing 'beginfacet' keyword in '%s'"), str);
 		return(NOSTRING);
 	}
 
 	/* get the facet name */
-	st = getkeyword(&pt, " \t;");
+	st = getkeyword(&pt, x_(" \t;"));
 	if (st == NOSTRING) return(NOSTRING);
 
 	/* make sure it ends with a ";" */
@@ -122,7 +122,7 @@ char *cli_parsebeginfacet(char *str, BOOLEAN quiet)
  * it.  This must be deallocated when done.  If "quiet" is true, do not
  * print error messages.  Returns NOEXPORT if the line cannot be parsed.
  */
-EXPORT *cli_parseexport(char *str, BOOLEAN quiet)
+EXPORT *cli_parseexport(CHAR *str, BOOLEAN quiet)
 {
 	REGISTER EXPORT *e;
 
@@ -151,19 +151,19 @@ EXPORT *cli_parseexport(char *str, BOOLEAN quiet)
  * points to the beginning of the line and "quiet" is the verbose error flag.
  * Fills the "e" structure and returns false if successful.
  */
-BOOLEAN cli_doparseexport(char *str, BOOLEAN quiet, EXPORT *e)
+BOOLEAN cli_doparseexport(CHAR *str, BOOLEAN quiet, EXPORT *e)
 {
-	char *pt, *opt;
-	REGISTER char *st;
+	CHAR *pt, *opt;
+	REGISTER CHAR *st;
 	REGISTER ATTR *a;
 	REGISTER INTBIG i;
 
 	pt = str;
 
 	/* get the "export" keyword */
-	st = getkeyword(&pt, " \t");
+	st = getkeyword(&pt, x_(" \t"));
 	if (st == NOSTRING) return(TRUE);
-	if (namesame(st, "export") != 0)
+	if (namesame(st, x_("export")) != 0)
 	{
 		if (!quiet) ttyputerr(M_("Missing 'export' keyword in '%s'"), str);
 		return(TRUE);
@@ -176,7 +176,7 @@ BOOLEAN cli_doparseexport(char *str, BOOLEAN quiet, EXPORT *e)
 		for(;;)
 		{
 			/* get name of option */
-			opt = getkeyword(&pt, " \t=");
+			opt = getkeyword(&pt, x_(" \t="));
 			if (opt == NOSTRING) return(TRUE);
 			if (*opt == 0)
 			{
@@ -189,29 +189,30 @@ BOOLEAN cli_doparseexport(char *str, BOOLEAN quiet, EXPORT *e)
 				return(TRUE);
 			}
 
-			if (namesame(opt, "type") == 0)
+			if (namesame(opt, x_("type")) == 0)
 			{
-				st = getkeyword(&pt, " \t],");
+				st = getkeyword(&pt, x_(" \t],"));
 				if (st == NOSTRING) return(TRUE);
 				if (*st == 0)
 				{
 					if (!quiet) ttyputerr(M_("Missing type in '%s'"), str);
 					return(TRUE);
 				}
-				if (namesame(st, "input")        == 0) e->bits |= INPORT; else
-				if (namesame(st, "output")       == 0) e->bits |= OUTPORT; else
-				if (namesame(st, "bidirectional")== 0) e->bits |= BIDIRPORT; else
-				if (namesame(st, "power")        == 0) e->bits |= PWRPORT; else
-				if (namesame(st, "ground")       == 0) e->bits |= GNDPORT; else
-				if (namesame(st, "clock")        == 0) e->bits |= CLKPORT; else
-				if (namesame(st, "clock1")       == 0) e->bits |= C1PORT; else
-				if (namesame(st, "clock2")       == 0) e->bits |= C2PORT; else
-				if (namesame(st, "clock3")       == 0) e->bits |= C3PORT; else
-				if (namesame(st, "clock4")       == 0) e->bits |= C4PORT; else
-				if (namesame(st, "clock5")       == 0) e->bits |= C5PORT; else
-				if (namesame(st, "clock6")       == 0) e->bits |= C6PORT; else
-				if (namesame(st, "refout")       == 0) e->bits |= REFOUTPORT; else
-				if (namesame(st, "refin")        == 0) e->bits |= REFINPORT; else
+				if (namesame(st, x_("input"))        == 0) e->bits |= INPORT; else
+				if (namesame(st, x_("output"))       == 0) e->bits |= OUTPORT; else
+				if (namesame(st, x_("bidirectional"))== 0) e->bits |= BIDIRPORT; else
+				if (namesame(st, x_("power"))        == 0) e->bits |= PWRPORT; else
+				if (namesame(st, x_("ground"))       == 0) e->bits |= GNDPORT; else
+				if (namesame(st, x_("clock"))        == 0) e->bits |= CLKPORT; else
+				if (namesame(st, x_("clock1"))       == 0) e->bits |= C1PORT; else
+				if (namesame(st, x_("clock2"))       == 0) e->bits |= C2PORT; else
+				if (namesame(st, x_("clock3"))       == 0) e->bits |= C3PORT; else
+				if (namesame(st, x_("clock4"))       == 0) e->bits |= C4PORT; else
+				if (namesame(st, x_("clock5"))       == 0) e->bits |= C5PORT; else
+				if (namesame(st, x_("clock6"))       == 0) e->bits |= C6PORT; else
+				if (namesame(st, x_("refout"))       == 0) e->bits |= REFOUTPORT; else
+				if (namesame(st, x_("refin"))        == 0) e->bits |= REFINPORT; else
+				if (namesame(st, x_("refbase"))      == 0) e->bits |= REFBASEPORT; else
 				{
 					if (!quiet) ttyputerr(M_("Invalid port type in '%s'"), str);
 					return(TRUE);
@@ -239,21 +240,21 @@ BOOLEAN cli_doparseexport(char *str, BOOLEAN quiet, EXPORT *e)
 	}
 
 	/* get the exported port name */
-	st = getkeyword(&pt, " \t;");
+	st = getkeyword(&pt, x_(" \t;"));
 	if (st == NOSTRING) return(TRUE);
 	(void)allocstring(&e->portname, st, el_tempcluster);
 
 	/* get the "is" keyword */
-	st = getkeyword(&pt, " \t");
+	st = getkeyword(&pt, x_(" \t"));
 	if (st == NOSTRING) return(TRUE);
-	if (namesame(st, "is") != 0)
+	if (namesame(st, x_("is")) != 0)
 	{
 		if (!quiet) ttyputerr(M_("Missing 'is' keyword in '%s'"), str);
 		return(TRUE);
 	}
 
 	/* get the component name */
-	st = getkeyword(&pt, " \t;:");
+	st = getkeyword(&pt, x_(" \t;:"));
 	if (st == NOSTRING) return(TRUE);
 	(void)allocstring(&e->component, st, el_tempcluster);
 
@@ -262,7 +263,7 @@ BOOLEAN cli_doparseexport(char *str, BOOLEAN quiet, EXPORT *e)
 	{
 		/* get the subport name */
 		(void)tonextchar(&pt);
-		st = getkeyword(&pt, " \t;");
+		st = getkeyword(&pt, x_(" \t;"));
 		if (st == NOSTRING) return(TRUE);
 		(void)allocstring(&e->subport, st, el_tempcluster);
 	}
@@ -286,7 +287,7 @@ BOOLEAN cli_doparseexport(char *str, BOOLEAN quiet, EXPORT *e)
  * CONNECTION structure that describes it.  If "quiet" is true, do not
  * print error messages.  Returns NOCONNECTION on error.
  */
-CONNECTION *cli_parseconn(char *str, BOOLEAN quiet)
+CONNECTION *cli_parseconn(CHAR *str, BOOLEAN quiet)
 {
 	REGISTER CONNECTION *dcl;
 
@@ -318,19 +319,19 @@ CONNECTION *cli_parseconn(char *str, BOOLEAN quiet)
  * points to the beginning of the line and "quiet" is the verbose error flag.
  * Fills the "dcl" structure and returns false if successful.
  */
-BOOLEAN cli_doparseconn(char *str, BOOLEAN quiet, CONNECTION *dcl)
+BOOLEAN cli_doparseconn(CHAR *str, BOOLEAN quiet, CONNECTION *dcl)
 {
-	REGISTER char *st, *opt;
-	char *pt;
+	REGISTER CHAR *st, *opt;
+	CHAR *pt;
 	REGISTER CONS *cons, *lastcons;
 	REGISTER INTBIG i;
 	REGISTER ATTR *a;
 
 	pt = str;
 
-	st = getkeyword(&pt, " \t");
+	st = getkeyword(&pt, x_(" \t"));
 	if (st == NOSTRING) return(TRUE);
-	if (namesame(st, "connect") != 0)
+	if (namesame(st, x_("connect")) != 0)
 	{
 		if (!quiet) ttyputerr(M_("Missing 'connect' keyword in '%s'"), str);
 		return(TRUE);
@@ -343,7 +344,7 @@ BOOLEAN cli_doparseconn(char *str, BOOLEAN quiet, CONNECTION *dcl)
 		for(;;)
 		{
 			/* get name of option */
-			opt = getkeyword(&pt, " \t=");
+			opt = getkeyword(&pt, x_(" \t="));
 			if (opt == NOSTRING) return(TRUE);
 			if (*opt == 0)
 			{
@@ -356,9 +357,9 @@ BOOLEAN cli_doparseconn(char *str, BOOLEAN quiet, CONNECTION *dcl)
 				return(TRUE);
 			}
 
-			if (namesame(opt, "layer") == 0)
+			if (namesame(opt, x_("layer")) == 0)
 			{
-				st = getkeyword(&pt, " \t],");
+				st = getkeyword(&pt, x_(" \t],"));
 				if (st == NOSTRING) return(TRUE);
 				if (*st == 0)
 				{
@@ -367,9 +368,9 @@ BOOLEAN cli_doparseconn(char *str, BOOLEAN quiet, CONNECTION *dcl)
 				}
 				(void)allocstring(&dcl->layer, st, el_tempcluster);
 				dcl->flag |= LAYERVALID;
-			} else if (namesame(opt, "width") == 0)
+			} else if (namesame(opt, x_("width")) == 0)
 			{
-				st = getkeyword(&pt, " \t],");
+				st = getkeyword(&pt, x_(" \t],"));
 				if (st == NOSTRING) return(TRUE);
 				if (*st == 0)
 				{
@@ -400,7 +401,7 @@ BOOLEAN cli_doparseconn(char *str, BOOLEAN quiet, CONNECTION *dcl)
 	}
 
 	/* get the name of the first node */
-	st = getkeyword(&pt, " \t;:");
+	st = getkeyword(&pt, x_(" \t;:"));
 	if (st == NOSTRING) return(TRUE);
 	if (*st == 0)
 	{
@@ -413,7 +414,7 @@ BOOLEAN cli_doparseconn(char *str, BOOLEAN quiet, CONNECTION *dcl)
 	{
 		/* parse the port prototype for end 1 */
 		(void)tonextchar(&pt);
-		st = getkeyword(&pt, " \t;");
+		st = getkeyword(&pt, x_(" \t;"));
 		if (st == NOSTRING) return(TRUE);
 		if (*st == 0)
 		{
@@ -428,11 +429,11 @@ BOOLEAN cli_doparseconn(char *str, BOOLEAN quiet, CONNECTION *dcl)
 	lastcons = NOCONS;
 	for(;;)
 	{
-		st = getkeyword(&pt, " \t;[");
+		st = getkeyword(&pt, x_(" \t;["));
 		if (st == NOSTRING) return(TRUE);
 
 		/* termination with the keyword "to" */
-		if (namesame(st, "to") == 0) break;
+		if (namesame(st, x_("to")) == 0) break;
 
 		/* handle the "[X,Y]" construct */
 		if (*st == 0)
@@ -442,7 +443,7 @@ BOOLEAN cli_doparseconn(char *str, BOOLEAN quiet, CONNECTION *dcl)
 				if (!quiet) ttyputerr(M_("Incorrect constraint syntax in '%s'"), str);
 				return(TRUE);
 			}
-			st = getkeyword(&pt, " \t,");
+			st = getkeyword(&pt, x_(" \t,"));
 			if (st == NOSTRING) return(TRUE);
 			dcl->xoff = atola(st, 0);
 			dcl->flag |= OFFSETVALID;
@@ -451,7 +452,7 @@ BOOLEAN cli_doparseconn(char *str, BOOLEAN quiet, CONNECTION *dcl)
 				if (!quiet) ttyputerr(M_("Missing comma in arc extent '%s'"), str);
 				return(TRUE);
 			}
-			st = getkeyword(&pt, " \t]");
+			st = getkeyword(&pt, x_(" \t]"));
 			dcl->yoff = atola(st, 0);
 			if (tonextchar(&pt) != ']')
 			{
@@ -462,8 +463,8 @@ BOOLEAN cli_doparseconn(char *str, BOOLEAN quiet, CONNECTION *dcl)
 		}
 
 		/* handle constraint directions */
-		if (namesame(st, "left") != 0 && namesame(st, "right") != 0 &&
-			namesame(st, "up") != 0 && namesame(st, "down") != 0)
+		if (namesame(st, x_("left")) != 0 && namesame(st, x_("right")) != 0 &&
+			namesame(st, x_("up")) != 0 && namesame(st, x_("down")) != 0)
 		{
 			if (!quiet) ttyputerr(M_("Invalid relationship '%s' in '%s'"), st, str);
 			return(TRUE);
@@ -483,7 +484,7 @@ BOOLEAN cli_doparseconn(char *str, BOOLEAN quiet, CONNECTION *dcl)
 		(void)allocstring(&cons->direction, st, el_tempcluster);
 
 		/* get amount */
-		st = getkeyword(&pt, " \t;[");
+		st = getkeyword(&pt, x_(" \t;["));
 		if (st == NOSTRING) return(TRUE);
 		cons->amount = atofr(st);
 
@@ -491,18 +492,18 @@ BOOLEAN cli_doparseconn(char *str, BOOLEAN quiet, CONNECTION *dcl)
 		cons->flag = EQUAL;
 		if (seenextchar(&pt) == 'o')
 		{
-			st = getkeyword(&pt, " \t;[");
+			st = getkeyword(&pt, x_(" \t;["));
 			if (st == NOSTRING) return(TRUE);
-			if (namesame(st, "or") != 0)
+			if (namesame(st, x_("or")) != 0)
 			{
 				if (!quiet) ttyputerr(M_("Unknown qualifier '%s' in '%s'"), st, str);
 				return(TRUE);
 			}
-			st = getkeyword(&pt, " \t;[");
+			st = getkeyword(&pt, x_(" \t;["));
 			if (st == NOSTRING) return(TRUE);
 			cons->flag = 999;
-			if (namesame(st, "more") == 0) cons->flag = GEQ;
-			if (namesame(st, "less") == 0) cons->flag = LEQ;
+			if (namesame(st, x_("more")) == 0) cons->flag = GEQ;
+			if (namesame(st, x_("less")) == 0) cons->flag = LEQ;
 			if (cons->flag == 999)
 			{
 				if (!quiet) ttyputerr(M_("Unknown qualifier '%s' in '%s'"), st, str);
@@ -512,7 +513,7 @@ BOOLEAN cli_doparseconn(char *str, BOOLEAN quiet, CONNECTION *dcl)
 	}
 
 	/* get the name of the second node */
-	st = getkeyword(&pt, " \t;:[");
+	st = getkeyword(&pt, x_(" \t;:["));
 	if (st == NOSTRING) return(TRUE);
 	if (*st == 0)
 	{
@@ -525,7 +526,7 @@ BOOLEAN cli_doparseconn(char *str, BOOLEAN quiet, CONNECTION *dcl)
 	{
 		/* parse the port prototype for end 2 */
 		(void)tonextchar(&pt);
-		st = getkeyword(&pt, " \t;[");
+		st = getkeyword(&pt, x_(" \t;["));
 		if (st == NOSTRING) return(TRUE);
 		if (*st == 0)
 		{
@@ -551,10 +552,10 @@ BOOLEAN cli_doparseconn(char *str, BOOLEAN quiet, CONNECTION *dcl)
  * COMPONENTDEC structure that describes it.  If "quiet" is true, do not
  * print error messages.  Returns NOCOMPONENTDEC on error.
  */
-COMPONENTDEC *cli_parsecomp(char *str, BOOLEAN quiet)
+COMPONENTDEC *cli_parsecomp(CHAR *str, BOOLEAN quiet)
 {
-	REGISTER char *st;
-	char *pt;
+	REGISTER CHAR *st;
+	CHAR *pt;
 	REGISTER COMPONENTDEC *dcl;
 
 	/* allocate a declaration object */
@@ -571,11 +572,11 @@ COMPONENTDEC *cli_parsecomp(char *str, BOOLEAN quiet)
 	pt = str;
 
 	/* look for "declare" keyword */
-	st = getkeyword(&pt, " \t");
-	if (st == NOSTRING || namesame(st, "declare") != 0)
+	st = getkeyword(&pt, x_(" \t"));
+	if (st == NOSTRING || namesame(st, x_("declare")) != 0)
 	{
 		if (!quiet) ttyputerr(M_("Missing 'declare' keyword in '%s'"), str);
-		efree((char *)dcl);
+		efree((CHAR *)dcl);
 		return(NOCOMPONENTDEC);
 	}
 
@@ -597,9 +598,9 @@ COMPONENTDEC *cli_parsecomp(char *str, BOOLEAN quiet)
  * is the verbose error flag.  Fills the "dcl" structure and returns false
  * if successful
  */
-BOOLEAN cli_doparsecomp(char **pt, char *str, BOOLEAN quiet, COMPONENTDEC *dcl)
+BOOLEAN cli_doparsecomp(CHAR **pt, CHAR *str, BOOLEAN quiet, COMPONENTDEC *dcl)
 {
-	REGISTER char *st, *opt;
+	REGISTER CHAR *st, *opt;
 	REGISTER COMPONENT *compo, *listpos;
 	REGISTER INTBIG i;
 	REGISTER ATTR *a;
@@ -609,7 +610,7 @@ BOOLEAN cli_doparsecomp(char **pt, char *str, BOOLEAN quiet, COMPONENTDEC *dcl)
 	dcl->count = 0;
 	for(;;)
 	{
-		st = getkeyword(pt, " \t,;[");
+		st = getkeyword(pt, x_(" \t,;["));
 		if (st == NOSTRING) return(TRUE);
 		if (*st == 0)
 		{
@@ -644,7 +645,7 @@ BOOLEAN cli_doparsecomp(char **pt, char *str, BOOLEAN quiet, COMPONENTDEC *dcl)
 			for(;;)
 			{
 				/* get name of option */
-				opt = getkeyword(pt, " \t=");
+				opt = getkeyword(pt, x_(" \t="));
 				if (opt == NOSTRING) return(TRUE);
 				if (*opt == 0)
 				{
@@ -657,22 +658,22 @@ BOOLEAN cli_doparsecomp(char **pt, char *str, BOOLEAN quiet, COMPONENTDEC *dcl)
 					return(TRUE);
 				}
 
-				if (namesame(opt, "size") == 0)
+				if (namesame(opt, x_("size")) == 0)
 				{
-					if (cli_parsetwovalue(&compo->sizex, &compo->sizey, "size", pt, quiet))
+					if (cli_parsetwovalue(&compo->sizex, &compo->sizey, x_("size"), pt, quiet))
 						return(TRUE);
 					compo->flag |= COMPSIZE;
-				} else if (namesame(opt, "location") == 0)
+				} else if (namesame(opt, x_("location")) == 0)
 				{
-					if (cli_parsetwovalue(&compo->locx, &compo->locy, "location", pt, quiet))
+					if (cli_parsetwovalue(&compo->locx, &compo->locy, x_("location"), pt, quiet))
 						return(TRUE);
 					compo->flag |= COMPLOC;
-				} else if (namesame(opt, "rotation") == 0)
+				} else if (namesame(opt, x_("rotation")) == 0)
 				{
-					st = getkeyword(pt, " \t,]");
+					st = getkeyword(pt, x_(" \t,]"));
 					if (st == NOSTRING) return(TRUE);
 					compo->rot = atofr(st)*10/WHOLE;
-					i = strlen(st)-1;
+					i = estrlen(st)-1;
 					if (st[i] == 't' || st[i] == 'T') compo->trans = 1; else
 						compo->trans = 0;
 					compo->flag |= COMPROT;
@@ -703,7 +704,7 @@ BOOLEAN cli_doparsecomp(char **pt, char *str, BOOLEAN quiet, COMPONENTDEC *dcl)
 	}
 
 	/* take last string as prototype name */
-	st = getkeyword(pt, " \t;");
+	st = getkeyword(pt, x_(" \t;"));
 	if (st == NOSTRING) return(TRUE);
 	if (*st == 0)
 	{
@@ -729,16 +730,16 @@ BOOLEAN cli_doparsecomp(char **pt, char *str, BOOLEAN quiet, COMPONENTDEC *dcl)
  * the values in "x" and "y".  The name of this option is in "name" and the
  * verbose error message flag is in "quiet".  Returns true on error
  */
-BOOLEAN cli_parsetwovalue(INTBIG *x, INTBIG *y, char *name, char **pt, BOOLEAN quiet)
+BOOLEAN cli_parsetwovalue(INTBIG *x, INTBIG *y, CHAR *name, CHAR **pt, BOOLEAN quiet)
 {
-	REGISTER char *st;
+	REGISTER CHAR *st;
 
 	if (tonextchar(pt) != '(')
 	{
 		if (!quiet) ttyputerr(M_("Missing '(' after %s option"), name);
 		return(TRUE);
 	}
-	st = getkeyword(pt, " \t,)]");
+	st = getkeyword(pt, x_(" \t,)]"));
 	if (st == NOSTRING) return(TRUE);
 	*x = atola(st, 0);
 	if (tonextchar(pt) != ',')
@@ -746,7 +747,7 @@ BOOLEAN cli_parsetwovalue(INTBIG *x, INTBIG *y, char *name, char **pt, BOOLEAN q
 		if (!quiet) ttyputerr(M_("Missing ',' in %s option"), name);
 		return(TRUE);
 	}
-	st = getkeyword(pt, " \t)]");
+	st = getkeyword(pt, x_(" \t)]"));
 	if (st == NOSTRING) return(TRUE);
 	*y = atola(st, 0);
 	if (tonextchar(pt) != ')')
@@ -763,10 +764,10 @@ BOOLEAN cli_parsetwovalue(INTBIG *x, INTBIG *y, char *name, char **pt, BOOLEAN q
  * in "str", and the error verbose flag is in "quiet".  Returns the attribute
  * strucutre (NOATTR on error).
  */
-ATTR *cli_getattr(char *opt, char **pt, char *str, BOOLEAN quiet)
+ATTR *cli_getattr(CHAR *opt, CHAR **pt, CHAR *str, BOOLEAN quiet)
 {
 	REGISTER ATTR *a;
-	REGISTER char *st;
+	REGISTER CHAR *st;
 
 	a = (ATTR *)emalloc(sizeof (ATTR), el_tempcluster);
 	if (a == 0) return(NOATTR);
@@ -779,14 +780,14 @@ ATTR *cli_getattr(char *opt, char **pt, char *str, BOOLEAN quiet)
 	{
 		/* quoted string */
 		(void)tonextchar(pt);
-		st = getkeyword(pt, "\"");
+		st = getkeyword(pt, x_("\""));
 		if (st == NOSTRING) return(NOATTR);
-		(void)allocstring((char **)&a->value, st, el_tempcluster);
+		(void)allocstring((CHAR **)&a->value, st, el_tempcluster);
 		a->type = VSTRING;
 		(void)tonextchar(pt);
 	} else
 	{
-		st = getkeyword(pt, " \t,]");
+		st = getkeyword(pt, x_(" \t,]"));
 		if (st == NOSTRING) return(NOATTR);
 		if (*st == 0)
 		{
@@ -799,7 +800,7 @@ ATTR *cli_getattr(char *opt, char **pt, char *str, BOOLEAN quiet)
 			a->type = VINTEGER;
 		} else
 		{
-			(void)allocstring((char **)&a->value, st, el_tempcluster);
+			(void)allocstring((CHAR **)&a->value, st, el_tempcluster);
 			a->type = VSTRING;
 		}
 	}
@@ -812,7 +813,7 @@ ATTR *cli_getattr(char *opt, char **pt, char *str, BOOLEAN quiet)
  * routine to find the node with the name "name" in the current graphics facet.
  * Returns that node (NONODEINST if not found).
  */
-NODEINST *cli_findnodename(char *name)
+NODEINST *cli_findnodename(CHAR *name)
 {
 	REGISTER NODEINST *ni, *numni;
 	REGISTER VARIABLE *var;
@@ -821,11 +822,11 @@ NODEINST *cli_findnodename(char *name)
 	{
 		var = getvalkey((INTBIG)ni, VNODEINST, VSTRING, el_node_name_key);
 		if (var == NOVARIABLE) continue;
-		if (namesame(name, (char *)var->addr) == 0) return(ni);
+		if (namesame(name, (CHAR *)var->addr) == 0) return(ni);
 	}
 
 	/* look for the special case of "NODEdddd" */
-	if (namesamen(name, "node", 4) != 0) return(NONODEINST);
+	if (namesamen(name, x_("node"), 4) != 0) return(NONODEINST);
 	numni = (NODEINST *)myatoi(&name[4]);
 	for(ni = cli_curfacet->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
 		if (ni == numni) break;
@@ -836,7 +837,7 @@ NODEINST *cli_findnodename(char *name)
  * routine to find the arc described by the line "line".  Returns that arc
  * (NOARCINST if not found).
  */
-ARCINST *cli_findarcname(char *line)
+ARCINST *cli_findarcname(CHAR *line)
 {
 	NODEINST *nA, *nB;
 	PORTPROTO *pA, *pB;
@@ -1024,10 +1025,10 @@ void cli_deletecomponentdec(COMPONENTDEC *dec)
 		nextcomp = compo->nextcomponent;
 		cli_freeattr(compo->firstattr);
 		efree(compo->name);
-		efree((char *)compo);
+		efree((CHAR *)compo);
 	}
 	if (dec->protoname != 0) efree(dec->protoname);
-	efree((char *)dec);
+	efree((CHAR *)dec);
 }
 
 void cli_deleteconnection(CONNECTION *dec)
@@ -1037,7 +1038,7 @@ void cli_deleteconnection(CONNECTION *dec)
 	for(cons = dec->firstcons; cons != NOCONS; cons = nextcons)
 	{
 		nextcons = cons->nextcons;
-		efree((char *)cons);
+		efree((CHAR *)cons);
 	}
 	if ((dec->flag&LAYERVALID) != 0) efree(dec->layer);
 	if ((dec->flag&END1VALID) != 0) efree(dec->end1);
@@ -1045,7 +1046,7 @@ void cli_deleteconnection(CONNECTION *dec)
 	if ((dec->flag&END2VALID) != 0) efree(dec->end2);
 	if ((dec->flag&PORT2VALID) != 0) efree(dec->port2);
 	cli_freeattr(dec->firstattr);
-	efree((char *)dec);
+	efree((CHAR *)dec);
 }
 
 void cli_deleteexport(EXPORT *e)
@@ -1054,7 +1055,7 @@ void cli_deleteexport(EXPORT *e)
 	if (e->component != 0) efree(e->component);
 	if (e->subport != 0) efree(e->subport);
 	cli_freeattr(e->firstattr);
-	efree((char *)e);
+	efree((CHAR *)e);
 }
 
 void cli_freeattr(ATTR *a)
@@ -1065,7 +1066,7 @@ void cli_freeattr(ATTR *a)
 	{
 		nexta = a->nextattr;
 		efree(a->name);
-		if ((a->type&VTYPE) == VSTRING) efree((char *)a->value);
-		efree((char *)a);
+		if ((a->type&VTYPE) == VSTRING) efree((CHAR *)a->value);
+		efree((CHAR *)a);
 	}
 }
