@@ -38,23 +38,23 @@ static void (*cli_oldttermhandler)(WINDOWPART*);	/* former text editor terminati
 /* prototypes for local routines */
 static BOOLEAN cli_charhandler(WINDOWPART*, INTSML, INTBIG);
 static void cli_termhandler(WINDOWPART*);
-static void cli_changehandler(WINDOWPART*, INTBIG, char*, char*, INTBIG);
-static void cli_changeexport(char*, char*, INTBIG, WINDOWPART*);
-static void cli_changedeclaration(char*, char*, INTBIG, WINDOWPART*);
-static void cli_changeconnection(char*, char*, INTBIG, WINDOWPART*);
+static void cli_changehandler(WINDOWPART*, INTBIG, CHAR*, CHAR*, INTBIG);
+static void cli_changeexport(CHAR*, CHAR*, INTBIG, WINDOWPART*);
+static void cli_changedeclaration(CHAR*, CHAR*, INTBIG, WINDOWPART*);
+static void cli_changeconnection(CHAR*, CHAR*, INTBIG, WINDOWPART*);
 static void cli_updateattrs(ATTR*, ATTR*, INTBIG, INTBIG);
-static void cli_deletedeclaration(char*);
-static void cli_deletewire(char*);
-static void cli_deleteexportline(char*);
-static BOOLEAN cli_adddeclaration(char*, INTBIG, WINDOWPART*);
-static BOOLEAN cli_addwire(char*, INTBIG, WINDOWPART*);
-static void cli_addexport(char*, INTBIG, WINDOWPART*);
+static void cli_deletedeclaration(CHAR*);
+static void cli_deletewire(CHAR*);
+static void cli_deleteexportline(CHAR*);
+static BOOLEAN cli_adddeclaration(CHAR*, INTBIG, WINDOWPART*);
+static BOOLEAN cli_addwire(CHAR*, INTBIG, WINDOWPART*);
+static void cli_addexport(CHAR*, INTBIG, WINDOWPART*);
 static PORTPROTO *cli_getexportsubport(EXPORT*, NODEINST*);
 static void cli_getfactors(NODEINST*, NODEPROTO*, COMPONENT*, INTBIG*, INTBIG*, INTBIG*,
 				INTBIG*, INTBIG*, INTBIG*, INTBIG, INTBIG);
 static void cli_killthenode(NODEINST*);
 static void cli_commentline(INTBIG, WINDOWPART*);
-static void cli_restoreline(char*, INTBIG, WINDOWPART*);
+static void cli_restoreline(CHAR*, INTBIG, WINDOWPART*);
 
 /************************ EDITOR WINDOW CONTROL ************************/
 
@@ -63,13 +63,13 @@ static void cli_restoreline(char*, INTBIG, WINDOWPART*);
  * title is in "header" and the number of characters/lines are returned
  * in "chars" and "lines".  Returns NOWINDOWPART if there is an error.
  */
-WINDOWPART *cli_makeeditorwindow(char *header, INTBIG *chars, INTBIG *lines)
+WINDOWPART *cli_makeeditorwindow(CHAR *header, INTBIG *chars, INTBIG *lines)
 {
 	REGISTER WINDOWPART *win;
 
-	win = (WINDOWPART *)asktool(us_tool, "window-new");
+	win = (WINDOWPART *)asktool(us_tool, x_("window-new"));
 	if (win == NOWINDOWPART) return(NOWINDOWPART);
-	if (asktool(us_tool, "edit-starteditor", (INTBIG)win, (INTBIG)header,
+	if (asktool(us_tool, x_("edit-starteditor"), (INTBIG)win, (INTBIG)header,
 		(INTBIG)chars, (INTBIG)lines) != 0) return(NOWINDOWPART);
 
 	cli_realcharhandler = win->charhandler;
@@ -88,7 +88,7 @@ WINDOWPART *cli_makeeditorwindow(char *header, INTBIG *chars, INTBIG *lines)
  */
 BOOLEAN cli_charhandler(WINDOWPART *win, INTSML i, INTBIG special)
 {
-	REGISTER char *line;
+	REGISTER CHAR *line;
 	REGISTER ARCINST *ai;
 	REGISTER NODEINST *ni;
 	REGISTER COMPONENTDEC *comd;
@@ -107,7 +107,7 @@ BOOLEAN cli_charhandler(WINDOWPART *win, INTSML i, INTBIG special)
 		ttyputmsg(M_("No valid facet to associate"));
 		return(FALSE);
 	}
-	line = (char *)asktool(us_tool, "edit-getline", (INTBIG)win, -1);
+	line = (CHAR *)asktool(us_tool, x_("edit-getline"), (INTBIG)win, -1);
 	if (line == NOSTRING) type = LINEUNKN; else type = cli_linetype(line);
 
 	switch (type)
@@ -135,8 +135,8 @@ BOOLEAN cli_charhandler(WINDOWPART *win, INTSML i, INTBIG special)
 				ttyputmsg(M_("Cannot find equivalent arc for this line"));
 				return(0);
 			}
-			(void)asktool(us_tool, "clear");
-			(void)asktool(us_tool, "show-object", (INTBIG)ai->geom);
+			(void)asktool(us_tool, x_("clear"));
+			(void)asktool(us_tool, x_("show-object"), (INTBIG)ai->geom);
 			break;
 
 		case LINEDECL:
@@ -151,8 +151,8 @@ BOOLEAN cli_charhandler(WINDOWPART *win, INTSML i, INTBIG special)
 			{
 				ni = cli_findnodename(compo->name);
 				if (ni == NONODEINST) continue;
-				if (count == 0) (void)asktool(us_tool, "clear");
-				(void)asktool(us_tool, "show-object", (INTBIG)ni->geom);
+				if (count == 0) (void)asktool(us_tool, x_("clear"));
+				(void)asktool(us_tool, x_("show-object"), (INTBIG)ni->geom);
 				count++;
 			}
 			if (count == 0)
@@ -178,11 +178,11 @@ void cli_termhandler(WINDOWPART *win)
 /*
  * routine to handle changes to the text window.
  */
-void cli_changehandler(WINDOWPART *win, INTBIG nature, char *oldline, char *newline,
+void cli_changehandler(WINDOWPART *win, INTBIG nature, CHAR *oldline, CHAR *newline,
 	INTBIG changed)
 {
-	char *newpar[3];
-	REGISTER char *oldname, *newname, **newlist;
+	CHAR *newpar[3];
+	REGISTER CHAR *oldname, *newname, **newlist;
 	REGISTER INTBIG otype, ntype;
 	REGISTER INTBIG i, count;
 	REGISTER NODEPROTO *np;
@@ -192,14 +192,14 @@ void cli_changehandler(WINDOWPART *win, INTBIG nature, char *oldline, char *newl
 	switch (nature)
 	{
 		case REPLACETEXTLINE:                break;
-		case DELETETEXTLINE: newline = "";   break;
-		case INSERTTEXTLINE: oldline = "";   break;
+		case DELETETEXTLINE: newline = x_("");   break;
+		case INSERTTEXTLINE: oldline = x_("");   break;
 		case REPLACEALLTEXT:
 			/* this is not totally correct, because it ignores the former line values!!! */
-			newlist = (char **)newline;
+			newlist = (CHAR **)newline;
 			count = changed;
 			for(i=0; i<count; i++)
-				cli_changehandler(win, REPLACETEXTLINE, "", newlist[i], i);
+				cli_changehandler(win, REPLACETEXTLINE, x_(""), newlist[i], i);
 			return;
 	}
 
@@ -240,7 +240,7 @@ void cli_changehandler(WINDOWPART *win, INTBIG nature, char *oldline, char *newl
 				{
 					if (namesame(oldname, newname) != 0)
 					{
-						(void)setval((INTBIG)cli_curfacet->cell, VCELL, "cellname", (INTBIG)newname, VSTRING);
+						(void)setval((INTBIG)cli_curfacet->cell, VCELL, x_("cellname"), (INTBIG)newname, VSTRING);
 						ttyputmsg(M_("Facet name changed from %s to %s"), oldname, newname);
 					}
 				} else if (newname == NOSTRING)
@@ -331,7 +331,7 @@ void cli_changehandler(WINDOWPART *win, INTBIG nature, char *oldline, char *newl
 				np = getnodeproto(newname);
 				if (np != NONODEPROTO && np->primindex != 0)
 				{
-					newpar[0] = "killfacet";
+					newpar[0] = x_("killfacet");
 					newpar[1] = newname;
 					telltool(us_tool, 2, newpar);
 				}
@@ -348,11 +348,11 @@ void cli_changehandler(WINDOWPART *win, INTBIG nature, char *oldline, char *newl
 				/* create the specified facet */
 				if (w != NOWINDOWPART)
 				{
-					newpar[0] = "window";
-					newpar[1] = "use";
+					newpar[0] = x_("window");
+					newpar[1] = x_("use");
 					newpar[2] = w->location;
 					telltool(us_tool, 3, newpar);
-					newpar[0] = "editfacet";
+					newpar[0] = x_("editfacet");
 					newpar[1] = newname;
 					telltool(us_tool, 2, newpar);
 					cli_curfacet = getcurfacet();
@@ -363,8 +363,8 @@ void cli_changehandler(WINDOWPART *win, INTBIG nature, char *oldline, char *newl
 			case LINEEND:
 				/* put the line at the bottom of the file */
 				infstr = initinfstr();
-				addstringtoinfstr(infstr, (char *)asktool(us_tool, "edit-getline", (INTBIG)win, changed));
-				(void)asktool(us_tool, "edit-deleteline", (INTBIG)win, changed);
+				addstringtoinfstr(infstr, (CHAR *)asktool(us_tool, x_("edit-getline"), (INTBIG)win, changed));
+				(void)asktool(us_tool, x_("edit-deleteline"), (INTBIG)win, changed);
 				cli_replaceendfacet(returninfstr(infstr), win);
 				break;
 		}
@@ -378,7 +378,7 @@ void cli_changehandler(WINDOWPART *win, INTBIG nature, char *oldline, char *newl
  * The index of the line that changed is in "changed".  Text was changed
  * in window "win".
  */
-void cli_changeexport(char *oldline, char *newline, INTBIG changed, WINDOWPART *win)
+void cli_changeexport(CHAR *oldline, CHAR *newline, INTBIG changed, WINDOWPART *win)
 {
 	REGISTER EXPORT *olde, *newe;
 	REGISTER NODEINST *oldni, *newni;
@@ -472,7 +472,7 @@ void cli_changeexport(char *oldline, char *newline, INTBIG changed, WINDOWPART *
  * The index of the line that changed is in "changed".  Text was changed
  * in window "win".
  */
-void cli_changedeclaration(char *oldline, char *newline, INTBIG changed,
+void cli_changedeclaration(CHAR *oldline, CHAR *newline, INTBIG changed,
 	WINDOWPART *win)
 {
 	REGISTER COMPONENTDEC *oldcd, *newcd;
@@ -724,7 +724,7 @@ void cli_changedeclaration(char *oldline, char *newline, INTBIG changed,
  * The index of the line that changed is in "changed".  Text was changed
  * in window "win".
  */
-void cli_changeconnection(char *oldline, char *newline, INTBIG changed, WINDOWPART *win)
+void cli_changeconnection(CHAR *oldline, CHAR *newline, INTBIG changed, WINDOWPART *win)
 {
 	REGISTER CONNECTION *oldcon, *newcon;
 	REGISTER ARCINST *ai, *newai;
@@ -952,10 +952,10 @@ void cli_changeconnection(char *oldline, char *newline, INTBIG changed, WINDOWPA
 	{
 		if (oldcons->assoc != NOCONS) continue;
 		resolve = TRUE;
-		if (namesame(oldcons->direction, "left") == 0) variable = CLLEFT; else
-			if (namesame(oldcons->direction, "right") == 0) variable = CLRIGHT; else
-				if (namesame(oldcons->direction, "down") == 0) variable = CLDOWN; else
-					if (namesame(oldcons->direction, "up") == 0) variable = CLUP;
+		if (namesame(oldcons->direction, x_("left")) == 0) variable = CLLEFT; else
+			if (namesame(oldcons->direction, x_("right")) == 0) variable = CLRIGHT; else
+				if (namesame(oldcons->direction, x_("down")) == 0) variable = CLDOWN; else
+					if (namesame(oldcons->direction, x_("up")) == 0) variable = CLUP;
 		cli_ownchanges = TRUE;
 		cli_deletearcconstraint(ai, variable, oldcons->flag, oldcons->amount);
 		cli_ownchanges = FALSE;
@@ -966,10 +966,10 @@ void cli_changeconnection(char *oldline, char *newline, INTBIG changed, WINDOWPA
 	{
 		if (newcons->assoc != NOCONS) continue;
 		resolve = TRUE;
-		if (namesame(newcons->direction, "left") == 0) variable = CLLEFT; else
-			if (namesame(newcons->direction, "right") == 0) variable = CLRIGHT; else
-				if (namesame(newcons->direction, "down") == 0) variable = CLDOWN; else
-					if (namesame(newcons->direction, "up") == 0) variable = CLUP;
+		if (namesame(newcons->direction, x_("left")) == 0) variable = CLLEFT; else
+			if (namesame(newcons->direction, x_("right")) == 0) variable = CLRIGHT; else
+				if (namesame(newcons->direction, x_("down")) == 0) variable = CLDOWN; else
+					if (namesame(newcons->direction, x_("up")) == 0) variable = CLUP;
 		cli_ownchanges = TRUE;
 		(void)cli_addarcconstraint(ai, variable, newcons->flag, newcons->amount, 1);
 		cli_ownchanges = FALSE;
@@ -1074,7 +1074,7 @@ void cli_updateattrs(ATTR *oldlist, ATTR *newlist, INTBIG addr, INTBIG type)
 				if (a->value == b->value) continue;
 			} else if ((a->type&VTYPE) == VSTRING)
 			{
-				if (namesame((char *)a->value, (char *)b->value) == 0) continue;
+				if (namesame((CHAR *)a->value, (CHAR *)b->value) == 0) continue;
 			}
 		}
 		cli_ownchanges = TRUE;
@@ -1090,7 +1090,7 @@ void cli_updateattrs(ATTR *oldlist, ATTR *newlist, INTBIG addr, INTBIG type)
  * routine to delete the graphics associated with the declaration in line
  * "oldline"
  */
-void cli_deletedeclaration(char *oldline)
+void cli_deletedeclaration(CHAR *oldline)
 {
 	REGISTER COMPONENTDEC *dec;
 	REGISTER COMPONENT *compo;
@@ -1127,7 +1127,7 @@ void cli_deletedeclaration(char *oldline)
  * routine to delete the graphics associated with the connection in line
  * "oldline"
  */
-void cli_deletewire(char *oldline)
+void cli_deletewire(CHAR *oldline)
 {
 	REGISTER ARCINST *ai;
 
@@ -1142,7 +1142,7 @@ void cli_deletewire(char *oldline)
 /*
  * routine to delete the graphics associated with the export line "oldline"
  */
-void cli_deleteexportline(char *oldline)
+void cli_deleteexportline(CHAR *oldline)
 {
 	REGISTER EXPORT *e;
 	REGISTER PORTPROTO *pp;
@@ -1174,7 +1174,7 @@ void cli_deleteexportline(char *oldline)
  * with the line index "changed".  Text was changed in window "win".  Returns
  * true on error
  */
-BOOLEAN cli_adddeclaration(char *newline, INTBIG changed, WINDOWPART *win)
+BOOLEAN cli_adddeclaration(CHAR *newline, INTBIG changed, WINDOWPART *win)
 {
 	REGISTER COMPONENTDEC *dec;
 	REGISTER COMPONENT *compo, *ocomp;
@@ -1255,7 +1255,7 @@ BOOLEAN cli_adddeclaration(char *newline, INTBIG changed, WINDOWPART *win)
  * with the line index "changed".  Text was changed in window "win".  Returns
  * true on error
  */
-BOOLEAN cli_addwire(char *newline, INTBIG changed, WINDOWPART *win)
+BOOLEAN cli_addwire(CHAR *newline, INTBIG changed, WINDOWPART *win)
 {
 	REGISTER CONNECTION *dcl;
 	REGISTER CONS *cons;
@@ -1300,19 +1300,19 @@ BOOLEAN cli_addwire(char *newline, INTBIG changed, WINDOWPART *win)
 	gothor = gotver = FALSE;
 	for(cons = dcl->firstcons; cons != NOCONS; cons = cons->nextcons)
 	{
-		if (namesame(cons->direction, "left") == 0)
+		if (namesame(cons->direction, x_("left")) == 0)
 		{
 			variable = CLLEFT;
 			gothor = TRUE;
-		} else if (namesame(cons->direction, "right") == 0)
+		} else if (namesame(cons->direction, x_("right")) == 0)
 		{
 			variable = CLRIGHT;
 			gothor = TRUE;
-		} else if (namesame(cons->direction, "down") == 0)
+		} else if (namesame(cons->direction, x_("down")) == 0)
 		{
 			variable = CLDOWN;
 			gotver = TRUE;
-		} else if (namesame(cons->direction, "up") == 0)
+		} else if (namesame(cons->direction, x_("up")) == 0)
 		{
 			variable = CLUP;
 			gotver = TRUE;
@@ -1344,7 +1344,7 @@ BOOLEAN cli_addwire(char *newline, INTBIG changed, WINDOWPART *win)
  * routine to add graphics equivalent to the new text connection "newline"
  * with the line index "changed".  Text was changed in window "win".
  */
-void cli_addexport(char *newline, INTBIG changed, WINDOWPART *win)
+void cli_addexport(CHAR *newline, INTBIG changed, WINDOWPART *win)
 {
 	REGISTER EXPORT *e;
 	REGISTER PORTPROTO *pp, *newpp;
@@ -1542,47 +1542,47 @@ void cli_commentline(INTBIG cindex, WINDOWPART *win)
 	REGISTER void *infstr;
 
 	infstr = initinfstr();
-	addstringtoinfstr(infstr, "; ");
-	addstringtoinfstr(infstr, (char *)asktool(us_tool, "edit-getline", (INTBIG)win, cindex));
-	(void)asktool(us_tool, "edit-replaceline", (INTBIG)win, cindex, (INTBIG)returninfstr(infstr));
+	addstringtoinfstr(infstr, x_("; "));
+	addstringtoinfstr(infstr, (CHAR *)asktool(us_tool, x_("edit-getline"), (INTBIG)win, cindex));
+	(void)asktool(us_tool, x_("edit-replaceline"), (INTBIG)win, cindex, (INTBIG)returninfstr(infstr));
 }
 
 /*
  * routine to comment line "cindex" and restore line "str" of text.  Text
  * was changed in window "win".
  */
-void cli_restoreline(char *str, INTBIG cindex, WINDOWPART *win)
+void cli_restoreline(CHAR *str, INTBIG cindex, WINDOWPART *win)
 {
 	REGISTER void *infstr;
 
 	/* first insert this old line */
-	(void)asktool(us_tool, "edit-addline", (INTBIG)win, cindex+1, (INTBIG)str);
+	(void)asktool(us_tool, x_("edit-addline"), (INTBIG)win, cindex+1, (INTBIG)str);
 
 	/* now comment out line "cindex" */
 	infstr = initinfstr();
-	addstringtoinfstr(infstr, "; ");
-	addstringtoinfstr(infstr, (char *)asktool(us_tool, "edit-getline", (INTBIG)win, cindex));
-	(void)asktool(us_tool, "edit-replaceline", (INTBIG)win, cindex, (INTBIG)returninfstr(infstr));
+	addstringtoinfstr(infstr, x_("; "));
+	addstringtoinfstr(infstr, (CHAR *)asktool(us_tool, x_("edit-getline"), (INTBIG)win, cindex));
+	(void)asktool(us_tool, x_("edit-replaceline"), (INTBIG)win, cindex, (INTBIG)returninfstr(infstr));
 }
 
-void cli_replaceendfacet(char *str, WINDOWPART *win)
+void cli_replaceendfacet(CHAR *str, WINDOWPART *win)
 {
 	REGISTER INTBIG i, maxlines, type;
 
-	maxlines = asktool(us_tool, "edit-totallines", (INTBIG)win);
+	maxlines = asktool(us_tool, x_("edit-totallines"), (INTBIG)win);
 
 	/* search for all other "beginfacet" lines */
 	for(i = 0; i < maxlines; i++)
 	{
-		type = cli_linetype((char *)asktool(us_tool, "edit-getline", (INTBIG)win, i));
+		type = cli_linetype((CHAR *)asktool(us_tool, x_("edit-getline"), (INTBIG)win, i));
 		if (type != LINEEND) continue;
 
 		/* found another "beginfacet", delete the text */
-		(void)asktool(us_tool, "edit-deleteline", (INTBIG)win, i);
+		(void)asktool(us_tool, x_("edit-deleteline"), (INTBIG)win, i);
 		i--;
 		maxlines--;
 	}
 
 	/* place this line at the beginning */
-	(void)asktool(us_tool, "edit-addline", (INTBIG)win, maxlines, (INTBIG)str);
+	(void)asktool(us_tool, x_("edit-addline"), (INTBIG)win, maxlines, (INTBIG)str);
 }
