@@ -33,9 +33,9 @@
 /*
  * sample routines and their arguments:
  *
- * aa_init(INTBIG *argc, char *argv[], TOOL *tool) {}
- * BOOLEAN aa_set(INTBIG count, char *par[]) {}
- * INTBIG aa_request(char *command,...) {}
+ * aa_init(INTBIG *argc, CHAR1 *argv[], TOOL *tool) {}
+ * BOOLEAN aa_set(INTBIG count, CHAR *par[]) {}
+ * INTBIG aa_request(CHAR *command,...) {}
  * aa_examinenodeproto(NODEPROTO *np) {}
  * aa_slice() {}
  * aa_done() {}
@@ -178,7 +178,7 @@ TOOL el_tools[] =
 	/********** the interactive tools **********/
 
 	/* user interface */
-	{"user", TOOLON | TOOLINCREMENTAL | USEDIALOGS, 0, &us_userp, NOCLUSTER,
+	{x_("user"), TOOLON | TOOLINCREMENTAL | USEDIALOGS, 0, &us_userp, NOCLUSTER,
 	us_init,               us_done,              us_set,				/* init/done/set */
 	us_request,            us_examinenodeproto,  us_slice,				/* request/examine/slice */
 	us_startbatch,         us_endbatch,									/* startbatch/endbatch */
@@ -192,7 +192,7 @@ TOOL el_tools[] =
 	NOVARIABLE, 0},
 
 	/* I/O module */
-	{"io", 0, 0, &io_iop, NOCLUSTER,
+	{x_("io"), 0, 0, &io_iop, NOCLUSTER,
 	io_init,               io_done,              io_set,				/* init/done/set */
 	io_request,            0,                    io_slice,				/* request/examine/slice */
 	0,                     0,											/* startbatch/endbatch */
@@ -207,7 +207,7 @@ TOOL el_tools[] =
 
 #if DBMIRRORTOOL
 	/* database mirror module */
-	{"dbmirror", TOOLSYNTHESIS,	0,	NOCOMCOMP,	NOCLUSTER,
+	{x_("dbmirror"), TOOLSYNTHESIS,	0,	NOCOMCOMP,	NOCLUSTER,
 	dbm_init,              dbm_done,             dbm_set,				/* init/done/set */
 	dbm_request,           dbm_examinenodeproto, dbm_slice,				/* request/examine/slice */
 	dbm_startbatch,        dbm_endbatch,								/* startbatch/endbatch */
@@ -223,7 +223,7 @@ TOOL el_tools[] =
 
 #if COMTOOL
 	/* compaction module */
-	{"compaction", TOOLSYNTHESIS,              0, &com_compactp, NOCLUSTER,
+	{x_("compaction"), TOOLSYNTHESIS,              0, &com_compactp, NOCLUSTER,
 	com_init,              com_done,             com_set,				/* init/done/set */
 	0,                     0,                    com_slice,				/* request/examine/slice */
 	0,                     0,											/* startbatch/endbatch */
@@ -239,7 +239,7 @@ TOOL el_tools[] =
 
 #if PLATOOL
 	/* PLA generation module */
-	{"pla", TOOLSYNTHESIS,                     0, &pla_plap, NOCLUSTER,
+	{x_("pla"), TOOLSYNTHESIS,                     0, &pla_plap, NOCLUSTER,
 	pla_init,              pla_done,             pla_set,				/* init/done/set */
 	0,                     0,                    pla_slice,				/* request/examine/slice */
 	0,                     0,											/* startbatch/endbatch */
@@ -255,7 +255,7 @@ TOOL el_tools[] =
 
 #if ROUTTOOL
 	/* wire routing module */
-	{"routing", TOOLINCREMENTAL | TOOLSYNTHESIS, 0, &ro_routerp, NOCLUSTER,
+	{x_("routing"), TOOLINCREMENTAL | TOOLSYNTHESIS, 0, &ro_routerp, NOCLUSTER,
 	ro_init,               ro_done,              ro_set,				/* init/done/set */
 	0,                     0,                    ro_slice,				/* request/examine/slice */
 	ro_startbatch,         ro_endbatch,									/* startbatch/endbatch */
@@ -271,7 +271,7 @@ TOOL el_tools[] =
 
 #if SCTOOL
 	/* Quisc "Silicon" Compiler module */
-	{"silicon-compiler", TOOLSYNTHESIS,	0,	&sc_silcomp,	NOCLUSTER,
+	{x_("silicon-compiler"), TOOLSYNTHESIS,	0,	&sc_silcomp,	NOCLUSTER,
 	sc_init,               sc_done,              sc_set,				/* init/done/set */
 	sc_request,            0,                    sc_slice,				/* request/examine/slice */
 	0,                     0,											/* startbatch/endbatch */
@@ -287,7 +287,7 @@ TOOL el_tools[] =
 
 #if MAPPERTOOL
 	/* mapper module */
-	{"mapper", TOOLSYNTHESIS,	0,	&map_mapperp,	NOCLUSTER,
+	{x_("mapper"), TOOLSYNTHESIS,	0,	&map_mapperp,	NOCLUSTER,
 	map_init,              map_done,             map_set,				/* init/done/set */
 	map_request,           map_examinenodeproto, map_slice,				/* request/examine/slice */
 	map_startbatch,        map_endbatch,								/* startbatch/endbatch */
@@ -303,7 +303,7 @@ TOOL el_tools[] =
 
 #if VHDLTOOL
 	/* VHDL compiler module */
-	{"vhdl-compiler", TOOLSYNTHESIS,	0,	&vhdl_comp,	NOCLUSTER,
+	{x_("vhdl-compiler"), TOOLSYNTHESIS,	0,	&vhdl_comp,	NOCLUSTER,
 	vhdl_init,             vhdl_done,            vhdl_set,				/* init/done/set */
 	vhdl_request,          0,                    vhdl_slice,			/* request/examine/slice */
 	0,                     0,											/* startbatch/endbatch */
@@ -319,7 +319,7 @@ TOOL el_tools[] =
 
 #if COMPENTOOL
 	/* compensation module */
-	{"compensation", TOOLSYNTHESIS,	0,	&compen_compensatep,	NOCLUSTER,
+	{x_("compensation"), TOOLSYNTHESIS,	0,	&compen_compensatep,	NOCLUSTER,
 	compen_init,           compen_done,          compen_set,			/* init/done/set */
 	0,                     0,                    compen_slice,			/* request/examine/slice */
 	0,                     0,											/* startbatch/endbatch */
@@ -335,7 +335,7 @@ TOOL el_tools[] =
 
 #if LOGEFFTOOL
 	/* logical effort module */
-	{"logeffort", TOOLSYNTHESIS,	0,	&le_tablep,	NOCLUSTER,
+	{x_("logeffort"), TOOLSYNTHESIS,	0,	&le_tablep,	NOCLUSTER,
 	le_init,               le_done,              le_set,				/* init/done/set */
 	0,                     0,                    0,						/* request/examine/slice */
 	0,                     0,											/* startbatch/endbatch */
@@ -350,7 +350,7 @@ TOOL el_tools[] =
 #endif
 
 	/* network maintenance and comparison */
-	{"network", TOOLON | TOOLINCREMENTAL, 0, &net_networkp, NOCLUSTER,
+	{x_("network"), TOOLON | TOOLINCREMENTAL, 0, &net_networkp, NOCLUSTER,
 	net_init,              net_done,             net_set,				/* init/done/set */
 	net_request,           net_examinenodeproto, net_slice,				/* request/examine/slice */
 	net_startbatch,        net_endbatch,								/* startbatch/endbatch */
@@ -365,7 +365,7 @@ TOOL el_tools[] =
 
 #if DRCTOOL
 	/* design-rule checker */
-	{"drc", TOOLON | TOOLINCREMENTAL | TOOLANALYSIS, 0, &dr_drcp, NOCLUSTER,
+	{x_("drc"), TOOLON | TOOLINCREMENTAL | TOOLANALYSIS, 0, &dr_drcp, NOCLUSTER,
 	dr_init,               dr_done,              dr_set,				/* init/done/set */
 	dr_request,            dr_examinenodeproto,  dr_slice,				/* request/examine/slice */
 	0,                     0,											/* startbatch/endbatch */
@@ -381,7 +381,7 @@ TOOL el_tools[] =
 
 #if ERCTOOL
 	/* electrical-rule checker */
-	{"erc", TOOLANALYSIS, 0, &erc_tablep, NOCLUSTER,
+	{x_("erc"), TOOLANALYSIS, 0, &erc_tablep, NOCLUSTER,
 	erc_init,              erc_done,             erc_set,				/* init/done/set */
 	0,                     0,                    0,						/* request/examine/slice */
 	0,                     0,											/* startbatch/endbatch */
@@ -397,9 +397,9 @@ TOOL el_tools[] =
 
 #if SIMTOOL
 	/* simulation module */
-	{"simulation", TOOLANALYSIS, 0, &sim_simulatorp, NOCLUSTER,
+	{x_("simulation"), TOOLANALYSIS, 0, &sim_simulatorp, NOCLUSTER,
 	sim_init,              sim_done,             sim_set,				/* init/done/set */
-	0,                     0,                    sim_slice,				/* request/examine/slice */
+	sim_request,           0,                    sim_slice,				/* request/examine/slice */
 	sim_startbatch,        0,											/* startbatch/endbatch */
 	0,                     0,											/* startobject/endobject */
 	sim_modifynodeinst,    0,                    sim_modifyarcinst,		/* modnode/modnodes/modarc */
@@ -413,7 +413,7 @@ TOOL el_tools[] =
 
 #if PROJECTTOOL
 	/* project management module */
-	{"project", TOOLON | TOOLINCREMENTAL, 0, &proj_projp, NOCLUSTER,
+	{x_("project"), TOOLON | TOOLINCREMENTAL, 0, &proj_projp, NOCLUSTER,
 	proj_init,             proj_done,            proj_set,				/* init/done/set */
 	0,                     0,                    proj_slice,			/* request/examine/slice */
 	proj_startbatch,       0,											/* startbatch/endbatch */
