@@ -33,7 +33,7 @@
 
 /******************************* GLOBAL *******************************/
 
-char       **el_namespace;				/* names in name space */
+CHAR       **el_namespace;				/* names in name space */
 INTBIG       el_numnames;				/* number of names in name space */
 
 /* some keys to commonly used variable names */
@@ -51,6 +51,7 @@ INTBIG       el_arc_width_default_key;	/* key for "ARC_width_default" */
 INTBIG       el_attrkey_width;			/* key for "ATTR_width" */
 INTBIG       el_attrkey_length;			/* key for "ATTR_length" */
 INTBIG       el_attrkey_area;			/* key for "ATTR_area" */
+INTBIG       el_attrkey_M;			    /* key for "ATTR_M" */
 INTBIG       el_techstate_key;			/* key for "TECH_state" */
 
 CLUSTER     *el_tempcluster;			/* cluster for temporary allocation */
@@ -85,11 +86,12 @@ WINDOWFRAME *el_curwindowframe;
 
 TECHNOLOGY  *el_technologies;			/* defined in "tectable.c" */
 TECHNOLOGY  *el_curtech;				/* pointer to current technology */
+TECHNOLOGY  *el_curlayouttech;			/* last layout technology referenced */
 INTBIG       el_maxtech;				/* current number of technologies */
 
 CONSTRAINT  *el_curconstraint;			/* current constraint solver */
 
-char        *el_libdir;					/* pointer to library directory */
+CHAR        *el_libdir;					/* pointer to library directory */
 
 INTBIG       el_filetypetext;			/* Plain text disk file descriptor */
 
