@@ -64,7 +64,7 @@ static void         db_freechangefacet(CHANGEFACET*);
 static void         db_loadhistorylist(INTBIG, void*);
 static void         db_broadcastchange(CHANGE*, BOOLEAN, BOOLEAN);
 static BOOLEAN      db_reversechange(CHANGE*);
-static char        *db_describechange(INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG);
+static CHAR        *db_describechange(INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG);
 static BOOLEAN      db_majorvariable(INTBIG type, INTBIG key);
 static void         db_setdirty(INTBIG change, INTBIG obj, INTBIG a1, INTBIG a2, INTBIG a3, INTBIG a4);
 
@@ -81,19 +81,19 @@ void db_freechangememory(void)
 	{
 		c = db_changefree;
 		db_changefree = db_changefree->nextchange;
-		efree((char *)c);
+		efree((CHAR *)c);
 	}
 	while (db_changefacetfree != NOCHANGEFACET)
 	{
 		cf = db_changefacetfree;
 		db_changefacetfree = db_changefacetfree->nextchangefacet;
-		efree((char *)cf);
+		efree((CHAR *)cf);
 	}
 	while (db_changebatchfree != NOCHANGEBATCH)
 	{
 		b = db_changebatchfree;
 		db_changebatchfree = db_changebatchfree->nextchangebatch;
-		efree((char *)b);
+		efree((CHAR *)b);
 	}
 }
 
@@ -126,7 +126,7 @@ CHANGE *db_change(INTBIG obj, INTBIG change, INTBIG a1, INTBIG a2, INTBIG a3, IN
 {
 	REGISTER BOOLEAN firstchange;
 	REGISTER CHANGE *c;
-	static char *broadcasttype[] = {M_("nodeinstnew"), M_("nodeinstkill"), M_("nodeinstmod"),
+	static CHAR *broadcasttype[] = {M_("nodeinstnew"), M_("nodeinstkill"), M_("nodeinstmod"),
 		M_("arcinstnew"), M_("arcinstkill"), M_("arcinstmod"), M_("portprotonew"),
 		M_("portprotokill"), M_("portprotomod"), M_("nodeprotonew"), M_("nodeprotokill"),
 		M_("nodeprotomod"), M_("objectstart"), M_("objectend"), M_("objectnew"), M_("objectkill"),
@@ -139,8 +139,8 @@ CHANGE *db_change(INTBIG obj, INTBIG change, INTBIG a1, INTBIG a2, INTBIG a3, IN
 	if (db_broadcasting != 0)
 	{
 		ttyputerr(_("Recieved this change during broadcast of type %s:"),
-			_(broadcasttype[db_broadcasting-1]));
-		ttyputmsg("%s", db_describechange(change, obj, a1, a2, a3, a4, a5, a6));
+			TRANSLATE(broadcasttype[db_broadcasting-1]));
+		ttyputmsg(x_("%s"), db_describechange(change, obj, a1, a2, a3, a4, a5, a6));
 	}
 
 	/* determine what needs to be marked as changed */
@@ -629,7 +629,7 @@ void db_erasebatch(CHANGEBATCH *batch)
 			/* free the array entry if it is allocated */
 			if ((c->p3&(VCODE1|VCODE2)) != 0 || (c->p3&VTYPE) == VSTRING)
 			{
-				efree((char *)c->p5);
+				efree((CHAR *)c->p5);
 			}
 		}
 		db_freechange(c);
@@ -753,7 +753,7 @@ INTBIG getcurrentbatchnumber(void)
 /*
  * routine to set the activity message for the current batch of changes
  */
-void setactivity(char *message)
+void setactivity(CHAR *message)
 {
 	if (db_currentbatch == NOCHANGEBATCH) return;		/* should save for later !!! */
 	if (db_currentbatch->activity != 0) efree(db_currentbatch->activity);
@@ -931,8 +931,8 @@ BOOLEAN db_reversechange(CHANGE *c)
 	REGISTER VARIABLE *var;
 	REGISTER VIEW *v, *lastv, *view;
 	REGISTER WINDOWPART *w;
-	REGISTER char *attname;
-	char *storage;
+	REGISTER CHAR *attname;
+	CHAR *storage;
 	INTBIG oldval;
 	REGISTER INTSML oldshort;
 
@@ -1083,7 +1083,7 @@ BOOLEAN db_reversechange(CHANGE *c)
 			{
 				/* change to fixed attribute */
 				attname = changedvariablename(c->p1, c->p2, c->p3);
-				var = getval(c->entryaddr, c->p1, c->p3 & (VTYPE|VISARRAY), attname);
+				var = getvalnoeval(c->entryaddr, c->p1, c->p3 & (VTYPE|VISARRAY), attname);
 				if (var == NOVARIABLE)
 				{
 					ttyputmsg(_("Warning: Could not find attribute %s on object %s"),
@@ -1098,15 +1098,15 @@ BOOLEAN db_reversechange(CHANGE *c)
 				if (c->p1 == VNODEINST || c->p1 == VARCINST) return(TRUE);
 				if (c->p1 == VPORTPROTO)
 				{
-					if (strcmp(attname, "textdescript") == 0 ||
-						strcmp(attname, "userbits") == 0 ||
-						strcmp(attname, "protoname") == 0) return(TRUE);
+					if (estrcmp(attname, x_("textdescript")) == 0 ||
+						estrcmp(attname, x_("userbits")) == 0 ||
+						estrcmp(attname, x_("protoname")) == 0) return(TRUE);
 				}
 				break;
 			}
 
 			/* change to variable attribute: get current value */
-			var = getvalkey(c->entryaddr, c->p1, c->p3&(VTYPE|VISARRAY), c->p2);
+			var = getvalkeynoeval(c->entryaddr, c->p1, c->p3&(VTYPE|VISARRAY), c->p2);
 			if (var == NOVARIABLE)
 			{
 				ttyputmsg(_("Warning: Could not find attribute %s on object %s"),
@@ -1170,7 +1170,7 @@ BOOLEAN db_reversechange(CHANGE *c)
 				c->p5 = oldval;
 				if (c->p1 == VPORTPROTO)
 				{
-					if (strcmp(attname, "textdescript") == 0) return(TRUE);
+					if (estrcmp(attname, x_("textdescript")) == 0) return(TRUE);
 				}
 			} else
 			{
@@ -1183,7 +1183,7 @@ BOOLEAN db_reversechange(CHANGE *c)
 				if ((c->p3&(VCODE1|VCODE2)) != 0 || (c->p3&VTYPE) == VSTRING)
 				{
 					/* because this change is done quietly, the memory is freed and must be saved */
-					(void)allocstring(&storage, (char *)oldval, db_cluster);
+					(void)allocstring(&storage, (CHAR *)oldval, db_cluster);
 					oldval = (INTBIG)storage;
 				}
 				nextchangequiet();
@@ -1214,7 +1214,7 @@ BOOLEAN db_reversechange(CHANGE *c)
 			if (c->p1 == VNODEINST || c->p1 == VARCINST) return(TRUE);
 			break;
 		case DESCRIPTMOD:
-			var = getvalkey(c->entryaddr, c->p1, -1, c->p2);
+			var = getvalkeynoeval(c->entryaddr, c->p1, -1, c->p2);
 			if (var == NOVARIABLE) break;
 			oldval = var->textdescript[0];   var->textdescript[0] = c->p4;   c->p4 = oldval;
 			oldval = var->textdescript[1];   var->textdescript[1] = c->p5;   c->p5 = oldval;
@@ -1298,7 +1298,7 @@ void showhistorylist(INTBIG which)
 	REGISTER INTBIG lobatch, hibatch;
 	REGISTER CHANGEBATCH *batchreport;
 	REGISTER CHANGE *c;
-	char line[50];
+	CHAR line[50];
 	REGISTER void *infstr;
 
 	/* specific display of a batch */
@@ -1317,10 +1317,10 @@ void showhistorylist(INTBIG which)
 			if (batchreport->activity != 0)
 				formatinfstr(infstr, M_(", caused by '%s'"), batchreport->activity);
 			addstringtoinfstr(infstr, M_(" is:"));
-			ttyputmsg("%s", returninfstr(infstr));
+			ttyputmsg(x_("%s"), returninfstr(infstr));
 
 			for(c = batchreport->changehead; c != NOCHANGE; c = c->nextchange)
-				ttyputmsg("%s", db_describechange(c->changetype, c->entryaddr, c->p1, c->p2,
+				ttyputmsg(x_("%s"), db_describechange(c->changetype, c->entryaddr, c->p1, c->p2,
 					c->p3, c->p4, c->p5, c->p6));
 			return;
 		}
@@ -1376,46 +1376,46 @@ void showhistorylist(INTBIG which)
 		}
 
 		infstr = initinfstr();
-		(void)sprintf(line, "%ld {", batchreport->batchnumber);
+		(void)esnprintf(line, 50, x_("%ld {"), batchreport->batchnumber);
 		addstringtoinfstr(infstr, line);
 		if (batchreport->activity != 0) addstringtoinfstr(infstr, batchreport->activity);
 		addstringtoinfstr(infstr, M_("} affects"));
 
 		if (node != 0)
 		{
-			(void)sprintf(line, " %ld %s", node, makeplural(M_("node"), node));
+			(void)esnprintf(line, 50, x_(" %ld %s"), node, makeplural(M_("node"), node));
 			addstringtoinfstr(infstr, line);
 		}
 		if (arcinst != 0)
 		{
-			(void)sprintf(line, " %ld %s", arcinst, makeplural(M_("arc"), arcinst));
+			(void)esnprintf(line, 50, x_(" %ld %s"), arcinst, makeplural(M_("arc"), arcinst));
 			addstringtoinfstr(infstr, line);
 		}
 		if (portproto != 0)
 		{
-			(void)sprintf(line, " %ld %s", portproto, makeplural(M_("port"), portproto));
+			(void)esnprintf(line, 50, x_(" %ld %s"), portproto, makeplural(M_("port"), portproto));
 			addstringtoinfstr(infstr, line);
 		}
 		if (nproto != 0)
 		{
-			(void)sprintf(line, " %ld %s", nproto, makeplural(M_("facet"), nproto));
+			(void)esnprintf(line, 50, x_(" %ld %s"), nproto, makeplural(M_("facet"), nproto));
 			addstringtoinfstr(infstr, line);
 		}
 		if (object != 0)
 		{
-			(void)sprintf(line, " %ld %s", object, makeplural(M_("object"), object));
+			(void)esnprintf(line, 50, x_(" %ld %s"), object, makeplural(M_("object"), object));
 			addstringtoinfstr(infstr, line);
 		}
 		if (variable != 0)
 		{
-			(void)sprintf(line, " %ld %s", variable, makeplural(M_("variable"), variable));
+			(void)esnprintf(line, 50, x_(" %ld %s"), variable, makeplural(M_("variable"), variable));
 			addstringtoinfstr(infstr, line);
 		}
-		ttyputmsg("%s", returninfstr(infstr));
+		ttyputmsg(x_("%s"), returninfstr(infstr));
 	}
 }
 
-char *db_describechange(INTBIG changetype, INTBIG entryaddr, INTBIG p1, INTBIG p2,
+CHAR *db_describechange(INTBIG changetype, INTBIG entryaddr, INTBIG p1, INTBIG p2,
 	INTBIG p3, INTBIG p4, INTBIG p5, INTBIG p6)
 {
 	REGISTER NODEINST *ni;
@@ -1448,7 +1448,7 @@ char *db_describechange(INTBIG changetype, INTBIG entryaddr, INTBIG p1, INTBIG p
 				describenodeinst(ni), describenodeproto(ni->parent), latoa(p3-p1, lambda),
 				latoa(p4-p2, lambda), latoa((p1+p3)/2, lambda), latoa((p2+p4)/2, lambda), p5);
 			if (p6 != 0) addstringtoinfstr(infstr, M_(", transposed"));
-			addstringtoinfstr(infstr, "]");
+			addstringtoinfstr(infstr, x_("]"));
 			return(returninfstr(infstr));
 		case ARCINSTNEW:
 			ai = (ARCINST *)entryaddr;
@@ -1570,24 +1570,24 @@ char *db_describechange(INTBIG changetype, INTBIG entryaddr, INTBIG p1, INTBIG p
 				makename(p2), p4, p5);
 			return(returninfstr(infstr));
 	}
-	return("?");
+	return(x_("?"));
 }
 
 /* Undo dialog */
 static DIALOGITEM db_undodialogitems[] =
 {
  /*  1 */ {0, {468,608,492,680}, BUTTON, N_("OK")},
- /*  2 */ {0, {468,16,492,88}, BUTTON, N_("Undo")},
- /*  3 */ {0, {32,8,455,690}, SCROLL, ""},
+ /*  2 */ {0, {32,8,455,690}, SCROLL, x_("")},
+ /*  3 */ {0, {468,16,492,88}, BUTTON, N_("Undo")},
  /*  4 */ {0, {8,8,24,241}, MESSAGE, N_("These are the recent changes:")},
  /*  5 */ {0, {8,344,24,456}, CHECK, N_("Show details")},
  /*  6 */ {0, {468,108,492,180}, BUTTON, N_("Redo")}
 };
-static DIALOG db_undodialog = {{50,75,555,774}, N_("Change History"), 0, 6, db_undodialogitems, 0, 0};
+static DIALOG db_undodialog = {{50,75,555,775}, N_("Change History"), 0, 6, db_undodialogitems, 0, 0};
 
 /* special items in the "undo" dialog: */
-#define DUND_UNDO      2		/* Undo (button) */
-#define DUND_CHGLIST   3		/* Change list (scroll) */
+#define DUND_CHGLIST   2		/* Change list (scroll) */
+#define DUND_UNDO      3		/* Undo (button) */
 #define DUND_DETAILS   5		/* Show detail (check box) */
 #define DUND_REDO      6		/* Redo (button) */
 
@@ -1644,7 +1644,7 @@ void db_loadhistorylist(INTBIG details, void *dia)
 {
 	REGISTER INTBIG node, arcinst, portproto, nproto, object, variable, lineno, curline;
 	REGISTER CHANGE *c;
-	char line[50];
+	CHAR line[50];
 	CHANGEBATCH *batch;
 	REGISTER void *infstr;
 
@@ -1693,39 +1693,39 @@ void db_loadhistorylist(INTBIG details, void *dia)
 
 		infstr = initinfstr();
 		if (details != 0) addstringtoinfstr(infstr, M_("***** BATCH "));
-		(void)sprintf(line, "%ld {", batch->batchnumber);
+		(void)esnprintf(line, 50, x_("%ld {"), batch->batchnumber);
 		addstringtoinfstr(infstr, line);
 		if (batch->activity != 0) addstringtoinfstr(infstr, batch->activity);
 		addstringtoinfstr(infstr, M_("} affects"));
 
 		if (node != 0)
 		{
-			(void)sprintf(line, " %ld %s", node, makeplural(M_("node"), node));
+			(void)esnprintf(line, 50, x_(" %ld %s"), node, makeplural(M_("node"), node));
 			addstringtoinfstr(infstr, line);
 		}
 		if (arcinst != 0)
 		{
-			(void)sprintf(line, " %ld %s", arcinst, makeplural(M_("arc"), arcinst));
+			(void)esnprintf(line, 50, x_(" %ld %s"), arcinst, makeplural(M_("arc"), arcinst));
 			addstringtoinfstr(infstr, line);
 		}
 		if (portproto != 0)
 		{
-			(void)sprintf(line, " %ld %s", portproto, makeplural(M_("port"), portproto));
+			(void)esnprintf(line, 50, x_(" %ld %s"), portproto, makeplural(M_("port"), portproto));
 			addstringtoinfstr(infstr, line);
 		}
 		if (nproto != 0)
 		{
-			(void)sprintf(line, " %ld %s", nproto, makeplural(M_("facet"), nproto));
+			(void)esnprintf(line, 50, x_(" %ld %s"), nproto, makeplural(M_("facet"), nproto));
 			addstringtoinfstr(infstr, line);
 		}
 		if (object != 0)
 		{
-			(void)sprintf(line, " %ld %s", object, makeplural(M_("object"), object));
+			(void)esnprintf(line, 50, x_(" %ld %s"), object, makeplural(M_("object"), object));
 			addstringtoinfstr(infstr, line);
 		}
 		if (variable != 0)
 		{
-			(void)sprintf(line, " %ld %s", variable, makeplural(M_("variable"), variable));
+			(void)esnprintf(line, 50, x_(" %ld %s"), variable, makeplural(M_("variable"), variable));
 			addstringtoinfstr(infstr, line);
 		}
 		DiaStuffLine(dia, DUND_CHGLIST, returninfstr(infstr));
