@@ -427,10 +427,10 @@ void killcontour(CONTOUR *con)
 	for(conel = con->firstcontourelement; conel != NOCONTOURELEMENT; conel = nextconel)
 	{
 		nextconel = conel->nextcontourelement;
-		efree((char *)conel);
+		efree((CHAR *)conel);
 	}
-	if (con->childtotal > 0) efree((char *)con->children);
-	efree((char *)con);
+	if (con->childtotal > 0) efree((CHAR *)con->children);
+	efree((CHAR *)con);
 }
 
 /******************************** ARC SEGMENT GENERATION ********************************/
@@ -445,10 +445,10 @@ void db_getcontoursegmentparameters(void)
 {
 	REGISTER VARIABLE *var;
 
-	var = getval((INTBIG)io_tool, VTOOL, VINTEGER, "IO_curve_resolution");
+	var = getval((INTBIG)io_tool, VTOOL, VINTEGER, x_("IO_curve_resolution"));
 	if (var == NOVARIABLE) db_arcres = DEFARCRES; else
 		db_arcres = var->addr;
-	var = getval((INTBIG)io_tool, VTOOL, VINTEGER, "IO_curve_sag");
+	var = getval((INTBIG)io_tool, VTOOL, VINTEGER, x_("IO_curve_sag"));
 	if (var == NOVARIABLE) db_arcsag = scalefromdispunit(0.0005f, DISPUNITMM); else
 		db_arcsag = var->addr;
 }
@@ -475,8 +475,8 @@ void setcontoursegmentparameters(INTBIG arcres, INTBIG arcsag)
 	db_arcres = arcres;
 	db_arcsag = arcsag;
 
-	(void)setval((INTBIG)io_tool, VTOOL, "IO_curve_resolution", arcres, VINTEGER);
-	(void)setval((INTBIG)io_tool, VTOOL, "IO_curve_sag", arcsag, VINTEGER);
+	(void)setval((INTBIG)io_tool, VTOOL, x_("IO_curve_resolution"), arcres, VINTEGER);
+	(void)setval((INTBIG)io_tool, VTOOL, x_("IO_curve_sag"), arcsag, VINTEGER);
 }
 
 /*
