@@ -66,7 +66,7 @@ NODEINST *allocnodeinst(CLUSTER *cluster)
 	defaulttextsize(5, ni->textdescript);
 	TDSETPOS(ni->textdescript, VTPOSBOXED);
 	ni->arraysize = 0;
-	ni->changeaddr = (char *)NOCHANGE;
+	ni->changeaddr = (CHAR *)NOCHANGE;
 	ni->changed = 0;
 	ni->userbits = ni->temp1 = ni->temp2 = 0;
 	ni->firstvar = NOVARIABLE;
@@ -81,7 +81,7 @@ void freenodeinst(NODEINST *ni)
 {
 	if (ni == NONODEINST) return;
 	if (ni->numvar != 0) db_freevars(&ni->firstvar, &ni->numvar);
-	efree((char *)ni);
+	efree((CHAR *)ni);
 }
 
 void startobjectchange(INTBIG addr, INTBIG type)
@@ -189,7 +189,7 @@ NODEINST *db_newnodeinst(NODEPROTO *np, INTBIG lx, INTBIG hx, INTBIG ly, INTBIG
 		db_setchangefacet(parnt);
 
 		/* tell all tools about this nodeinst */
-		ni->changeaddr = (char *)db_change((INTBIG)ni, NODEINSTNEW, 0, 0, 0, 0, 0, 0);
+		ni->changeaddr = (CHAR *)db_change((INTBIG)ni, NODEINSTNEW, 0, 0, 0, 0, 0, 0);
 
 		/* tell constraint system about new node */
 		(*el_curconstraint->newobject)((INTBIG)ni, VNODEINST);
@@ -285,7 +285,7 @@ void db_killnodeinst(NODEINST *ni)
 		db_setchangefacet(ni->parent);
 
 		/* tell all tools about this nodeinst */
-		ni->changeaddr = (char *)db_change((INTBIG)ni, NODEINSTKILL, 0, 0, 0, 0, 0, 0);
+		ni->changeaddr = (CHAR *)db_change((INTBIG)ni, NODEINSTKILL, 0, 0, 0, 0, 0, 0);
 
 		/* tell constraint system about killed node */
 		(*el_curconstraint->killobject)((INTBIG)ni, VNODEINST);
@@ -490,7 +490,7 @@ void db_freearcproto(ARCPROTO *ap)
 {
 	if (ap == NOARCPROTO) return;
 	if (ap->numvar != 0) db_freevars(&ap->firstvar, &ap->numvar);
-	efree((char *)ap);
+	efree((CHAR *)ap);
 }
 
 /*
@@ -501,11 +501,11 @@ void db_freearcproto(ARCPROTO *ap)
  * prototype has successfully been created.  It returns NOARCPROTO if the arc
  * prototype cannot be created.
  */
-ARCPROTO *db_newarcproto(TECHNOLOGY *tech, char *name, INTBIG nomwidth, INTBIG ind)
+ARCPROTO *db_newarcproto(TECHNOLOGY *tech, CHAR *name, INTBIG nomwidth, INTBIG ind)
 {
 	REGISTER ARCPROTO *ap;
 	REGISTER ARCPROTO *lat, *tat;
-	REGISTER char *pp;
+	REGISTER CHAR *pp;
 
 	/* make sure name is valid */
 	for(pp = name; *pp != 0; pp++) if (*pp <= ' ' || *pp >= 0177) return(NOARCPROTO);
@@ -536,7 +536,7 @@ ARCINST *allocarcinst(CLUSTER *cluster)
 
 	ai = (ARCINST *)emalloc((sizeof (ARCINST)), cluster);
 	if (ai == 0) return(NOARCINST);
-	ai->changed = 0;   ai->changeaddr = (char *)NOCHANGE;
+	ai->changed = 0;   ai->changeaddr = (CHAR *)NOCHANGE;
 	ai->userbits = ai->temp1 = ai->temp2 = 0;
 	ai->numvar = 0;
 	ai->network = NONETWORK;
@@ -563,7 +563,7 @@ void freearcinst(ARCINST *ai)
 {
 	if (ai == NOARCINST) return;
 	if (ai->numvar != 0) db_freevars(&ai->firstvar, &ai->numvar);
-	efree((char *)ai);
+	efree((CHAR *)ai);
 }
 
 /*
@@ -591,7 +591,7 @@ void freeportarcinst(PORTARCINST *pi)
 {
 	if (pi == NOPORTARCINST) return;
 	if (pi->numvar != 0) db_freevars(&pi->firstvar, &pi->numvar);
-	efree((char *)pi);
+	efree((CHAR *)pi);
 }
 
 /*
@@ -793,7 +793,7 @@ ARCINST *db_newarcinst(ARCPROTO *typ, INTBIG wid, INTBIG initialbits, NODEINST *
 		db_setchangefacet(parnt);
 
 		/* tell all tools about this arcinst */
-		ai->changeaddr = (char *)db_change((INTBIG)ai, ARCINSTNEW, 0, 0, 0, 0, 0, 0);
+		ai->changeaddr = (CHAR *)db_change((INTBIG)ai, ARCINSTNEW, 0, 0, 0, 0, 0, 0);
 
 		/* tell constraint system about new arc */
 		(*el_curconstraint->newobject)((INTBIG)ai, VARCINST);
@@ -929,7 +929,7 @@ void db_killarcinst(ARCINST *ai)
 		db_setchangefacet(ai->parent);
 
 		/* tell all tools about this arcinst */
-		ai->changeaddr = (char *)db_change((INTBIG)ai, ARCINSTKILL, 0, 0, 0, 0, 0, 0);
+		ai->changeaddr = (CHAR *)db_change((INTBIG)ai, ARCINSTKILL, 0, 0, 0, 0, 0, 0);
 
 		/* tell constraint system about killed arc */
 		(*el_curconstraint->killobject)((INTBIG)ai, VARCINST);
@@ -1072,7 +1072,7 @@ BOOLEAN modifyarcinst(ARCINST *ai, INTBIG deltawid, INTBIG deltax1, INTBIG delta
 	if (!db_donextchangequietly && !db_dochangesquietly)
 	{
 		/* tell all tools about this arcinst */
-		ai->changeaddr = (char *)db_change((INTBIG)ai, ARCINSTMOD, oldx0, oldy0, oldx1, oldy1,
+		ai->changeaddr = (CHAR *)db_change((INTBIG)ai, ARCINSTMOD, oldx0, oldy0, oldx1, oldy1,
 			oldwid, oldlen);
 
 		/* tell constraint system about modified arc */
@@ -1288,8 +1288,8 @@ PORTPROTO *allocportproto(CLUSTER *cluster)
 	pp->network = NONETWORK;
 	pp->connects = 0;
 	pp->numvar = 0;
-	pp->changeaddr = (char *)NOCHANGE;
-	pp->protoname = (char *)-1;
+	pp->changeaddr = (CHAR *)NOCHANGE;
+	pp->protoname = (CHAR *)-1;
 	pp->firstvar = NOVARIABLE;
 	pp->nextportproto = NOPORTPROTO;
 	pp->parent = NONODEPROTO;
@@ -1310,7 +1310,7 @@ void freeportproto(PORTPROTO *pp)
 {
 	if (pp == NOPORTPROTO) return;
 	if (pp->numvar != 0) db_freevars(&pp->firstvar, &pp->numvar);
-	efree((char *)pp);
+	efree((CHAR *)pp);
 }
 
 /*
@@ -1338,7 +1338,7 @@ void freeportexpinst(PORTEXPINST *pe)
 {
 	if (pe == NOPORTEXPINST) return;
 	if (pe->numvar != 0) db_freevars(&pe->firstvar, &pe->numvar);
-	efree((char *)pe);
+	efree((CHAR *)pe);
 }
 
 /*
@@ -1350,10 +1350,10 @@ void freeportexpinst(PORTEXPINST *pe)
  * if the portproto cannot be created.
  */
 PORTPROTO *newportproto(NODEPROTO *np, NODEINST *nodeinst, PORTPROTO *portaddress,
-	char *name)
+	CHAR *name)
 {
 	REGISTER PORTPROTO *pp;
-	REGISTER char *ptr;
+	REGISTER CHAR *ptr;
 
 	/* error checks */
 	if (np == NONODEPROTO)
@@ -1397,7 +1397,7 @@ PORTPROTO *newportproto(NODEPROTO *np, NODEINST *nodeinst, PORTPROTO *portaddres
  * upon error
  */
 PORTPROTO *db_newportproto(NODEPROTO *np, NODEINST *nodeinst, PORTPROTO *portaddress,
-	char *name)
+	CHAR *name)
 {
 	REGISTER PORTPROTO *pp;
 
@@ -1434,7 +1434,7 @@ PORTPROTO *db_newportproto(NODEPROTO *np, NODEINST *nodeinst, PORTPROTO *portadd
 		db_setchangefacet(np);
 
 		/* announce it */
-		pp->changeaddr = (char *)db_change((INTBIG)pp, PORTPROTONEW, 0, 0, 0, 0, 0, 0);
+		pp->changeaddr = (CHAR *)db_change((INTBIG)pp, PORTPROTONEW, 0, 0, 0, 0, 0, 0);
 
 		/* tell constraint system about new port */
 		(*el_curconstraint->newobject)((INTBIG)pp, VPORTPROTO);
@@ -1544,11 +1544,11 @@ void db_addportexpinst(NODEINST *ni, PORTEXPINST *npe)
  * The name of the portproto is in "name".  The routine returns the address of
  * the portproto if sucessful, NOPORTPROTO if the portproto cannot be created.
  */
-PORTPROTO *db_newprimportproto(NODEPROTO *np, ARCPROTO **arcs, char *name)
+PORTPROTO *db_newprimportproto(NODEPROTO *np, ARCPROTO **arcs, CHAR *name)
 {
 	REGISTER PORTPROTO *last;
 	REGISTER PORTPROTO *pp;
-	REGISTER char *ptr;
+	REGISTER CHAR *ptr;
 
 	/* error checks */
 	if (np == NONODEPROTO) return(NOPORTPROTO);
@@ -1663,7 +1663,7 @@ void db_killportproto(PORTPROTO *pp)
 		db_setchangefacet(np);
 
 		/* report the change */
-		pp->changeaddr = (char *)db_change((INTBIG)pp, PORTPROTOKILL, 0, 0, 0, 0, 0, 0);
+		pp->changeaddr = (CHAR *)db_change((INTBIG)pp, PORTPROTOKILL, 0, 0, 0, 0, 0, 0);
 
 		/* tell constraint system about killed port */
 		(*el_curconstraint->killobject)((INTBIG)pp, VPORTPROTO);
@@ -1687,7 +1687,7 @@ void db_retractportproto(PORTPROTO *pp)
 	/* remove the portproto from the list */
 	lpo = NOPORTPROTO;
 	np = pp->parent;
-	for(ppo=np->firstportproto; ppo != NOPORTPROTO; ppo = ppo->nextportproto)
+	for(ppo = np->firstportproto; ppo != NOPORTPROTO; ppo = ppo->nextportproto)
 	{
 		if (ppo == pp)
 		{
@@ -1748,7 +1748,7 @@ void db_buildportprotohashtable(NODEPROTO *facet)
 	if (facet->portprotohashtablesize > 0)
 	{
 		facet->portprotohashtablesize = 0;
-		efree((char *)facet->portprotohashtable);
+		efree((CHAR *)facet->portprotohashtable);
 	}
 
 	/* determine the size of the hash table */
