@@ -33,10 +33,12 @@
 #include "database.h"
 #include "usr.h"
 
+#define	NEWERRORS 1		/* uncomment to remove newly added code */
+
 INTBIG  db_lasterror;			/* last error message */
 BOOLEAN db_printerrors;			/* flag for printing internal errors */
 
-static char *db_errortype[] =
+static CHAR *db_errortype[] =
 {
 	N_("no error"),								/* DBNOERROR */
 	N_("no memory"),							/* DBNOMEM */
@@ -80,58 +82,58 @@ static char *db_errortype[] =
 /*
  * database error routine codes
  */
-static char *db_routines[] =
+static CHAR *db_routines[] =
 {
-	"addstringtoinfstr",	/*  1 */
-	"addtechnology",		/*  2 */
-	"addtoinfstr",			/*  3 */
-	"allocarcinst",			/*  4 */
-	"alloccell",			/*  5 */
-	"allocgeom",			/*  6 */
-	"alloclibrary",			/*  7 */
-	"allocnodeinst",		/*  8 */
-	"allocnodeproto",		/*  9 */
-	"allocpolygon",			/* 10 */
-	"allocportarcinst",		/* 11 */
-	"allocportexpinst",		/* 12 */
-	"allocportproto",		/* 13 */
-	"allocstring",			/* 14 */
-	"alloctechnology",		/* 15 */
-	"allocview",			/* 16 */
-	"copynodeproto",		/* 17 */
-	"delind",				/* 18 */
-	"delindkey",			/* 19 */
-	"delvalkey",			/* 20 */
-	"describevariable",		/* 21 */
-	"extendpolygon",		/* 22 */
-	"initinfstr",			/* 23 */
-	"initobjlist",			/* 24 */
-	"insind",				/* 25 */
-	"insindkey",			/* 26 */
-	"killarcinst",			/* 27 */
-	"killlibrary",			/* 28 */
-	"killnodeinst",			/* 29 */
-	"killnodeproto",		/* 30 */
-	"killportproto",		/* 31 */
-	"killtechnology",		/* 32 */
-	"makekey",				/* 33 */
-	"modifyarcinst",		/* 34 */
-	"moveportproto",		/* 35 */
-	"newarcinst",			/* 36 */
-	"newlibrary",			/* 37 */
-	"newnodeinst",			/* 38 */
-	"newnodeproto",			/* 39 */
-	"newportproto",			/* 40 */
-	"newview",				/* 41 */
-	"replacearcinst",		/* 42 */
-	"replacenodeinst",		/* 43 */
-	"returninfstr",			/* 44 */
-	"setind",				/* 45 */
-	"setindkey",			/* 46 */
-	"setval",				/* 47 */
-	"setvalkey",			/* 48 */
-	"transmult",			/* 49 */
-	"xform",				/* 50 */
+	x_("addstringtoinfstr"),	/*  1 */
+	x_("addtechnology"),		/*  2 */
+	x_("addtoinfstr"),			/*  3 */
+	x_("allocarcinst"),			/*  4 */
+	x_("alloccell"),			/*  5 */
+	x_("allocgeom"),			/*  6 */
+	x_("alloclibrary"),			/*  7 */
+	x_("allocnodeinst"),		/*  8 */
+	x_("allocnodeproto"),		/*  9 */
+	x_("allocpolygon"),			/* 10 */
+	x_("allocportarcinst"),		/* 11 */
+	x_("allocportexpinst"),		/* 12 */
+	x_("allocportproto"),		/* 13 */
+	x_("allocstring"),			/* 14 */
+	x_("alloctechnology"),		/* 15 */
+	x_("allocview"),			/* 16 */
+	x_("copynodeproto"),		/* 17 */
+	x_("delind"),				/* 18 */
+	x_("delindkey"),			/* 19 */
+	x_("delvalkey"),			/* 20 */
+	x_("describevariable"),		/* 21 */
+	x_("extendpolygon"),		/* 22 */
+	x_("initinfstr"),			/* 23 */
+	x_("initobjlist"),			/* 24 */
+	x_("insind"),				/* 25 */
+	x_("insindkey"),			/* 26 */
+	x_("killarcinst"),			/* 27 */
+	x_("killlibrary"),			/* 28 */
+	x_("killnodeinst"),			/* 29 */
+	x_("killnodeproto"),		/* 30 */
+	x_("killportproto"),		/* 31 */
+	x_("killtechnology"),		/* 32 */
+	x_("makekey"),				/* 33 */
+	x_("modifyarcinst"),		/* 34 */
+	x_("moveportproto"),		/* 35 */
+	x_("newarcinst"),			/* 36 */
+	x_("newlibrary"),			/* 37 */
+	x_("newnodeinst"),			/* 38 */
+	x_("newnodeproto"),			/* 39 */
+	x_("newportproto"),			/* 40 */
+	x_("newview"),				/* 41 */
+	x_("replacearcinst"),		/* 42 */
+	x_("replacenodeinst"),		/* 43 */
+	x_("returninfstr"),			/* 44 */
+	x_("setind"),				/* 45 */
+	x_("setindkey"),			/* 46 */
+	x_("setval"),				/* 47 */
+	x_("setvalkey"),			/* 48 */
+	x_("transmult"),			/* 49 */
+	x_("xform"),				/* 50 */
 };
 
 /*
@@ -154,15 +156,15 @@ void telldatabaseerror(void)
 	routine = (db_lasterror >> 16) - 1;
 	error = db_lasterror & 0xFFFF;
 	if (error == DBNOERROR) ttyputmsg(_("No error")); else
-		ttyputmsg("%s: %s", db_routines[routine], _(db_errortype[error]));
+		ttyputmsg(x_("%s: %s"), db_routines[routine], TRANSLATE(db_errortype[error]));
 }
 
 /******************** ERROR REPORTING ********************/
 
 /*
  * These are the routines to log errors:
- *   initerrorlogging(char *s)                   initialize for subsystem "s"
- *   e = logerror(char *msg, NODEPROTO *f, k)    log message "msg" in facet "f", sort key "k"
+ *   initerrorlogging(CHAR *s)                   initialize for subsystem "s"
+ *   e = logerror(CHAR *msg, NODEPROTO *f, k)    log message "msg" in facet "f", sort key "k"
  *   addgeomtoerror(void *e, GEOM *g, BOOLEAN s, INTBIG l, NODEINST **p)
  *                                               add geom "g" to error "e" (show if "s" nonzero)
  *   addexporttoerror(void *e, PORTPROTO *p, BOOLEAN s)  add export "pp" to error "e"
@@ -209,7 +211,7 @@ typedef struct
 
 typedef struct iErrorList
 {
-	char              *message;
+	CHAR              *message;
 	NODEPROTO         *facet;
 	INTBIG             sortkey;
 	INTBIG             index;
@@ -225,7 +227,7 @@ static ERRORLIST *db_curerrorlist = NOERRORLIST;
 static ERRORLIST *db_nexterrorlist = NOERRORLIST;
 static ERRORLIST *db_preverrorlist = NOERRORLIST;
 
-static char       db_errorsystem[100] = "";
+static CHAR       db_errorsystem[100] = {0};
 static INTBIG     db_numerrors;
 static INTBIG     db_truenumerrors;
 static INTBIG     db_maxerrors = 0;
@@ -234,8 +236,11 @@ static void     (*db_errorchangedroutine)(void) = 0;
 
 static BOOLEAN db_addtoerrorlist(ERRORLIST *el, ERRORHIGHLIGHT *eh);
 static int     db_errorlistascending(const void *e1, const void *e2);
-static char   *db_reportcurrenterror(INTBIG showhigh, GEOM **g1, GEOM **g2);
+static CHAR   *db_reportcurrenterror(INTBIG showhigh, GEOM **g1, GEOM **g2);
 static void    db_clearerrorlist(void);
+#ifdef	NEWERRORS
+static BOOLEAN db_validatefacet(NODEPROTO *facet);
+#endif
 
 /*
  * Routine to free memory associated with this module.
@@ -252,7 +257,7 @@ void db_freeerrormemory(void)
 	{
 		el = db_errorlistfree;
 		db_errorlistfree = el->nexterrorlist;
-		efree((char *)el);
+		efree((CHAR *)el);
 	}
 }
 
@@ -261,7 +266,7 @@ void db_freeerrormemory(void)
  * The errors are described by "system" and up to two facets "facet1" and
  * "facet2" (may be NONODEPROTO).
  */
-void initerrorlogging(char *system)
+void initerrorlogging(CHAR *system)
 {
 	REGISTER VARIABLE *var;
 
@@ -272,9 +277,9 @@ void initerrorlogging(char *system)
 	db_curerrorlist = NOERRORLIST;
 	db_nexterrorlist = NOERRORLIST;
 	db_preverrorlist = NOERRORLIST;
-	strncpy(db_errorsystem, system, 100);
+	estrncpy(db_errorsystem, system, 100);
 	db_numerrors = db_truenumerrors = 0;
-	var = getval((INTBIG)us_tool, VTOOL, VINTEGER, "USER_maximum_errors");
+	var = getval((INTBIG)us_tool, VTOOL, VINTEGER, x_("USER_maximum_errors"));
 	if (var == NOVARIABLE) db_maxerrors = 0; else
 		db_maxerrors = var->addr;
 	if (ensurevalidmutex(&db_errorreportmutex, TRUE)) return;
@@ -303,10 +308,10 @@ void db_clearerrorlist(void)
 		for(i=0; i<el->numhighlights; i++)
 		{
 			eh = el->highlights[i];
-			if (eh->pathlen > 0) efree((char *)eh->path);
-			efree((char *)eh);
+			if (eh->pathlen > 0) efree((CHAR *)eh->path);
+			efree((CHAR *)eh);
 		}
-		if (el->numhighlights > 0) efree((char *)el->highlights);
+		if (el->numhighlights > 0) efree((CHAR *)el->highlights);
 
 		/* place the module on the free list */
 		el->nexterrorlist = db_errorlistfree;
@@ -318,7 +323,7 @@ void db_clearerrorlist(void)
  * Routine to create an error message with the text "message" applying to facet "facet".
  * Returns a pointer to the message (0 on error) which can be used to add highlights.
  */
-void *logerror(char *message, NODEPROTO *facet, INTBIG sortkey)
+void *logerror(CHAR *message, NODEPROTO *facet, INTBIG sortkey)
 {
 	REGISTER ERRORLIST *el;
 
@@ -541,10 +546,10 @@ void sorterrors(void)
 			el->nexterrorlist = NOERRORLIST;
 	}
 	db_firsterrorlist = sortedlist[0];
-	efree((char *)sortedlist);
+	efree((CHAR *)sortedlist);
 }
 
-#if 0
+#if 0		/* cannot save errors to file yet */
 static void    db_describenodetoerrorfile(FILE *io, NODEINST *ni);
 
 /*
@@ -556,43 +561,43 @@ void saveerrors(void)
 	REGISTER ERRORHIGHLIGHT *eh;
 	FILE *io;
 
-	io = fopen("errors.txt", "w");
+	io = efopen(x_("errors.txt"), x_("w"));
 	if (io == 0) return;
 	for(el = db_firsterrorlist; el != NOERRORLIST; el = el->nexterrorlist)
 	{
-		fprintf(io, "ERROR %ld %s %s\n", el->numhighlights, describenodeproto(el->facet), el->message);
+		efprintf(io, x_("ERROR %ld %s %s\n"), el->numhighlights, describenodeproto(el->facet), el->message);
 		for(i=0; i<el->numhighlights; i++)
 		{
 			eh = el->highlights[i];
 			switch (eh->type)
 			{
 				case ERRORTYPEGEOM:
-					fprintf(io, "  GEOM");
+					efprintf(io, x_("  GEOM"));
 					if (eh->geom->entryisnode)
 					{
-						fprintf(io, " NODE");
+						efprintf(io, x_(" NODE"));
 						ni = eh->geom->entryaddr.ni;
 						db_describenodetoerrorfile(io, ni);
 					} else
 					{
 						ai = eh->geom->entryaddr.ai;
 						var = getvalkey((INTBIG)ai, VARCINST, -1, el_arc_name_key);
-						if (var != NOVARIABLE) fprintf(io, "ARC NAME %s", (char *)var->addr); else
+						if (var != NOVARIABLE) efprintf(io, x_("ARC NAME %s"), (CHAR *)var->addr); else
 						{
-							fprintf(io, "ARC TYPE %s WIDTH %s AT %s %s %s %s", ai->proto->protoname,
+							efprintf(io, x_("ARC TYPE %s WIDTH %s AT %s %s %s %s"), ai->proto->protoname,
 								ai->width, ai->end[0].xpos, ai->end[0].ypos, ai->end[1].xpos,
 									ai->end[1].ypos);
 						}
 					}
-					if (eh->showgeom) fprintf(io, " SHOW"); else fprintf(io, " NOSHOW");
-					fprintf(io, " PATH %ld", eh->pathlen);
+					if (eh->showgeom) efprintf(io, x_(" SHOW")); else efprintf(io, x_(" NOSHOW"));
+					efprintf(io, x_(" PATH %ld"), eh->pathlen);
 					for(j=0; j<eh->pathlen; j++)
 					{
 						ni = el->path[j];
-						fprintf(io, " %s", describenodeproto(ni->parent));
+						efprintf(io, x_(" %s"), describenodeproto(ni->parent));
 						db_describenodetoerrorfile(io, ni);
 					}
-					fprintf(io, "\n");
+					efprintf(io, x_("\n"));
 					break;
 			}
 		}
@@ -604,9 +609,9 @@ void db_describenodetoerrorfile(FILE *io, NODEINST *ni)
 	REGISTER VARIABLE *var;
 
 	var = getvalkey((INTBIG)ni, VNODEINST, -1, el_node_name_key);
-	if (var != NOVARIABLE) fprintf(io, " NAME %s", (char *)var->addr); else
+	if (var != NOVARIABLE) efprintf(io, x_(" NAME %s"), (CHAR *)var->addr); else
 	{
-		fprintf(io, " TYPE %s AT %ld %ld %ld %ld", describenodeproto(ni->proto),
+		efprintf(io, x_(" TYPE %s AT %ld %ld %ld %ld"), describenodeproto(ni->proto),
 			ni->lowx, ni->highx, ni->lowy, ni->highy);
 	}
 }
@@ -623,7 +628,7 @@ INTBIG numerrors(void)
 /*
  * Routine to advance to the next error and report it.
  */
-char *reportnexterror(INTBIG showhigh, GEOM **g1, GEOM **g2)
+CHAR *reportnexterror(INTBIG showhigh, GEOM **g1, GEOM **g2)
 {
 	if (db_nexterrorlist != NOERRORLIST)
 	{
@@ -644,7 +649,7 @@ char *reportnexterror(INTBIG showhigh, GEOM **g1, GEOM **g2)
 /*
  * Routine to back up to the previous error and report it.
  */
-char *reportpreverror(void)
+CHAR *reportpreverror(void)
 {
 	REGISTER ERRORLIST *el;
 
@@ -732,7 +737,7 @@ void *geterrorgeom(void *elv, INTBIG index)
 /*
  * Routine to describe an object on an error.  The object is "ehv".
  */
-char *describeerrorgeom(void *ehv)
+CHAR *describeerrorgeom(void *ehv)
 {
 	REGISTER ERRORHIGHLIGHT *eh;
 	REGISTER GEOM *geom;
@@ -740,7 +745,7 @@ char *describeerrorgeom(void *ehv)
 	REGISTER INTBIG i;
 	REGISTER NODEINST *ni;
 
-	if (ehv == 0) return("");
+	if (ehv == 0) return(x_(""));
 	eh = (ERRORHIGHLIGHT *)ehv;
 	geom = eh->geom;
 	infstr = initinfstr();
@@ -777,13 +782,13 @@ void showerrorgeom(void *ehv)
 	{
 		el_curwindowpart = us_wantnewwindow(0);
 		us_fullview(np, &lx, &hx, &ly, &hy);
-		us_switchtofacet(np, lx, hx, ly, hy, NONODEINST, NOPORTPROTO, FALSE, 0);
+		us_switchtofacet(np, lx, hx, ly, hy, NONODEINST, NOPORTPROTO, FALSE, FALSE, FALSE);
 	}
-	(void)asktool(us_tool, "show-object", (INTBIG)geom);
+	(void)asktool(us_tool, x_("show-object"), (INTBIG)geom);
 
 	for(i=eh->pathlen-1; i>=0; i--)
 	{
-		sethierarchicalparent(np, eh->path[i]);
+		sethierarchicalparent(np, eh->path[i], NOWINDOWPART, 0);
 		np = eh->path[i]->parent;
 	}
 }
@@ -791,11 +796,11 @@ void showerrorgeom(void *ehv)
 /*
  * Routine to describe error "elv".
  */
-char *describeerror(void *elv)
+CHAR *describeerror(void *elv)
 {
 	REGISTER ERRORLIST *el;
 
-	if (elv == 0) return("");
+	if (elv == 0) return(x_(""));
 	el = (ERRORLIST *)elv;
 	return(el->message);
 }
@@ -841,7 +846,7 @@ BOOLEAN db_addtoerrorlist(ERRORLIST *el, ERRORHIGHLIGHT *eh)
 	for(i=0; i<el->numhighlights; i++)
 		neweh[i] = el->highlights[i];
 	neweh[el->numhighlights] = eh;
-	if (el->numhighlights > 0) efree((char *)el->highlights);
+	if (el->numhighlights > 0) efree((CHAR *)el->highlights);
 	el->highlights = neweh;
 	el->numhighlights++;
 	return(FALSE);
@@ -866,13 +871,15 @@ int db_errorlistascending(const void *e1, const void *e2)
  */
 #define MAXFACETS 20
 
-char *db_reportcurrenterror(INTBIG showhigh, GEOM **g1, GEOM **g2)
+CHAR *db_reportcurrenterror(INTBIG showhigh, GEOM **g1, GEOM **g2)
 {
 	REGISTER ERRORLIST *el;
-	REGISTER NODEPROTO *facet, *np;
+	REGISTER NODEPROTO *facet;
+	REGISTER PORTPROTO *pp;
 	NODEPROTO *facetlist[MAXFACETS];
 	REGISTER INTBIG i, j, consize, numfacets, havegeoms, newwindows, count, hierpathcount;
-	REGISTER NODEINST **hierpath;
+	REGISTER NODEINST **hierpath, *ni;
+	REGISTER ARCINST *ai;
 	INTBIG lx, hx, ly, hy;
 	REGISTER ERRORHIGHLIGHT *eh;
 	REGISTER GEOM *geom1, *geom2;
@@ -891,19 +898,80 @@ char *db_reportcurrenterror(INTBIG showhigh, GEOM **g1, GEOM **g2)
 	/* turn off highlighting */
 	if (showhigh != 0)
 	{
-		(void)asktool(us_tool, "clear");
+		(void)asktool(us_tool, x_("clear"));
+
+		/* validate the facet (it may have been deleted) */
+		facet = el->facet;
+#ifdef	NEWERRORS
+		if (facet != NONODEPROTO)
+		{
+			if (!db_validatefacet(facet))
+			{
+				infstr = initinfstr();
+				formatinfstr(infstr, _("%s error %ld of %ld (but facet is deleted): %s"), db_errorsystem,
+					el->index, db_numerrors, el->message);
+				return(returninfstr(infstr));
+			}
+		}
+#else
+		{
+			REGISTER NODEPROTO *np;
+			REGISTER LIBRARY *lib;
+			for(lib = el_curlib; lib != NOLIBRARY; lib = lib->nextlibrary)
+			{
+				for(np = lib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
+					if (np == facet) break;
+				if (np != NONODEPROTO) break;
+			}
+			if (lib == NOLIBRARY)
+			{
+				infstr = initinfstr();
+				formatinfstr(infstr, _("%s error %ld of %ld (but facet is deleted): %s"), db_errorsystem,
+					el->index, db_numerrors, el->message);
+				return(returninfstr(infstr));
+			}
+		}
+#endif
 
 		/* first figure out which facets need to be displayed */
 		numfacets = 0;
 		for(i=0; i<el->numhighlights; i++)
 		{
 			eh = el->highlights[i];
-			facet = el->facet;
 			hierpathcount = 0;
+			facet = el->facet;
+#ifdef	NEWERRORS
+			if (eh->showgeom && eh->type == ERRORTYPEGEOM && facet == NONODEPROTO)
+			{
+				facet = geomparent(eh->geom);
+				if (facet != NONODEPROTO && !db_validatefacet(facet))
+					facet = NONODEPROTO;
+			}
+#endif
 			switch (eh->type)
 			{
 				case ERRORTYPEGEOM:
 					if (!eh->showgeom) facet = NONODEPROTO; else
+#ifdef	NEWERRORS
+						if (facet != NONODEPROTO)
+#endif
+					{
+						/* validate the geometry */
+						for(ai = facet->firstarcinst; ai != NOARCINST; ai = ai->nextarcinst)
+							if (ai->geom == eh->geom) break;
+						if (ai == NOARCINST)
+						{
+							for(ni = facet->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
+								if (ni->geom == eh->geom) break;
+							if (ni == NONODEINST)
+							{
+								/* geometry pointer is not valid */
+								eh->showgeom = FALSE;
+								facet = NONODEPROTO;
+							}
+						}
+					}
+					if (eh->showgeom)
 					{
 						facet = geomparent(eh->geom);
 						if (eh->pathlen > 0)
@@ -915,7 +983,19 @@ char *db_reportcurrenterror(INTBIG showhigh, GEOM **g1, GEOM **g2)
 					break;
 				case ERRORTYPEEXPORT:
 					if (!eh->showgeom) facet = NONODEPROTO; else
-						facet = eh->pp->parent;
+#ifdef	NEWERRORS
+						if (facet != NONODEPROTO)
+#endif
+					{
+						/* validate the export */
+						for(pp = facet->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
+							if (pp == eh->pp) break;
+						if (pp == NOPORTPROTO)
+						{
+							eh->showgeom = FALSE;
+							facet = NONODEPROTO;
+						} else facet = eh->pp->parent;
+					}
 					break;
 				case ERRORTYPELINE:
 				case ERRORTYPEPOINT:
@@ -927,14 +1007,6 @@ char *db_reportcurrenterror(INTBIG showhigh, GEOM **g1, GEOM **g2)
 			if (j < numfacets) continue;
 			if (numfacets >= MAXFACETS) break;
 			facetlist[numfacets] = facet;
-
-			/* add this hierarchical path */
-			np = facet;
-			for(j=hierpathcount-1; j>=0; j--)
-			{
-				sethierarchicalparent(np, hierpath[j]);
-				np = hierpath[j]->parent;
-			}
 			numfacets++;
 		}
 
@@ -983,7 +1055,7 @@ char *db_reportcurrenterror(INTBIG showhigh, GEOM **g1, GEOM **g2)
 				if (facetlist[i] == NONODEPROTO) continue;
 				el_curwindowpart = neww[count++];
 				us_fullview(facetlist[i], &lx, &hx, &ly, &hy);
-				us_switchtofacet(facetlist[i], lx, hx, ly, hy, NONODEINST, NOPORTPROTO, FALSE, 0);
+				us_switchtofacet(facetlist[i], lx, hx, ly, hy, NONODEINST, NOPORTPROTO, FALSE, FALSE, FALSE);
 				facetlist[i] = NONODEPROTO;
 				if (count >= 4) break;
 			}
@@ -996,25 +1068,25 @@ char *db_reportcurrenterror(INTBIG showhigh, GEOM **g1, GEOM **g2)
 	for(i=0; i<el->numhighlights; i++)
 	{
 		eh = el->highlights[i];
+		if (showhigh == 0 || !eh->showgeom) continue;
 		switch (eh->type)
 		{
 			case ERRORTYPEGEOM:
 				if (geom1 == NOGEOM) geom1 = eh->geom; else
 					if (geom2 == NOGEOM) geom2 = eh->geom;
-				if (showhigh == 0 || !eh->showgeom) continue;
 
 				/* include this geometry module in list to show */
 				if (havegeoms == 0) infstr = initinfstr(); else
 					addtoinfstr(infstr, '\n');
 				havegeoms++;
-				formatinfstr(infstr, "FACET=%s FROM=0%lo;-1;0",
+				formatinfstr(infstr, x_("FACET=%s FROM=0%lo;-1;0"),
 					describenodeproto(geomparent(eh->geom)), (INTBIG)eh->geom);
 				break;
 			case ERRORTYPEEXPORT:
 				if (havegeoms == 0) infstr = initinfstr(); else
 					addtoinfstr(infstr, '\n');
 				havegeoms++;
-				formatinfstr(infstr, "FACET=%s TEXT=0%lo;0%lo;-",
+				formatinfstr(infstr, x_("FACET=%s TEXT=0%lo;0%lo;-"),
 					describenodeproto(eh->pp->parent), (INTBIG)eh->pp->subnodeinst->geom,
 						(INTBIG)eh->pp);
 				break;
@@ -1022,10 +1094,26 @@ char *db_reportcurrenterror(INTBIG showhigh, GEOM **g1, GEOM **g2)
 			case ERRORTYPEPOINT:
 				break;
 		}
+
+		/* set the hierarchical path */
+		if (eh->type == ERRORTYPEGEOM && eh->showgeom && eh->pathlen > 0)
+		{
+			facet = geomparent(eh->geom);
+			for(w=el_topwindowpart; w != NOWINDOWPART; w = w->nextwindowpart)
+				if (w->curnodeproto == facet) break;
+			if (w != NOWINDOWPART)
+			{
+				for(j=eh->pathlen-1; j>=0; j--)
+				{
+					sethierarchicalparent(facet, eh->path[j], w, 0);
+					facet = eh->path[j]->parent;
+				}
+			}
+		}
 	}
 
 	if (havegeoms != 0)
-		(void)asktool(us_tool, "show-multiple", (INTBIG)returninfstr(infstr));
+		(void)asktool(us_tool, x_("show-multiple"), (INTBIG)returninfstr(infstr));
 
 	/* now show the lines and points associated with this error */
 	for(i=0; i<el->numhighlights; i++)
@@ -1035,16 +1123,16 @@ char *db_reportcurrenterror(INTBIG showhigh, GEOM **g1, GEOM **g2)
 		{
 			case ERRORTYPELINE:
 				if (showhigh != 0)
-					(void)asktool(us_tool, "show-line", eh->x1, eh->y1, eh->x2, eh->y2,
+					(void)asktool(us_tool, x_("show-line"), eh->x1, eh->y1, eh->x2, eh->y2,
 						el->facet);
 				break;
 			case ERRORTYPEPOINT:
 				if (showhigh != 0)
 				{
 					consize = lambdaoffacet(el->facet) * 5;
-					(void)asktool(us_tool, "show-line", eh->x1-consize, eh->y1-consize,
+					(void)asktool(us_tool, x_("show-line"), eh->x1-consize, eh->y1-consize,
 						eh->x1+consize, eh->y1+consize, el->facet);
-					(void)asktool(us_tool, "show-line", eh->x1-consize, eh->y1+consize,
+					(void)asktool(us_tool, x_("show-line"), eh->x1-consize, eh->y1+consize,
 						eh->x1+consize, eh->y1-consize, el->facet);
 				}
 				break;
@@ -1064,3 +1152,18 @@ char *db_reportcurrenterror(INTBIG showhigh, GEOM **g1, GEOM **g2)
 		el->index, db_numerrors, el->message);
 	return(returninfstr(infstr));
 }
+
+#ifdef NEWERRORS
+BOOLEAN db_validatefacet(NODEPROTO *facet)
+{
+	REGISTER LIBRARY *lib;
+	REGISTER NODEPROTO *np;
+
+	for(lib = el_curlib; lib != NOLIBRARY; lib = lib->nextlibrary)
+	{
+		for(np = lib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
+			if (np == facet) return(TRUE);
+	}
+	return(FALSE);
+}
+#endif
