@@ -77,7 +77,7 @@ void db_freegeomemory(void)
 	{
 		rs = db_rsearchfree;
 		db_rsearchfree = (RSEARCH *)db_rsearchfree->lx;
-		efree((char *)rs);
+		efree((CHAR *)rs);
 	}
 }
 
@@ -118,7 +118,7 @@ void freertnode(RTNODE *rtn)
 {
 	if (rtn == NORTNODE) return;
 	if (rtn->numvar != 0) db_freevars(&rtn->firstvar, &rtn->numvar);
-	efree((char *)rtn);
+	efree((CHAR *)rtn);
 }
 
 /*
@@ -148,7 +148,7 @@ void freegeom(GEOM *geom)
 {
 	if (geom == NOGEOM) return;
 	if (geom->numvar != 0) db_freevars(&geom->firstvar, &geom->numvar);
-	efree((char *)geom);
+	efree((CHAR *)geom);
 }
 
 /*
@@ -779,12 +779,12 @@ void db_printrtree(RTNODE *expectedparent, RTNODE *rtn, INTBIG indent)
 {
 	REGISTER INTBIG i, j;
 	INTBIG lx, hx, ly, hy, lowestxv, highestxv, lowestyv, highestyv;
-	char line[100];
+	CHAR line[100];
 	REGISTER void *infstr;
 
 	infstr = initinfstr();
 	for(i=0; i<indent; i++) addtoinfstr(infstr, ' ');
-	(void)sprintf(line, M_("Node X(%s-%s) Y(%s-%s) has %d children:"),
+	(void)esnprintf(line, 100, M_("Node X(%s-%s) Y(%s-%s) has %d children:"),
 		latoa(rtn->lowx, 0), latoa(rtn->highx, 0), latoa(rtn->lowy, 0), latoa(rtn->highy, 0), rtn->total);
 	addstringtoinfstr(infstr, line);
 
@@ -812,7 +812,7 @@ void db_printrtree(RTNODE *expectedparent, RTNODE *rtn, INTBIG indent)
 		rtn->lowy = lowestyv;
 		rtn->highy = highestyv;
 	}
-	ttyputmsg("%s", returninfstr(infstr));
+	ttyputmsg(x_("%s"), returninfstr(infstr));
 
 	for(j=0; j<rtn->total; j++)
 	{
@@ -822,9 +822,10 @@ void db_printrtree(RTNODE *expectedparent, RTNODE *rtn, INTBIG indent)
 			for(i=0; i<indent+3; i++) addtoinfstr(infstr, ' ');
 			addstringtoinfstr(infstr, geomname((GEOM *)rtn->pointers[j]));
 			db_rtnbbox(rtn, j, &lx, &hx, &ly, &hy);
-			(void)sprintf(line, " X(%s-%s) Y(%s-%s)", latoa(lx, 0), latoa(hx, 0), latoa(ly, 0), latoa(hy, 0));
+			(void)esnprintf(line, 100, x_(" X(%s-%s) Y(%s-%s)"),
+				latoa(lx, 0), latoa(hx, 0), latoa(ly, 0), latoa(hy, 0));
 			addstringtoinfstr(infstr, line);
-			ttyputmsg("%s", returninfstr(infstr));
+			ttyputmsg(x_("%s"), returninfstr(infstr));
 		} else db_printrtree(rtn, (RTNODE *)rtn->pointers[j], indent+3);
 	}
 }
