@@ -36,7 +36,7 @@
 #define EVALUATIONCACHESIZE 20
 typedef struct
 {
-	char     *code;					/* the interpreted code that is being cached */
+	CHAR     *code;					/* the interpreted code that is being cached */
 	INTBIG    oaddr, otype;			/* address/type of object this code sits on */
 	UINTBIG   type;					/* type of the result of the code */
 	UINTBIG   reqtype;				/* requested type of the result of the code */
@@ -53,9 +53,9 @@ static void   *db_languagecachemutex = 0;		/* mutex for caching language evaluat
 
 /* prototypes for local routines */
 #if LANGLISP || LANGTCL || LANGJAVA || LANGMM
-static VARIABLE *db_enterqueryincache(char *code, INTBIG type, INTBIG reqtype, INTBIG value, INTBIG oaddr, INTBIG otype);
+static VARIABLE *db_enterqueryincache(CHAR *code, INTBIG type, INTBIG reqtype, INTBIG value, INTBIG oaddr, INTBIG otype);
 #endif
-static BOOLEAN db_codehasvariables(char *code, INTBIG language);
+static BOOLEAN db_codehasvariables(CHAR *code, INTBIG language);
 
 /****************************** LANGUAGE INTERFACE ******************************/
 
@@ -74,20 +74,20 @@ void db_initlanguages(void)
 /*
  * routine to return a string describing the currently available languages
  */
-char *languagename(void)
+CHAR *languagename(void)
 {
-	char *pt;
+	CHAR *pt;
 	REGISTER void *infstr;
 
 	infstr = initinfstr();
 #if	LANGJAVA
-	addstringtoinfstr(infstr, ", Java");
+	addstringtoinfstr(infstr, x_(", Java"));
 #endif
 #if LANGLISP
-	addstringtoinfstr(infstr, ", ELK Lisp");
+	addstringtoinfstr(infstr, x_(", ELK Lisp"));
 #endif
 #if LANGTCL
-	addstringtoinfstr(infstr, ", TCL ");
+	addstringtoinfstr(infstr, x_(", TCL "));
 	addstringtoinfstr(infstr, TCL_PATCH_LEVEL);
 #endif
 	pt = returninfstr(infstr);
@@ -99,7 +99,7 @@ char *languagename(void)
  * routine to load the code in the file "program" into the language interpreter
  * specified by "language".  Returns true on error.
  */
-BOOLEAN loadcode(char *program, INTBIG language)
+BOOLEAN loadcode(CHAR *program, INTBIG language)
 {
 #if LANGTCL
 	REGISTER INTBIG code;
@@ -110,7 +110,7 @@ BOOLEAN loadcode(char *program, INTBIG language)
 #if LANGLISP
 		case VLISP:
 			lsp_init();
-			(void)General_Load(Make_String(program, strlen(program)), The_Environment);
+			(void)General_Load(Make_String(program, estrlen(program)), The_Environment);
 			return(FALSE);
 #endif
 
@@ -118,7 +118,7 @@ BOOLEAN loadcode(char *program, INTBIG language)
 		case VTCL:
 			code = Tcl_EvalFile(tcl_interp, program);
 			if (code != TCL_OK)
-				ttyputerr("%s", tcl_interp->result);
+				ttyputerr(x_("%s"), tcl_interp->result);
 			break;
 #endif
 
@@ -135,7 +135,7 @@ BOOLEAN loadcode(char *program, INTBIG language)
  * Routine to return TRUE if "code" (in language "language") has variables in it (and so may evaluate
  * differently with different contexts).
  */
-BOOLEAN db_codehasvariables(char *code, INTBIG language)
+BOOLEAN db_codehasvariables(CHAR *code, INTBIG language)
 {
 #if LANGJAVA
 	REGISTER INTBIG i;
@@ -181,7 +181,7 @@ BOOLEAN db_codehasvariables(char *code, INTBIG language)
  * routine to evaluate string "code" in the specified "language", trying to match
  * "type" as a return type.  Returns a variable that describes the result (NOVARIABLE on error).
  */
-VARIABLE *doquerry(char *code, INTBIG language, UINTBIG type)
+VARIABLE *doquerry(CHAR *code, INTBIG language, UINTBIG type)
 {
 #if LANGTCL
 	INTBIG result;
@@ -190,18 +190,22 @@ VARIABLE *doquerry(char *code, INTBIG language, UINTBIG type)
 	ELKObject obj;
 #endif
 #if LANGJAVA
-	char *str;
+	CHAR *str;
 	INTBIG methodreturntype, reqtype;
 #endif
 #if	LANGMM
-	char *str;
+	CHAR *str;
 	static INTBIG retarray[1];
 	long ival;
 	double fval;
 	REGISTER void *infstr;
+#endif
+#if LANGTCL | LANGLISP | LANGJAVA | LANGMM
+	INTBIG addr;
 #endif
 	REGISTER INTBIG index;
-	INTBIG addr, oaddr, otype;
+	INTBIG oaddr, otype;
+	WINDOWPART *owin;
 	REGISTER VARIABLE *retvar;
 	REGISTER BOOLEAN hasvariables;
 	REGISTER EVALUATIONCACHE *ec;
@@ -212,26 +216,29 @@ VARIABLE *doquerry(char *code, INTBIG language, UINTBIG type)
 
 	/* search cache of evaluations */
 	if (db_multiprocessing) emutexlock(db_languagecachemutex);
-	if (!getcurrentvariableobject(&oaddr, &otype)) oaddr = otype = 0;
-	for(index=0; index<EVALUATIONCACHESIZE; index++)
+	if (!getcurrentvariableenvironment(&oaddr, &otype, &owin)) oaddr = otype = 0;
+	if (!hasvariables)
 	{
-		ec = &db_evaluationcache[index];
-		if (ec->code == 0) continue;
-		if (strcmp(ec->code, code) != 0) continue;
-		if (ec->reqtype != type) continue;
-		if (hasvariables)
+		for(index=0; index<EVALUATIONCACHESIZE; index++)
 		{
-			if (ec->changetimestamp != db_changetimestamp) continue;
-			if (ec->traversaltimestamp != db_traversaltimestamp) continue;
-			if (ec->oaddr != oaddr) continue;
-			if (ec->otype != otype) continue;
-		}
+			ec = &db_evaluationcache[index];
+			if (ec->code == 0) continue;
+			if (estrcmp(ec->code, code) != 0) continue;
+			if (ec->reqtype != type) continue;
+			if (hasvariables)
+			{
+				if (ec->changetimestamp != db_changetimestamp) continue;
+				if (ec->traversaltimestamp != db_traversaltimestamp) continue;
+				if (ec->oaddr != oaddr) continue;
+				if (ec->otype != otype) continue;
+			}
 
-		/* found in cache: return value */
-		retvar = &ec->var;
-		ec->usagestamp = db_evaluationusagetime;
-		if (db_multiprocessing) emutexunlock(db_languagecachemutex);
-		return(retvar);
+			/* found in cache: return value */
+			retvar = &ec->var;
+			ec->usagestamp = db_evaluationusagetime;
+			if (db_multiprocessing) emutexunlock(db_languagecachemutex);
+			return(retvar);
+		}
 	}
 
 	/* do the evaluation */
@@ -262,7 +269,7 @@ VARIABLE *doquerry(char *code, INTBIG language, UINTBIG type)
 			result = Tcl_Eval(tcl_interp, code);
 			if (result != TCL_OK)
 			{
-				ttyputerr("%s", tcl_interp->result);
+				ttyputerr(x_("TCL: %s"), tcl_interp->result);
 				return(NOVARIABLE);
 			}
 
@@ -291,13 +298,13 @@ VARIABLE *doquerry(char *code, INTBIG language, UINTBIG type)
 			if (db_mathematicainit() != 0) break;
 
 			/* send the string to Mathematica */
-			MLPutFunction(db_mathematicalink, "EvaluatePacket", 1);
-				MLPutFunction(db_mathematicalink, "ToExpression",1);
+			MLPutFunction(db_mathematicalink, x_("EvaluatePacket"), 1);
+				MLPutFunction(db_mathematicalink, x_("ToExpression"),1);
 					MLPutString(db_mathematicalink, code);
 			MLEndPacket(db_mathematicalink);
 			if (MLError(db_mathematicalink) != MLEOK)
 			{
-				ttyputerr("Mathematica error: %s", MLErrorMessage(db_mathematicalink));
+				ttyputerr(x_("Mathematica error: %s"), MLErrorMessage(db_mathematicalink));
 				break;
 			}
 
@@ -405,7 +412,7 @@ BOOLEAN languageconverse(INTBIG language)
 	static INTBIG curlang;
 #if LANGTCL
 	static BOOLEAN gotPartial;
-	char *cmd, *tstr, *promptCmd;
+	CHAR *cmd, *tstr, *promptCmd;
 	REGISTER INTBIG code;
 	static Tcl_DString command;
 #endif
@@ -413,10 +420,10 @@ BOOLEAN languageconverse(INTBIG language)
 	ELKObject pred;
 #endif
 #if LANGMM
-	char *mstr;
+	CHAR *mstr;
 #endif
 #if LANGJAVA
-	char *jstr;
+	CHAR *jstr;
 #endif
 
 	/* on the first call, initialize the interpreter */
@@ -469,22 +476,22 @@ BOOLEAN languageconverse(INTBIG language)
 	{
 #if LANGLISP
 		case VLISP:
-			pred = Eval(Intern("the-top-level"));
+			pred = Eval(Intern(x_("the-top-level")));
 			(void)Funcall(pred, Null, 0);
 			break;
 #endif
 
 #if LANGTCL
 		case VTCL:
-			promptCmd = Tcl_GetVar(tcl_interp, (char *)(gotPartial ? "tcl_prompt2" : "tcl_prompt1"),
+			promptCmd = Tcl_GetVar(tcl_interp, (CHAR *)(gotPartial ? x_("tcl_prompt2") : x_("tcl_prompt1")),
 				TCL_GLOBAL_ONLY);
-			if (promptCmd == NULL && !gotPartial) promptCmd = "puts -nonewline \"% \""; 
+			if (promptCmd == NULL && !gotPartial) promptCmd = x_("puts -nonewline \"% \""); 
 			if (promptCmd != NULL)
 			{
 				code = Tcl_Eval(tcl_interp, promptCmd);
 				if (code != TCL_OK)
 				{
-					ttyputerr("%s (script that generates prompt)", tcl_interp->result);
+					ttyputerr(x_("%s (script that generates prompt)"), tcl_interp->result);
 					promptCmd = NULL;
 				}
 			}
@@ -507,17 +514,17 @@ BOOLEAN languageconverse(INTBIG language)
 			Tcl_DStringFree(&command);
 			if (code != TCL_OK)
 			{
-				ttyputerr("%s", tcl_interp->result);
+				ttyputerr(x_("%s"), tcl_interp->result);
 			} else if (*tcl_interp->result != 0)
 			{
-				ttyputmsg("%s", tcl_interp->result);
+				ttyputmsg(x_("%s"), tcl_interp->result);
 			}
 			return(FALSE);
 #endif
 
 #if LANGJAVA
 		case VJAVA:
-			jstr = ttygetlinemessages("> ");
+			jstr = ttygetlinemessages(x_("> "));
 			if (jstr == 0) return(TRUE);
 
 			/* send the string to Java */
@@ -527,11 +534,11 @@ BOOLEAN languageconverse(INTBIG language)
 
 #if LANGMM
 		case VMATHEMATICA:
-			mstr = ttygetlinemessages("> ");
+			mstr = ttygetlinemessages(x_("> "));
 			if (mstr == 0) return(TRUE);
 
 			/* send the string to Mathematica */
-			MLPutFunction(db_mathematicalink, "ToExpression", 1);
+			MLPutFunction(db_mathematicalink, x_("ToExpression"), 1);
 				MLPutString(db_mathematicalink, mstr);
 			MLEndPacket(db_mathematicalink);
 
@@ -554,7 +561,7 @@ BOOLEAN languageconverse(INTBIG language)
  * Routine to enter code "code" which returns "addr" of type "type" into the
  * cache of evaluations.  The code sits on object "oaddr" of type "otype".
  */
-VARIABLE *db_enterqueryincache(char *code, INTBIG type, INTBIG reqtype, INTBIG addr, INTBIG oaddr, INTBIG otype)
+VARIABLE *db_enterqueryincache(CHAR *code, INTBIG type, INTBIG reqtype, INTBIG addr, INTBIG oaddr, INTBIG otype)
 {
 	REGISTER VARIABLE *var;
 	REGISTER INTBIG oldeststamp, i;
@@ -575,9 +582,9 @@ VARIABLE *db_enterqueryincache(char *code, INTBIG type, INTBIG reqtype, INTBIG a
 	}
 	if (oldestec->code != 0)
 	{
-		efree((char *)oldestec->code);
+		efree((CHAR *)oldestec->code);
 		if ((oldestec->type&VTYPE) == VSTRING)
-			efree((char *)oldestec->value);
+			efree((CHAR *)oldestec->value);
 	}
 
 	/* load the cache entry */
@@ -592,7 +599,7 @@ VARIABLE *db_enterqueryincache(char *code, INTBIG type, INTBIG reqtype, INTBIG a
 
 	if ((type&VTYPE) == VSTRING)
 	{
-		(void)allocstring((char **)&oldestec->value, (char *)addr, db_cluster);
+		(void)allocstring((CHAR **)&oldestec->value, (CHAR *)addr, db_cluster);
 	} else
 	{
 		oldestec->value = addr;
@@ -620,14 +627,14 @@ void db_termlanguage(void)
 	for(i=0; i<EVALUATIONCACHESIZE; i++)
 	{
 		if (db_evaluationcache[i].code == 0) continue;
-		efree((char *)db_evaluationcache[i].code);
+		efree((CHAR *)db_evaluationcache[i].code);
 		if ((db_evaluationcache[i].type&VTYPE) == VSTRING)
-			efree((char *)db_evaluationcache[i].value);
+			efree((CHAR *)db_evaluationcache[i].value);
 	}
 #if LANGMM
 	if (db_mathematicalink != NULL)
 	{
-		MLPutFunction(db_mathematicalink, "Exit", 0);
+		MLPutFunction(db_mathematicalink, x_("Exit"), 0);
 		MLEndPacket(db_mathematicalink);
 		MLClose(db_mathematicalink);
 	}
