@@ -53,7 +53,7 @@ LIBRARY *alloclibrary(void)
 	REGISTER TECHNOLOGY *tech;
 	REGISTER CLUSTER *cluster;
 
-	cluster = alloccluster("");
+	cluster = alloccluster(x_(""));
 	if (cluster == NOCLUSTER) return((LIBRARY *)db_error(DBNOMEM|DBALLOCLIBRARY));
 	lib = (LIBRARY *)emalloc((sizeof (LIBRARY)), cluster);
 	if (lib == 0) return((LIBRARY *)db_error(DBNOMEM|DBALLOCLIBRARY));
@@ -99,10 +99,10 @@ void freelibrary(LIBRARY *lib)
 
 	if (lib == NOLIBRARY) return;
 	if (lib->numvar != 0) db_freevars(&lib->firstvar, &lib->numvar);
-	efree((char *)lib->lambda);
-	if (lib->cellhashtablesize > 0) efree((char *)lib->cellhashtable);
+	efree((CHAR *)lib->lambda);
+	if (lib->cellhashtablesize > 0) efree((CHAR *)lib->cellhashtable);
 	clus = lib->cluster;
-	efree((char *)lib);
+	efree((CHAR *)lib);
 	freecluster(clus);
 }
 
@@ -111,10 +111,10 @@ void freelibrary(LIBRARY *lib)
  * is "name" and its disk file is "file".  If there is any error, NOLIBRARY
  * is returned.
  */
-LIBRARY *newlibrary(char *name, char *file)
+LIBRARY *newlibrary(CHAR *name, CHAR *file)
 {
 	REGISTER LIBRARY *lib;
-	REGISTER char *ch, nc;
+	REGISTER CHAR *ch, nc;
 	REGISTER BOOLEAN renamed;
 
 	/* error checks */
@@ -135,8 +135,8 @@ LIBRARY *newlibrary(char *name, char *file)
 	/* create the library */
 	lib = alloclibrary();
 	if (lib == NOLIBRARY) return((LIBRARY *)db_error(DBNOMEM|DBNEWLIBRARY));
-	(void)strcpy(lib->cluster->clustername, "lib:");
-	(void)strncpy(&lib->cluster->clustername[4], name, 25);
+	(void)estrcpy(lib->cluster->clustername, x_("lib:"));
+	(void)estrncpy(&lib->cluster->clustername[4], name, 25);
 
 	/* set library name and file */
 	if (allocstring(&lib->libname, name, lib->cluster)) return(NOLIBRARY);
@@ -172,7 +172,7 @@ LIBRARY *newlibrary(char *name, char *file)
  * routine to set the current library (represented by the global "el_curlib")
  * to "lib"
  */
-void selectlibrary(LIBRARY *lib)
+void selectlibrary(LIBRARY *lib, BOOLEAN changelambda)
 {
 	REGISTER LIBRARY *l, *lastlib;
 	REGISTER TECHNOLOGY *tech;
@@ -194,8 +194,11 @@ void selectlibrary(LIBRARY *lib)
 	lib->nextlibrary = el_curlib;
 	el_curlib = lib;
 
-	for(tech = el_technologies; tech != NOTECHNOLOGY; tech = tech->nexttechnology)
-		changetechnologylambda(tech, el_curlib->lambda[tech->techindex]);
+	if (changelambda)
+	{
+		for(tech = el_technologies; tech != NOTECHNOLOGY; tech = tech->nexttechnology)
+			changetechnologylambda(tech, el_curlib->lambda[tech->techindex]);
+	}
 
 	/* mark a change to the database */
 	db_changetimestamp++;
@@ -333,7 +336,7 @@ void eraselibrary(LIBRARY *lib)
 	lib->numcells = 0;
 	if (lib->cellhashtablesize > 0)
 	{
-		efree((char *)lib->cellhashtable);
+		efree((CHAR *)lib->cellhashtable);
 		lib->cellhashtablesize = 0;
 	}
 
@@ -452,7 +455,7 @@ void changelambda(INTBIG count, TECHNOLOGY **techarray, INTBIG *newlam,
 	for(lib = el_curlib; lib != NOLIBRARY; lib = lib->nextlibrary)
 	{
 		if (how == 1 && whichlib != lib) continue;
-		efree((char *)lib->temp2);
+		efree((CHAR *)lib->temp2);
 
 		/* announce end of changes to this library */
 		endobjectchange((INTBIG)lib, VLIBRARY);
@@ -509,7 +512,7 @@ void db_scalefacet(NODEPROTO *np, INTBIG count, TECHNOLOGY **techarray, INTBIG *
 			position[0] = muldiv(position[0], newlam, oldlam);
 			position[1] = muldiv(position[1], newlam, oldlam);
 		}
-		var = getval((INTBIG)np, VNODEPROTO, VINTEGER|VISARRAY, "FACET_characteristic_spacing");
+		var = getval((INTBIG)np, VNODEPROTO, VINTEGER|VISARRAY, x_("FACET_characteristic_spacing"));
 		if (var != NOVARIABLE)
 		{
 			position = (INTBIG *)var->addr;
@@ -706,7 +709,7 @@ void changeinternalunits(LIBRARY *whichlib, INTBIG oldunits, INTBIG newunits)
 	REGISTER INTBIG hardscaleerror, softscaleerror, len;
 	INTBIG num, den;
 	REGISTER INTBIG i;
-	REGISTER char *errortype, *errorlocation;
+	REGISTER CHAR *errortype, *errorlocation;
 	REGISTER TECHNOLOGY *tech;
 	REGISTER LIBRARY *lib;
 	REGISTER NODEPROTO *np;
