@@ -36,39 +36,29 @@
 #  include <unistd.h>
 #endif
 
-#if defined(MACOS) && !defined(MACOSX)
-#  include <Memory.h>
-#  define MUSTALLOW 32768L				/* leave this much unallocated for system uses */
-#  define LOWLEVELALLOC NewPtr			/* system-routine to allocate memory */
-#  define LOWLEVELFREE  DisposePtr		/* system-routine to deallocate memory */
-#else
-#  define LOWLEVELALLOC malloc			/* system-routine to allocate memory */
-#  define LOWLEVELFREE  free			/* system-routine to deallocate memory */
-#endif
-
-#if (defined(MACOS) && !defined(MACOSX)) || defined(DEBUGMEMORY)	/* memory clustering only on MAC (or if debugging memory) */
+#ifdef DEBUGMEMORY					/* memory clustering only if debugging memory */
 #  define USECLUSTERS  1
 #endif
 
-#if defined(ONUNIX)                             /* WINDOW and MAC already do filling */ 
-#define FILLBYTE       0x41                     /* byte to fill emalloc memory */
-#endif
+#ifdef USECLUSTERS
+#  if defined(ONUNIX)                             /* WINDOW and MAC already do filling */ 
+#    define FILLBYTE       0x41                     /* byte to fill emalloc memory */
+#  endif
 
 /* the information bits in the header word */
-#define FREE		0			/* block is free */
-#define USED		1			/* block is in use */
-#define SKIP		2			/* block is dummy for re-pointing */
-#define FLAGBITS	3			/* the above flag bits */
+#  define FREE		0			/* block is free */
+#  define USED		1			/* block is in use */
+#  define SKIP		2			/* block is dummy for re-pointing */
+#  define FLAGBITS	3			/* the above flag bits */
 
-#define ROUNDUP (SIZEOFINTBIG+SIZEOFINTBIG) /* slop to give whole block */
-#define SPAREPAGELIMIT 20		/* spare page groups to save */
-#define PAGEBLOCK      64		/* amount to allocate at once */
+#  define ROUNDUP (SIZEOFINTBIG+SIZEOFINTBIG) /* slop to give whole block */
+#  define SPAREPAGELIMIT 20		/* spare page groups to save */
+#  define PAGEBLOCK      64		/* amount to allocate at once */
 
-#ifdef USECLUSTERS
 typedef struct
 {
-	INTBIG pagecount;
-	char *pageaddress;
+	INTBIG  pagecount;
+	UCHAR1 *pageaddress;
 } SPAREPAGES;
 static SPAREPAGES db_sparepages[SPAREPAGELIMIT];
 static INTBIG db_sparepagecount = 0;
@@ -77,8 +67,8 @@ INTBIG        db_clustercount = 0;
 CLUSTER     *db_firstcluster;	/* top of list of clusters */
 CLUSTER     *db_clusterfree;	/* list of free memory clusters */
 
-char    *db_getmorememory(CLUSTER*, INTBIG, INTBIG);
-char    *db_getpages(INTBIG);
+UCHAR1  *db_getmorememory(CLUSTER*, INTBIG, INTBIG);
+UCHAR1  *db_getpages(INTBIG);
 void     db_coalescecluster(CLUSTER*);
 void     db_printoneclusterarena(CLUSTER*, INTBIG, INTBIG*, INTBIG*, INTBIG*);
 #endif
@@ -88,13 +78,15 @@ void     db_printoneclusterarena(CLUSTER*, INTBIG, INTBIG*, INTBIG*, INTBIG*);
   static INTBIG getpagesize(void);
 #endif
 #ifndef HAVE_VALLOC
-  static char  *valloc(INTBIG);
+  static UCHAR1 *valloc(INTBIG);
 #endif
 #ifdef DEBUGMEMORY
-  static void   db_checkmemoryblock(char *addr);
+  static void   db_checkmemoryblock(UCHAR1 *addr);
+#  ifdef USECLUSTERS
   static void   db_checkcluster(CLUSTER *clus);
+#  endif
   static FILE  *db_memerrio = 0;
-  static char   db_initialdirectory[256];
+  static CHAR   db_initialdirectory[256];
 #endif
 
 /*
@@ -152,11 +144,11 @@ void db_initclusters(void)
 		;
 
 	/* create the database cluster by hand since it is the first */
-	db_cluster = (CLUSTER *)LOWLEVELALLOC(sizeof (CLUSTER));
+	db_cluster = (CLUSTER *)malloc(sizeof (CLUSTER));
 	if (db_cluster == 0) error(_("Memory system cannot initialize"));
 	db_cluster->clustersize = 0;
 	db_cluster->flags = CLUSTERFILLING;
-	(void)strcpy(db_cluster->clustername, "DATABASE");
+	(void)estrcpy(db_cluster->clustername, x_("DATABASE"));
 
 	/* create the linked list of active clusters */
 	db_firstcluster = db_cluster;
@@ -165,15 +157,15 @@ void db_initclusters(void)
 	/* initialize the linked list of free clusters */
 	db_clusterfree = NOCLUSTER;
 #else
-	db_cluster = alloccluster("DATABASE");
+	db_cluster = alloccluster(x_("DATABASE"));
 #endif
 
 #ifdef DEBUGMEMORY
-	strcpy(db_initialdirectory, currentdirectory());
+	estrcpy(db_initialdirectory, currentdirectory());
 #endif
 
 	/* create the temporary cluster normally */
-	el_tempcluster = alloccluster("TEMPORARY");
+	el_tempcluster = alloccluster(x_("TEMPORARY"));
 }
 
 /*
@@ -181,7 +173,7 @@ void db_initclusters(void)
  * address of the cluster for subsequent calls to "emalloc".  Returns
  * NOCLUSTER if there is an error.
  */
-CLUSTER *alloccluster(char *name)
+CLUSTER *alloccluster(CHAR *name)
 {
 #ifdef	USECLUSTERS
 	REGISTER CLUSTER *clus;
@@ -203,16 +195,17 @@ CLUSTER *alloccluster(char *name)
 	clus->nextcluster = db_firstcluster;
 	db_firstcluster = clus;
 	clus->flags = CLUSTERFILLING;
-	(void)strncpy(clus->clustername, name, 29);
+	(void)estrncpy(clus->clustername, name, 29);
 	clus->address = clus->clustersize = 0;
 	db_clustercount++;
 	return(clus);
 #else
 	static CLUSTER clus;
+	Q_UNUSED( name );
 
 	clus.nextcluster = NOCLUSTER;
 	clus.clustersize = 0;
-	(void)strcpy(clus.clustername, "NOCLUSTERNAME");
+	(void)estrcpy(clus.clustername, x_("NOCLUSTERNAME"));
 	clus.address = clus.flags = 0;
 	return(&clus);
 #endif
@@ -309,6 +302,8 @@ void freecluster(CLUSTER *clus)
 	clus->nextcluster = db_clusterfree;
 	db_clusterfree = clus;
 	db_clustercount--;
+#else
+	Q_UNUSED( clus );
 #endif
 }
 
@@ -320,12 +315,12 @@ void freecluster(CLUSTER *clus)
  * memory if successful, 0 if not.
  */
 #ifdef DEBUGMEMORY
-INTBIG *_emalloc(INTBIG amount, CLUSTER *cluster, char *file, INTBIG line)
+INTBIG *_emalloc(INTBIG amount, CLUSTER *cluster, CHAR *file, INTBIG line)
 #else
 INTBIG *emalloc(INTBIG amount, CLUSTER *cluster)
 #endif
 {
-	REGISTER char *addr;
+	REGISTER UCHAR1 *addr;
 #ifdef	DEBUGMEMORY
 	REGISTER INTBIG *pt, filelen, endf;
 #endif
@@ -341,11 +336,11 @@ INTBIG *emalloc(INTBIG amount, CLUSTER *cluster)
 	/* block must be a word amount */
 	amount = (amount + SIZEOFINTBIG - 1) & ~(SIZEOFINTBIG - 1);
 #ifdef	DEBUGMEMORY
-	filelen = strlen(file);
+	filelen = estrlen(file);
 	for(endf = filelen-1; endf > 0; endf--)
 		if (file[endf] == DIRSEP) break;
 	if (file[endf] == DIRSEP) file += endf + 1;
-	filelen = (strlen(file)+SIZEOFINTBIG) & ~(SIZEOFINTBIG - 1);
+	filelen = (estrlen(file)*SIZEOFCHAR+SIZEOFINTBIG) & ~(SIZEOFINTBIG - 1);
 	amount += 4 * SIZEOFINTBIG + filelen;
 #endif
 
@@ -393,7 +388,7 @@ INTBIG *emalloc(INTBIG amount, CLUSTER *cluster)
 			{
 #  ifdef DEBUGMEMORY
 				if ((head&FLAGBITS) == USED)
-					db_checkmemoryblock((char *)(&ptr[1]));
+					db_checkmemoryblock((UCHAR1 *)(&ptr[1]));
 #  endif
 				ptr = (INTBIG *)(head & ~FLAGBITS);
 				if (ptr == start) atend++;
@@ -441,7 +436,7 @@ INTBIG *emalloc(INTBIG amount, CLUSTER *cluster)
 			}
 
 			/* compute the address of the returned memory */
-			addr = (char *)((INTBIG)ptr + SIZEOFINTBIG);
+			addr = (UCHAR1 *)((INTBIG)ptr + SIZEOFINTBIG);
 
 			/* give the entire block if the request matches close enough */
 			if (amount + (INTBIG)ROUNDUP >= size)
@@ -461,7 +456,7 @@ INTBIG *emalloc(INTBIG amount, CLUSTER *cluster)
 	} else 
 #endif /* USECLUSTERS */
 	{
-		addr = (char *)LOWLEVELALLOC((unsigned)amount);
+		addr = (UCHAR1 *)malloc((size_t)amount);
 		if (addr == 0) return(0);
 	}
 
@@ -474,7 +469,7 @@ INTBIG *emalloc(INTBIG amount, CLUSTER *cluster)
 	((INTBIG *)addr)[1] = 0xC0CEC0CE;
 	*pt++ = 0xC0CEC0CE;
 	*pt++ = line;
-	strcpy((char *)pt, file);
+	estrcpy((CHAR *)pt, file);
 	addr += SIZEOFINTBIG * 2;
 #endif
 	return((INTBIG *)addr);
@@ -484,18 +479,20 @@ INTBIG *emalloc(INTBIG amount, CLUSTER *cluster)
  * routine to free memory obtained with "emalloc".  The memory is kept
  * in the cluster and may be re-used by subsequent calls to "emalloc"
  */
-void efree(char *addr)
+void efree(CHAR *caddr)
 {
 #ifdef	USECLUSTERS
 	REGISTER INTBIG *ptr;
 #endif
+	REGISTER UCHAR1 *addr;
 
 	/* don't free null pointers */
-	if (addr == NOSTRING) return;
+	addr = (UCHAR1 *)caddr;
+	if (addr == ((UCHAR1 *)-1)) return;
 
 #ifdef DEBUGMEMORY
 	addr -= SIZEOFINTBIG * 2;
-	db_checkmemoryblock(addr);
+	db_checkmemoryblock((UCHAR1 *)addr);
 #endif
 
 #ifdef USECLUSTERS
@@ -515,7 +512,7 @@ void efree(char *addr)
 	cluster->flags &= ~CLUSTERFILLING;
 #  endif
 #else
-	LOWLEVELFREE(addr);
+	free(addr);
 #endif
 }
 
@@ -535,7 +532,7 @@ void db_checkallmemoryfree(void)
 	{
 		clus = db_clusterfree;
 		db_clusterfree = db_clusterfree->nextcluster;
-		efree((char *)clus);
+		efree((CHAR *)clus);
 	}
 	freecluster(db_cluster);
 	if (db_memerrio != 0) fclose(db_memerrio);
@@ -544,7 +541,7 @@ void db_checkallmemoryfree(void)
 }
 
 #ifdef DEBUGMEMORY
-void db_checkmemoryblock(char *addr)
+void db_checkmemoryblock(UCHAR1 *addr)
 {
 	REGISTER INTBIG *botptr, *endptr;
 
@@ -558,10 +555,11 @@ void db_checkmemoryblock(char *addr)
 			&endptr[2], endptr[1]);
 }
 
+#  ifdef USECLUSTERS
 void db_checkcluster(CLUSTER *clus)
 {
 	REGISTER INTBIG *start, *ptr, head, *endptr, line, errors, size, i;
-	char *modulename, *dataptr, dataarray[21], errorfile[300];
+	CHAR *modulename, dataarray[21], errorfile[300], *dataptr;
 
 	start = ptr = (INTBIG *)clus->address;
 	size = clus->clustersize;
@@ -582,20 +580,20 @@ void db_checkcluster(CLUSTER *clus)
 					endptr = (INTBIG *)ptr[1];
 					if (db_memerrio == 0)
 					{
-						strcpy(errorfile, db_initialdirectory);
-						strcat(errorfile, "MemoryErrors.txt");
-						db_memerrio = fopen(errorfile, "w");
+						estrcpy(errorfile, db_initialdirectory);
+						estrcat(errorfile, x_("MemoryErrors.txt"));
+						db_memerrio = efopen(errorfile, x_("w"));
 					}
 					if (errors == 0)
-						fprintf(db_memerrio, _("***Errors from cluster %s:\n"), clus->clustername);
+						efprintf(db_memerrio, _("***Errors from cluster %s:\n"), clus->clustername);
 					errors++;
-					modulename = (char *)&endptr[2];
+					modulename = (CHAR *)&endptr[2];
 					line = endptr[1];
-					dataptr = (char *)&ptr[3];
+					dataptr = (CHAR *)&ptr[3];
 					for(i=0; i<20; i++) if (dataptr[i] < ' ' || dataptr[i] >= 0177) dataarray[i] = ' '; else
 						dataarray[i] = dataptr[i];
 					dataarray[20] = 0;
-					fprintf(db_memerrio, _("  Block allocated from %s, line %ld ('%s': 0%o 0%o 0%o 0%o)\n"), modulename, line,
+					efprintf(db_memerrio, _("  Block allocated from %s, line %ld ('%s': 0%o 0%o 0%o 0%o)\n"), modulename, line,
 						dataarray, dataptr[0]&0xFF, dataptr[1]&0xFF, dataptr[2]&0xFF, dataptr[3]&0xFF);
 				}
 
@@ -610,6 +608,7 @@ void db_checkcluster(CLUSTER *clus)
 		}
 	}
 }
+#  endif
 #endif
 
 #ifdef USECLUSTERS
@@ -620,10 +619,10 @@ void db_checkcluster(CLUSTER *clus)
  * should be placed in the cluster's "address" field.  Returns the address of
  * this new memory (zero if error).
  */
-char *db_getmorememory(CLUSTER *clus, INTBIG size, INTBIG insert)
+UCHAR1 *db_getmorememory(CLUSTER *clus, INTBIG size, INTBIG insert)
 {
 	REGISTER INTBIG *ptr, lastword, *pt;
-	REGISTER char *addr;
+	REGISTER UCHAR1 *addr;
 
 	/* allocate the pages of memory */
 	addr = db_getpages(size);
@@ -660,9 +659,9 @@ char *db_getmorememory(CLUSTER *clus, INTBIG size, INTBIG insert)
  * Returns 0 if there is an allocation error.  This routine was modified by
  * J.P. Polonovski to be more robust when memory is low.
  */
-char *db_getpages(INTBIG size)
+UCHAR1 *db_getpages(INTBIG size)
 {
-	REGISTER char *addr;
+	REGISTER UCHAR1 *addr;
 	REGISTER INTBIG i, j, newcount, smallest, amount;
 	REGISTER INTBIG pass;
 	static INTBIG old_status = 1, old_size = 0;
@@ -701,12 +700,12 @@ char *db_getpages(INTBIG size)
 		{
 			if (old_size != 1)
 				ttyputerr(_("Not able to allocate %ld byte from memory"), size * db_pagesize); else
-					ttyputerr("SAVE QUICKLY THERE IS NO MORE MEMORY!!");
+					ttyputerr(x_("SAVE QUICKLY THERE IS NO MORE MEMORY!!"));
 			return(0);
 		} else amount = size / 2;
 	}
 
-	addr = (char *)valloc((unsigned)(amount*db_pagesize));
+	addr = (UCHAR1 *)valloc((unsigned)(amount*db_pagesize));
 	if (addr == 0)
 	{
 		if (old_status == 0 && old_size >= size) return(0);
@@ -719,7 +718,7 @@ char *db_getpages(INTBIG size)
 			if (size > amount)
 			{
 				amount = size;
-				addr = (char *)valloc((unsigned) (amount * db_pagesize));
+				addr = (UCHAR1 *)valloc((unsigned) (amount * db_pagesize));
 				if (addr == 0)
 				{
 					ttyputerr(_("!! No memory left !!"));
@@ -729,7 +728,7 @@ char *db_getpages(INTBIG size)
 				}
 				break;
 			}
-			addr = (char *)valloc((unsigned) (amount * db_pagesize));
+			addr = (UCHAR1 *)valloc((unsigned) (amount * db_pagesize));
 			if (addr == 0) continue; else
 			{
 				ttyputerr(_("!! Only %ld bytes of memory left !!"), amount * db_pagesize);
@@ -766,7 +765,7 @@ char *db_getpages(INTBIG size)
 }
 #endif
 
-void db_printclusterarena(char *which)
+void db_printclusterarena(CHAR *which)
 {
 #ifdef USECLUSTERS
 	REGISTER CLUSTER *clus;
@@ -796,7 +795,8 @@ void db_printclusterarena(char *which)
 		ttyputmsg(_("No cluster called %s"), which);
 	}
 #else
-		ttyputmsg(_("Cluster option is not in use"));
+	Q_UNUSED( which );
+	ttyputmsg(_("Cluster option is not in use"));
 #endif
 }
 
@@ -822,24 +822,24 @@ void db_printoneclusterarena(CLUSTER *cluster, INTBIG verbose, INTBIG *freesize,
 		switch (value & FLAGBITS)
 		{
 			case FREE:
-				if (verbose > 0) ttyputmsg("  Free block at 0%o is %ld long",
+				if (verbose > 0) ttyputmsg(x_("  Free block at 0%o is %ld long"),
 					ptr, addr-(INTBIG)ptr-SIZEOFINTBIG);
 				freethis += addr - (INTBIG)ptr - SIZEOFINTBIG;
 				break;
 			case USED:
-				if (verbose > 0) ttyputmsg("  Used block at 0%o is %ld long",
+				if (verbose > 0) ttyputmsg(x_("  Used block at 0%o is %ld long"),
 					ptr, addr-(INTBIG)ptr-SIZEOFINTBIG);
 				usedthis += addr - (INTBIG)ptr - SIZEOFINTBIG;
 				break;
 			case SKIP:
-				if (verbose > 0) ttyputmsg("  Skip block at 0%o", ptr);
+				if (verbose > 0) ttyputmsg(x_("  Skip block at 0%o"), ptr);
 				break;
 		}
 		ptr = (INTBIG *)addr;
 		if (ptr == start) break;
 	}
 	if (verbose >= 0)
-		ttyputmsg("%4d blocks, %6d used, %6d free in cluster %s",
+		ttyputmsg(x_("%4d blocks, %6d used, %6d free in cluster %s"),
 			cluster->clustersize, usedthis, freethis, cluster->clustername);
 	*freesize += freethis;   *usedsize += usedthis;
 	*blocksused += cluster->clustersize;
@@ -929,23 +929,23 @@ INTBIG getpagesize(void)
  * Can waste up to db_pagesize - 1.
  * Space allocated with valloc is generally not free'd.
  */
-char *valloc(INTBIG nbytes)
+UCHAR1 *valloc(INTBIG nbytes)
 {
 #  if defined(MACOS) && !defined(MACOSX)
-	char *ptr;
+	UCHAR1 *ptr;
 	INTBIG left, dummy;
 
 	left = MaxMem((Size *)&dummy);
-	if (left-MUSTALLOW >= nbytes) ptr = (char *)LOWLEVELALLOC(nbytes); else ptr = 0;
+	if (left-MUSTALLOW >= nbytes) ptr = (UCHAR1 *)malloc(nbytes); else ptr = 0;
 	return(ptr);
 #  else
-	char *ptr;
+	UCHAR1 *ptr;
 	INTBIG page;
 
 	page = getpagesize();
-	ptr = LOWLEVELALLOC(nbytes + page - 1);
+	ptr = malloc(nbytes + page - 1);
 	if (ptr == 0) return(0);
-	return(char *)(((INTBIG)ptr + page -1) & ~(page-1));
+	return(UCHAR1 *)(((INTBIG)ptr + page -1) & ~(page-1));
 #  endif
 }
 #endif	/* HAVE_VALLOC */
