@@ -45,9 +45,11 @@
 #define MAXARCPIECES   16		/* maximum segments in curved arc */
 
 static GRAPHICS tech_arrow = {LAYERO, FACETOUT, SOLIDC, SOLIDC,
-	{0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF}, NOVARIABLE, 0};
+	{0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,
+	0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF}, NOVARIABLE, 0};
 static GRAPHICS tech_vartxt = {LAYERO, FACETTXT, SOLIDC, SOLIDC,
-	{0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF}, NOVARIABLE, 0};
+	{0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,
+	0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF}, NOVARIABLE, 0};
 
 /* prototypes for local routines */
 static void      db_adjusttree(NODEPROTO*);
@@ -176,7 +178,7 @@ BOOLEAN tech_doaddportsandvars(TECHNOLOGY *tech)
 	for(i=0; tech->variables[i].name != 0; i++)
 	{
 		/* handle "prototype_center" variable specially */
-		if (namesame(tech->variables[i].name, "prototype_center") == 0)
+		if (namesame(tech->variables[i].name, x_("prototype_center")) == 0)
 		{
 			centerlist = (INTBIG *)tech->variables[i].value;
 			for(j=0; j<tech->variables[i].type; j++)
@@ -201,7 +203,8 @@ BOOLEAN tech_doaddportsandvars(TECHNOLOGY *tech)
 		/* normal variable setting */
 		nextchangequiet();
 		if (setvalkey((INTBIG)tech, VTECHNOLOGY, makekey(tech->variables[i].name),
-			(INTBIG)tech->variables[i].value, tech->variables[i].type) == NOVARIABLE) return(TRUE);
+			(INTBIG)tech->variables[i].value, tech->variables[i].type) == NOVARIABLE)
+				return(TRUE);
 	}
 
 	return(FALSE);
@@ -221,7 +224,7 @@ void tech_convertmocmoslib(LIBRARY *lib)
 	REGISTER TECHNOLOGY *mocmostech;
 
 	for(mocmostech = el_technologies; mocmostech != NOTECHNOLOGY; mocmostech = mocmostech->nexttechnology)
-		if (namesame(mocmostech->techname, "mocmos") == 0) break;
+		if (namesame(mocmostech->techname, x_("mocmos")) == 0) break;
 	if (mocmostech == NOTECHNOLOGY)
 	{
 		ttyputmsg(M_("Cannot find 'mocmos' technology"));
@@ -235,7 +238,7 @@ void tech_convertmocmoslib(LIBRARY *lib)
 		for(ai = np->firstarcinst; ai != NOARCINST; ai = ai->nextarcinst)
 		{
 			if (ai->proto->tech != mocmostech) continue;
-			if (namesame(ai->proto->protoname, "S-Active") != 0) continue;
+			if (namesame(ai->proto->protoname, x_("S-Active")) != 0) continue;
 			undogeom(ai->geom, np);
 			ai->width += 4 * lambda;
 			linkgeom(ai->geom, np);
@@ -245,9 +248,9 @@ void tech_convertmocmoslib(LIBRARY *lib)
 		{
 			if (ni->proto->primindex == 0) continue;
 			if (ni->proto->tech != mocmostech) continue;
-			if (namesame(ni->proto->primname, "S-Active-Pin") == 0 ||
-				namesame(ni->proto->primname, "S-Transistor") == 0 ||
-				namesame(ni->proto->primname, "Metal-1-S-Active-Con") == 0)
+			if (namesame(ni->proto->primname, x_("S-Active-Pin")) == 0 ||
+				namesame(ni->proto->primname, x_("S-Transistor")) == 0 ||
+				namesame(ni->proto->primname, x_("Metal-1-S-Active-Con")) == 0)
 			{
 				undogeom(ni->geom, np);
 				ni->lowx -= 2 * lambda;
@@ -506,7 +509,7 @@ INTBIG tech_getextendfactor(INTBIG wid, INTBIG extend)
 	/* compute the amount of extension (from 0 to wid/2) */
 	if (extend <= 0) return(wid/2);
 
-	/* values should be from 0 to 90, but stupidity reigns */
+	/* values should be from 0 to 90, but check anyway */
 	if (extend > 90) return(wid/2);
 
 	/* return correct extension */
@@ -538,7 +541,7 @@ BOOLEAN tech_pinusecount(NODEINST *ni, WINDOWPART *win)
 	/* if the next level up the hierarchy is visible, consider arcs connected there */
 	if (win != NOWINDOWPART && ni->firstportexpinst != NOPORTEXPINST)
 	{
-		db_gettraversalpath(ni->parent, &nilist, &depth);
+		db_gettraversalpath(ni->parent, win, &nilist, &depth);
 		if (depth == 1)
 		{
 			upni = nilist[0];
@@ -798,7 +801,7 @@ void tech_fillpoly(POLYGON *poly, TECH_POLYGON *lay, NODEINST *ni, INTBIG lambda
 	poly->count = lay->count;
 	poly->style = lay->style;
 	if (lay->style >= TEXTCENT && lay->style <= TEXTBOX)
-		poly->string = (char *)lay->points[lastpoint];
+		poly->string = (CHAR *)lay->points[lastpoint];
 }
 
 /*
@@ -1838,14 +1841,16 @@ VARIABLE *tech_filldisplayableanyvar(POLYGON *poly, INTBIG lx, INTBIG hx,
 {
 	REGISTER INTBIG len, language, whichindex;
 	UINTBIG descript[TEXTDESCRIPTSIZE];
-	REGISTER char *query;
+	REGISTER CHAR *query;
 	REGISTER VARIABLE *var, *retvar;
 	REGISTER NODEINST *ni;
+	REGISTER WINDOWPART *oldwin;
 
 	/* get next displayable variable */
 	if (varnoeval != 0)
 		(*varnoeval) = NOVARIABLE;
 	if (win == NOWINDOWPART) win = el_curwindowpart;
+	oldwin = setvariablewindow(win);
 	poly->count = 1;
 	poly->xv[0] = (lx+hx)/2;
 	poly->yv[0] = (ly+hy)/2;
@@ -1855,7 +1860,7 @@ VARIABLE *tech_filldisplayableanyvar(POLYGON *poly, INTBIG lx, INTBIG hx,
 		if (pl->ndisplayindex >= pl->numvar)
 		{
 			TDCLEAR(descript);
-			poly->string = "ERROR";
+			poly->string = x_("ERROR");
 			var = NOVARIABLE;
 			break;
 		}
@@ -1871,8 +1876,8 @@ VARIABLE *tech_filldisplayableanyvar(POLYGON *poly, INTBIG lx, INTBIG hx,
 			language = var->type & (VCODE1|VCODE2);
 			if (language != 0)
 			{
-				if ((var->type&VISARRAY) == 0) query = (char *)var->addr; else
-					query = ((char **)var->addr)[0];
+				if ((var->type&VISARRAY) == 0) query = (CHAR *)var->addr; else
+					query = ((CHAR **)var->addr)[0];
 				retvar = doquerry(query, language, var->type & ~(VCODE1|VCODE2|VISARRAY|VLENGTH));
 				if (retvar != NOVARIABLE)
 				{
@@ -1924,5 +1929,6 @@ VARIABLE *tech_filldisplayableanyvar(POLYGON *poly, INTBIG lx, INTBIG hx,
 	poly->desc = &tech_vartxt;
 	tech_vartxt.col = el_colfacettxt;
 	poly->layer = -1;
+	(void)setvariablewindow(oldwin);
 	return(var);
 }
