@@ -36,8 +36,6 @@
 
 #ifdef _DEBUG
 #define new DEBUG_NEW
-#undef THIS_FILE
-static char THIS_FILE[] = __FILE__;
 #endif
 
 /////////////////////////////////////////////////////////////////////////////
@@ -145,7 +143,7 @@ int CMainFrame::OnCreate(LPCREATESTRUCT lpCreateStruct)
 		!m_wndStatusBar.SetIndicators(indicators,
 		  sizeof(indicators)/sizeof(UINT)))
 	{
-		TRACE0("Failed to create status bar\n");
+		TRACE(x_("%s"), x_("Failed to create status bar\n"));
 		return -1;      /* fail to create */
 	}
 
@@ -154,7 +152,7 @@ int CMainFrame::OnCreate(LPCREATESTRUCT lpCreateStruct)
 	r.left = 1150;   r.right = 1250;
 	r.top = 20;    r.bottom = 600;
 	m_wndComponentMenu = new CFrameWnd();
-	m_wndComponentMenu->Create(NULL, "Components",
+	m_wndComponentMenu->Create(NULL, x_("Components"),
 		WS_OVERLAPPED|WS_CAPTION, r, this, NULL, WS_EX_TOOLWINDOW, NULL);
 	m_wndComponentMenu->ShowWindow(SW_SHOW);
 #endif
