@@ -37,8 +37,6 @@
 
 #ifdef _DEBUG
 #define new DEBUG_NEW
-#undef THIS_FILE
-static char THIS_FILE[] = __FILE__;
 #endif
 
 /////////////////////////////////////////////////////////////////////////////
@@ -206,10 +204,10 @@ void CElectricMsgView::LoadColors(void)
 	ctrl->SetSel(startsel, endsel);
 	ctrl->SetDefaultCharFormat(cf);
 
-#if 0
+#if 0		/* code for changing background color of messages window */
 	int pos = ctrl->GetLimitText();
 	ctrl->SetSel(pos, pos);
-	ctrl->ReplaceSel("Color changes\r\n");
+	ctrl->ReplaceSel(x_("Color changes\r\n"));
 	ctrl->SetRedraw(TRUE);
 	ctrl->Invalidate();
 	GdiFlush();
