@@ -30,6 +30,7 @@
  */
 
 #include "global.h"
+#include "graphqt.h"
 #include "graphqtdlg.h"
 #include "edialogs.h"
 
@@ -65,6 +66,8 @@
 static EDialogPrivate *gra_firstactivemodaldialog = 0;
 static EDialogPrivate *gra_firstmodelessdialog = 0;
 
+extern EApplication *gra;
+
 static INTBIG gra_dialogstringpos;
 extern "C"
 {
@@ -72,6 +75,360 @@ extern "C"
 }
 
 
+/****************************** C Dialog API  ******************************/
+
+/*
+ * Routine to initialize a dialog described by "dialog".
+ * Returns the address of the dialog object (0 if dialog cannot be initialized).
+ */
+void *DiaInitDialog(DIALOG *dialog)
+{
+	return(new EDialogModal( dialog ));
+}
+
+/*
+ * Routine to handle actions and return the next item hit.
+ */
+INTBIG DiaNextHit(void *vdia)
+{
+	EDialog *dia = (EDialog *)vdia;
+	return(dia->nextHit());
+}
+
+void DiaDoneDialog(void *vdia)
+{
+	EDialog *dia = (EDialog *)vdia;
+	delete dia;
+}
+
+/*
+ * Routine to change the size of the dialog
+ */
+void DiaResizeDialog(void *vdia, INTBIG wid, INTBIG hei)
+{
+	EDialog *dia = (EDialog *)vdia;
+	dia->resizeDialog( wid, hei );
+}
+
+/*
+ * Routine to forces dialog be displayed on top of other windows
+ */
+void DiaBringToTop(void *vdia)
+{
+	EDialog *dia = (EDialog *)vdia;
+	dia->bringToTop();
+}
+
+/*
+ * Routine to set the text in item "item" to "msg"
+ */
+void DiaSetText(void *vdia, INTBIG item, CHAR *msg)
+{
+	EDialog *dia = (EDialog *)vdia;
+	dia->setText(item, msg);
+}
+
+/*
+ * Routine to return the text in item "item"
+ */
+CHAR *DiaGetText(void *vdia, INTBIG item)
+{
+	EDialog *dia = (EDialog *)vdia;
+	return(dia->getText(item));
+}
+
+/*
+ * Routine to set the value in item "item" to "value"
+ */
+void DiaSetControl(void *vdia, INTBIG item, INTBIG value)
+{
+	EDialog *dia = (EDialog *)vdia;
+	dia->setControl(item, value);
+}
+
+/*
+ * Routine to return the value in item "item"
+ */
+INTBIG DiaGetControl(void *vdia, INTBIG item)
+{
+	EDialog *dia = (EDialog *)vdia;
+	return(dia->getControl(item));
+}
+
+/*
+ * Routine to check item "item" to make sure that there is
+ * text in it.  If so, it returns true.  Otherwise it beeps and returns false.
+ */
+BOOLEAN DiaValidEntry(void *vdia, INTBIG item)
+{
+	EDialog *dia = (EDialog *)vdia;
+	return(dia->validEntry(item));
+}
+
+/*
+ * Routine to dim item "item"
+ */
+void DiaDimItem(void *vdia, INTBIG item)
+{
+	EDialog *dia = (EDialog *)vdia;
+	dia->dimItem(item);
+}
+
+/*
+ * Routine to un-dim item "item"
+ */
+void DiaUnDimItem(void *vdia, INTBIG item)
+{
+	EDialog *dia = (EDialog *)vdia;
+	dia->unDimItem(item);
+}
+
+/*
+ * Routine to change item "item" to be a message rather
+ * than editable text
+ */
+void DiaNoEditControl(void *vdia, INTBIG item)
+{
+	EDialog *dia = (EDialog *)vdia;
+	dia->noEditControl(item);
+}
+
+/*
+ * Routine to change item "item" to be editable text rather
+ * than a message
+ */
+void DiaEditControl(void *vdia, INTBIG item)
+{
+	EDialog *dia = (EDialog *)vdia;
+	dia->editControl(item);
+}
+
+void DiaOpaqueEdit(void *vdia, INTBIG item)
+{
+	EDialog *dia = (EDialog *)vdia;
+	dia->opaqueEdit(item);
+}
+
+/*
+ * Routine to cause item "item" to be the default button
+ */
+void DiaDefaultButton(void *vdia, INTBIG item)
+{
+	EDialog *dia = (EDialog *)vdia;
+	dia->defaultButton(item);
+}
+
+/*
+ * Routine to change the icon in item "item" to be the 32x32 bitmap (128 bytes) at "addr".
+ */
+void DiaChangeIcon(void *vdia, INTBIG item, UCHAR1 *addr)
+{
+	EDialog *dia = (EDialog *)vdia;
+	dia->changeIcon(item, addr);
+}
+
+/*
+ * Routine to change item "item" into a popup with "count" entries
+ * in "names".
+ */
+void DiaSetPopup(void *vdia, INTBIG item, INTBIG count, CHAR **names)
+{
+	EDialog *dia = (EDialog *)vdia;
+	dia->setPopup(item, count, names);
+}
+
+/*
+ * Routine to change popup item "item" so that the current entry is "entry".
+ */
+void DiaSetPopupEntry(void *vdia, INTBIG item, INTBIG entry)
+{
+	EDialog *dia = (EDialog *)vdia;
+	dia->setPopupEntry(item, entry);
+}
+
+/*
+ * Routine to return the current item in popup menu item "item".
+ */
+INTBIG DiaGetPopupEntry(void *vdia, INTBIG item)
+{
+	EDialog *dia = (EDialog *)vdia;
+	return(dia->getPopupEntry(item));
+}
+
+void DiaInitTextDialog(void *vdia, INTBIG item, BOOLEAN (*toplist)(CHAR **), CHAR *(*nextinlist)(void),
+	void (*donelist)(void), INTBIG sortpos, INTBIG flags)
+{
+	EDialog *dia = (EDialog *)vdia;
+	dia->initTextDialog(item, toplist, nextinlist, donelist, sortpos, flags);
+}
+
+void DiaLoadTextDialog(void *vdia, INTBIG item, BOOLEAN (*toplist)(CHAR **), CHAR *(*nextinlist)(void),
+	void (*donelist)(void), INTBIG sortpos)
+{
+	EDialog *dia = (EDialog *)vdia;
+	dia->loadTextDialog(item, toplist, nextinlist, donelist, sortpos);
+}
+
+/*
+ * Routine to stuff line "line" at the end of the edit buffer.
+ */
+void DiaStuffLine(void *vdia, INTBIG item, CHAR *line)
+{
+	EDialog *dia = (EDialog *)vdia;
+	dia->stuffLine(item, line);
+}
+
+/*
+ * Routine to select line "line" of scroll item "item".
+ */
+void DiaSelectLine(void *vdia, INTBIG item, INTBIG line)
+{
+	EDialog *dia = (EDialog *)vdia;
+	dia->selectLine(item, line);
+}
+
+/*
+ * Routine to select "count" lines in "lines" of scroll item "item".
+ */
+void DiaSelectLines(void *vdia, INTBIG item, INTBIG count, INTBIG *lines)
+{
+	EDialog *dia = (EDialog *)vdia;
+	dia->selectLines(item, count, lines);
+}
+
+/*
+ * Returns the currently selected line in the scroll list "item".
+ */
+INTBIG DiaGetCurLine(void *vdia, INTBIG item)
+{
+	EDialog *dia = (EDialog *)vdia;
+	return(dia->getCurLine(item));
+}
+
+/*
+ * Returns the currently selected lines in the scroll list "item".  The returned
+ * array is terminated with -1.
+ */
+INTBIG *DiaGetCurLines(void *vdia, INTBIG item)
+{
+	EDialog *dia = (EDialog *)vdia;
+	return(dia->getCurLines(item));
+}
+
+INTBIG DiaGetNumScrollLines(void *vdia, INTBIG item)
+{
+	EDialog *dia = (EDialog *)vdia;
+	return(dia->getNumScrollLines(item));
+}
+
+CHAR *DiaGetScrollLine(void *vdia, INTBIG item, INTBIG line)
+{
+	EDialog *dia = (EDialog *)vdia;
+	return(dia->getScrollLine(item, line));
+}
+
+void DiaSetScrollLine(void *vdia, INTBIG item, INTBIG line, CHAR *msg)
+{
+	EDialog *dia = (EDialog *)vdia;
+	dia->setScrollLine(item, line, msg);
+}
+
+void DiaSynchVScrolls(void *vdia, INTBIG item1, INTBIG item2, INTBIG item3)
+{
+	EDialog *dia = (EDialog *)vdia;
+	dia->synchVScrolls(item1, item2, item3);
+}
+
+void DiaUnSynchVScrolls(void *vdia)
+{
+	EDialog *dia = (EDialog *)vdia;
+	dia->unSynchVScrolls();
+}
+
+void DiaItemRect(void *vdia, INTBIG item, RECTAREA *rect)
+{
+	EDialog *dia = (EDialog *)vdia;
+	dia->itemRect(item, rect);
+}
+
+void DiaPercent(void *vdia, INTBIG item, INTBIG percent)
+{
+	EDialog *dia = (EDialog *)vdia;
+	dia->percent(item, percent);
+}
+
+void DiaRedispRoutine(void *vdia, INTBIG item, void (*routine)(RECTAREA*, void*))
+{
+	EDialog *dia = (EDialog *)vdia;
+	dia->redispRoutine(item, routine);
+}
+
+void DiaAllowUserDoubleClick(void *vdia)
+{
+	EDialog *dia = (EDialog *)vdia;
+	dia->allowUserDoubleClick();
+}
+
+void DiaFillPoly(void *vdia, INTBIG item, INTBIG *xv, INTBIG *yv, INTBIG count, INTBIG r, INTBIG g, INTBIG b)
+{
+	EDialog *dia = (EDialog *)vdia;
+	dia->fillPoly(item, xv, yv, count, r, g, b);
+}
+
+void DiaDrawRect(void *vdia, INTBIG item, RECTAREA *rect, INTBIG r, INTBIG g, INTBIG b)
+{
+	EDialog *dia = (EDialog *)vdia;
+	dia->drawRect(item, rect, r, g, b);
+}
+
+void DiaFrameRect(void *vdia, INTBIG item, RECTAREA *r)
+{
+	EDialog *dia = (EDialog *)vdia;
+	dia->frameRect(item, r);
+}
+
+void DiaInvertRect(void *vdia, INTBIG item, RECTAREA *r)
+{
+	EDialog *dia= (EDialog *)vdia;
+	dia->invertRect(item, r);
+}
+
+void DiaDrawLine(void *vdia, INTBIG item, INTBIG fx, INTBIG fy, INTBIG tx, INTBIG ty, INTBIG mode)
+{
+	EDialog *dia = (EDialog *)vdia;
+	dia->drawLine(item, fx, fy, tx, ty, mode);
+}
+
+void DiaSetTextSize(void *vdia, INTBIG size)
+{
+	EDialog *dia = (EDialog *)vdia;
+	dia->setTextSize(size);
+}
+
+void DiaGetTextInfo(void *vdia, CHAR *msg, INTBIG *wid, INTBIG *hei)
+{
+	EDialog *dia = (EDialog *)vdia;
+	dia->getTextInfo(msg, wid, hei);
+}
+
+void DiaPutText(void *vdia, INTBIG item, CHAR *msg, INTBIG x, INTBIG y)
+{
+	EDialog *dia = (EDialog *)vdia;
+	dia->putText(item, msg, x, y);
+}
+
+void DiaTrackCursor(void *vdia, void (*eachdown)(INTBIG x, INTBIG y))
+{
+	EDialog *dia = (EDialog *)vdia;
+	dia->trackCursor(eachdown);
+}
+
+void DiaGetMouse(void *vdia, INTBIG *x, INTBIG *y)
+{
+	EDialog *dia = (EDialog *)vdia;
+	dia->getMouse(x, y);
+}
+
 /****************************** EDialog class ******************************/
 
 EDialog::EDialog(DIALOG *dialog )
@@ -93,11 +450,8 @@ EDialog::~EDialog()
     itemdesc->windowRect.top += disp.y();
     itemdesc->windowRect.bottom += disp.y();
 
-#if QT_VERSION >= 300
     d->deleteLater();
-#else
-    delete d;
-#endif
+	gra->toolTimeSlice();
 }
 
 void EDialog::reset()
@@ -117,9 +471,13 @@ INTBIG EDialog::nextHit(void)
 
 	while(d->itemHit == -1)
 	{
+#if 0
 		QTimer timer( d );
 		timer.start( MAXEVENTTIME, TRUE );
 		qApp->processOneEvent();
+#else
+		qApp->processEvents(MAXEVENTTIME);
+#endif
 	}
 	INTBIG item = d->itemHit;
 	d->itemHit = -1;
@@ -193,8 +551,8 @@ void EDialog::setText(INTBIG item, char *msg)
 	    QLineEdit *lineEdit = (QLineEdit*)d->items[item];
 	    QObject::disconnect(lineEdit,SIGNAL(textChanged(const QString&)),d->mapper,SLOT(map()));
 	    lineEdit->setText ( qmsg );
-	    if (highlight != 0) lineEdit->selectAll(); else lineEdit->deselect();
 	    lineEdit->setCursorPosition( lineEdit->text().length() );
+	    if (highlight) lineEdit->selectAll(); else lineEdit->deselect();
 	    QObject::connect(lineEdit,SIGNAL(textChanged(const QString&)),d->mapper,SLOT(map()));
 	}
 	break;
@@ -204,11 +562,7 @@ void EDialog::setText(INTBIG item, char *msg)
 	  if (itemdesc == &us_eprogressdialog || itemdesc == &us_progressdialog)
 		  {
 			  label->repaint();
-#if QT_VERSION >= 300
 			  qApp->flush();
-#else
-              QApplication::flushX();
-#endif
 		  }
 	}
 	break;
@@ -418,7 +772,7 @@ void EDialog::defaultButton(INTBIG item)
 	}
 }
 
-void EDialog::changeIcon(INTBIG item, char *addr)
+void EDialog::changeIcon(INTBIG item, UCHAR1 *addr)
 {
 	item--;
 	INTBIG type = itemdesc->list[item].type;
@@ -426,7 +780,7 @@ void EDialog::changeIcon(INTBIG item, char *addr)
 	case ICON: {
 	    EIconField *icon = (EIconField*)d->items[item];
 	    itemdesc->list[item].data = (INTBIG)addr;
-	    icon->setBits( (uchar*)addr );
+	    icon->setBits( addr );
 	}
 	break;
 	default:
@@ -553,6 +907,7 @@ void EDialog::loadTextDialog(INTBIG item, BOOLEAN (*toplist)(char **), char *(*n
 		(*donelist)();
 
 		/* allocate space for the strings */
+		list = 0;
 		if (it > 0)
 		{
 			list = (char **)emalloc(it * (sizeof (char *)), el_tempcluster);
@@ -623,7 +978,7 @@ void EDialog::selectLine(INTBIG item, INTBIG line)
 	/* make sure lines are visible */
 	int first = scroll->topItem();
 	int visible = scroll->numItemsVisible();
-	if (line < first || line >= first+visible) {
+	if (line < first || line >= first+visible-1) {
 		first = QMAX( line - visible/2 , 0);
 		scroll->setTopItem( first );
 	}
@@ -638,7 +993,7 @@ void EDialog::selectLines(INTBIG item, INTBIG count, INTBIG *lines)
 	EScrollField *scroll = (EScrollField*)d->items[item];
 	scroll->blockSignals( TRUE );
 	scroll->clearSelection();
-	int low, high;
+	int low=0, high=0;
 	for(int i=0; i<count; i++)
 	{
 		int line = lines[i];
@@ -718,7 +1073,6 @@ void EDialog::setScrollLine(INTBIG item, INTBIG line, char *msg)
 
 void EDialog::synchVScrolls(INTBIG item1, INTBIG item2, INTBIG item3)
 {
-#if QT_VERSION >= 300
 	if (item1 <= 0 || item1 > itemdesc->items) return;
 	if (item2 <= 0 || item2 > itemdesc->items) return;
 	if (item3 < 0 || item3 > itemdesc->items) return;
@@ -737,12 +1091,10 @@ void EDialog::synchVScrolls(INTBIG item1, INTBIG item2, INTBIG item3)
 		QObject::connect(d->lock2[d->numlocks],SIGNAL(valueChanged(int)), d->lock1[d->numlocks],SLOT(setValue(int)));
 	}
 	d->numlocks++;
-#endif
 }
 
 void EDialog::unSynchVScrolls(void)
 {
-#if QT_VERSION >= 300
 	while (d->numlocks > 0) {
 		d->numlocks--;	
 
@@ -756,7 +1108,6 @@ void EDialog::unSynchVScrolls(void)
 			QObject::disconnect(d->lock2[d->numlocks],SIGNAL(valueChanged(int)), d->lock1[d->numlocks],SLOT(setValue(int)));
 		}
 	}
-#endif
 }
 
 void EDialog::itemRect(INTBIG item, RECTAREA *rect)
@@ -774,11 +1125,7 @@ void EDialog::percent(INTBIG item, INTBIG percent)
 	item--;
 	QProgressBar *progress = (QProgressBar*)d->items[item];
 	progress->setProgress( percent );
-#if QT_VERSION >= 300
 	qApp->flush();
-#else
-    QApplication::flushX();
-#endif
 }
 
 void EDialog::redispRoutine(INTBIG item, void (*routine)(RECTAREA *rect, void *dia))
@@ -966,6 +1313,8 @@ QStrList *EDialog::itemNamesFromUi( char *uiFile, BOOLEAN ext )
 	}
     return slist;
 #else
+	Q_UNUSED( uiFile );
+	Q_UNUSED( ext );
     return 0;
 #endif
 }
@@ -973,22 +1322,17 @@ QStrList *EDialog::itemNamesFromUi( char *uiFile, BOOLEAN ext )
 EDialogModal::EDialogModal( DIALOG *dialog )
 	: EDialog( dialog ), in_loop(FALSE), result(Rejected)
 {
-	QWidget *base;
+	QWidget *base=0;
 	
 	/* make the dialog structure */
-#if QT_VERSION >= 300
-	if (gra_firstactivemodaldialog != 0) base = gra_firstactivemodaldialog; else
+	if (gra_firstactivemodaldialog != 0) base = gra_firstactivemodaldialog;
+#ifndef MACOSX
+	else if (el_curwindowpart == NOWINDOWPART) base = qApp->mainWidget(); else
+		base = ((QWidget*)el_curwindowpart->frame->draw)->parentWidget();
 #endif
-	if (el_curwindowpart == NOWINDOWPART) base = qApp->mainWidget(); else
-		base = (QWidget*)el_curwindowpart->frame->qt;
 
-#if QT_VERSION >= 300
     d = new EDialogPrivate( base, itemDesc()->movable );
     d->init( this, TRUE );
-#else
-    d = new EDialogPrivate( base, itemDesc()->movable, TRUE);
-    d->init( this );
-#endif
 
 	/* add this to the list of active dialogs */
     d->nexttdialog = gra_firstactivemodaldialog;
@@ -1037,7 +1381,6 @@ EDialogModeless::EDialogModeless( DIALOG *dialog )
     : EDialog( dialog )
 {
 	/* make the dialog structure */
-#if QT_VERSION >= 300
 #  ifdef QTSTRETCH
     if (dialog->uiFile != 0)
     {
@@ -1068,10 +1411,6 @@ EDialogModeless::EDialogModeless( DIALOG *dialog )
 #  endif
     d = new EDialogPrivate( qApp->mainWidget(), itemDesc()->movable );
     d->init( this, FALSE );
-#else
-    d = new EDialogPrivate( qApp->mainWidget(), itemDesc()->movable, FALSE );
-    d->init( this );
-#endif
 
 	/* add this to the list of modeless dialogs */
     d->nexttdialog = gra_firstmodelessdialog;
@@ -1100,6 +1439,7 @@ void EDialogModeless::show()
 void EDialogModeless::hide()
 {
     d->hide();
+	gra->toolTimeSlice();
 }
 
 bool EDialogModeless::isHidden()
@@ -1107,33 +1447,19 @@ bool EDialogModeless::isHidden()
     return d->isHidden();
 }
 
-#if QT_VERSION >= 300
 EDialogPrivate::EDialogPrivate(QWidget *parent, const char *name )
     : QDialog( parent, name ),
       numlocks( 0 ), mapper( 0 ), dia( 0 ), nexttdialog( 0 ), itemHit( -1 )
 {
 }
-#else
-EDialogPrivate::EDialogPrivate(QWidget *parent, const char *name, bool modal )
-    : QDialog( parent, name, modal ),
-      numlocks( 0 ), mapper( 0 ), dia( 0 ), nexttdialog( 0 ), itemHit( -1 )
-{
-}
-#endif
 
-#if QT_VERSION >= 300
 void EDialogPrivate::init( EDialog *dia, bool modal )
-#else
-void EDialogPrivate::init( EDialog *dia )
-#endif
 {
 	INTBIG i, j, itemtype, x, y, wid, hei;
     DIALOG *dialog = dia->itemDesc();
 
     EDialogPrivate::dia = dia;
-#if QT_VERSION >= 300
     if (modal) setWFlags(WShowModal);
-#endif
 
 	getdialogcoordinates(&dialog->windowRect, &x, &y, &wid, &hei);
     if (dialog->briefHeight != 0)
@@ -1210,16 +1536,15 @@ void EDialogPrivate::init( EDialog *dia )
 				break;
 			case EDITTEXT:
 				widget = lineEdit = new QLineEdit( this );
+#if 1
+				widget->installEventFilter( this );
+#endif
 				connect(lineEdit,SIGNAL(textChanged(const QString&)),mapper,SLOT(map()));
 				if (focus == 0) focus = lineEdit;
 				break;
 			case MESSAGE:
 				widget = label = new QLabel( unimsg, this );
-#if QT_VERSION >= 300
                 label->setAlignment( AlignAuto | AlignTop | ExpandTabs | WordBreak | BreakAnywhere);
-#else
-                label->setAlignment( AlignLeft | AlignTop | ExpandTabs | WordBreak );
-#endif
 				break;
 			case PROGRESS:
 				widget = progress = new QProgressBar( 100, this );
@@ -1284,18 +1609,24 @@ void EDialogPrivate::showMe()
 
 char *EDialogPrivate::localize (QString qstr)
 {
-    static QCString str;
+    static QCString str[2];
+	static int i = 0;
 
-    str = qstr.local8Bit();
-    const char *s = str;
+    str[i] = qstr.local8Bit();
+    const char *s = str[i];
+	i = (i + 1) % (sizeof(str)/sizeof(str[0]));
     return((char*)s);
 }
 
 #ifdef QTSTRETCH
+#define REORDER
 bool EDialogPrivate::checkChildren()
 {
 	INTBIG i, j, itemtype;
     DIALOG *dialog = dia->itemDesc();
+#ifdef REORDER
+	char line[40];
+#endif
 
 	/* load the items */
 	mapper = new QSignalMapper( this, "mapper");
@@ -1303,7 +1634,11 @@ bool EDialogPrivate::checkChildren()
 	QWidget *focus = 0;
 	QPushButton *defbutton = 0;
 	QPushButton *buttonzero = 0;
+#ifdef REORDER
+	for (i = 0; i < dialog->items; i++) items[i] = 0;
+#else
     i = 0;
+#endif
 
 	for (uint isExt = FALSE; isExt <= (dialog->briefHeight != 0); isExt++)
 	{
@@ -1312,11 +1647,28 @@ bool EDialogPrivate::checkChildren()
 		{
 			if (!ol.at(li)->isWidgetType() || ol.at(li) == extension()) continue;
 			QWidget *widget = (QWidget*)ol.at(li);
+#ifdef REORDER
+			strncpy(line, widget->name(), sizeof(line));
+			for (i = 0; i < (int)sizeof(line); i++)
+				if (line[i] == '_' || i == sizeof(line)-1) line[i] = 0;
+			i = atol(line)-1;
+			if (i < 0 || i >= dialog->items)
+			{
+				ttyputerr("Invalid dialog item number %s", widget->name());
+				return FALSE;
+			}
+			if (items[i])
+			{
+				ttyputerr("Duplicated dialog item number %s", widget->name());
+				return FALSE;
+			}
+#else
 			if (i >= dialog->items)
 			{
 				ttyputerr("Too many items in .ui");
 				return FALSE;
 			}
+#endif
 
 			itemtype = dialog->list[i].type;
 			switch (itemtype&ITEMTYPE)
@@ -1325,7 +1677,7 @@ bool EDialogPrivate::checkChildren()
 				case DEFBUTTON:
 					if (!widget->isA("QPushButton"))
 					{
-						ttyputerr("Invalid item in .ui");
+						ttyputerr("Invalid item %d BUTTON in .ui", i);
 						return FALSE;
 					}
 					{
@@ -1340,7 +1692,7 @@ bool EDialogPrivate::checkChildren()
 					{
 						if (!widget->isA("QCheckBox"))
 						{
-							ttyputerr("Invalid item in .ui");
+							ttyputerr("Invalid item %d AUTOCHECK in .ui", i);
 							return FALSE;
 						}
 						connect(widget,SIGNAL(clicked()),mapper,SLOT(map()));
@@ -1348,7 +1700,7 @@ bool EDialogPrivate::checkChildren()
 					{
 						if (!widget->isA("ECheckField"))
 						{
-							ttyputerr("Invalid item in .ui");
+							ttyputerr("Invalid item %d CHECK in .ui", i);
 							return FALSE;
 						}
 						connect(widget,SIGNAL(clicked()),mapper,SLOT(map()));
@@ -1357,7 +1709,7 @@ bool EDialogPrivate::checkChildren()
 				case RADIO:
 					if (!widget->isA("QRadioButton"))
 					{
-						ttyputerr("Invalid item in .ui");
+						ttyputerr("Invalid item %d RADIO in .ui", i);
 						return FALSE;
 					}
 					connect(widget,SIGNAL(clicked()),mapper,SLOT(map()));
@@ -1385,7 +1737,7 @@ bool EDialogPrivate::checkChildren()
 				case EDITTEXT:
 					if (!widget->isA("QLineEdit"))
 					{
-						ttyputerr("Invalid item in .ui");
+						ttyputerr("Invalid item %d EDITTEXT in .ui", i);
 						return FALSE;
 					}
 					connect(widget,SIGNAL(textChanged(const QString&)),mapper,SLOT(map()));
@@ -1394,21 +1746,21 @@ bool EDialogPrivate::checkChildren()
 				case MESSAGE:
 					if (!widget->isA("QLabel"))
 					{
-						ttyputerr("Invalid item in .ui");
+						ttyputerr("Invalid item %d MESSAGE in .ui", i);
 						return FALSE;
 					}
 					break;
 				case PROGRESS:
 					if (!widget->isA("QProgressBar"))
 					{
-						ttyputerr("Invalid item in .ui");
+						ttyputerr("Invalid item %d PROGRESS in .ui", i);
 						return FALSE;
 					}
 					break;
 				case DIVIDELINE:
 					if (!widget->isA("QWidget"))
 					{
-						ttyputerr("Invalid item in .ui");
+						ttyputerr("Invalid item %d DIVIDELINE in .ui", i);
 						return FALSE;
 					}
 					widget->setBackgroundMode( PaletteForeground );
@@ -1416,7 +1768,7 @@ bool EDialogPrivate::checkChildren()
 				case USERDRAWN:
 					if (!widget->isA("EUserDrawnField"))
 					{
-						ttyputerr("Invalid item in .ui");
+						ttyputerr("Invalid item %d USERDRAWN in .ui", i);
 						return FALSE;
 					}
 					((EUserDrawnField*)widget)->dia = dia;
@@ -1425,7 +1777,7 @@ bool EDialogPrivate::checkChildren()
 				case POPUP:
 					if (!widget->isA("QComboBox"))
 					{
-						ttyputerr("Invalid item in .ui");
+						ttyputerr("Invalid item %d POPUP in .ui", i);
 						return FALSE;
 					}
 					connect(widget,SIGNAL(activated(int)),mapper,SLOT(map()));
@@ -1434,7 +1786,7 @@ bool EDialogPrivate::checkChildren()
 					{
 						if (!widget->isA("EIconField"))
 						{
-							ttyputerr("Invalid item in .ui");
+							ttyputerr("Invalid item %d ICON in .ui", i);
 							return FALSE;
 						}
 						dialog->list[i].data = (INTBIG)dialog->list[i].msg;
@@ -1448,7 +1800,7 @@ bool EDialogPrivate::checkChildren()
 				case SCROLLMULTI:
 					if (!widget->isA("EScrollField"))
 					{
-						ttyputerr("Invalid item in .ui");
+						ttyputerr("Invalid item %d SCROLL in .ui", i);
 						return FALSE;
 					}
 					connect(widget,SIGNAL(selectionChanged()),mapper,SLOT(map()));
@@ -1458,22 +1810,38 @@ bool EDialogPrivate::checkChildren()
 				default:
 					break;
 			}
+#ifdef REORDER
+			items[i] = widget;
+			mapper->setMapping( widget, i );
+#else
 			items[i] = widget;
 			mapper->setMapping( widget, i );
 			i++;
+#endif
 		}
 	}
+#ifdef REORDER
+	for (i = 0; i < dialog->items; i++)
+	{
+		if (!items[i])
+		{
+			ttyputerr("Dialog item %d is absent", i+1);
+			return FALSE;
+		}
+	}
+#else
     if (i != dialog->items)
     {
         ttyputerr("Too few items in .ui");
         return FALSE;
     }
+#endif
 	if (defbutton == 0 && buttonzero != 0) defbutton = buttonzero;
 	if (defbutton != 0) defbutton->setDefault(TRUE);
 	if (focus == 0) focus = defbutton;
 	if (focus == 0) focus = items[0];
 	if (focus != 0) focus->setFocus();
-    return true;
+    return TRUE;
 }
 #endif
 
@@ -1508,11 +1876,30 @@ void EDialogPrivate::closeEvent( QCloseEvent *e )
 
 void EDialogPrivate::keyPressEvent( QKeyEvent *e )
 {
-    /* ignore Escape because we should terminate by doneDialog only */
-    if( e->key() == Key_Escape ) return;
+    /* handle escape key (fakes a click on item 2 */
+    if( e->key() == Key_Escape && isModal() )
+	{
+		dia->itemHitAction(2);
+		return;
+	}
     QDialog::keyPressEvent( e );
 }
 
+bool EDialogPrivate::eventFilter( QObject *watched, QEvent *e )
+{
+#ifdef ETRACE
+    if (e->type () == QEvent::KeyPress) {
+		QKeyEvent* ke = (QKeyEvent*) e;
+		etrace(GTRACE, "  EDialogPrivate::eventFilter %s KeyPress <%c>\n", watched->className(), ke->ascii());
+	} else if (e->type() != QEvent::Paint && e->type() != QEvent::MouseMove)
+	{
+		/* Event type codes are in "/qt/include/qevent.h" */
+		etrace(GTRACE, "  EDialogPrivate::eventFilter %s type=%d\n", watched->className(), e->type());
+	}
+#endif
+    return QWidget::eventFilter( watched, e );
+}
+
 /******************************** Check Field ********************************/
 
 ECheckField::ECheckField( QString &text, QWidget *parent )
@@ -1547,6 +1934,11 @@ EScrollField::EScrollField( QWidget *parent )
 
 void EScrollField::keyPressEvent( QKeyEvent *e )
 {
+	if ( e->key() == Key_Enter || e->key() == Key_Return)
+	{
+		e->ignore();
+		return;
+	}
     if ( e->key() == Key_C && (e->state() & ControlButton) ||
 	 e->key() == Key_F16) { // Copy key on Sun keyboards
         qDebug( "Copy list");
