@@ -355,7 +355,7 @@ static EFont *gra_gettextfont(WINDOWPART *win, TECHNOLOGY *tech, UINTBIG *descri
 		return(0);
 	}
 	if (size < MINIMUMTEXTSIZE) size = MINIMUMTEXTSIZE;
-#if 1
+#if 0
     /* Increase font size to match Unix X11 port */
     size += 4;
 #endif
@@ -411,9 +411,7 @@ static EFont *gra_createtextfont(INTBIG fontSize, QString face, INTBIG italic, I
 	INTBIG underline)
 {
 	QFont font( face, fontSize );
-#if QT_VERSION >= 300
 	font.setStyleStrategy( QFont::NoAntialias );
-#endif
 	font.setItalic( italic );
 	font.setBold( bold );
 	font.setUnderline( underline );
@@ -479,7 +477,7 @@ void screendrawtext(WINDOWPART *win, INTBIG atx, INTBIG aty, char *s, GRAPHICS *
  * the pixels are returned in an array of character vectors "rowstart".
  * The routine returns nonzero if the operation cannot be done.
  */
-BOOLEAN gettextbits(WINDOWPART *win, char *msg, INTBIG *wid, INTBIG *hei, char ***rowstart)
+BOOLEAN gettextbits(WINDOWPART *win, char *msg, INTBIG *wid, INTBIG *hei, UCHAR1 ***rowstart)
 {
 	Q_UNUSED( win );
 
@@ -520,7 +518,7 @@ BOOLEAN gettextbits(WINDOWPART *win, char *msg, INTBIG *wid, INTBIG *hei, char *
 	{
 		if (gra_textbitsrowstartsize > 0) efree((char *)gra_textbitsrowstart);
 		gra_textbitsrowstartsize = 0;
-		gra_textbitsrowstart = (char **)emalloc(*hei * (sizeof (char *)), us_tool->cluster);
+		gra_textbitsrowstart = (char **)emalloc(*hei * (sizeof (UCHAR1 *)), us_tool->cluster);
 		if (gra_textbitsrowstart == 0) return(TRUE);
 		gra_textbitsrowstartsize = *hei;
 	}
@@ -530,7 +528,7 @@ BOOLEAN gettextbits(WINDOWPART *win, char *msg, INTBIG *wid, INTBIG *hei, char *
 	{
 		gra_textbitsrowstart[y] = &gra_textbitsdata[*wid * y];
 	}
-	*rowstart = gra_textbitsrowstart;
+	*rowstart = (UCHAR1 **)gra_textbitsrowstart;
 
 	if (*hei > MAXCHARBITS)
 	{
