@@ -34,9 +34,9 @@ extern "C"
 {
 #endif
 
-void com_init(INTBIG*, char*[], TOOL*);
+void com_init(INTBIG*, CHAR1*[], TOOL*);
 void com_done(void);
-void com_set(INTBIG, char*[]);
+void com_set(INTBIG, CHAR*[]);
 void com_slice(void);
 
 #if defined(__cplusplus) && !defined(ALLCPLUSPLUS)
