@@ -34,9 +34,9 @@ extern "C"
 {
 #endif
 
-void compen_init(INTBIG*, char*[], TOOL*);
+void compen_init(INTBIG*, CHAR1*[], TOOL*);
 void compen_done(void);
-void compen_set(INTBIG, char*[]);
+void compen_set(INTBIG, CHAR*[]);
 void compen_slice(void);
 void compen_modifynodeinst(NODEINST*,INTBIG,INTBIG,INTBIG,INTBIG,INTBIG,INTBIG);
 void compen_killobject(INTBIG, INTBIG);
