@@ -70,9 +70,9 @@
 #    else
 #      include "defines.h"
 #    endif
-#    define DIRSEP         '/'						/* directory separator */
-#    define DIRSEPSTR      "/"						/* directory separator */
-#    define LIBDIR         "lib/"					/* location of library files */
+#    define DIRSEP         '/'								/* directory separator */
+#    define DIRSEPSTR      x_("/")							/* directory separator */
+#    define LIBDIR         x_("lib/")						/* location of library files */
 #  else
 #    include <QDOffscreen.h>
 #    define u_int64_t      uint64_t
@@ -82,23 +82,23 @@
 #    define HAVE_STRING_H    1
 #    define HAVE_STDLIB_H    1
 #    define HAVE_INTTYPES_H  1
-#    define DIRSEP         ':'						/* directory separator */
-#    define DIRSEPSTR      ":"						/* directory separator */
-#    define LIBDIR         ":lib:"					/* location of library files */
+#    define DIRSEP         ':'								/* directory separator */
+#    define DIRSEPSTR      x_(":")							/* directory separator */
+#    define LIBDIR         x_(":lib:")						/* location of library files */
 #  endif
 #  define MACFSTAG(x)      x
-#  define NONFILECH        '|'						/* character that cannot be in file name */
-#  define CADRCFILENAME    "cadrc"					/* CAD startup file */
-#  define ESIMLOC          ""
-#  define RSIMLOC          ""
-#  define PRESIMLOC        ""
-#  define RNLLOC           ""
-#  define SPICELOC         ""
-#  define FASTHENRYLOC     ""
-#  define SORTLOC          ""
-#  define FLATDRCLOC       ""
-#  define SFLATDRCLOC      ""
-#  define BYTES_SWAPPED    1						/* bytes are MSB first */
+#  define NONFILECH        '|'								/* character that cannot be in file name */
+#  define CADRCFILENAME    x_("cadrc")						/* CAD startup file */
+#  define ESIMLOC          x_("")
+#  define RSIMLOC          x_("")
+#  define PRESIMLOC        x_("")
+#  define RNLLOC           x_("")
+#  define SPICELOC         x_("")
+#  define FASTHENRYLOC     x_("")
+#  define SORTLOC          x_("")
+#  define FLATDRCLOC       x_("")
+#  define SFLATDRCLOC      x_("")
+#  define BYTES_SWAPPED    1								/* bytes are MSB first */
 #endif
 
 #ifdef WIN32						/***** Windows *****/
@@ -108,22 +108,23 @@
 #  define HAVE_QSORT       1
 #  define HAVE_STRCHR      1
 #  define HAVE_STRING_H    1
-#  define DIRSEP           '\\'						/* directory separator */
-#  define DIRSEPSTR        "\\"						/* directory separator */
+#  define HAVE_MKTEMP      1
+#  define DIRSEP           '\\'								/* directory separator */
+#  define DIRSEPSTR        x_("\\")							/* directory separator */
 #  define MACFSTAG(x)      0
-#  define NONFILECH        '|'						/* character that cannot be in file name */
-#  define CADRCFILENAME    "cadrc"					/* CAD startup file */
-#  define LIBDIR           "lib\\"					/* location of library files */
-#  define TCLLIBDIR        "C:\\Program Files\\Tcl\\lib\\tcl8.3"/* installed TCL libraries */
-#  define ESIMLOC          ""
-#  define RSIMLOC          ""
-#  define PRESIMLOC        ""
-#  define RNLLOC           ""
-#  define SPICELOC         ""
-#  define FASTHENRYLOC     ""
-#  define SORTLOC          ""
-#  define FLATDRCLOC       ""
-#  define SFLATDRCLOC      ""
+#  define NONFILECH        '|'								/* character that cannot be in file name */
+#  define CADRCFILENAME    x_("cadrc")						/* CAD startup file */
+#  define LIBDIR           x_("lib\\")						/* location of library files */
+#  define TCLLIBDIR        x_("C:\\Program Files\\Tcl\\lib\\tcl8.3")/* installed TCL libraries */
+#  define ESIMLOC          x_("")
+#  define RSIMLOC          x_("")
+#  define PRESIMLOC        x_("")
+#  define RNLLOC           x_("")
+#  define SPICELOC         x_("")
+#  define FASTHENRYLOC     x_("")
+#  define SORTLOC          x_("")
+#  define FLATDRCLOC       x_("")
+#  define SFLATDRCLOC      x_("")
 #  undef TECHNOLOGY
 #  define int64_t          __int64
 #  define u_int64_t        unsigned __int64
@@ -135,26 +136,38 @@
 #    include <X11/Intrinsic.h>
 #  endif
 #  ifdef sparc
-#    define BYTES_SWAPPED  1						/* bytes are MSB first */
+#    define BYTES_SWAPPED  1								/* bytes are MSB first */
 #  endif
-#  define DIRSEP           '/'						/* directory separator */
-#  define DIRSEPSTR        "/"						/* directory separator */
+#  define DIRSEP           '/'								/* directory separator */
+#  define DIRSEPSTR        x_("/")							/* directory separator */
 #  define MACFSTAG(x)      0
-#  define NONFILECH        '?'						/* character that cannot be in file name */
-#  define CADRCFILENAME    ".cadrc"					/* CAD startup file */
-#  define LIBDIR           "/usr/local/lib/electric/"		/* location of library files */
-#  define DOCDIR           "/usr/local/doc/electric/html/"	/* location of HTML files */
-#  define ESIMLOC          "/usr/local/bin/esim"
-#  define RSIMLOC          "/usr/local/bin/rsim"
-#  define PRESIMLOC        "/usr/local/bin/presim"
-#  define RNLLOC           "/usr/local/bin/rnl"
-#  define SPICELOC         "/usr/local/bin/spice"
-#  define FASTHENRYLOC     "/usr/local/bin/fasthenry"
-#  define SORTLOC          "/usr/bin/sort"
-#  define FLATDRCLOC       "/usr/local/bin/ffindshort"
-#  define SFLATDRCLOC      "/usr/local/bin/findshort"
+#  define NONFILECH        '?'								/* character that cannot be in file name */
+#  define CADRCFILENAME    x_(".cadrc")						/* CAD startup file */
 #  ifdef sun
+#    define LIBDIR           x_("/usr/local/share/electric/lib/")	/* location of library files */
+#    define DOCDIR           x_("/usr/local/share/electric/doc/html/")	/* location of HTML files */
+#    define ESIMLOC          x_("/usr/local/bin/esim")
+#    define RSIMLOC          x_("/usr/local/bin/rsim")
+#    define PRESIMLOC        x_("/usr/local/bin/presim")
+#    define RNLLOC           x_("/usr/local/bin/rnl")
+#    define SPICELOC         x_("/usr/local/bin/spice")
+#    define FASTHENRYLOC     x_("/usr/local/bin/fasthenry")
+#    define SORTLOC          x_("/usr/local/bin/sort")
+#    define FLATDRCLOC       x_("/usr/local/bin/ffindshort")
+#    define SFLATDRCLOC      x_("/usr/local/bin/findshort")
 #    define u_int64_t uint64_t
+#  else
+#    define LIBDIR           x_("/usr/share/electric/lib/")	/* location of library files */
+#    define DOCDIR           x_("/usr/share/electric/doc/html/")	/* location of HTML files */
+#    define ESIMLOC          x_("/usr/bin/esim")
+#    define RSIMLOC          x_("/usr/bin/rsim")
+#    define PRESIMLOC        x_("/usr/bin/presim")
+#    define RNLLOC           x_("/usr/bin/rnl")
+#    define SPICELOC         x_("/usr/bin/spice")
+#    define FASTHENRYLOC     x_("/usr/bin/fasthenry")
+#    define SORTLOC          x_("/usr/bin/sort")
+#    define FLATDRCLOC       x_("/usr/bin/ffindshort")
+#    define SFLATDRCLOC      x_("/usr/bin/findshort")
 #  endif
 #endif
 
