@@ -49,8 +49,8 @@ extern INTBIG      cla_changeclock;		/* timestamp for changes */
 
 void cla_layconinit(CONSTRAINT*);
 void cla_layconterm(void);
-void cla_layconsetmode(INTBIG, char*[]);
-INTBIG cla_layconrequest(char*, INTBIG);
+void cla_layconsetmode(INTBIG, CHAR*[]);
+INTBIG cla_layconrequest(CHAR*, INTBIG);
 void cla_layconsolve(NODEPROTO*);
 void cla_layconnewobject(INTBIG, INTBIG);
 void cla_layconkillobject(INTBIG, INTBIG);
