@@ -82,7 +82,7 @@ extern BOOLEAN    cli_texton;		/* true if text/graphics system is on */
 
 typedef struct Iattr
 {
-	char         *name;				/* name of attribute */
+	CHAR         *name;				/* name of attribute */
 	INTBIG        type;				/* type of attribute */
 	struct Iattr *equiv;			/* for associating lists */
 	INTBIG        value;			/* value of attribute */
@@ -101,11 +101,11 @@ typedef struct Iattr
 
 typedef struct Icomponent
 {
-	INTBIG sizex, sizey;			/* object size (in half-millimicrons) */
-	INTBIG locx, locy;				/* object location (in half-millimicrons) */
+	INTBIG sizex, sizey;			/* object size (in database units) */
+	INTBIG locx, locy;				/* object location (in database units) */
 	INTBIG rot, trans;				/* rotation and transpose */
 	INTBIG flag;					/* valid information (see above) */
-	char  *name;
+	CHAR  *name;
 	ATTR  *firstattr;				/* list of attributes */
 	struct Icomponent *assoc;		/* for comparing component lists */
 	struct Icomponent *nextcomponent;
@@ -116,7 +116,7 @@ typedef struct Icomponent
 typedef struct Icomponentdec
 {
 	INTBIG count;
-	char *protoname;
+	CHAR *protoname;
 	COMPONENT *firstcomponent;
 } COMPONENTDEC;
 
@@ -131,7 +131,7 @@ typedef struct Icomponentdec
 
 typedef struct Icons
 {
-	char  *direction;				/* the constraint direction */
+	CHAR  *direction;				/* the constraint direction */
 	INTBIG amount;					/* the constraint amount (in WHOLE units) */
 	INTBIG flag;					/* 0: equal   1: geq   -1: leq */
 	struct Icons *assoc;			/* associated constraint */
@@ -151,15 +151,15 @@ typedef struct Icons
 
 typedef struct Iconnection
 {
-	char  *layer;					/* the connecting arc type (optional) */
+	CHAR  *layer;					/* the connecting arc type (optional) */
 	INTBIG width;					/* the width of the arc (optional) */
 	ATTR  *firstattr;				/* list of attributes (optional) */
-	char  *end1;					/* the node at end 1 */
-	char  *port1;					/* the port on the node at end 1 (optional) */
+	CHAR  *end1;					/* the node at end 1 */
+	CHAR  *port1;					/* the port on the node at end 1 (optional) */
 	CONS  *firstcons;				/* the constraints on the arc */
 	INTBIG xoff, yoff;				/* the actual distance (optional) */
-	char  *end2;					/* the node at end 2 */
-	char  *port2;					/* the port on the node at end 2 (optional) */
+	CHAR  *end2;					/* the node at end 2 */
+	CHAR  *port2;					/* the port on the node at end 2 (optional) */
 	INTBIG flag;					/* bits saying what is valid in this list */
 } CONNECTION;
 
@@ -172,9 +172,9 @@ typedef struct Iconnection
 
 typedef struct Iexport
 {
-	char  *portname;				/* the exported port name */
-	char  *component;				/* the component source of the port */
-	char  *subport;					/* the subport on the exported component */
+	CHAR  *portname;				/* the exported port name */
+	CHAR  *component;				/* the component source of the port */
+	CHAR  *subport;					/* the subport on the exported component */
 	INTBIG bits;					/* the characteristics/location of the port */
 	ATTR  *firstattr;				/* list of attributes (optional) */
 	INTBIG flag;					/* bits saying what is valid in list */
@@ -185,8 +185,8 @@ typedef struct Iexport
 
 void cli_linconinit(CONSTRAINT*);
 void cli_linconterm(void);
-void cli_linconsetmode(INTBIG, char*[]);
-INTBIG cli_linconrequest(char*, INTBIG);
+void cli_linconsetmode(INTBIG, CHAR*[]);
+INTBIG cli_linconrequest(CHAR*, INTBIG);
 void cli_linconsolve(NODEPROTO*);
 void cli_linconnewobject(INTBIG, INTBIG);
 void cli_linconkillobject(INTBIG, INTBIG);
@@ -223,19 +223,19 @@ void cli_eq_modnode(NODEINST*);
 void cli_eq_modport(PORTPROTO*);
 void cli_eq_newvar(INTBIG, INTBIG, INTBIG);
 void cli_eq_killvar(INTBIG, INTBIG, INTBIG);
-INTBIG cli_linetype(char*);
-COMPONENTDEC *cli_parsecomp(char*, BOOLEAN);
+INTBIG cli_linetype(CHAR*);
+COMPONENTDEC *cli_parsecomp(CHAR*, BOOLEAN);
 void cli_deletecomponentdec(COMPONENTDEC*);
-WINDOWPART *cli_makeeditorwindow(char*, INTBIG*, INTBIG*);
-void cli_replaceendfacet(char*, WINDOWPART*);
-EXPORT *cli_parseexport(char*, BOOLEAN);
+WINDOWPART *cli_makeeditorwindow(CHAR*, INTBIG*, INTBIG*);
+void cli_replaceendfacet(CHAR*, WINDOWPART*);
+EXPORT *cli_parseexport(CHAR*, BOOLEAN);
 void cli_deleteexport(EXPORT*);
-CONNECTION *cli_parseconn(char*, BOOLEAN);
+CONNECTION *cli_parseconn(CHAR*, BOOLEAN);
 void cli_deleteconnection(CONNECTION*);
-ARCINST *cli_findarcname(char*);
-NODEINST *cli_findnodename(char*);
-char *cli_parsebeginfacet(char*, BOOLEAN);
-void cli_replacename(char*, char*);
+ARCINST *cli_findarcname(CHAR*);
+NODEINST *cli_findnodename(CHAR*);
+CHAR *cli_parsebeginfacet(CHAR*, BOOLEAN);
+void cli_replacename(CHAR*, CHAR*);
 BOOLEAN cli_pickwire(CONNECTION*, NODEINST**, PORTPROTO**, NODEINST**, PORTPROTO**, ARCPROTO**, INTBIG*, ARCINST*, NODEINST*, NODEINST*);
 void cli_deletearcconstraint(ARCINST*, INTBIG, INTBIG, INTBIG);
 BOOLEAN cli_addarcconstraint(ARCINST*, INTBIG, INTBIG, INTBIG, INTBIG);
