@@ -39,7 +39,7 @@ extern "C"
 #if LANGLISP
 # include "elkkernel.h"
   void      lsp_init(void);
-  ELKObject lsp_makeobject(char*);
+  ELKObject lsp_makeobject(CHAR*);
   BOOLEAN   lsp_describeobject(ELKObject, INTBIG, INTBIG*);
 #endif
 
@@ -48,11 +48,11 @@ extern "C"
 #if LANGTCL
 # include "tcl.h"
   void    el_tclinterpreter(Tcl_Interp *interp);
-  INTBIG  tcl_converttoelectric(char *tclstr, INTBIG type);
+  INTBIG  tcl_converttoelectric(CHAR *tclstr, INTBIG type);
   void    tcl_nativemenuinitialize(void);
-  BOOLEAN tcl_nativemenuload(INTBIG count, char *par[]);
+  BOOLEAN tcl_nativemenuload(INTBIG count, CHAR *par[]);
   extern Tcl_Interp *tcl_interp;
-  extern char *tcl_outputbuffer, *tcl_outputloc;
+  extern CHAR *tcl_outputbuffer, *tcl_outputloc;
 #endif
 
 /***************************** JAVA DECLARATIONS *****************************/
@@ -70,11 +70,11 @@ extern "C"
 # define METHODRETURNSLONG    7
 # define METHODRETURNSFLOAT   8
 # define METHODRETURNSDOUBLE  9
-  char   *java_init(void);
-  BOOLEAN java_evaluate(char *str);
-  char   *java_query(char *str, INTBIG *methodreturntype);
+  CHAR   *java_init(void);
+  BOOLEAN java_evaluate(CHAR *str);
+  CHAR   *java_query(CHAR *str, INTBIG *methodreturntype);
   void    java_freememory(void);
-  BOOLEAN java_addprivatenatives(char *methodname, char *methoddescription, void *method);
+  BOOLEAN java_addprivatenatives(CHAR1 *methodname, CHAR1 *methoddescription, void *method);
   jobject java_makeobject(INTBIG addr, INTBIG type);
 
   extern JNIEnv  *java_environment;
