@@ -37,7 +37,6 @@ extern "C"
 /* #define SURROUNDRULES 1 */		/* uncomment to add surround rule code (not ready yet) */
 
 /* the meaning of "DRC_options" */
-#define DRCHIERDIALOG              1		/* set to force hierarchical DRC to use dialog */
 #define DRCFIRSTERROR              2		/* set to stop after first error in a facet */
 #define DRCREASONABLE              4		/* set to only examine "reasonable" number of polygons per node */
 #define DRCMULTIPROC             010		/* set to use multiple processors for DRC */
@@ -70,31 +69,31 @@ extern "C"
 
 typedef struct
 {
-	char    *techname;			/* name of the technology */
+	CHAR    *techname;			/* name of the technology */
 	INTBIG   numlayers;			/* number of layers in the technology */
 	INTBIG   utsize;			/* size of upper-triangle of layers */
 	INTBIG   widelimit;			/* width limit that triggers wide rules */
-	char   **layernames;		/* names of layers */
+	CHAR   **layernames;		/* names of layers */
 	INTBIG  *minwidth;			/* minimum width of layers */
-	char   **minwidthR;			/* minimum width rules */
+	CHAR   **minwidthR;			/* minimum width rules */
 	INTBIG  *conlist;			/* minimum distances when connected */
-	char   **conlistR;			/* minimum distance ruless when connected */
+	CHAR   **conlistR;			/* minimum distance ruless when connected */
 	INTBIG  *unconlist;			/* minimum distances when unconnected */
-	char   **unconlistR;		/* minimum distance rules when unconnected */
+	CHAR   **unconlistR;		/* minimum distance rules when unconnected */
 	INTBIG  *conlistW;			/* minimum distances when connected (wide) */
-	char   **conlistWR;			/* minimum distance rules when connected (wide) */
+	CHAR   **conlistWR;			/* minimum distance rules when connected (wide) */
 	INTBIG  *unconlistW;		/* minimum distances when unconnected (wide) */
-	char   **unconlistWR;		/* minimum distance rules when unconnected (wide) */
+	CHAR   **unconlistWR;		/* minimum distance rules when unconnected (wide) */
 	INTBIG  *conlistM;			/* minimum distances when connected (multi-cut) */
-	char   **conlistMR;			/* minimum distance rules when connected (multi-cut) */
+	CHAR   **conlistMR;			/* minimum distance rules when connected (multi-cut) */
 	INTBIG  *unconlistM;		/* minimum distances when unconnected (multi-cut) */
-	char   **unconlistMR;		/* minimum distance rules when unconnected (multi-cut) */
+	CHAR   **unconlistMR;		/* minimum distance rules when unconnected (multi-cut) */
 	INTBIG  *edgelist;			/* edge distances */
-	char   **edgelistR;			/* edge distance rules */
+	CHAR   **edgelistR;			/* edge distance rules */
 	INTBIG   numnodes;			/* number of nodes in the technology */
-	char   **nodenames;			/* names of nodes */
+	CHAR   **nodenames;			/* names of nodes */
 	INTBIG  *minnodesize;		/* minimim node size in the technology */
-	char   **minnodesizeR;		/* minimim node size rules */
+	CHAR   **minnodesizeR;		/* minimim node size rules */
 } DRCRULES;
 
 extern TOOL       *dr_tool;								/* the DRC tool object */
@@ -129,12 +128,12 @@ extern BOOLEAN     dr_logerrors;						/* TRUE to log errors in error reporting s
 extern TECHNOLOGY *dr_curtech;							/* technology whose valid layers are cached */
 extern BOOLEAN    *dr_layersvalid;						/* list of valid layers in cached technology */
 
-void      dr_init(INTBIG*, char*[], TOOL*);
+void      dr_init(INTBIG*, CHAR1*[], TOOL*);
 void      dr_done(void);
-void      dr_set(INTBIG, char*[]);
+void      dr_set(INTBIG, CHAR*[]);
 void      dr_examinenodeproto(NODEPROTO*);
 void      dr_slice(void);
-INTBIG    dr_request(char *command, va_list ap);
+INTBIG    dr_request(CHAR *command, va_list ap);
 void      dr_modifynodeinst(NODEINST*,INTBIG,INTBIG,INTBIG,INTBIG,INTBIG,INTBIG);
 void      dr_modifyarcinst(ARCINST*,INTBIG,INTBIG,INTBIG,INTBIG,INTBIG,INTBIG);
 void      dr_newobject(INTBIG, INTBIG);
@@ -144,16 +143,16 @@ void      dr_eraselibrary(LIBRARY*);
 
 /* intertool prototypes */
 void      dr_flatwrite(NODEPROTO*);
-void      dr_flatignore(char*);
-void      dr_flatunignore(char*);
+void      dr_flatignore(CHAR*);
+void      dr_flatunignore(CHAR*);
 INTBIG    dr_rulesdlog(TECHNOLOGY *tech, DRCRULES *rules);
-DRCRULES *dr_allocaterules(INTBIG layercount, INTBIG nodecount, char *techname);
+DRCRULES *dr_allocaterules(INTBIG layercount, INTBIG nodecount, CHAR *techname);
 void      dr_freerules(DRCRULES *rules);
 INTBIG    dr_getoptionsvalue(void);
 void      dr_reset_dates(void);
 void      dr_cachevalidlayers(TECHNOLOGY *tech);
 INTBIG    dr_adjustedmindist(TECHNOLOGY *tech, LIBRARY *lib, INTBIG layer1, INTBIG size1,
-			INTBIG layer2, INTBIG size2, BOOLEAN con, BOOLEAN multi, INTBIG *edge, char **rule);
+			INTBIG layer2, INTBIG size2, BOOLEAN con, BOOLEAN multi, INTBIG *edge, CHAR **rule);
 
 INTBIG    drcb_check(NODEPROTO *facet, BOOLEAN report, BOOLEAN justarea);
 void      drcb_initincrementalcheck(NODEPROTO *facet);
