@@ -172,7 +172,7 @@ typedef struct Idialogitem
                                   that is used by the dialog system. It should be 0 initially. */
 	RECTAREA      r;           /**< location of item. The bounds of the item */
 	INTBIG        type;        /**< the type of the item - OR'ed #DialogItemType. */
-	char         *msg;         /**< initial item string placed in the item */
+	CHAR         *msg;         /**< initial item string placed in the item */
 } DIALOGITEM;
 
 /** Platform-independent description of dialog structure.
@@ -181,13 +181,13 @@ typedef struct Idialogitem
 typedef struct
 {
 	RECTAREA    windowRect;    /**< location of dialog on the display */
-	char       *movable;       /**< dialog title (o if none).
+	CHAR       *movable;       /**< dialog title (o if none).
                                   If 0, no title bar will be displayed for the dialog. */
 	INTBIG      translated;    /**< translated into foreign language */
 	INTBIG      items;         /**< number of items in the dialog */
 	DIALOGITEM *list;          /**< array of dialog items. An array of DIALOGITEM
                                   structures that define the items in the dialog */
-    char       *uiFile;        /**< name of Qt ".ui" file with form description */
+    CHAR       *uiFile;        /**< name of Qt ".ui" file with form description */
     INTBIG      briefHeight;   /**< height of brief part of extensible dialog.
                                   If 0, dialog is not extensible */
 } DIALOG;
@@ -217,7 +217,11 @@ public:
 	 * Dialogs usually are created by EDialogModal and EDialogModeless constructors.
      */
 	EDialog(DIALOG *dialog); 
+#if defined(__GNUC__) && __GNUC__ >= 3
+	virtual ~EDialog(); //!< Destroys the dialog
+#else
 	~EDialog(); //!< Destroys the dialog
+#endif
 	/** This function can be reimplemented in a subclass to return dialog state to initial.
      * It is called when it is necessary to reset state of dialog to initial (for example,
      * after library saving.
@@ -246,8 +250,8 @@ public:
 
 	/** \name C++ API - Control of standard dialog items */
 	/*@{*/	
-	void setText(INTBIG item, char *msg); //!< puts \a msg in \a item in the dialog
-	char *getText(INTBIG item); //!< gets text in \a item in the dialog
+	void setText(INTBIG item, CHAR *msg); //!< puts \a msg in \a item in the dialog
+	CHAR *getText(INTBIG item); //!< gets text in \a item in the dialog
 	void setControl(INTBIG item, INTBIG value); //!< puts \a value in \a item in the dialog
 	INTBIG getControl(INTBIG item); //!< gets integer in \a item in the dialog
 	BOOLEAN validEntry(INTBIG item); //!< returns true if \a item is nonblank in the dialog
@@ -261,12 +265,12 @@ public:
 	void editControl(INTBIG item); //!< makes \a item editable in the dialog
 	void opaqueEdit(INTBIG item); //!< makes \a item not display text
 	void defaultButton(INTBIG item); //!< makes \a item the default button
-	void changeIcon(INTBIG item, char *icon); //!< sets the icon in \a item to \a addr
+	void changeIcon(INTBIG item, UCHAR1 *icon); //!< sets the icon in \a item to \a addr
 	/*@}*/
 
 	/** \name C++ API -  Control of popup items */
 	/*@{*/
-	void setPopup(INTBIG item, INTBIG count, char **names); //!< makes \a item a popup with \a count entries in \a names
+	void setPopup(INTBIG item, INTBIG count, CHAR **names); //!< makes \a item a popup with \a count entries in \a names
 	void setPopupEntry(INTBIG item, INTBIG entry); //!< makes popup \a item use entry \a entry as current
 	INTBIG getPopupEntry(INTBIG item); //!< gets current entry in popup \a item
 	/*@}*/
@@ -282,7 +286,7 @@ public:
      * ::SCSMALLFONT to display the list with a small font; and ::SCFIXEDWIDTH to display the list with
      * a fixed-width font.
      */
-	void initTextDialog(INTBIG item, BOOLEAN (*toplist)(char **), char *(*nextinlist)(void),
+	void initTextDialog(INTBIG item, BOOLEAN (*toplist)(CHAR **), CHAR *(*nextinlist)(void),
 			void (*donelist)(void), INTBIG sortpos, INTBIG flags);
 	/** This routine reloads the scroll-list \a item.
      * The scroll-list \a item will contain strings obtained by \a toplist, \a nextinlist,
@@ -294,16 +298,16 @@ public:
      * ::DiaNullDlogList, ::DiaNullDlogItem, ::DiaNullDlogDone. The items are sorted in character
      * position \a sortpos (-1 to not sort). \sa initTextDialog
 	 */
-	void loadTextDialog(INTBIG item, BOOLEAN (*toplist)(char **), char *(*nextinlist)(void),
+	void loadTextDialog(INTBIG item, BOOLEAN (*toplist)(CHAR **), CHAR *(*nextinlist)(void),
 			void (*donelist)(void), INTBIG sortpos);
-	void stuffLine(INTBIG item, char *line); //!< add \a line to \a item
+	void stuffLine(INTBIG item, CHAR *line); //!< add \a line to \a item
 	void selectLine(INTBIG item, INTBIG line); //!< select line \a l in \a item
 	void selectLines(INTBIG item, INTBIG count, INTBIG *lines); //!< select \a count lines in \a lines in \a item
 	INTBIG getCurLine(INTBIG item); //!< get current line number in scroll \a item
 	INTBIG *getCurLines(INTBIG item); //!< get array of selected lines in scroll \a item
 	INTBIG getNumScrollLines(INTBIG item); //!< returns number of lines in scroll \a item
-	char *getScrollLine(INTBIG item, INTBIG line); //!< get \a line in scroll \a item
-	void setScrollLine(INTBIG item, INTBIG line, char *msg); //!< set line \a which in scroll \a item
+	CHAR *getScrollLine(INTBIG item, INTBIG line); //!< get \a line in scroll \a item
+	void setScrollLine(INTBIG item, INTBIG line, CHAR *msg); //!< set line \a which in scroll \a item
 	void synchVScrolls(INTBIG item1, INTBIG item2, INTBIG item3); //!< synchronizes vertical scroll items \a item1 \a item2 \a item3
 	void unSynchVScrolls(); //!< removes all vertical scroll synchronization
 	/*@}*/
@@ -322,15 +326,15 @@ public:
 	//! draw line from (\a fx, \a fy) to (\a tx, \a ty) with \a mode
 	void drawLine(INTBIG item, INTBIG fx, INTBIG fy, INTBIG tx, INTBIG ty, INTBIG mode);
 	void setTextSize(INTBIG size); //!< set size of text to \a size
-	void getTextInfo(char *msg, INTBIG *wid, INTBIG *hei); //!< get \a wid and \a hei of \a msg
-	void putText(INTBIG item, char *msg, INTBIG x, INTBIG y); //!< put text \ msg at (\a x, \a y)
+	void getTextInfo(CHAR *msg, INTBIG *wid, INTBIG *hei); //!< get \a wid and \a hei of \a msg
+	void putText(INTBIG item, CHAR *msg, INTBIG x, INTBIG y); //!< put text \ msg at (\a x, \a y)
 	void trackCursor(void (*eachdown)(INTBIG x, INTBIG y)); //!< track cursor calling \a eachdown on mouse move
 	void getMouse(INTBIG *x, INTBIG *y); //!< get current mouse position into \a x/ \a y
 	/*@}*/
 
 	DIALOG *itemDesc() { return itemdesc; } //!< DIALOG structure, describing this dialog
 #ifdef USEQT
-	static QStrList *itemNamesFromUi( char *uiFile, BOOLEAN ext = FALSE );
+	static QStrList *itemNamesFromUi( CHAR *uiFile, BOOLEAN ext = FALSE );
 #endif
 protected:
 	EDialogPrivate *d;
@@ -411,10 +415,10 @@ INTBIG  DiaNextHit(void *dia);
 /*@{*/
 /** puts \a msg in \a item in the dialog
  */
-void    DiaSetText(void *dia, INTBIG item, char *msg);
+void    DiaSetText(void *dia, INTBIG item, CHAR *msg);
 /** gets text in \a item in the dialog
  */
-char   *DiaGetText(void *dia, INTBIG item);
+CHAR   *DiaGetText(void *dia, INTBIG item);
 /** puts \a value in \a item in the dialog
  */
 void    DiaSetControl(void *dia, INTBIG item, INTBIG value);
@@ -447,14 +451,14 @@ void    DiaOpaqueEdit(void *dia, INTBIG item);
 void    DiaDefaultButton(void *dia, INTBIG item);
 /** sets the icon in \a item to \a addr
  */
-void    DiaChangeIcon(void *dia, INTBIG item, char *addr);
+void    DiaChangeIcon(void *dia, INTBIG item, UCHAR1 *addr);
 /*@}*/
 
 /** \name C API - Control of popup items */
 /*@{*/
 /** makes \a item a popup with \a count entries in \a names
  */
-void    DiaSetPopup(void *dia, INTBIG item, INTBIG count, char **names);
+void    DiaSetPopup(void *dia, INTBIG item, INTBIG count, CHAR **names);
 /** makes popup \a item use entry \a entry as current
  */
 void    DiaSetPopupEntry(void *dia, INTBIG item, INTBIG entry);
@@ -467,16 +471,16 @@ INTBIG  DiaGetPopupEntry(void *dia, INTBIG item);
 /*@{*/
 /** \sa EDialog::initTextDialog
   */
-void    DiaInitTextDialog(void *dia, INTBIG item, BOOLEAN (*toplist)(char **),
-			char *(*nextinlist)(void), void (*donelist)(void),
+void    DiaInitTextDialog(void *dia, INTBIG item, BOOLEAN (*toplist)(CHAR **),
+			CHAR *(*nextinlist)(void), void (*donelist)(void),
             INTBIG sortpos, INTBIG flags);
 /** \sa EDialog::loadTextDialog
  */
-void    DiaLoadTextDialog(void *dia, INTBIG item, BOOLEAN (*toplist)(char **),
-			char *(*nextinlist)(void), void (*donelist)(void), INTBIG sortpos);
+void    DiaLoadTextDialog(void *dia, INTBIG item, BOOLEAN (*toplist)(CHAR **),
+			CHAR *(*nextinlist)(void), void (*donelist)(void), INTBIG sortpos);
 /** add line \a msg to \a item
  */
-void    DiaStuffLine(void *dia, INTBIG item, char *line);
+void    DiaStuffLine(void *dia, INTBIG item, CHAR *line);
 /** select line \a l in \a item
  */
 void    DiaSelectLine(void *dia, INTBIG item, INTBIG which);
@@ -494,10 +498,10 @@ INTBIG *DiaGetCurLines(void *dia, INTBIG item);
 INTBIG  DiaGetNumScrollLines(void *dia, INTBIG item);
 /** get line \a l in scroll \a item
  */
-char   *DiaGetScrollLine(void *dia, INTBIG item, INTBIG which);
+CHAR   *DiaGetScrollLine(void *dia, INTBIG item, INTBIG which);
 /** set line \a which in scroll \a item
  */
-void    DiaSetScrollLine(void *dia, INTBIG item, INTBIG which, char *msg);
+void    DiaSetScrollLine(void *dia, INTBIG item, INTBIG which, CHAR *msg);
 /** synchronizes vertical scroll items \a item1 \a item2 \a item3
  */
 void    DiaSynchVScrolls(void *dia, INTBIG item1, INTBIG item2, INTBIG item3);
@@ -540,10 +544,10 @@ void    DiaDrawLine(void *dia, INTBIG item, INTBIG fx, INTBIG fy, INTBIG tx, INT
 void    DiaSetTextSize(void *dia, INTBIG size);
 /** get \a wid and \a hei of \a msg
  */
-void    DiaGetTextInfo(void *dia, char *msg, INTBIG *wid, INTBIG *hei);
+void    DiaGetTextInfo(void *dia, CHAR *msg, INTBIG *wid, INTBIG *hei);
 /** put text \a msg at (\a x, \a y)
  */
-void    DiaPutText(void *dia, INTBIG item, char *msg, INTBIG x, INTBIG y);
+void    DiaPutText(void *dia, INTBIG item, CHAR *msg, INTBIG x, INTBIG y);
 /** track cursor calling \a eachdown on mouse move
  */
 void    DiaTrackCursor(void *dia, void (*eachdown)(INTBIG x, INTBIG y));
@@ -553,7 +557,7 @@ void    DiaGetMouse(void *dia, INTBIG *x, INTBIG *y);
 /*@}*/
 
 /** routine to show message in a message dialog */
-void    DiaMessageInDialog(char*, ...);
+void    DiaMessageInDialog(CHAR*, ...);
 
 /** routine used by tools to create private dialogs.
  * The parameter \a terminputkeyword is the keyword that the "terminal input" command
@@ -561,11 +565,11 @@ void    DiaMessageInDialog(char*, ...);
  * command completion objects that, when parsed, will invoke the dialog. The parameter
  * \a routine is the code that runs the dialog.
  */
-void    DiaDeclareHook(char *terminputkeyword, COMCOMP *getlinecomp, void (*routine)(void));
+void    DiaDeclareHook(CHAR *terminputkeyword, COMCOMP *getlinecomp, void (*routine)(void));
 /** routine used for toplist argument EDialog::initTextDialog and EDialog::loadTextDialog if empty initial list is desired */
-BOOLEAN DiaNullDlogList(char**);
+BOOLEAN DiaNullDlogList(CHAR**);
 /** routine used for nextinlist argument EDialog::initTextDialog and EDialog::loadTextDialog if empty initial list is desired */
-char   *DiaNullDlogItem(void);
+CHAR   *DiaNullDlogItem(void);
 /** routine used for donelist argument EDialog::initTextDialog and EDialog::loadTextDialog if empty initial list is desired */
 void    DiaNullDlogDone(void);
 /** routine translates dialog \a dia into a foreign-language.
@@ -587,18 +591,18 @@ void    DiaCloseAllModeless();
  * If \a caption is 0, caption is not shown.
  * Returned pointer is passed as dia argument to other progress bar routines
  */
-void   *DiaInitProgress(char *label, char *caption);
+void   *DiaInitProgress(CHAR *label, CHAR *caption);
 /** update progress bar of progress dialog.
  * Progress bar will show \a dia to \a progress / \a totalSteps * 100 percent.
  * On Qt dialog is hidden if \a progress == \a totalSteps .
  */
 void    DiaSetProgress(void *dia, INTBIG progress, INTBIG totalSteps);
 /** change label of progress dialog */
-void    DiaSetTextProgress(void *dia, char *label);
+void    DiaSetTextProgress(void *dia, CHAR *label);
 /** get lable of progress dialog */
-char   *DiaGetTextProgress(void *dia);
+CHAR   *DiaGetTextProgress(void *dia);
 /** change caption of progress dialog */
-void    DiaSetCaptionProgress(void *dia, char *caption);
+void    DiaSetCaptionProgress(void *dia, CHAR *caption);
 /** destroy progress dialog */
 void    DiaDoneProgress(void *dia);
 /*@}*/
