@@ -50,9 +50,9 @@ extern "C"
 extern TOOL       *erc_tool;				/* this tool */
 extern INTBIG      erc_antennaarcratiokey;	/* key for "ERC_antenna_arc_ratio" */
 
-void erc_init(INTBIG*, char*[], TOOL*);
+void erc_init(INTBIG*, CHAR1*[], TOOL*);
 void erc_done(void);
-void erc_set(INTBIG, char*[]);
+void erc_set(INTBIG, CHAR*[]);
 
 /* the antenna rules interface */
 void erc_antcheckfacet(NODEPROTO *facet);
