@@ -130,10 +130,10 @@ typedef enum
 
 typedef struct
 {
-	char a11[7];
-	char a12[7];
-	char a21[7];
-	char a22[7];
+	CHAR a11[7];
+	CHAR a12[7];
+	CHAR a21[7];
+	CHAR a22[7];
 } orientation_type;
 
 typedef struct
@@ -142,35 +142,8 @@ typedef struct
 	INTBIG	py;
 } point_type;
 
-typedef struct
-{
-	INTBIG	tag;
-	union {
-		UINTSML	value;
-		struct
-		{
-			unsigned flag15:1;
-			unsigned flag14:1;
-			unsigned flag13:1;
-			unsigned flag12:1;
-			unsigned flag11:1;
-			unsigned flag10:1;
-			unsigned flag9:1;
-			unsigned flag8:1;
-			unsigned flag7:1;
-			unsigned flag6:1;
-			unsigned flag5:1;
-			unsigned flag4:1;
-			unsigned flag3:1;
-			unsigned flag2:1;
-			unsigned flag1:1;
-			unsigned flag0:1;
-		} f;
-	} u;
-} bit_array;
-
 typedef struct _stream
 {
 	FILE   *fp;
-	char    buf[BLOCKSIZE];
+	UCHAR1   buf[BLOCKSIZE];
 } STREAM;
