@@ -33,7 +33,7 @@
 
 typedef struct Iviadef
 {
-	char       *vianame;
+	CHAR       *vianame;
 	NODEPROTO  *via;
 	ARCPROTO   *lay1, *lay2;
 	INTBIG      sx, sy;
