@@ -45,9 +45,9 @@ extern "C"
 extern TOOL    *le_tool;				/* the Logical Effort tool object */
 extern INTBIG   le_wire_ratio_key;		/* variable key for "LE_wire_ratio" */
 
-void le_init(INTBIG*, char*[], TOOL*);
+void le_init(INTBIG*, CHAR1*[], TOOL*);
 void le_done(void);
-void le_set(INTBIG, char*[]);
+void le_set(INTBIG, CHAR*[]);
 
 #if defined(__cplusplus) && !defined(ALLCPLUSPLUS)
 }
