@@ -34,6 +34,8 @@ extern "C"
 {
 #endif
 
+#define NEWNCC	1		/* comment out to remove last-minute changes */
+
 /* the meaning of tool:network.NET_options */
 #define NETCONPWRGND          1		/* set to connect power and ground */
 #define NETCONCOMMONNAME      2		/* set to connect commonly named nets */
@@ -44,14 +46,17 @@ extern "C"
 
 #define HASHTYPE        INTHUGE		/* the size of hash values */
 
+extern INTBIG      net_options;					/* cached value for "NET_options" */
+extern INTBIG      net_unifystringskey;			/* key for "NET_unify_strings" */
+extern INTBIG      net_unifystringskey;			/* key for "NET_component_tolerance" */
+extern INTBIG      net_node_abbrev_key;			/* key for "NET_node_abbreviations" */
+extern INTBIG      net_node_abbrevlen_key;		/* key for "NET_node_abbreviation_length" */
 extern INTBIG      net_ncc_optionskey;			/* key for "NET_ncc_options" */
 extern INTBIG      net_ncc_comptolerancekey;	/* key for "NET_ncc_component_tolerance" */
 extern INTBIG      net_ncc_comptoleranceamtkey;	/* key for "NET_ncc_component_tolerance_amt" */
 extern INTBIG      net_ncc_matchkey;			/* key for "NET_ncc_match" */
-extern INTBIG      net_node_abbrev_key;			/* key for "NET_node_abbreviations" */
-extern INTBIG      net_node_abbrevlen_key;		/* key for "NET_node_abbreviation_length" */
 extern INTBIG      net_ncc_processors_key;		/* key for "NET_ncc_num_processors" */
-extern INTBIG      net_options;					/* cached value for "NET_options" */
+extern INTBIG      net_ncc_options;				/* options to use in NCC */
 
 /* the meaning of tool:network.NET_ncc_options */
 #define NCCHIERARCHICAL               01		/* set to expand hierarchy during NCC */
@@ -61,6 +66,9 @@ extern INTBIG      net_options;					/* cached value for "NET_options" */
 #define NCCIGNOREPWRGND              020		/* set to ignore power/ground during NCC */
 #define NCCRECURSE                   040		/* set to do NCC recursively */
 #define NCCHIDEMATCHTAGS            0200		/* set to hide "NCCMatch" tags */
+#ifdef NEWNCC
+#define NCCINCLUDENOCOMPNETS        0400		/* set to include no-component nets */
+#endif
 #define NCCCHECKSIZE               01000		/* set to check component size during NCC */
 #define NCCNOMERGEPARALLEL         04000		/* set to not merge parallel components during NCC */
 #define NCCNOMERGEPARALLELOVER    010000		/* set to override parallel component nonmerge for a facet */
@@ -70,6 +78,109 @@ extern INTBIG      net_options;					/* cached value for "NET_options" */
 #define NCCEXPERIMENTAL          0200000		/* set to use experimental NCC */
 #define NCCGRAPHICPROGRESS       0400000		/* set to show NCC progress graphically */
 
+/*********************** NET FACET PRIVATE ************************/
+
+#ifdef __cplusplus
+
+#define CHECKARITY                          /* data structures to speed up check of bus names arity */
+
+class NetFacetPrivate;                      /* private network data */
+class NetName;                              /* name of network */
+class NetFacetShorts;                       /* electrical shortcuts between exports inside facet */
+
+class NetFacetPrivate
+{
+	friend class NetName;
+public:
+	void* operator new( size_t size );
+	void* operator new( size_t size, CLUSTER *cluster );
+	void operator delete( void* obj );
+#ifndef MACOS
+	void operator delete( void *obj, CLUSTER *cluster );
+#endif
+	NetFacetPrivate( NODEPROTO *np, CLUSTER *cluster );
+	~NetFacetPrivate();
+	BOOLEAN updateShorts();
+	NetFacetShorts *netshorts() { return _netshorts; };
+	NetName *findNetName( CHAR *name, BOOLEAN insert );
+	void check();
+private:
+	void rehashNetNames();
+	void insertNetName( NetName *nn, INTBIG hash );
+	NODEPROTO *_np;
+	CLUSTER *_cluster;
+	NetName **_netnamehash;
+	INTBIG _netnametotal;
+	INTBIG _netnamecount;
+	NetFacetShorts *_netshorts;
+};
+
+class NetFacetShorts
+{
+public:
+	void* operator new( size_t size );
+	void* operator new( size_t size, CLUSTER *cluster );
+	void operator delete( void* obj );
+#ifndef MACOS
+	void operator delete( void *obj, CLUSTER *cluster );
+#endif
+	NetFacetShorts( NODEPROTO *np, CLUSTER *cluster );
+	~NetFacetShorts();
+	BOOLEAN isConsistent();
+	void printf();
+	INTBIG portwidth( INTBIG portno );
+	INTBIG portcount() { return _portcount; };
+	INTBIG globalcount() { return _portbeg[0]; };
+	INTBIG portdeepcount() { return _portbeg[_portcount] - _portbeg[0]; };
+	INTBIG portshallowmap(INTBIG portno) { return _portshallowmap[portno]; };
+	BOOLEAN globalshort() { return _globalshort; };
+private:
+	static void clearNetworks(NODEPROTO *np);
+	NODEPROTO *_np;
+	INTBIG _portcount;
+	INTBIG *_portbeg;
+	CHAR **_globalnames;
+	INTBIG *_portshallowmap;
+	INTBIG *_portdeepmap;
+	BOOLEAN _globalshort;
+};
+
+/*********************** NET NAME ************************/
+
+class NetName
+{
+	friend class NetFacetPrivate;
+public:
+	void* operator new( size_t size );
+	void* operator new( size_t size, CLUSTER *cluster );
+	void operator delete( void* obj );
+#ifndef MACOS
+	void operator delete( void *obj, CLUSTER *cluster );
+#endif
+	NetName( NetFacetPrivate *npd, CHAR *name );
+	~NetName();
+	NETWORK *firstNet();
+	void addNet(NETWORK *net);
+	void removeNet(NETWORK *net);
+	CHAR *name() { return _name; };
+#ifdef CHECKARITY
+	void checkArity();
+#endif
+private:
+	void check();
+	void checkNet(NETWORK *net);
+	NetFacetPrivate *_npd;
+	CHAR *_name;
+	INTBIG _netcount;
+	INTBIG _netaddr;
+#ifdef CHECKARITY
+	class NetName *_baseNetName;
+	INTBIG _baseRefCount;
+#endif
+};        
+
+#endif
+
 /*********************** PCOMP MODULES ***********************/
 
 #define NOPCOMP ((PCOMP *)-1)
@@ -102,7 +213,7 @@ typedef struct Ipcomp
 	INTSML           truewirecount;		/* number of unconnected ports, excluding ignored Pwr&Gnd */
 	INTBIG           timestamp;			/* time stamp for entry into symmetry group */
 	HASHTYPE         hashvalue;			/* hash value for NCC */
-	char            *hashreason;		/* the explanation of the hash value */
+	CHAR            *hashreason;		/* the explanation of the hash value */
 	float            length;			/* length/size of component */
 	float            width;				/* width of component (if FET) */
 	INTSML          *portindices;		/* normalized indices for each wire */
@@ -133,7 +244,7 @@ typedef struct Ipnet
 	void          *realportlist;	/* top-level export(s) on this net */
 	NETWORK       *network;			/* real network that this references */
 	HASHTYPE       hashvalue;		/* hash value for NCC */
-	char          *hashreason;		/* the explanation of the hash value */
+	CHAR          *hashreason;		/* the explanation of the hash value */
 	INTBIG         timestamp;		/* time stamp for entry into symmetry group */
 	INTBIG         nodecount;		/* number of pnodes on this network */
 	INTBIG         nodetotal;		/* allocated space for pnodes and wires on this network */
@@ -170,10 +281,10 @@ extern TRANSISTORINFO   net_transistor_p_active;	/* info on P transistors connec
 extern TRANSISTORINFO   net_transistor_n_active;	/* info on N transistors connected at active */
 
 /* prototypes for tool interface */
-void net_init(INTBIG*, char*[], TOOL*);
+void net_init(INTBIG*, CHAR1*[], TOOL*);
 void net_done(void);
-void net_set(INTBIG, char*[]);
-INTBIG net_request(char*, va_list);
+void net_set(INTBIG, CHAR*[]);
+INTBIG net_request(CHAR*, va_list);
 void net_examinenodeproto(NODEPROTO*);
 void net_slice(void);
 void net_startbatch(TOOL*, BOOLEAN);
@@ -188,12 +299,12 @@ void net_eraselibrary(LIBRARY*);
 
 /* prototypes for intratool interface */
 int        net_areaperimdepthascending(const void *e1, const void *e2);
-NETWORK   *net_gethighlightednet(BOOLEAN, BOOLEAN);
 NETWORK  **net_gethighlightednets(BOOLEAN disperror);
 void       net_freeallpcomp(PCOMP*);
 void       net_freeallpnet(PNET*);
 void       net_freepcomp(PCOMP*);
 void       net_freepnet(PNET*);
+void       net_initnetflattening(void);
 PCOMP     *net_makepseudo(NODEPROTO*, INTBIG*, INTBIG*, INTBIG*, INTBIG*, PNET**,
 			BOOLEAN, BOOLEAN, BOOLEAN, BOOLEAN, BOOLEAN);
 AREAPERIM *net_gathergeometry(NETWORK *net, TRANSISTORINFO **p_gate, TRANSISTORINFO **n_gate,
@@ -201,8 +312,8 @@ AREAPERIM *net_gathergeometry(NETWORK *net, TRANSISTORINFO **p_gate, TRANSISTORI
 BOOLEAN    net_equate(BOOLEAN);
 INTBIG	   net_getequivalentnet(NETWORK *net, NETWORK ***equiv, INTBIG *numequiv, BOOLEAN allowchild);
 BOOLEAN    net_compare(BOOLEAN preanalyze, BOOLEAN interactive, NODEPROTO *facet1, NODEPROTO *facet2);
-INTBIG     net_buswidth(char*);
-INTBIG     net_evalbusname(INTBIG, char*, char***, ARCINST*, NODEPROTO*, INTBIG);
+INTBIG     net_buswidth(CHAR*);
+INTBIG     net_evalbusname(INTBIG, CHAR*, CHAR***, ARCINST*, NODEPROTO*, INTBIG);
 void       net_freediffmemory(void);
 void       net_freeflatmemory(void);
 BOOLEAN    net_samenetworkname(NETWORK *net1, NETWORK *net2);
@@ -210,11 +321,15 @@ INTBIG     net_mergeparallel(PCOMP **pcomp, PNET *pnet, INTBIG *components);
 BOOLEAN    net_comparewirelist(PCOMP *p1, PCOMP *p2, BOOLEAN useportnames);
 void       net_dumpnetwork(PCOMP *pclist, PNET *pnlist);
 void       net_removeextraneous(PCOMP **pcomplist, PNET **pnetlist, INTBIG *comp);
-char      *net_describepnet(PNET *pn);
-char      *net_describepcomp(PCOMP *pc);
+CHAR      *net_describepnet(PNET *pn);
+CHAR      *net_describepcomp(PCOMP *pc);
 HASHTYPE   net_getcomphash(PCOMP *pc, INTBIG verbose);
 HASHTYPE   net_getnethash(PNET *pn, INTBIG verbose);
+NETWORK   *net_getnetwork(CHAR *netname, NODEPROTO *facet);
 void       net_redoprim(void);
+void       net_initnetprivate(NODEPROTO*);
+void       net_freenetprivate(NODEPROTO*);
+void	   net_checknetprivate(NODEPROTO*);
 void       net_initdiff(void);
 void       net_showcomphash(WINDOWPART *win, PCOMP *pc, HASHTYPE hashvalue, INTBIG hashindex, INTBIG verbose);
 void       net_shownethash(WINDOWPART *win, PNET *pn, HASHTYPE hashvalue, INTBIG hashindex, INTBIG verbose);
@@ -230,10 +345,11 @@ void       net_parsenccresult(NODEPROTO *np, VARIABLE *var, NODEPROTO **facetmat
 			UINTBIG *facetdate);
 VARIABLE  *net_nccfindmatch(NODEPROTO *np, NODEPROTO *onp, UINTBIG *matchdate);
 void       net_setnodewidth(NODEINST *ni);
-INTBIG     net_gathernodenames(NODEPROTO *np, char ***namelist);
+INTBIG     net_gathernodenames(NODEPROTO *np, CHAR ***namelist);
 BOOLEAN    net_getfacets(NODEPROTO**, NODEPROTO**);
 void       net_listnccoverrides(BOOLEAN usetemp1);
 BOOLEAN    net_componentequalvalue(float v1, float v2);
+INTBIG     net_findglobalnet(NODEPROTO *np, CHAR *name);
 #ifdef FORCESUNTOOLS
 BOOLEAN    net_analyzefacet(void);
 void       net_freeexpdiffmemory(void);
