@@ -60,13 +60,13 @@ extern UCROW plac_row_list[PLAC_MAX_COL_SIZE][3];
 
 /* prototypes for intramodule routines */
 NODEINST *plac_make_instance(NODEPROTO*, NODEPROTO*, INTBIG, INTBIG, INTBIG);
-void plac_wire(char*, INTBIG, NODEINST*, PORTPROTO*, NODEINST*, PORTPROTO*, NODEPROTO*);
-NODEINST *plac_make_Pin(NODEPROTO*, INTBIG, INTBIG, INTBIG, char*);
-NODEPROTO *plac_pmos_grid(LIBRARY*, FILE*, char[]);
-NODEPROTO *plac_nmos_grid(LIBRARY*, FILE*, char[]);
-NODEPROTO *plac_decode_gen(LIBRARY*, NODEPROTO*, NODEPROTO*, char*, INTBIG);
-NODEPROTO *plac_or_plane(LIBRARY*, NODEPROTO*, char*, INTBIG);
-NODEPROTO *plac_make_pla(LIBRARY*, NODEPROTO*, NODEPROTO*, char*);
+void plac_wire(CHAR*, INTBIG, NODEINST*, PORTPROTO*, NODEINST*, PORTPROTO*, NODEPROTO*);
+NODEINST *plac_make_Pin(NODEPROTO*, INTBIG, INTBIG, INTBIG, CHAR*);
+NODEPROTO *plac_pmos_grid(LIBRARY*, FILE*, CHAR[]);
+NODEPROTO *plac_nmos_grid(LIBRARY*, FILE*, CHAR[]);
+NODEPROTO *plac_decode_gen(LIBRARY*, NODEPROTO*, NODEPROTO*, CHAR*, INTBIG);
+NODEPROTO *plac_or_plane(LIBRARY*, NODEPROTO*, CHAR*, INTBIG);
+NODEPROTO *plac_make_pla(LIBRARY*, NODEPROTO*, NODEPROTO*, CHAR*);
 INTBIG plac_read_hw(FILE*, INTBIG*, INTBIG*, INTBIG*, INTBIG*);
 INTBIG plac_read_rows(INTBIG[], INTBIG, INTBIG, FILE*);
 UCITEM *plac_newUCITEM(void);
