@@ -60,17 +60,17 @@
 #define POLY        1
 #define METAL       2
 
-#define PLADEFTECH  "nmos"
-#define DEFNAME     "Anonymous"
-#define INFILE      "program"			/* default file name */
-#define NULLSTR     ""
+#define PLADEFTECH  x_("nmos")
+#define DEFNAME     x_("Anonymous")
+#define INFILE      x_("program")			/* default file name */
+#define NULLSTR     x_("")
 
 /* Define String Names for the PLA Facets */
-#define nmosInput   "nmos_Input"
-#define nmosOutput  "nmos_Output"
-#define nmosPullup  "nmos_Pullup"
-#define nmosConnect "nmos_Connect"
-#define nmosProgram "nmos_Program"
+#define nmosInput   x_("nmos_Input")
+#define nmosOutput  x_("nmos_Output")
+#define nmosPullup  x_("nmos_Pullup")
+#define nmosConnect x_("nmos_Connect")
+#define nmosProgram x_("nmos_Program")
 
 /* Declare the Node and Arc prototypes */
 extern NODEPROTO *pla_pu_proto;			/* Pullup Prototype */
@@ -159,8 +159,8 @@ extern INTBIG  pla_userbits;
 extern INTBIG  pla_inputs, pla_outputs, pla_pterms;
 extern INTBIG  pla_VddWidth;			/* VDD width in use */
 extern INTBIG  pla_GndWidth;			/* Vdd and Gnd Widths in use */
-extern char    pla_infile[100];			/* Name of the input file */
-extern char    pla_name[32];			/* Name of the PLA facet */
+extern CHAR    pla_infile[100];			/* Name of the input file */
+extern CHAR    pla_name[32];			/* Name of the PLA facet */
 
 /*   Miscellaneous global variables  */
 extern INTBIG  pla_halfVdd, pla_halfGnd;   /* To save repeated division by 2 */
@@ -211,7 +211,7 @@ extern TOOL *pla_tool;		/* the PLA tool object */
 
 /* prototypes for intramodule routines */
 void pla_displayoptions(void);
-void pla_setoption(char*, char*);
+void pla_setoption(CHAR*, CHAR*);
 BOOLEAN pla_Make(void);
 NODEPROTO *pla_nmos_Pullup(void);
 NODEPROTO *pla_nmos_Input(void);
@@ -219,7 +219,7 @@ NODEPROTO *pla_nmos_Connect(void);
 NODEPROTO *pla_nmos_Program(void);
 NODEPROTO *pla_nmos_Output(void);
 BOOLEAN pla_ProcessFlags(void);
-INTBIG pla_GetKeyWord(char*);
+INTBIG pla_GetKeyWord(CHAR*);
 VDDGND *pla_MkVddGnd(INTBIG, VDDGND**);
 PORT *pla_AssignPort(NODEINST*, INTBIG, INTBIG);
 PORTPROTO *pla_FindPort(NODEINST*, INTBIG, INTBIG);
