@@ -34,9 +34,9 @@ extern "C"
 {
 #endif
 
-void proj_init(INTBIG*, char*[], TOOL*);
+void proj_init(INTBIG*, CHAR1*[], TOOL*);
 void proj_done(void);
-void proj_set(INTBIG, char*[]);
+void proj_set(INTBIG, CHAR*[]);
 void proj_slice(void);
 void proj_startbatch(TOOL*, BOOLEAN);
 void proj_modifynodeinst(NODEINST*,INTBIG,INTBIG,INTBIG,INTBIG,INTBIG,INTBIG);
