@@ -38,13 +38,13 @@ extern "C"
 	General Constants
 ------------------------------------------------------------------------
 */
-#define VERSION			"1.00"
-#define DATE			"Feb 24, 1987"
+#define VERSION			x_("1.00")
+#define DATE			x_("Feb 24, 1987")
 #define PARS			10
 #define MAXLINE         80
 #define GND				0
 #define PWR				1
-#define SCSIMFILE       "simset.tmp"
+#define SCSIMFILE       x_("simset.tmp")
 
 /***********************************************************************
 	Error Codes
@@ -207,7 +207,7 @@ extern "C"
 
 typedef struct Isccell
 {
-	char              *name;			/* name of complex cell */
+	CHAR              *name;			/* name of complex cell */
 	int                max_node_num;	/* maximum number of nodes */
 	struct Iscnitree  *niroot;			/* root to instance tree for cell */
 	struct Iscnitree  *nilist;			/* list of instances for cell */
@@ -224,7 +224,7 @@ typedef struct Isccell
 
 typedef struct Iscport
 {
-	char             *name;				/* name of port */
+	CHAR             *name;				/* name of port */
 	struct Iscnitree *node;				/* special node */
 	struct Isccell   *parent;			/* complex cell on which */
 										/* this port resides */
@@ -255,10 +255,10 @@ typedef struct Isccellnums
 
 typedef struct Iscnitree
 {
-	char				*name;		/* pointer to string of instance name */
+	CHAR				*name;		/* pointer to string of instance name */
 	int					number;		/* alternative number of node */
 	int					type;		/* type of instance */
-	char				*np;		/* pointer to leaf cell */
+	CHAR				*np;		/* pointer to leaf cell */
 									/* or SCCELL if complex */
 	int					size;		/* x size if leaf cell */
 	struct Iscconlist	*connect;	/* pointer to connection list */
@@ -266,7 +266,7 @@ typedef struct Iscnitree
 	struct Iscniport	*power;		/* list of actual power ports */
 	struct Iscniport	*ground;	/* list of actual ground ports */
 	int					flags;		/* bits for silicon compiler */
-	char				*tp;		/* generic temporary pointer */
+	CHAR				*tp;		/* generic temporary pointer */
 	struct Iscnitree	*next;		/* pointer to next instance in list */
 	struct Iscnitree	*lptr;		/* left pointer for tree structure */
 	struct Iscnitree	*rptr;		/* right pointer for tree structure */
@@ -274,7 +274,7 @@ typedef struct Iscnitree
 
 typedef struct Iscniport
 {
-	char				*port;		/* leaf port or */
+	CHAR				*port;		/* leaf port or */
 									/* SCPORT if on complex cell */
 	struct Iscextnode	*ext_node;	/* extracted node */
 	int					bits;		/* bits for processing */
@@ -315,10 +315,10 @@ typedef struct Iscextport
 
 typedef struct Iscextnode
 {
-	char				*name;		/* optional name of port */
+	CHAR				*name;		/* optional name of port */
 	struct Iscextport	*firstport;	/* link list of ports */
 	int					flags;		/* flags for processing */
-	char				*ptr;		/* generic pointer for processing */
+	CHAR				*ptr;		/* generic pointer for processing */
 	struct Iscextnode	*next;		/* link list of nodes */
 } SCEXTNODE;
 
@@ -333,7 +333,7 @@ typedef struct Iscextnode
 
 typedef struct Iscsim
 {
-	char		*model;
+	CHAR		*model;
 	struct Iscsim	*next;
 } SCSIM;
 
@@ -648,7 +648,7 @@ typedef struct Iscmakerinst
 	int						xsize;		/* size in X */
 	int						ysize;		/* size in Y */
 	int						flags;		/* processing flags */
-	char					*instance;	/* leaf instance */
+	CHAR					*instance;	/* leaf instance */
 	struct Iscmakerinst		*next;		/* next in row */
 } SCMAKERINST;
 
@@ -688,7 +688,7 @@ typedef struct Iscmakervia
 {
 	int						xpos;		/* X position */
 	struct Iscroutechport	*chport;	/* associated channel port */
-	char					*instance;	/* associated leaf instance */
+	CHAR					*instance;	/* associated leaf instance */
 	int						flags;		/* flags for processing */
 	struct Iscrouteexport	*xport;		/* export port */
 	struct Iscmakervia		*next;		/* next via */
@@ -740,79 +740,79 @@ extern INTBIG      sc_filetypescsim;	/* Silicon compiler simulation file descrip
 extern INTBIG      sc_filetypesctab;	/* Silicon compiler table file descriptor */
 
 /* prototypes for tool interface */
-void sc_init(INTBIG*, char*[], TOOL*);
+void sc_init(INTBIG*, CHAR1*[], TOOL*);
 void sc_done(void);
-void sc_set(INTBIG, char*[]);
-INTBIG sc_request(char*, va_list);
+void sc_set(INTBIG, CHAR*[]);
+INTBIG sc_request(CHAR*, va_list);
 void sc_slice(void);
 
 /* prototypes for intratool interface */
 void Sc_clear_stop(void);
 int Sc_stop(void);
-int Sc_connect(int, char*[]);
-int Sc_create(int, char*[]);
+int Sc_connect(int, CHAR*[]);
+int Sc_create(int, CHAR*[]);
 int Sc_delete(void);
-int Sc_export(int, char*[]);
-int Sc_extract(int, char*[]);
-int Sc_maker(int, char*[]);
-int Sc_place(int, char*[]);
-int Sc_route(int, char*[]);
+int Sc_export(int, CHAR*[]);
+int Sc_extract(int, CHAR*[]);
+int Sc_maker(int, CHAR*[]);
+int Sc_place(int, CHAR*[]);
+int Sc_route(int, CHAR*[]);
 void Sc_schematic(void);
-int Sc_simulation(int, char*[]);
+int Sc_simulation(int, CHAR*[]);
 int Sc_verify(void);
-char *Sc_find_leaf_facet(char*);
-char *Sc_first_leaf_port(char*);
-char *Sc_next_leaf_port(char*);
-int Sc_leaf_port_type(char*);
-int Sc_leaf_port_bits(char*);
-char *Sc_leaf_port_name(char*);
-void Sc_leaf_facet_get_nums(char*, SCCELLNUMS*);
+CHAR *Sc_find_leaf_facet(CHAR*);
+CHAR *Sc_first_leaf_port(CHAR*);
+CHAR *Sc_next_leaf_port(CHAR*);
+int Sc_leaf_port_type(CHAR*);
+int Sc_leaf_port_bits(CHAR*);
+CHAR *Sc_leaf_port_name(CHAR*);
+void Sc_leaf_facet_get_nums(CHAR*, SCCELLNUMS*);
 void Sc_extract_print_nodes(SCCELL*);
 void Sc_route_print_channel(SCROUTECHANNEL*);
-char *Sc_leaf_facet_name(char*);
-int Sc_leaf_facet_set_nums(char*, SCCELLNUMS*);
-SCNITREE **Sc_findni(SCNITREE**, char*);
-char *Sc_find_leaf_port(char*, char*);
-int *Sc_leaf_port_bits_address(char*);
-int Sc_library_read(char*);
-int Sc_library_use(char*);
-void Sc_leaf_port_set_next(char*, char*);
-void Sc_leaf_port_set_first(char*, char*);
+CHAR *Sc_leaf_facet_name(CHAR*);
+int Sc_leaf_facet_set_nums(CHAR*, SCCELLNUMS*);
+SCNITREE **Sc_findni(SCNITREE**, CHAR*);
+CHAR *Sc_find_leaf_port(CHAR*, CHAR*);
+int *Sc_leaf_port_bits_address(CHAR*);
+int Sc_library_read(CHAR*);
+int Sc_library_use(CHAR*);
+void Sc_leaf_port_set_next(CHAR*, CHAR*);
+void Sc_leaf_port_set_first(CHAR*, CHAR*);
 void Sc_remove_inst_from_itree(SCNITREE**, SCNITREE*);
 void Sc_make_nilist(SCNITREE*, SCCELL*);
 int Sc_seterrmsg(int, ...);
-int Sc_leaf_facet_xsize(char*);
-int Sc_leaf_facet_ysize(char*);
-int Sc_leaf_port_xpos(char*);
-int Sc_leaf_port_ypos(char*);
+int Sc_leaf_facet_xsize(CHAR*);
+int Sc_leaf_facet_ysize(CHAR*);
+int Sc_leaf_port_xpos(CHAR*);
+int Sc_leaf_port_ypos(CHAR*);
 void Sc_initialize(void);
 void Sc_main(void);
-void Sc_one_command(int, char*[]);
-SCNIPORT *Sc_findpp(SCNITREE*, char*);
-SCNITREE *Sc_new_instance(char*, int);
+void Sc_one_command(int, CHAR*[]);
+SCNIPORT *Sc_findpp(SCNITREE*, CHAR*);
+SCNITREE *Sc_new_instance(CHAR*, int);
 int Sc_conlist(SCNITREE*, SCNIPORT*, SCNITREE*, SCNIPORT*);
-char *Sc_cpu_time(int);
-char *Sc_create_leaf_facet(char*);
+CHAR *Sc_cpu_time(int);
+CHAR *Sc_create_leaf_facet(CHAR*);
 int Sc_setup_for_maker(ARCPROTO*, ARCPROTO*);
-char *Sc_create_leaf_instance(char*, char*, int, int, int, int, int, int, char*);
-char *Sc_create_layer2_node(int, int, int, int, char*);
-char *Sc_create_via(int, int, char*);
-char *Sc_create_layer1_node(int, int, int, int, char*);
-char *Sc_create_nwell(int, int, int, int, char*);
-char *Sc_create_pwell(int, int, int, int, char*);
-char *Sc_create_track_layer1(char*, char*, char*, char*, int, char*);
-char *Sc_create_track_layer2(char*, char*, char*, char*, int, char*);
-char *Sc_create_export_port(char*, char*, char*, int, char*);
+CHAR *Sc_create_leaf_instance(CHAR*, CHAR*, int, int, int, int, int, int, CHAR*);
+CHAR *Sc_create_layer2_node(int, int, int, int, CHAR*);
+CHAR *Sc_create_via(int, int, CHAR*);
+CHAR *Sc_create_layer1_node(int, int, int, int, CHAR*);
+CHAR *Sc_create_nwell(int, int, int, int, CHAR*);
+CHAR *Sc_create_pwell(int, int, int, int, CHAR*);
+CHAR *Sc_create_track_layer1(CHAR*, CHAR*, CHAR*, CHAR*, int, CHAR*);
+CHAR *Sc_create_track_layer2(CHAR*, CHAR*, CHAR*, CHAR*, int, CHAR*);
+CHAR *Sc_create_export_port(CHAR*, CHAR*, CHAR*, int, CHAR*);
 int Sc_free_placement(SCPLACE*);
 int Sc_free_route(SCROUTE*);
-int Sc_leaf_port_direction(char*);
+int Sc_leaf_port_direction(CHAR*);
 SCNIPORT *Sc_new_instance_port(SCNITREE*);
-char **Sc_leaf_facet_sim_info(char*);
-int Sc_leaf_facet_set_sim(SCSIM*, char*);
-char *Sc_first_leaf_facet(void);
-char *Sc_next_leaf_facet(char*);
-int *Sc_leaf_facet_bits_address(char*);
-int Sc_leaf_facet_bits(char*);
+CHAR **Sc_leaf_facet_sim_info(CHAR*);
+int Sc_leaf_facet_set_sim(SCSIM*, CHAR*);
+CHAR *Sc_first_leaf_facet(void);
+CHAR *Sc_next_leaf_facet(CHAR*);
+int *Sc_leaf_facet_bits_address(CHAR*);
+int Sc_leaf_facet_bits(CHAR*);
 INTBIG ScGetParameter(INTBIG paramnum);
 void ScSetParameter(INTBIG paramnum, INTBIG addr);
 
