@@ -64,11 +64,11 @@ extern INTBIG     sim_netfilekey;		/* key for "SIM_netfile" */
 extern INTBIG     sim_dontrunkey;		/* key for "SIM_dontrun" */
 extern INTBIG     sim_weaknodekey;		/* key for "SIM_weak_node" */
 extern INTBIG     sim_spice_partskey;	/* key for "SIM_spice_parts" */
-extern char      *sim_spice_parts;		/* cached value for "SIM_spice_parts" */
+extern CHAR      *sim_spice_parts;		/* cached value for "SIM_spice_parts" */
 extern NODEPROTO *sim_simnt;			/* facet being simulated */
-extern int        sim_tosim[2];			/* pipe to the simulator process */
-extern int        sim_fromsim[2];		/* pipe from the simulator process */
-extern INTBIG     sim_process;			/* process number of simulator */
+#if defined(__cplusplus)
+extern EProcess  *sim_process;          /* process of simulator */
+#endif
 extern INTBIG     sim_filetypeesim;		/* ESIM netlist disk file descriptor */
 extern INTBIG     sim_filetypefasthenry;/* FastHenry netlist disk file descriptor */
 extern INTBIG     sim_filetypemossim;	/* MOSSIM netlist disk file descriptor */
@@ -86,11 +86,13 @@ extern INTBIG     sim_filetypespicecmd;	/* SPICE command disk file descriptor */
 extern INTBIG     sim_filetypespiceout;	/* SPICE output disk file descriptor */
 extern INTBIG     sim_filetypehspiceout;/* HSPICE output file descriptor */
 extern INTBIG     sim_filetyperawspiceout; /* SPICE raw output disk file descriptor */
+extern INTBIG     sim_filetypesrawspiceout; /* SmartSPICE raw output disk file descriptor */
 extern INTBIG     sim_filetypecdl;		/* CDL output file descriptor */
 extern INTBIG     sim_filetypectemp;	/* CDL template disk file descriptor */
 extern INTBIG     sim_filetypetegas;	/* Tegas netlist disk file descriptor */
 extern INTBIG     sim_filetypetegastab;	/* Tegas table disk file descriptor */
 extern INTBIG     sim_filetypeverilog;	/* Verilog disk file descriptor */
+extern INTBIG     sim_filetypeverilogvcd;	/* Verilog VCD dump file descriptor */
 
 /********************* for Simulation Window *********************/
 
@@ -104,6 +106,7 @@ extern INTBIG     sim_filetypeverilog;	/* Verilog disk file descriptor */
 #define LOGIC_LOW              -1
 #define LOGIC_X                -2
 #define LOGIC_HIGH             -3
+#define LOGIC_Z                -4
 #define OFF_STRENGTH            0
 #define NODE_STRENGTH           2
 #define GATE_STRENGTH           4
@@ -122,21 +125,28 @@ extern INTBIG     sim_filetypeverilog;	/* Verilog disk file descriptor */
 #define WAVEPLACECAS            0		/*   cascade waveform windows */
 #define WAVEPLACETHOR        0100		/*   cascade waveform windows */
 #define WAVEPLACETVER        0200		/*   cascade waveform windows */
-#define SIMENGINE           01400		/* simulation engine to use */
+#define SIMENGINE           01400		/* simulation engine to use for "simulate" command */
 #define SIMENGINEALS            0		/*   use ALS simulation engine */
 #define SIMENGINEIRSIM       0400		/*   use IRSIM simulation engine */
+#define SIMENGINECUR       016000		/* simulation in this window */
+#define SIMENGINECURALS         0		/*   current window has ALS simulation */
+#define SIMENGINECURIRSIM   02000		/*   current window has IRSIM simulation */
+#define SIMENGINECURVERILOG 04000		/*   current window has Verilog simulation */
+#define SIMENGINECURSPICE  010000		/*   current window has SPICE simulation */
 
 extern INTBIG  sim_window_statekey;		/* key for "SIM_window_state" */
 extern INTBIG  sim_window_state;		/* cached value of "SIM_window_state" */
 extern INTBIG  sim_window_signalorder_key;	/* key for "SIM_window_signalorder" */
+extern INTBIG  sim_window_hierpos_key;	/* key for "SIM_window_hierarchy_pos" */
 extern INTBIG  sim_window_format;		/* type of simulation in window */
 
 /* prototypes */
 void    sim_window_init(void);
-void    sim_window_term(void);
 BOOLEAN sim_window_create(INTBIG, NODEPROTO*, BOOLEAN(*)(WINDOWPART*, INTSML, INTBIG),
 						  BOOLEAN(*)(WINDOWPART*, INTSML, INTBIG), INTBIG);
+void    sim_window_titleinfo(CHAR *title);
 void    sim_window_stopsimulation(void);
+void    sim_window_setvdd(float vdd);
 INTBIG  sim_window_isactive(NODEPROTO **np);
 void    sim_window_redraw(void);
 void    sim_window_setnumframes(INTBIG);
@@ -148,9 +158,9 @@ INTBIG  sim_window_gettopvisframe(void);
 void    sim_window_savegraph(void);
 void    sim_window_writespicecmd(void);
 void    sim_window_displaycolor(INTBIG strength, INTBIG color);
-INTBIG  sim_window_newtrace(INTBIG, char*, INTBIG);
+INTBIG  sim_window_newtrace(INTBIG, CHAR*, INTBIG);
 BOOLEAN sim_window_buscommand(void);
-INTBIG  sim_window_makebus(INTBIG count, INTBIG *traces, char *busname);
+INTBIG  sim_window_makebus(INTBIG count, INTBIG *traces, CHAR *busname);
 void    sim_window_loaddigtrace(INTBIG, INTBIG, double*, INTSML*);
 void    sim_window_loadanatrace(INTBIG, INTBIG, double*, float*);
 void    sim_window_settraceframe(INTBIG, INTBIG);
@@ -158,10 +168,12 @@ void    sim_window_killtrace(INTBIG);
 void    sim_window_killalltraces(BOOLEAN);
 INTBIG *sim_window_getbustraces(INTBIG);
 INTBIG  sim_window_gettraceframe(INTBIG);
-char   *sim_window_gettracename(INTBIG);
+CHAR   *sim_window_gettracename(INTBIG);
 INTBIG  sim_window_gettracedata(INTBIG);
 float   sim_window_getanatracevalue(INTBIG, double);
-INTBIG  sim_window_findtrace(char*);
+CHAR   *sim_window_getbustracevalue(INTBIG tri, double time);
+void    sim_window_getdigtracevalue(INTBIG tri, double time, INTBIG *level, INTBIG *strength);
+INTBIG *sim_window_findtrace(CHAR*, INTBIG*);
 void    sim_window_inittraceloop(void);
 void    sim_window_inittraceloop2(void);
 INTBIG  sim_window_nexttraceloop(void);
@@ -172,6 +184,7 @@ void    sim_window_deletehighlighttrace(INTBIG);
 INTBIG  sim_window_gethighlighttrace(void);
 INTBIG *sim_window_gethighlighttraces(void);
 void    sim_window_clearframehighlight(void);
+void    sim_window_showhighlightedtraces(void);
 void    sim_window_setmaincursor(double);
 double  sim_window_getmaincursor(void);
 void    sim_window_setextensioncursor(double);
@@ -181,7 +194,7 @@ void    sim_window_gettimerange(INTBIG, double*, double*);
 void    sim_window_getaveragetimerange(double *avgmintime, double *avgmaxtime);
 void    sim_window_gettimeextents(double*, double*);
 void    sim_window_updatelayoutwindow(void);
-void    sim_windowconvertengineeringnotation(double, char*);
+CHAR   *sim_windowconvertengineeringnotation(double);
 void    sim_window_setstate(INTBIG);
 INTBIG  sim_window_getwidevalue(INTBIG **bits);
 void    sim_window_auto_anarange(void);
@@ -189,28 +202,32 @@ void    sim_window_zoom_frame(INTBIG frameno);
 void    sim_window_zoomout_frame(INTBIG frameno);
 void    sim_window_shiftup_frame(INTBIG frameno);
 void    sim_window_shiftdown_frame(INTBIG frameno);
+void    sim_window_grabcachedsignalsonfacet(NODEPROTO *facet);
+INTBIG  sim_window_getcachedsignals(CHAR ***strings);
+void    sim_window_supresstraceprefix(CHAR *prefix);
+void    sim_window_renumberlines(void);
 
 /********************* for ESIM *********************/
 
-#define ESIMNAME    "esim"
+#define ESIMNAME    x_("esim")
 
 /********************* for RSIM *********************/
 
-#define RSIMPRENAME "presim"
-#define RSIMNAME    "rsim"
-#define RSIMIN      "rsim.in"			/* name of file with binary network */
+#define RSIMPRENAME x_("presim")
+#define RSIMNAME    x_("rsim")
+#define RSIMIN      x_("rsim.in")			/* name of file with binary network */
 
 /********************* for ALS *********************/
 
-#define NET_EXT		".net"
-#define PLOT_EXT	".hpgl"
+#define NET_EXT		x_(".net")
+#define PLOT_EXT	x_(".hpgl")
 
 /********************* for RNL *********************/
 
-#define RNLPRENAME  "presim"
-#define RNLNAME     "rnl"
-#define RNLIN       "rnl.in"			/* name of file with binary network */
-#define RNLCOMM     "nl.l"				/* file with simulator initialization */
+#define RNLPRENAME  x_("presim")
+#define RNLNAME     x_("rnl")
+#define RNLIN       x_("rnl.in")			/* name of file with binary network */
+#define RNLCOMM     x_("nl.l")				/* file with simulator initialization */
 
 /********************* for VERILOG *********************/
 
@@ -220,23 +237,35 @@ void    sim_window_shiftdown_frame(INTBIG frameno);
 
 extern INTBIG sim_verilog_statekey;		/* key for "SIM_verilog_state" */
 
+void        sim_verlevel_up(NODEPROTO *facet);
+void        sim_verlevel_set(CHAR *instname, NODEPROTO *facet);
+void        sim_verparsefile(CHAR*);
+BOOLEAN     sim_vertopofinstances(CHAR **c);
+CHAR       *sim_vernextinstance(void);
+CHAR       *sim_verlevel_cur(void);
+
 /********************* for SPICE *********************/
 
 #define MAXSPICELEVEL     3				/* levels 1, 2, and 3 */
 
 /* Meaning of bits in sim_spice_state */
-#define SPICERESISTANCE    01			/* set for resistances */
-#define SPICEPLOT          02			/* set for plots (vs prints) */
-#define SPICENODENAMES    010			/* set for node names (vs numbers) */
-#define SPICETYPE         060			/* mask for spice type */
-#define SPICE2            000			/*   spice 2 */
-#define SPICE3            020			/*   spice 3 */
-#define SPICEHSPICE       040			/*   hspice  */
-#define SPICEPSPICE       060			/*   pspice  */
-#define SPICERAWFILE     0100			/* set to read rawfile */
-#define SPICEGLOBALPG    0200			/* set to use global power and ground */
-#define SPICEFACETPARAM 01000			/* set to use facet parameters */
-#define SPICEUSELAMBDAS 02000			/* set to use lambdas instead of microns for transistor sizes */
+#define SPICERESISTANCE         01		/* set for resistances */
+#define SPICEPLOT               02		/* set for plots (vs prints) */
+#define SPICENODENAMES         010		/* set for node names (vs numbers) */
+#define SPICETYPE             0160		/* mask for spice type */
+#define SPICE2                 000		/*   spice 2 */
+#define SPICE3                 020		/*   spice 3 */
+#define SPICEHSPICE            040		/*   hspice */
+#define SPICEPSPICE            060		/*   pspice */
+#define SPICEGNUCAP           0100      /*   gnucap */
+#define SPICESMARTSPICE       0120      /*   smartspice */
+#define SPICEGLOBALPG         0200		/* set to use global power and ground */
+#define SPICEFACETPARAM      01000		/* set to use facet parameters */
+#define SPICEUSELAMBDAS      02000		/* set to use lambdas instead of microns for transistor sizes */
+#define SPICEOUTPUT         034000		/* mask for output format */
+#define SPICEOUTPUTNORM          0		/*   normal */
+#define SPICEOUTPUTRAW       04000		/*   raw */
+#define SPICEOUTPUTRAWSMART 010000		/*   raw for smartspice */
 
 extern INTBIG sim_spice_levelkey;		/* key for "SIM_spice_level" */
 extern INTBIG sim_spice_statekey;		/* key for "SIM_spice_state" */
@@ -271,9 +300,10 @@ extern INTBIG sim_fasthenryztailkey;		/* variable key for "SIM_fasthenry_z_tail"
 extern INTBIG sim_fasthenrygroupnamekey;	/* variable key for "SIM_fasthenry_group_name" */
 
 /* prototypes for tool interface */
-void        sim_init(INTBIG*, char*[], TOOL*);
+void        sim_init(INTBIG*, CHAR1*[], TOOL*);
 void        sim_done(void);
-void        sim_set(INTBIG, char*[]);
+void        sim_set(INTBIG, CHAR*[]);
+INTBIG      sim_request(CHAR *command, va_list ap);
 void        sim_slice(void);
 void        sim_startbatch(TOOL*, BOOLEAN);
 void        sim_modifynodeinst(NODEINST*,INTBIG,INTBIG,INTBIG,INTBIG,INTBIG,INTBIG);
@@ -289,15 +319,16 @@ void        sim_deletevariable(INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG);
 void        sim_readlibrary(LIBRARY*);
 
 /* prototypes for intratool interface */
+void        sim_freewindowmemory(void);
 void        sim_freespicememory(void);
 void        sim_freespicerun_memory(void);
 void        sim_freeirsimmemory(void);
 void        sim_freeverilogmemory(void);
-void        sim_spice_xprintf(FILE*, BOOLEAN, char*, ...);
-NETWORK    *sim_spice_networkfromname(char *name);
-char       *sim_spice_signalname(NETWORK *net);
-void        sim_simpointout(char*, INTBIG);
-void        sim_spice_execute(char*, char*, NODEPROTO*);
+void        sim_spice_xprintf(FILE*, BOOLEAN, CHAR*, ...);
+NETWORK    *sim_spice_networkfromname(CHAR *name);
+CHAR       *sim_spice_signalname(NETWORK *net);
+void        sim_simpointout(CHAR*, INTBIG);
+void        sim_spice_execute(CHAR*, CHAR*, NODEPROTO*);
 void        sim_writefasthenrynetlist(NODEPROTO*);
 void        sim_fasthenryinit(void);
 void        sim_writesim(NODEPROTO*, INTBIG);
@@ -309,8 +340,117 @@ void        sim_writespice(NODEPROTO*, BOOLEAN);
 void        sim_writevernetlist(NODEPROTO*);
 void        sim_writesilnetlist(NODEPROTO*);
 void        sim_resumesim(BOOLEAN);
-INTBIG      sim_alsclockdlog(char *paramstart[]);
+INTBIG      sim_alsclockdlog(CHAR *paramstart[]);
+void        sim_initbussignals(void);
+void        sim_addbussignal(INTBIG signal);
+INTBIG      sim_getbussignals(INTBIG **signallist);
 
 #if defined(__cplusplus) && !defined(ALLCPLUSPLUS)
 }
 #endif
+
+#if defined(__cplusplus)
+
+class SpiceCell;
+class SpiceInst;
+class SpiceBind;
+class SpiceParam;
+class SpiceNet;
+
+class SpiceCell
+{
+	friend class SpiceInst;
+	friend class SpiceNet;
+public:
+	SpiceCell( CHAR *name = "" );
+	~SpiceCell();
+	CHAR *name() { return _name; }
+	static SpiceCell *findByName( CHAR *name );
+	void setup();
+	static void traverseAll();
+	static void clearAll();
+	void printSpice();
+private:
+	void traverse();
+	CHAR *_name;
+	static SpiceCell *_firstCell;
+	SpiceCell *_nextCell;
+	SpiceInst *_firstInst, *_lastInst;
+	SpiceNet *_firstNet;
+	INTBIG _pathlen;
+	INTBIG _totalnets;
+	static CHAR *_path;
+	static CHAR *_pathend;
+	static CHAR *_rpath;
+	static CHAR *_rpathbeg;
+};
+
+class SpiceInst
+{
+	friend class SpiceCell;
+	friend class SpiceBind;
+public:
+    SpiceInst( SpiceCell *parentCell, CHAR *name );
+	~SpiceInst();
+	CHAR *name() { return _name; }
+	void setInstCell( SpiceCell *instCell );
+	void addParam( SpiceParam *param );
+	void addParamM( NODEINST *ni );
+	void addError( CHAR *error );
+private:
+	void addBind( SpiceBind *bind );
+	void printSpice();
+	void traverse();
+	CHAR *_name;
+	SpiceCell *_parentCell;
+	SpiceCell *_instCell;
+	SpiceBind *_firstBind, *_lastBind;
+	SpiceParam *_firstParam, *_lastParam;
+	CHAR *_error;
+	SpiceInst *_nextInst;
+};
+
+class SpiceBind
+{
+	friend class SpiceInst;
+public:
+	SpiceBind( SpiceInst *inst, SpiceNet *net = 0 );
+	~SpiceBind();
+private:
+	void printSpice();
+	SpiceInst *_inst;
+	SpiceNet *_net;
+	SpiceBind *_nextBind;
+};
+
+class SpiceParam
+{
+	friend class SpiceInst;
+public:
+	SpiceParam( CHAR *str );
+	~SpiceParam();
+	CHAR *str() { return _str; }
+private:
+	CHAR *_str;
+	SpiceParam *_nextParam;
+};
+
+class SpiceNet
+{
+	friend class SpiceCell;
+	friend class SpiceBind;
+ public:
+	SpiceNet( SpiceCell *parentCell, INTBIG netnumber, NETWORK *netw = 0 );
+	~SpiceNet();
+private:
+	void printSpice();
+	INTBIG _netnumber;
+	NETWORK *_netw;
+	SpiceCell *_parentCell;
+	SpiceNet *_nextNet;
+};
+
+extern CHAR **sim_spice_printlist;
+extern INTBIG sim_spice_printlistlen;
+
+#endif
