@@ -30,6 +30,11 @@
  * info@staticfreesoft.com
  */
 
+#if defined(__cplusplus) && !defined(ALLCPLUSPLUS)
+extern "C"
+{
+#endif
+
 typedef enum {DELAY_MIN=0, DELAY_TYP, DELAY_MAX} DELAY_TYPES;
 
 /* The trace buffer in ALS can currently hold 10000 events.
@@ -41,16 +46,16 @@ typedef enum {DELAY_MIN=0, DELAY_TYP, DELAY_MAX} DELAY_TYPES;
 typedef struct model_ds
 {
 	INTBIG              num;
-	char               *name;
-	char                type;
-	char               *ptr;	/* may be CONPTR or ROWPTR or FUNCPTR */
+	CHAR               *name;
+	CHAR                type;
+	CHAR               *ptr;	/* may be CONPTR or ROWPTR or FUNCPTR */
 	struct export_ds   *exptr;
 	struct io_ds       *setptr;
 	struct load_ds     *loadptr;
-	char                fanout;
+	CHAR                fanout;
 	INTSML              priority;
 	struct model_ds    *next;
-	char               *level;  /* hierarchical level */
+	CHAR               *level;  /* hierarchical level */
 } MODEL;
 typedef MODEL *MODPTR;
 
@@ -64,15 +69,15 @@ typedef struct row_ds
 	float           random;
 	float           abs;    /* BA delay - SDF absolute port delay */
 	struct row_ds  *next;
-	char           *delay;  /* delay transition name (01, 10, etc) */
+	CHAR           *delay;  /* delay transition name (01, 10, etc) */
 } ROW;
 typedef ROW *ROWPTR;
 
 typedef struct io_ds
 {
 	struct node_ds *nodeptr;
-	unsigned char   operatr;
-	char           *operand;
+	UCHAR           operatr;
+	CHAR           *operand;
 	INTSML          strength;
 	struct io_ds   *next;
 } IO;
@@ -80,8 +85,8 @@ typedef IO *IOPTR;
 
 typedef struct connect_ds
 {
-	char               *inst_name;
-	char               *model_name;
+	CHAR               *inst_name;
+	CHAR               *model_name;
 	struct export_ds   *exptr;
 	struct connect_ds  *parent;
 	struct connect_ds  *child;
@@ -93,7 +98,7 @@ typedef CONNECT *CONPTR;
 
 typedef struct export_ds
 {
-	char              *node_name;
+	CHAR              *node_name;
 	struct node_ds    *nodeptr;
 	struct export_ds  *next;
 	INTBIG            td[12];  /* transition delays */
@@ -102,7 +107,7 @@ typedef EXPORT *EXPTR;
 
 typedef struct load_ds
 {
-	char            *ptr;
+	CHAR            *ptr;
 	float            load;
 	struct load_ds  *next;
 } LOAD;
@@ -117,7 +122,7 @@ typedef struct func_ds
 	float              exp;
 	float              abs;    /* absolute delay for back annotation */
 	float              random;
-	char              *userptr;
+	CHAR              *userptr;
 	INTBIG             userint;
 	float              userfloat;
 } FUNC;
@@ -152,7 +157,7 @@ typedef struct stat_ds
 	struct node_ds   *nodeptr;
 	INTBIG            new_state;
 	INTSML            new_strength;
-	unsigned char     sched_op;
+	UCHAR             sched_op;
 	INTBIG            sched_state;
 	INTSML            sched_strength;
 	struct stat_ds   *next;
@@ -165,9 +170,9 @@ typedef struct link_ds
 	struct link_ds  *right;
 	struct link_ds  *up;
 	struct link_ds  *down;
-	char            *ptr;
-	char             type;
-	unsigned char    operatr;
+	CHAR            *ptr;
+	CHAR             type;
+	UCHAR            operatr;
 	INTBIG           state;
 	INTSML           strength;
 	INTSML           priority;
@@ -187,7 +192,7 @@ typedef TRAK *TRAKPTR;
 
 typedef struct channel_ds
 {
-	char            *name;
+	CHAR            *name;
 	struct node_ds  *nodeptr;
 	INTBIG           displayptr;
 } CHANNEL;
@@ -205,8 +210,8 @@ extern NODEPTR     simals_noderoot, simals_drive_node;
 extern LINKPTR     simals_linkfront, simals_linkback, simals_setroot;
 extern TRAKPTR     simals_trakroot;
 extern LOADPTR     simals_chekroot;
-extern char      **simals_rowptr1, **simals_ioptr1;
-extern char       *simals_instbuf;
+extern CHAR      **simals_rowptr1, **simals_ioptr1;
+extern CHAR       *simals_instbuf;
 extern INTBIG      simals_pseq, simals_nseq, *simals_instptr,
 				   simals_trakfull, simals_trakptr;
 extern INTBIG      simals_no_update_key;		/* variable key for "SIM_als_no_update" */
@@ -214,57 +219,62 @@ extern BOOLEAN     simals_seed_flag, simals_trace_all_nodes;
 extern double      simals_time_abs;
 extern NODEPROTO  *simals_mainproto;
 extern INTBIG      simals_trace_size;
+extern CHAR       *simals_title;
 
 /* prototypes for intratool interface */
 LINKPTR   simals_alloc_link_mem(void);
 #ifdef DEBUGMEMORY
-  char   *_simals_alloc_mem(INTBIG, char*, INTBIG);
-# define  simals_alloc_mem(a) _simals_alloc_mem((a), (char *)__FILE__, (INTBIG)__LINE__)
+  CHAR   *_simals_alloc_mem(INTBIG, CHAR*, INTBIG);
+# define  simals_alloc_mem(a) _simals_alloc_mem((a), (CHAR *)__FILE__, (INTBIG)__LINE__)
 #else
-  char   *simals_alloc_mem(INTBIG);
+  CHAR   *simals_alloc_mem(INTBIG);
 #endif
-void      simals_annotate_command(INTBIG, char*[]);
-INTBIG    simals_atoi(char*);
-void      simals_build_actel_command(INTBIG, char*[]);
+void      simals_annotate_command(INTBIG, CHAR*[]);
+INTBIG    simals_atoi(CHAR*);
+void      simals_build_actel_command(INTBIG, CHAR*[]);
 void      simals_clearallvectors(BOOLEAN);
-void      simals_clock_command(INTBIG, char*[]);
-void      simals_com_comp(INTBIG, char*[10]);
-void      simals_compute_node_name(NODEPTR, char*);
-char     *simals_compute_path_name(CONPTR);
-void      simals_convert_to_upper(char*);
+void      simals_clock_command(INTBIG, CHAR*[]);
+void      simals_com_comp(INTBIG, CHAR*[10]);
+void      simals_compute_node_name(NODEPTR, CHAR*);
+CHAR     *simals_compute_path_name(CONPTR);
+void      simals_convert_to_upper(CHAR*);
 void      simals_erase_model(void);
 void      simals_fill_display_arrays(void);
-CONPTR    simals_find_level(char*);
-NODEPTR   simals_find_node(char*);
+CONPTR    simals_find_level(CHAR*);
+NODEPTR   simals_find_node(CHAR*);
 BOOLEAN   simals_flatten_network(void);
-BOOLEAN   simals_fragment_command(char*);
+BOOLEAN   simals_fragment_command(CHAR*);
 void      simals_free_link_mem(LINKPTR);
 void      simals_freeflatmemory(void);
 void      simals_freesimmemory(void);
-INTBIG   *simals_get_function_address(char*);
-void      simals_go_command(INTBIG, char*[]);
+INTBIG   *simals_get_function_address(CHAR*);
+void      simals_go_command(INTBIG, CHAR*[]);
 void      simals_help_command(void);
 void      simals_init(void);
 void      simals_init_display(void);
 double    simals_initialize_simulator(BOOLEAN);
 void      simals_insert_link_list(LINKPTR);
-char    **simals_insert_set_list(LINKPTR);
+CHAR    **simals_insert_set_list(LINKPTR);
 void      simals_level_up_command(void);
-void      simals_level_set_command(char *instname);
-char     *simals_nextinstance(void);
-void      simals_order_command(INTBIG, char*[]);
-void      simals_print_command(INTBIG, char*[]);
+void      simals_level_set_command(CHAR *instname);
+CHAR     *simals_nextinstance(void);
+void      simals_order_command(INTBIG, CHAR*[]);
+void      simals_print_command(INTBIG, CHAR*[]);
 BOOLEAN   simals_read_net_desc(NODEPROTO*);
-void      simals_seed_command(INTBIG, char*[]);
-void      simals_set_command(INTBIG, char*[]);
+void      simals_seed_command(INTBIG, CHAR*[]);
+void      simals_set_command(INTBIG, CHAR*[]);
 BOOLEAN   simals_set_current_level(void);
 void      simals_term(void);
-BOOLEAN   simals_topofinstances(char**);
-void      simals_trace_command(INTBIG, char*[]);
-void      simals_trans_number_to_state(INTBIG, char*);
-INTBIG    simals_trans_state_to_number(char*);
-void      simals_vector_command(INTBIG, char*[]);
+BOOLEAN   simals_topofinstances(CHAR**);
+void      simals_trace_command(INTBIG, CHAR*[]);
+CHAR     *simals_trans_number_to_state(INTBIG);
+INTBIG    simals_trans_state_to_number(CHAR*);
+void      simals_vector_command(INTBIG, CHAR*[]);
 
 BOOLEAN   simals_startsimulation(NODEPROTO *np);
 BOOLEAN   simals_charhandlerschem(WINDOWPART*, INTSML, INTBIG);
 BOOLEAN   simals_charhandlerwave(WINDOWPART*, INTSML, INTBIG);
+
+#if defined(__cplusplus) && !defined(ALLCPLUSPLUS)
+}
+#endif
