@@ -30,6 +30,11 @@
  * info@staticfreesoft.com
  */
 
+#if defined(__cplusplus) && !defined(ALLCPLUSPLUS)
+extern "C"
+{
+#endif
+
 /* the meaning of "SIM_irsim_state": */
 #define IRSIMPARASITICS   03		/* the nature of parasitics for IRSIM */
 #define IRSIMPARAQUICK     0		/*   quick IRSIM parasitics (transistor only) */
@@ -38,7 +43,7 @@
 #define IRSIMSHOWCOMMANDS 04		/* show executing commands on messages window */ 
 
 #define DEFIRSIMTIMERANGE  10.0E-9f			/* initial size of simulation window: 10ns */
-#define DEFIRSIMPARAMFILE  "scmos0.3.prm"	/* default parameter file name */
+#define DEFIRSIMPARAMFILE  x_("scmos0.3.prm")	/* default parameter file name */
 #define DEFIRSIMSTATE      IRSIMPARALOCAL	/* default value of "SIM_irsim_state" */
 
 #define NOIRSIMTRANSISTOR ((IRSIMTRANSISTOR *)-1)
@@ -55,6 +60,7 @@ typedef struct Iirsimtransistor
 	INTBIG                   drainx, drainy;			/* location of transistor drain */
 	float                    sarea, darea;				/* area of source/drain */
 	INTBIG                   sperimeter, dperimeter;	/* perimeter of source/drain */
+	float                    m;                         /* magnitude factor */
 	struct Iirsimtransistor *nextirsimtransistor;		/* next in list of all transistors */
 	struct Iirsimtransistor *nextfacetirsimtransistor;	/* next in list of transistors in this facet */
 } IRSIMTRANSISTOR;
@@ -65,7 +71,7 @@ typedef struct Iirsimtransistor
 
 typedef struct Iirsimnetwork
 {
-	char      *name;							/* net name in IRSIM */
+	CHAR      *name;							/* net name in IRSIM */
 	INTBIG     signal;							/* waveform pointer */
 	INTBIG     flags;							/* flags for this network */
 } IRSIMNETWORK;
@@ -73,8 +79,8 @@ typedef struct Iirsimnetwork
 #if SIMFSDBWRITE != 0
 typedef struct Iirsimalias
 {
-	char      *name;							/* net name in IRSIM (IRSIMNETWORK.name) */
-	char      *alias;                           /* its alias */
+	CHAR      *name;							/* net name in IRSIM (IRSIMNETWORK.name) */
+	CHAR      *alias;                           /* its alias */
 } IRSIMALIAS;
 #endif
 
@@ -93,11 +99,15 @@ BOOLEAN  irsim_startsimulation(NODEPROTO *np);
 BOOLEAN  irsim_charhandlerschem(WINDOWPART *w, INTSML chr, INTBIG special);
 BOOLEAN  irsim_charhandlerwave(WINDOWPART *w, INTSML chr, INTBIG special);
 void     irsim_clearallvectors(void);
-void     irsim_loadvectorfile(char *filename);
-void     irsim_savevectorfile(char *filename);
-void     irsim_level_up(void);
-void     irsim_level_set(char *level);
-BOOLEAN  irsim_topofinstances(char **c);
-char    *irsim_nextinstance(void);
+void     irsim_loadvectorfile(CHAR *filename);
+void     irsim_savevectorfile(CHAR *filename);
+void     irsim_level_up(NODEPROTO *facet);
+void     irsim_level_set(CHAR *level, NODEPROTO *facet);
+BOOLEAN  irsim_topofinstances(CHAR **c);
+CHAR    *irsim_nextinstance(void);
 void     irsim_freememory(void);
 #endif
+
+#if defined(__cplusplus) && !defined(ALLCPLUSPLUS)
+}
+#endif
