@@ -37,7 +37,7 @@ extern "C"
 /* prototypes for technology routines */
 BOOLEAN fpga_initprocess(TECHNOLOGY*, INTBIG);
 void    fpga_termprocess(void);
-void    fpga_setmode(INTBIG, char*[]);
+void    fpga_setmode(INTBIG, CHAR*[]);
 INTBIG  fpga_nodepolys(NODEINST*, INTBIG*, WINDOWPART*);
 void    fpga_shapenodepoly(NODEINST*, INTBIG, POLYGON*);
 INTBIG  fpga_allnodepolys(NODEINST*, POLYLIST*, WINDOWPART*, BOOLEAN);
