@@ -1,4 +1,5 @@
-/*
+/* -*- tab-width: 4 -*-
+ *
  * Electric(tm) VLSI Design System
  *
  * File: tecgen.h
@@ -41,6 +42,8 @@ extern NODEPROTO  *gen_unroutedpinprim;		/* Unrouted Pin */
 extern NODEPROTO  *gen_facetcenterprim;		/* Facet center */
 extern NODEPROTO  *gen_portprim;			/* Port */
 extern NODEPROTO  *gen_drcprim;				/* DRC Node */
+extern NODEPROTO  *gen_essentialprim;		/* Essential area marker */
+
 
 extern ARCPROTO   *gen_universalarc;		/* universal arc */
 extern ARCPROTO   *gen_invisiblearc;		/* invisible arc */
