@@ -1,4 +1,5 @@
-/*
+/* -*- tab-width: 4 -*-
+ *
  * Electric(tm) VLSI Design System
  *
  * File: tech.h
@@ -492,7 +493,7 @@ void      tech_moscutpoly(NODEINST*, INTBIG, INTBIG[], POLYLOOP*);
 void      tech_fillpoly(POLYGON*, TECH_POLYGON*, NODEINST*, INTBIG, INTBIG);
 void      tech_filltransport(NODEINST*, PORTPROTO*, POLYGON*, XARRAY, TECH_NODES*, INTBIG,
 			INTBIG, INTBIG, INTBIG, INTBIG);
-void      tech_fillportpoly(NODEINST*, PORTPROTO*, POLYGON*, XARRAY, TECH_NODES*, INTBIG);
+void      tech_fillportpoly(NODEINST*, PORTPROTO*, POLYGON*, XARRAY, TECH_NODES*, INTBIG, INTBIG);
 void      tech_resetnegated(ARCINST*);
 INTBIG    tech_displayableavars(ARCINST*, WINDOWPART*, POLYLOOP*);
 VARIABLE *tech_filldisplayableavar(ARCINST*, POLYGON*, WINDOWPART*, VARIABLE**, POLYLOOP*);
@@ -507,6 +508,8 @@ INTBIG    tech_nodeEpolys(NODEINST *ni, INTBIG *reasonable, WINDOWPART *win, POL
 void      tech_shapeEnodepoly(NODEINST *ni, INTBIG box, POLYGON *poly, POLYLOOP *pl);
 INTBIG    tech_arcpolys(ARCINST *ai, WINDOWPART *win, POLYLOOP *pl);
 void      tech_shapearcpoly(ARCINST *ai, INTBIG box, POLYGON *poly, POLYLOOP *pl);
+void      tech_nodeprotosizeoffset(NODEPROTO *np, INTBIG *lx, INTBIG *ly, INTBIG *hx, INTBIG *hy,
+			INTBIG lambda);
 
 #if defined(__cplusplus) && !defined(ALLCPLUSPLUS)
 }
