@@ -66,8 +66,8 @@ extern INTBIG      mocmos_transcontactkey;
 
 /* prototypes for local routines */
 BOOLEAN mocmos_initprocess(TECHNOLOGY*, INTBIG);
-void    mocmos_setmode(INTBIG, char*[]);
-INTBIG  mocmos_request(char*, va_list);
+void    mocmos_setmode(INTBIG, CHAR*[]);
+INTBIG  mocmos_request(CHAR*, va_list);
 INTBIG  mocmos_nodepolys(NODEINST *ni, INTBIG *reasonable, WINDOWPART *win);
 void    mocmos_shapenodepoly(NODEINST *ni, INTBIG box, POLYGON *poly);
 INTBIG  mocmos_allnodepolys(NODEINST *ni, POLYLIST *plist, WINDOWPART *win, BOOLEAN onlyreasonable);
