@@ -36,7 +36,7 @@ extern "C"
 
 /* prototypes for local routines */
 BOOLEAN mocmosold_initprocess(TECHNOLOGY*, INTBIG);
-void    mocmosold_setmode(INTBIG, char*[]);
+void    mocmosold_setmode(INTBIG, CHAR*[]);
 INTBIG  mocmosold_arcpolys(ARCINST*, WINDOWPART*);
 void    mocmosold_shapearcpoly(ARCINST*, INTBIG, POLYGON*);
 INTBIG  mocmosold_allarcpolys(ARCINST*, POLYLIST*, WINDOWPART*);
