@@ -38,77 +38,80 @@ INTBIG us_3ddepthdlog();
 INTBIG us_aboutdlog(void);
 INTBIG us_alignmentdlog(void);
 INTBIG us_annularringdlog(void);
-INTBIG us_arcsizedlog(char*[]);
-INTBIG us_arraydlog(char*[]);
+INTBIG us_arcsizedlog(CHAR*[]);
+INTBIG us_arraydlog(CHAR*[]);
 INTBIG us_artlookdlog(void);
 INTBIG us_attrenumdlog(void);
 INTBIG us_attributesdlog(void);
 INTBIG us_attrparamdlog(void);
 INTBIG us_attrreportdlog(void);
-void us_colormixdlog(char *overlayernames[]);
-INTBIG us_copyfacetdlog(char*);
-INTBIG us_createtodlog(char*[]);
+BOOLEAN us_colormixdlog(CHAR *overlayernames[], INTBIG layercount, CHAR **layernames, INTBIG *printcolors);
+INTBIG us_copyfacetdlog(CHAR*);
+INTBIG us_copyrightdlog(void);
+INTBIG us_createtodlog(CHAR*[]);
 INTBIG us_defarcdlog(void);
 INTBIG us_defnodedlog(void);
-INTBIG us_deftextdlog(char*);
+INTBIG us_deftextdlog(CHAR*);
 INTBIG us_dependentlibdlog(void);
-INTBIG us_editfacetdlog(char*);
+INTBIG us_editfacetdlog(CHAR*);
 INTBIG us_examineoptionsdlog(void);
 INTBIG us_facetdlog(void);
 INTBIG us_facetlist(void);
-INTBIG us_facetselect(char*, char*[], INTBIG);
+INTBIG us_facetselect(CHAR*, CHAR*[], INTBIG);
+INTBIG us_findoptionsdlog(void);
 INTBIG us_findtextdlog(void);
 INTBIG us_frameoptionsdlog(void);
 INTBIG us_generaloptionsdlog(void);
 INTBIG us_globalsignaldlog(void);
 INTBIG us_griddlog(void);
-INTBIG us_helpdlog(char*);
+INTBIG us_helpdlog(CHAR*);
 INTBIG us_highlayerlog(void);
 INTBIG us_iconstyledlog(void);
 INTBIG us_javaoptionsdlog(void);
 INTBIG us_lambdadlog(void);
 INTBIG us_librarypathdlog(void);
 INTBIG us_libtotechnologydlog(void);
-INTBIG us_menudlog(char*[]);
+INTBIG us_menudlog(CHAR*[]);
 INTBIG us_modtextsizedlog(void);
-INTBIG us_newviewdlog(char*[]);
-INTBIG us_nodesizedlog(char*[]);
-INTBIG us_noyesalwaysdlog(char*, char*[]);
-INTBIG us_noyescanceldlog(char*, char*[]);
-INTBIG us_noyesdlog(char*, char*[]);
+INTBIG us_newviewdlog(CHAR*[]);
+INTBIG us_nodesizedlog(CHAR*[]);
+INTBIG us_noyesalwaysdlog(CHAR*, CHAR*[]);
+INTBIG us_noyescanceldlog(CHAR*, CHAR*[]);
+INTBIG us_noyesdlog(CHAR*, CHAR*[]);
 INTBIG us_oldlibrarydlog(void);
 INTBIG us_optionsavingdlog(void);
 INTBIG us_patterndlog(void);
 INTBIG us_placetextdlog(void);
 INTBIG us_plotoptionsdlog(void);
 INTBIG us_portdisplaydlog(void);
-INTBIG us_portdlog(char*[]);
-INTBIG us_purelayernodedlog(char*[]);
+INTBIG us_portdlog(CHAR*[]);
+INTBIG us_purelayernodedlog(CHAR*[]);
 INTBIG us_quickkeydlog(void);
-INTBIG us_quitdlog(char*, INTBIG);
+INTBIG us_quitdlog(CHAR*, INTBIG);
 INTBIG us_renamedlog(INTBIG type);
 INTBIG us_replacedlog(void);
+INTBIG us_romgendlog(void);
 INTBIG us_selectoptdlog(void);
 INTBIG us_selectobjectdlog(INTBIG);
 INTBIG us_showdlog(BOOLEAN);
 INTBIG us_spreaddlog(void);
-INTBIG us_technologydlog(char*, char*[]);
+INTBIG us_technologydlog(CHAR*, CHAR*[]);
 INTBIG us_techoptdlog(void);
 INTBIG us_techvarsdlog(void);
 INTBIG us_tracedlog(void);
 INTBIG us_variablesdlog(void);
 INTBIG us_viewdlog(INTBIG);
-INTBIG us_visiblelayersdlog(char*);
+INTBIG us_visiblelayersdlog(CHAR*);
 INTBIG us_windowviewdlog(void);
-INTBIG us_yesnodlog(char*, char*[]);
+INTBIG us_yesnodlog(CHAR*, CHAR*[]);
 
 typedef struct
 {
-	char *name;
-	char *help;
+	CHAR *name;
+	CHAR *help;
 } HELPERS;
 extern HELPERS us_castofthousands[];
-extern char *us_capacitancenames[], *us_resistancenames[], *us_inductancenames[],
+extern CHAR *us_capacitancenames[], *us_resistancenames[], *us_inductancenames[],
 	*us_currentnames[], *us_voltagenames[], *us_timenames[];
 
 #if defined(__cplusplus) && !defined(ALLCPLUSPLUS)
