@@ -29,18 +29,18 @@
  * info@staticfreesoft.com
  */
 
-WINDOWPART *us_editpacmakeeditor(WINDOWPART*, char*, INTBIG*, INTBIG*);
+WINDOWPART *us_editpacmakeeditor(WINDOWPART*, CHAR*, INTBIG*, INTBIG*);
 void us_editpacterminate(EDITOR*);
 INTBIG us_editpactotallines(WINDOWPART*);
-char *us_editpacgetline(WINDOWPART*, INTBIG);
-void us_editpacaddline(WINDOWPART*, INTBIG, char*);
-void us_editpacreplaceline(WINDOWPART*, INTBIG, char*);
+CHAR *us_editpacgetline(WINDOWPART*, INTBIG);
+void us_editpacaddline(WINDOWPART*, INTBIG, CHAR*);
+void us_editpacreplaceline(WINDOWPART*, INTBIG, CHAR*);
 void us_editpacdeleteline(WINDOWPART*, INTBIG);
 void us_editpachighlightline(WINDOWPART*, INTBIG, INTBIG);
 void us_editpacsuspendgraphics(WINDOWPART*);
 void us_editpacresumegraphics(WINDOWPART*);
-void us_editpacwritetextfile(WINDOWPART*, char*);
-void us_editpacreadtextfile(WINDOWPART*, char*);
+void us_editpacwritetextfile(WINDOWPART*, CHAR*);
+void us_editpacreadtextfile(WINDOWPART*, CHAR*);
 void us_editpaceditorterm(WINDOWPART*);
 void us_editpacshipchanges(WINDOWPART*);
 BOOLEAN us_editpacgotchar(WINDOWPART*, INTSML, INTBIG);
@@ -48,5 +48,5 @@ void us_editpaccut(WINDOWPART*);
 void us_editpaccopy(WINDOWPART*);
 void us_editpacpaste(WINDOWPART*);
 void us_editpacundo(WINDOWPART*);
-void us_editpacsearch(WINDOWPART*, char*, char*, INTBIG);
+void us_editpacsearch(WINDOWPART*, CHAR*, CHAR*, INTBIG);
 void us_editpacpan(WINDOWPART*, INTBIG, INTBIG);
