@@ -41,6 +41,7 @@ extern "C"
 #define LAYERFUNCTION   4					/* function (layer facet) */
 #define LAYERLETTERS    5					/* letters (layer facet) */
 #define LAYERPATTERN    6					/* pattern (layer facet) */
+#define LAYERPATCONT    7					/* pattern control (layer facet) */
 #define LAYERPATCH      8					/* patch of layer (node/arc facet) */
 #define ARCFUNCTION     9					/* function (arc facet) */
 #define NODEFUNCTION   10					/* function (node facet) */
@@ -57,6 +58,7 @@ extern "C"
 #define NODESQUARE     21					/* square node (node facet) */
 #define NODEWIPES      22					/* pin node can disappear (node facet) */
 #define ARCINC         23					/* increment for arc angles (arc facet) */
+#define NODEMULTICUT   24					/* separation of multiple contact cuts (node facet) */
 #define NODELOCKABLE   25					/* lockable primitive (node facet) */
 #define CENTEROBJ      26					/* grab point object (node facet) */
 #define LAYERSPIRES    27					/* SPICE resistance (layer facet) */
@@ -65,27 +67,28 @@ extern "C"
 #define LAYERDXF       30					/* DXF layer (layer facet) */
 #define LAYER3DHEIGHT  31					/* 3D height (layer facet) */
 #define LAYER3DTHICK   32					/* 3D thickness (layer facet) */
+#define LAYERPRINTCOL  33					/* print colors (layer facet) */
 
 /* the strings that appear in the technology editor */
-#define TECEDNODETEXTCOLOR      "Color: "
-#define TECEDNODETEXTSTYLE      "Style: "
-#define TECEDNODETEXTFUNCTION   "Function: "
-#define TECEDNODETEXTLETTERS    "Layer letters: "
-#define TECEDNODETEXTGDS        "GDS-II Layer: "
-#define TECEDNODETEXTGDSOLD     "Calma GDS-II Layer: "
-#define TECEDNODETEXTCIF        "CIF Layer: "
-#define TECEDNODETEXTDXF        "DXF Layer(s): "
-#define TECEDNODETEXTSPICERES   "SPICE Resistance: "
-#define TECEDNODETEXTSPICECAP   "SPICE Capacitance: "
-#define TECEDNODETEXTSPICEECAP  "SPICE Edge Capacitance: "
-#define TECEDNODETEXTDRCMINWID  "DRC Minimum Width: "
-#define TECEDNODETEXT3DHEIGHT   "3D Height: "
-#define TECEDNODETEXT3DTHICK    "3D Thickness: "
+#define TECEDNODETEXTCOLOR      x_("Color: ")
+#define TECEDNODETEXTSTYLE      x_("Style: ")
+#define TECEDNODETEXTFUNCTION   x_("Function: ")
+#define TECEDNODETEXTLETTERS    x_("Layer letters: ")
+#define TECEDNODETEXTGDS        x_("GDS-II Layer: ")
+#define TECEDNODETEXTCIF        x_("CIF Layer: ")
+#define TECEDNODETEXTDXF        x_("DXF Layer(s): ")
+#define TECEDNODETEXTSPICERES   x_("SPICE Resistance: ")
+#define TECEDNODETEXTSPICECAP   x_("SPICE Capacitance: ")
+#define TECEDNODETEXTSPICEECAP  x_("SPICE Edge Capacitance: ")
+#define TECEDNODETEXTDRCMINWID  x_("DRC Minimum Width: ")
+#define TECEDNODETEXT3DHEIGHT   x_("3D Height: ")
+#define TECEDNODETEXT3DTHICK    x_("3D Thickness: ")
+#define TECEDNODETEXTPRINTCOL   x_("Print colors: ")
 
 typedef struct Ilist
 {
-	char  *name;
-	char  *constant;
+	CHAR  *name;
+	CHAR  *constant;
 	INTBIG value;
 } LIST;
 
@@ -174,27 +177,28 @@ typedef struct Irule
 #define HASEDGEDRCR  0200000000				/* has edge design rules reasons */
 #define HASMINNODE   0400000000				/* has minimum node size */
 #define HASMINNODER 01000000000				/* has minimum node size reasons */
+#define HASPRINTCOL 02000000000				/* has print colors */
 
 /* additional technology variables */
 #define NOTECHVAR ((TECHVAR *)-1)
 
 typedef struct Itechvar
 {
-	char            *varname;
+	CHAR            *varname;
 	struct Itechvar *nexttechvar;
 	BOOLEAN          changed;
 	INTBIG           ival;
 	float            fval;
-	char            *sval;
+	CHAR            *sval;
 	INTBIG           vartype;
-	char            *description;
+	CHAR            *description;
 } TECHVAR;
 
 extern TECHVAR us_knownvars[];
 
 /* the globals that define a technology */
 extern INTBIG           us_teceddrclayers;
-extern char           **us_teceddrclayernames;
+extern CHAR           **us_teceddrclayernames;
 
 extern LIST us_teclayer_functions[];
 extern LIST us_tecarc_functions[];
@@ -203,31 +207,33 @@ extern LIST us_tecarc_functions[];
 void       us_tecedgetbbox(NODEINST *ni, INTBIG *lx, INTBIG *hx, INTBIG *ly, INTBIG *hy);
 EXAMPLE   *us_tecedgetexamples(NODEPROTO *np, BOOLEAN isnode);
 INTBIG     us_teceditfindsequence(LIBRARY **dependentlibs, INTBIG dependentlibcount,
-			char *match, char *seqname, NODEPROTO ***sequence);
+			CHAR *match, CHAR *seqname, NODEPROTO ***sequence);
 INTBIG     us_teceditgetdependents(LIBRARY *lib, LIBRARY ***liblist);
-BOOLEAN    us_teceditgetlayerinfo(NODEPROTO *np, GRAPHICS *desc, char **cif, INTBIG *func,
-			char **layerletters, char **dxf, INTBIG *gds, float *spires, float *spicap,
-			float *spiecap, INTBIG *drcminwid, INTBIG *height3d, INTBIG *thick3d);
+BOOLEAN    us_teceditgetlayerinfo(NODEPROTO *np, GRAPHICS *desc, CHAR **cif, INTBIG *func,
+			CHAR **layerletters, CHAR **dxf, CHAR **gds, float *spires, float *spicap,
+			float *spiecap, INTBIG *drcminwid, INTBIG *height3d, INTBIG *thick3d, INTBIG *printcol);
 void       us_teceditsetpatch(NODEINST *ni, GRAPHICS *desc);
 void       us_tecedmakearc(NODEPROTO *np, INTBIG func, INTBIG fixang, INTBIG wipes,
 			INTBIG noextend, INTBIG anginc);
-void       us_tecedmakeinfo(NODEPROTO *np, INTBIG lambda, char *description);
-void       us_tecedmakelayer(NODEPROTO *np, INTBIG colorindex, UINTSML stip[8], INTBIG style,
-			char *ciflayer, INTBIG functionindex, char *layerletters, char *dxf,
-			INTBIG gds, float spires, float spicap, float spiecap,
-			INTBIG height3d, INTBIG thick3d);
+void       us_tecedmakeinfo(NODEPROTO *np, INTBIG lambda, CHAR *description);
+void       us_tecedmakelayer(NODEPROTO *np, INTBIG colorindex, UINTSML stip[16], INTBIG style,
+			CHAR *ciflayer, INTBIG functionindex, CHAR *layerletters, CHAR *dxf,
+			CHAR *gds, float spires, float spicap, float spiecap,
+			INTBIG height3d, INTBIG thick3d, INTBIG *printcolors);
 LIBRARY   *us_tecedmakelibfromtech(TECHNOLOGY *tech);
 void       us_tecedmakenode(NODEPROTO *np, INTBIG func, BOOLEAN serp, BOOLEAN square, BOOLEAN wipes,
-			BOOLEAN lockable);
+			BOOLEAN lockable, INTBIG multicutsep);
 void       us_tecedpointout(NODEINST *ni, NODEPROTO *np);
-char      *us_tecedsamplename(NODEPROTO *layernp);
+CHAR      *us_tecedsamplename(NODEPROTO *layernp);
 void       us_tecedswapports(INTBIG *p1, INTBIG *p2, TECH_NODES *tlist);
-void       us_tecfromlibinit(LIBRARY *lib, char *techname, BOOLEAN dumpc);
+void       us_tecfromlibinit(LIBRARY *lib, CHAR *techname, BOOLEAN dumpc);
 void       us_tecedfreeexamples(EXAMPLE *ne);
 void       us_tecedgetlayernamelist(void);
 void       us_tecedloaddrcmessage(DRCRULES *rules, LIBRARY *lib);
 void       us_teceditgetdrcarrays(VARIABLE *var, DRCRULES *rules);
 NODEPROTO *us_tecedgetlayer(NODEINST *ni);
+CHAR      *us_tecedgetportname(NODEINST *ni);
+void       us_teceditgetprintcol(VARIABLE *var, INTBIG *r, INTBIG *g, INTBIG *b, INTBIG *o, INTBIG *f);
 
 #if defined(__cplusplus) && !defined(ALLCPLUSPLUS)
 }
