@@ -175,7 +175,7 @@ extern TOOL *vhdl_tool;
 
 typedef struct
 {
-	char	*name;							/* string defining keyword */
+	CHAR	*name;							/* string defining keyword */
 	INTBIG	num;							/* number of keyword */
 } VKEYWORD;
 
@@ -186,7 +186,7 @@ typedef struct
 typedef struct Itokenlist
 {
 	INTBIG	token;							/* token number */
-	char	*pointer;						/* NULL if delimiter, */
+	CHAR	*pointer;						/* NULL if delimiter, */
 											/* pointer to global name space if identifier, */
 											/* pointer to keyword table if keyword, */
 											/* pointer to string if decimal literal, */
@@ -210,7 +210,7 @@ typedef struct Itokenlist
 
 typedef struct
 {
-	char	*string;						/* pointer to string, NULL if empty */
+	CHAR	*string;						/* pointer to string, NULL if empty */
 } IDENTTABLE;
 
 /********** Symbol Trees **********************************************/
@@ -232,7 +232,7 @@ typedef struct Isymboltree
 {
 	IDENTTABLE				*value;			/* identifier */
 	INTBIG					type;			/* type of item */
-	char					*pointer;		/* pointer to item */
+	CHAR					*pointer;		/* pointer to item */
 	struct Isymboltree		*lptr;			/* left pointer */
 	struct Isymboltree		*rptr;			/* right pointer */
 	INTBIG                   seen;			/* flag for deallocation */
@@ -250,7 +250,7 @@ typedef struct Isymbollist
 typedef struct Igate
 {
 	IDENTTABLE				*name;			/* name of gate */
-	char					*header;		/* header line */
+	CHAR					*header;		/* header line */
 	struct Igateline		*lines;			/* lines of gate def'n */
 	INTBIG					flags;			/* flags for general use */
 	struct Igate			*next;			/* next gate in list */
@@ -258,7 +258,7 @@ typedef struct Igate
 
 typedef struct Igateline
 {
-	char					*line;			/* line of gate def'n */
+	CHAR					*line;			/* line of gate def'n */
 	struct Igateline		*next;			/* next line in def'n */
 } GATELINE;
 
@@ -302,7 +302,7 @@ typedef struct Idbinterface
 {
 	IDENTTABLE				*name;			/* name of interface */
 	struct Idbportlist		*ports;			/* list of ports */
-	char					*interfacef;	/* interface declarations */
+	CHAR					*interfacef;	/* interface declarations */
 	INTBIG					flags;			/* for later code gen */
 	struct Idbbody			*bodies;		/* associated bodies */
 	struct Isymbollist		*symbols;		/* local symbols */
@@ -329,7 +329,7 @@ typedef struct Idbltype
 {
 	IDENTTABLE				*name;			/* name of type */
 	INTBIG					type;			/* type of type */
-	char					*pointer;		/* pointer to info */
+	CHAR					*pointer;		/* pointer to info */
 	struct Idbltype			*subtype;		/* possible subtype */
 } DBLTYPE;
 
@@ -401,7 +401,7 @@ typedef struct Idbname
 {
 	IDENTTABLE				*name;			/* name of name */
 	INTBIG					type;			/* type of name */
-	char					*pointer;		/* NULL if identifier */
+	CHAR					*pointer;		/* NULL if identifier */
 								 			/* pointer to DBEXPRLIST if indexed */
 								 			/* pointer to DBNAMELIST if concatenated */
 	struct Idbltype	*dbtype; 				/* pointer to type */
@@ -460,7 +460,7 @@ typedef struct Idbnamelist
 typedef struct Iptree
 {
 	INTBIG					type;			/* type of entity */
-	char					*pointer;		/* pointer to design unit */
+	CHAR					*pointer;		/* pointer to design unit */
 	struct Iptree			*next;			/* pointer to next */
 } PTREE;
 
@@ -498,7 +498,7 @@ typedef struct Ivinterface
 {
 	struct Itokenlist		*name;			/* name of entity */
 	struct Ifportlist		*ports;			/* list of ports */
-	char					*interfacef;	/* interface declarations */
+	CHAR					*interfacef;	/* interface declarations */
 } VINTERFACE;
 
 #define NOMODE				0
@@ -543,7 +543,7 @@ typedef struct Ibody
 typedef struct Ibodydeclare
 {
 	INTBIG					type;			/* type of declaration */
-	char					*pointer;		/* pointer to part tree */
+	CHAR					*pointer;		/* pointer to part tree */
 	struct Ibodydeclare		*next;			/* next in list */
 } BODYDECLARE;
 
@@ -559,7 +559,7 @@ typedef struct Ibodydeclare
 typedef struct Ibasicdeclare
 {
 	INTBIG					type;			/* type of basic declare */
-	char					*pointer;		/* pointer to parse tree */
+	CHAR					*pointer;		/* pointer to parse tree */
 } BASICDECLARE;
 
 #define NOOBJECTDECLARE			0
@@ -570,7 +570,7 @@ typedef struct Ibasicdeclare
 typedef struct Iobjectdeclare
 {
 	INTBIG					type;			/* type of object declare */
-	char					*pointer;		/* pointer to parse tree */
+	CHAR					*pointer;		/* pointer to parse tree */
 } OBJECTDECLARE;
 
 typedef struct Isignaldeclare
@@ -607,7 +607,7 @@ typedef struct Isubtypeind
 typedef struct Iconstaint
 {
 	INTBIG					type;			/* type of constaint */
-	char					*pointer;		/* pointer to parse tree */
+	CHAR					*pointer;		/* pointer to parse tree */
 } CONSTAINT;
 
 #define NOTYPE				0
@@ -617,7 +617,7 @@ typedef struct Itype
 {
 	struct Itokenlist		*identifier;	/* name of type */
 	INTBIG					type;			/* type definition */
-	char					*pointer;		/* pointer to type */
+	CHAR					*pointer;		/* pointer to type */
 } TYPE;
 
 #define NOCOMPOSITE			0
@@ -626,7 +626,7 @@ typedef struct Itype
 typedef struct Icomposite
 {
 	INTBIG					type;			/* type of composite */
-	char					*pointer;		/* pointer to composite */
+	CHAR					*pointer;		/* pointer to composite */
 } COMPOSITE;
 
 #define NOARRAY				0
@@ -635,7 +635,7 @@ typedef struct Icomposite
 typedef struct Iarray
 {
 	INTBIG					type;			/* (un)constrained array */
-	char					*pointer;		/* pointer to array */
+	CHAR					*pointer;		/* pointer to array */
 } ARRAY;
 
 typedef struct Iconstrained
@@ -662,7 +662,7 @@ typedef struct Iindexconstraint
 typedef struct Istatements
 {
 	INTBIG					type;			/* type of statement */
-	char					*pointer;		/* pointer to parse tree */
+	CHAR					*pointer;		/* pointer to parse tree */
 	struct Istatements		*next;			/* pointer to next */
 } STATEMENTS;
 
@@ -680,7 +680,7 @@ typedef struct Ivinstance
 typedef struct Iaportlist
 {
 	INTBIG					type;			/* type of actual port */
-	char					*pointer;		/* pointer to parse tree */
+	CHAR					*pointer;		/* pointer to parse tree */
 	struct Iaportlist		*next;			/* next in list */
 } APORTLIST;
 
@@ -740,7 +740,7 @@ typedef struct Iwaveform
 typedef struct Ivname
 {
 	INTBIG					type;			/* type of name */
-	char					*pointer;		/* pointer to parse tree */
+	CHAR					*pointer;		/* pointer to parse tree */
 } VNAME;
 
 #define NOSINGLENAME		0
@@ -751,7 +751,7 @@ typedef struct Ivname
 typedef struct Isinglename
 {
 	INTBIG					type;			/* type of simple name */
-	char					*pointer;		/* pointer to parse tree */
+	CHAR					*pointer;		/* pointer to parse tree */
 } SINGLENAME;
 
 typedef struct Isimplename
@@ -771,7 +771,7 @@ typedef struct Iselectedname
 typedef struct Iselectprefix
 {
 	INTBIG					type;			/* type of prefix */
-	char					*pointer;		/* pointer to parse tree */
+	CHAR					*pointer;		/* pointer to parse tree */
 } SELECTPREFIX;
 
 #define NOPREFIX				0
@@ -780,7 +780,7 @@ typedef struct Iselectprefix
 typedef struct Iprefix
 {
 	INTBIG					type;			/* type of prefix */
-	char					*pointer;		/* pointer to parse tree */
+	CHAR					*pointer;		/* pointer to parse tree */
 } PREFIX;
 
 #define NOSELECTSUFFIX			0
@@ -789,7 +789,7 @@ typedef struct Iprefix
 typedef struct Iselectsuffix
 {
 	INTBIG					type;			/* type of suffix */
-	char					*pointer;		/* pointer to parse tree */
+	CHAR					*pointer;		/* pointer to parse tree */
 } SELECTSUFFIX;
 
 typedef struct Iindexedname
@@ -816,7 +816,7 @@ typedef struct Islicename
 typedef struct Idiscreterange
 {
 	INTBIG					type;			/* type of discrete range */
-	char					*pointer;		/* pointer to parse tree */
+	CHAR					*pointer;		/* pointer to parse tree */
 } DISCRETERANGE;
 
 #define NORANGE				0
@@ -825,7 +825,7 @@ typedef struct Idiscreterange
 typedef struct Irange
 {
 	INTBIG					type;			/* type of range */
-	char					*pointer;		/* pointer to parse tree */
+	CHAR					*pointer;		/* pointer to parse tree */
 } RANGE;
 
 typedef struct Irangesimple
@@ -933,7 +933,7 @@ typedef struct Imfactors
 typedef struct Iprimary
 {
 	INTBIG					type;			/* type of primary */
-	char					*pointer;		/* pointer to primary */
+	CHAR					*pointer;		/* pointer to primary */
 } PRIMARY;
 
 #define NOLITERAL			0
@@ -944,22 +944,22 @@ typedef struct Iprimary
 typedef struct Iliteral
 {
 	INTBIG					type;			/* type of literal */
-	char					*pointer;		/* pointer to parse tree */
+	CHAR					*pointer;		/* pointer to parse tree */
 } LITERAL;
 
 #define NONUMERICLITERAL	0
 
 /* prototypes for tool interface */
-void           vhdl_init(INTBIG*, char*[], TOOL*);
+void           vhdl_init(INTBIG*, CHAR1*[], TOOL*);
 void           vhdl_done(void);
-void           vhdl_set(INTBIG, char*[]);
-INTBIG         vhdl_request(char*, va_list);
+void           vhdl_set(INTBIG, CHAR*[]);
+INTBIG         vhdl_request(CHAR*, va_list);
 void           vhdl_slice(void);
 
 /* prototypes for intratool interface */
 INTBIG         vhdl_evalexpression(EXPRESSION*);
 INTBIG         vhdl_evalsimpleexpr(SIMPLEEXPR*);
-IDENTTABLE    *vhdl_findidentkey(char*);
+IDENTTABLE    *vhdl_findidentkey(CHAR*);
 DBINTERFACE   *vhdl_findtopinterface(DBUNITS*);
 void           vhdl_freeparsermemory(void);
 void           vhdl_freesemantic(void);
@@ -975,7 +975,7 @@ IDENTTABLE    *vhdl_getprefixident(PREFIX*);
 TOKENLIST     *vhdl_getprefixtoken(PREFIX*);
 DBLTYPE        *vhdl_gettype(IDENTTABLE*);
 BOOLEAN        vhdl_keysame(TOKENLIST*, INTBIG);
-IDENTTABLE    *vhdl_makeidentkey(char*);
+IDENTTABLE    *vhdl_makeidentkey(CHAR*);
 DISCRETERANGE *vhdl_parsediscrete_range(void);
 EXPRESSION    *vhdl_parseexpression(void);
 VNAME         *vhdl_parsename(void);
@@ -984,9 +984,9 @@ SIMPLEEXPR    *vhdl_parsesimpleexpression(void);
 SIMPLENAME    *vhdl_parsesimplename(void);
 SUBTYPEIND    *vhdl_parsesubtype_indication(void);
 TYPE          *vhdl_parsetype(void);
-void           vhdl_print(char *fstring, ...);
-void           vhdl_printoneline(char *fstring, ...);
-void           vhdl_reporterrormsg(TOKENLIST*, char*);
+void           vhdl_print(CHAR *fstring, ...);
+void           vhdl_printoneline(CHAR *fstring, ...);
+void           vhdl_reporterrormsg(TOKENLIST*, CHAR*);
 SYMBOLTREE    *vhdl_searchsymbol(IDENTTABLE*, SYMBOLLIST*);
 BOOLEAN        vhdl_semantic(void);
 DBNAME        *vhdl_semname(VNAME*);
