@@ -37,12 +37,12 @@
 #define FILECOPYBUFSIZE 4096
 
 static BOOLEAN io_outputstage;		/* progress of database (aborting) */
-static char   *io_namesave;			/* for saving the global namespace */
-static char   *io_outfilename = 0;	/* the name of the file being written */
+static INTSML *io_namesave;			/* for saving the global namespace */
+static CHAR   *io_outfilename = 0;	/* the name of the file being written */
 
 /* prototypes for local routines */
 static void io_cleanup(void);
-static BOOLEAN io_copyfile(char *src, char *dst);
+static BOOLEAN io_copyfile(CHAR *src, CHAR *dst, BOOLEAN);
 static void io_writenodeproto(NODEPROTO*, BOOLEAN);
 static void io_writenodeinst(NODEINST*);
 static void io_writearcinst(ARCINST*);
@@ -53,7 +53,7 @@ static void io_findxlibvariables(VARIABLE*, INTSML);
 static void io_putoutvar(INTBIG*, INTBIG);
 static void io_putout(void*, INTBIG);
 static void io_putoutbig(void*);
-static void io_putstring(char*);
+static void io_putstring(CHAR*);
 
 /*
  * Routine to free all memory associated with this module.
@@ -82,9 +82,9 @@ BOOLEAN io_writebinlibrary(LIBRARY *lib, BOOLEAN nobackup)
 	REGISTER ARCINST *ai;
 	REGISTER LIBRARY *olib;
 	REGISTER TECHNOLOGY *tech;
-	REGISTER char *rename, *istrue, *dotaddr, *msg, *ext;
-	char *truename, *name, *arg[3], datesuffix[30];
-	unsigned char wordsize;
+	REGISTER CHAR *rename, *istrue, *dotaddr, *msg, *ext;
+	CHAR *truename, *name, *arg[3], datesuffix[30];
+	UCHAR1 wordsize;
 	REGISTER CELL *c;
 	REGISTER VIEW *v;
 	REGISTER void *infstr;
@@ -92,15 +92,15 @@ BOOLEAN io_writebinlibrary(LIBRARY *lib, BOOLEAN nobackup)
 	/* get the name of the file to write */
 	io_outputstage = FALSE;
 	dotaddr = 0;
-	ext = &lib->libfile[strlen(lib->libfile)-5];
-	if (strcmp(ext, ".elib") == 0)
+	ext = &lib->libfile[estrlen(lib->libfile)-5];
+	if (estrcmp(ext, x_(".elib")) == 0)
 	{
 		dotaddr = ext;
 		*ext = 0;
 	} else
 	{
-		ext = &lib->libfile[strlen(lib->libfile)-4];
-		if (strcmp(ext, ".txt") == 0)
+		ext = &lib->libfile[estrlen(lib->libfile)-4];
+		if (estrcmp(ext, x_(".txt")) == 0)
 		{
 			dotaddr = ext;
 			*ext = 0;
@@ -109,7 +109,7 @@ BOOLEAN io_writebinlibrary(LIBRARY *lib, BOOLEAN nobackup)
 	istrue = truepath(lib->libfile);
 	infstr = initinfstr();
 	addstringtoinfstr(infstr, istrue);
-	addstringtoinfstr(infstr, ".elib");
+	addstringtoinfstr(infstr, x_(".elib"));
 	err = FALSE;
 	if (io_outfilename == 0) 
 	{
@@ -150,46 +150,27 @@ BOOLEAN io_writebinlibrary(LIBRARY *lib, BOOLEAN nobackup)
 
 		/* if the file already exists, rename it */
 		if (filestatus == 1)
-			rename = (char *)emalloc((strlen(name)+15), el_tempcluster);
+			rename = (CHAR *)emalloc((estrlen(name)+15) * SIZEOFCHAR, el_tempcluster);
 		if (rename != 0)
 		{
 			switch (curstate[0]&BINOUTBACKUP)
 			{
 				case BINOUTNOBACK:
-					(void)strcpy(rename, name);
-					(void)strcat(rename, ".XXXXXX");
-					emaketemp(rename);
-					if ((curstate[1]&BINOUTPRECREADATE) != 0)
+					(void)estrcpy(rename, name);
+					(void)estrcat(rename, x_(".XXXXXX"));
+					if (io_copyfile(name, rename, TRUE))
 					{
-						if (io_copyfile(name, rename))
-						{
-							efree(rename);
-							rename = 0;
-						}
-						createit = FALSE;
-					} else
-					{
-						if (erename(name, rename) != 0)
-						{
-							ttyputerr(_("Could not rename file '%s' to '%s'"), rename, name);
-							efree(rename);
-							rename = 0;
-						}
+						efree(rename);
+						rename = 0;
 					}
+					createit = FALSE;
 					break;
 				case BINOUTONEBACK:
-					(void)strcpy(rename, name);
-					(void)strcat(rename, "~");
+					(void)estrcpy(rename, name);
+					(void)estrcat(rename, x_("~"));
 					if (fileexistence(rename) == 1) (void)eunlink(rename);
-					if ((curstate[1]&BINOUTPRECREADATE) != 0)
-					{
-						(void)io_copyfile(name, rename);
-						createit = FALSE;
-					} else
-					{
-						if (erename(name, rename) != 0)
-							ttyputerr(_("Could not rename file '%s' to '%s'"), rename, name);
-					}
+					(void)io_copyfile(name, rename, FALSE);
+					createit = FALSE;
 					efree(rename);
 					rename = 0;
 					break;
@@ -198,23 +179,23 @@ BOOLEAN io_writebinlibrary(LIBRARY *lib, BOOLEAN nobackup)
 					parsetime(olddate, &year, &month, &mday, &hour, &minute, &second);
 					for(i=0; i<1000; i++)
 					{
-						if (i == 0) sprintf(datesuffix, "-%ld-%ld-%ld", year, month+1, mday); else
-							sprintf(datesuffix, "-%ld-%ld-%ld--%ld", year, month+1, mday, i);
-						(void)strcpy(rename, name);
-						rename[strlen(rename)-5] = 0;
-						(void)strcat(rename, datesuffix);
-						(void)strcat(rename, ".elib");
+						if (i == 0)
+						{
+							esnprintf(datesuffix, 30, x_("-%ld-%ld-%ld"),
+								year, month+1, mday);
+						} else
+						{
+							esnprintf(datesuffix, 30, x_("-%ld-%ld-%ld--%ld"),
+								year, month+1, mday, i);
+						}
+						(void)estrcpy(rename, name);
+						rename[estrlen(rename)-5] = 0;
+						(void)estrcat(rename, datesuffix);
+						(void)estrcat(rename, x_(".elib"));
 						if (fileexistence(rename) == 0) break;
 					}
-					if ((curstate[1]&BINOUTPRECREADATE) != 0)
-					{
-						(void)io_copyfile(name, rename);
-						createit = FALSE;
-					} else
-					{
-						if (erename(name, rename) != 0)
-							ttyputerr(_("Could not rename file '%s' to '%s'"), rename, name);
-					}
+					(void)io_copyfile(name, rename, FALSE);
+					createit = FALSE;
 					efree(rename);
 					rename = 0;
 					break;
@@ -229,7 +210,7 @@ BOOLEAN io_writebinlibrary(LIBRARY *lib, BOOLEAN nobackup)
 	} else
 	{
 		/* remove the ".elib" because "xopen()" adds it */
-		i = strlen(name);
+		i = estrlen(name);
 		name[i-5] = 0;
 		io_fileout = xopen(name, io_filetypeblib|FILETYPEWRITE, 0, &truename);
 		if (io_outfilename == 0) 
@@ -239,7 +220,7 @@ BOOLEAN io_writebinlibrary(LIBRARY *lib, BOOLEAN nobackup)
 	}
 	if (io_fileout == NULL)
 	{
-		DiaMessageInDialog(_("Cannot write %s"), name);
+		if (truename != 0) DiaMessageInDialog(_("Cannot write %s"), name);
 		if (rename != 0) efree(rename);
 		return(TRUE);
 	}
@@ -249,7 +230,7 @@ BOOLEAN io_writebinlibrary(LIBRARY *lib, BOOLEAN nobackup)
 	{
 		arg[0] = lib->libname;
 		arg[1] = truename;
-		arg[2] = "library";
+		arg[2] = x_("library");
 		us_rename(3, arg);
 		if (io_outfilename == 0) 
 			(void)allocstring(&io_outfilename, truename, io_tool->cluster); else
@@ -273,11 +254,12 @@ BOOLEAN io_writebinlibrary(LIBRARY *lib, BOOLEAN nobackup)
 	/* first flush all changes so that database is clean */
 	noundoallowed();
 
-	/* initialize the file (writing version 10) */
-	magic = MAGIC10;
+	/* initialize the file (writing version 11) */
+	magic = MAGIC11;
 	io_putout(&magic, 4);
 	wordsize = SIZEOFINTSML;   io_putout(&wordsize, 1);
 	wordsize = SIZEOFINTBIG;   io_putout(&wordsize, 1);
+	wordsize = SIZEOFCHAR;     io_putout(&wordsize, 1);
 	aacount = el_maxtools;
 	io_putoutbig(&aacount);
 	techcount = el_maxtech;
@@ -636,7 +618,7 @@ BOOLEAN io_writebinlibrary(LIBRARY *lib, BOOLEAN nobackup)
 			timetostring(getcurrenttime()), facetshere,
 				makeplural(_("facet"), nodeprotoindex));
 #ifdef ONUNIX
-		printf(_("%s written on %s (%ld %s)\n"), name,
+		efprintf(stdout, _("%s written on %s (%ld %s)\n"), name,
 			timetostring(getcurrenttime()), facetshere,
 				makeplural(_("facet"), nodeprotoindex));
 #endif
@@ -855,7 +837,7 @@ void io_writenamespace(void)
 
 	for(i=0; i<el_numnames; i++) io_putstring(el_namespace[i]);
 
-	io_namesave = (char *)emalloc((el_numnames*2), el_tempcluster);
+	io_namesave = (INTSML *)emalloc(el_numnames*SIZEOFINTSML, el_tempcluster);
 	if (io_namesave == 0)
 	{
 		ttyputerr(_("No memory! destroying internal variables to save file"));
@@ -863,8 +845,7 @@ void io_writenamespace(void)
 		for(i=0; i<el_numnames; i++) *((INTSML *)el_namespace[i]) = (INTSML)i;
 	} else for(i=0; i<el_numnames; i++)
 	{
-		io_namesave[2*i] = el_namespace[i][0];
-		io_namesave[2*i+1] = el_namespace[i][1];
+		io_namesave[i] = *((INTSML *)el_namespace[i]);
 		*((INTSML *)el_namespace[i]) = (INTSML)i;
 	}
 }
@@ -875,11 +856,8 @@ void io_restorenamespace(void)
 
 	if (el_numnames == 0) return;
 	for(i=0; i<el_numnames; i++)
-	{
-		el_namespace[i][0] = io_namesave[2*i];
-		el_namespace[i][1] = io_namesave[2*i+1];
-	}
-	efree(io_namesave);
+		*((INTSML *)el_namespace[i]) = io_namesave[i];
+	efree((CHAR *)io_namesave);
 }
 
 /*
@@ -930,7 +908,6 @@ void io_writevariables(VARIABLE *firstvar, INTSML numvar, INTBIG type)
 {
 	REGISTER INTBIG i, j, datasize;
 	INTBIG num, ty, len, addr;
-	REGISTER void *infstr;
 
 	for(num=i=0; i<numvar; i++)
 		if ((firstvar[i].type&VDONTSAVE) == 0) num++;
@@ -938,19 +915,6 @@ void io_writevariables(VARIABLE *firstvar, INTSML numvar, INTBIG type)
 	for(i=0; i<numvar; i++)
 	{
 		if ((firstvar[i].type&VDONTSAVE) != 0) continue;
-		if (io_verbose > 0)
-		{
-			if (type == VTOOL)
-			{
-				infstr = initinfstr();
-				j = *((INTSML *)firstvar[i].key);
-				addtoinfstr(infstr, io_namesave[j*2]);
-				addtoinfstr(infstr, io_namesave[j*2+1]);
-				if (io_namesave[j*2+1] != 0)
-					addstringtoinfstr(infstr, &makename(firstvar[i].key)[2]);
-				ttyputmsg("Writing tool variable: %s", returninfstr(infstr));
-			}
-		}
 		io_putout((void *)firstvar[i].key, SIZEOFINTSML);
 		ty = firstvar[i].type;
 		io_putoutbig(&ty);
@@ -964,7 +928,7 @@ void io_writevariables(VARIABLE *firstvar, INTSML numvar, INTBIG type)
 			{
 				datasize = 1;
 				if (len == 0)
-					for(len=0; ((((char *)addr)[len])&0377) != 0377; len++)
+					for(len=0; ((((CHAR *)addr)[len])&0377) != 0377; len++)
 						;
 			} else if ((ty&VTYPE) == VDOUBLE)
 			{
@@ -1026,10 +990,10 @@ void io_putoutvar(INTBIG *addr, INTBIG ty)
 			break;
 		case VBOOLEAN:
 		case VCHAR:
-			io_putout(addr, sizeof (char));
+			io_putout(addr, sizeof (CHAR));
 			break;
 		case VSTRING:
-			io_putstring((char *)*addr);
+			io_putstring((CHAR *)*addr);
 			break;
 		case VTECHNOLOGY:
 			if ((TECHNOLOGY *)*addr != NOTECHNOLOGY)
@@ -1091,7 +1055,7 @@ void io_putoutvar(INTBIG *addr, INTBIG ty)
 		case VLIBRARY:
 			if ((LIBRARY *)*addr != NOLIBRARY)
 				io_putstring(((LIBRARY *)*addr)->libname); else
-					io_putstring("noname");
+					io_putstring(x_("noname"));
 			break;
 		case VTOOL:
 			if ((TOOL *)*addr != NOTOOL)
@@ -1109,11 +1073,12 @@ void io_putoutvar(INTBIG *addr, INTBIG ty)
 /*
  * Routine to copy file "src" to file "dst".  Displays an message and returns TRUE on error.
  */
-BOOLEAN io_copyfile(char *src, char *dst)
+BOOLEAN io_copyfile(CHAR *src, CHAR *dst, BOOLEAN tempfile)
 {
 	FILE *srcf, *dstf;
-	char buf[FILECOPYBUFSIZE], *truesrcname, *truedstname;
-	REGISTER INTBIG total, written;
+	UCHAR1 buf[FILECOPYBUFSIZE];
+	CHAR *truesrcname, *truedstname;
+	REGISTER INTBIG total, written, filetype;
 
 	srcf = xopen(src, io_filetypeblib, 0, &truesrcname);
 	if (srcf == NULL)
@@ -1121,7 +1086,9 @@ BOOLEAN io_copyfile(char *src, char *dst)
 		ttyputerr(_("Error: cannot open old library file %s"), src);
 		return(TRUE);
 	}
-	dstf = xcreate(dst, io_filetypeblib, 0, &truedstname);
+	filetype = io_filetypeblib;
+	if (tempfile) filetype |= FILETYPETEMPFILE;
+	dstf = xcreate(dst, filetype, 0, &truedstname);
 	if (dstf == NULL)
 	{
 		xclose(srcf);
@@ -1161,15 +1128,15 @@ void io_putout(void *data, INTBIG size)
 		ttyputmsg(_("Warning: null length data item; database may be bad"));
 		return;
 	}
-	ret = xfwrite((char *)data, size, 1, io_fileout);
+	ret = xfwrite((UCHAR1 *)data, size, 1, io_fileout);
 	if (ret == 0) longjmp(io_filerror, 1);
 }
 
-void io_putstring(char *name)
+void io_putstring(CHAR *name)
 {
 	INTBIG len;
 
-	len = strlen(name);
+	len = estrlen(name);
 	io_putoutbig(&len);
-	if (len != 0) io_putout(name, len);
+	if (len != 0) io_putout(name, len * SIZEOFCHAR);
 }
