@@ -77,7 +77,7 @@ static BOOLEAN   io_cifroundwires;		/* nonzero if wires should be rounded */
 typedef struct Iciflist
 {
 	INTBIG           identity;		/* specifies the nature of the entry */
-	char            *member;		/* will point to member's structure */
+	CHAR            *member;		/* will point to member's structure */
 	struct Iciflist *next;			/* next entry in list */
 } CIFLIST;
 
@@ -89,7 +89,7 @@ static CIFLIST *io_curlist;				/* current location in list */
 typedef struct Icfstart
 {
 	INTBIG cindex;					/* cell index */
-	char  *name;					/* cell name */
+	CHAR  *name;					/* cell name */
 	INTBIG l, r, t, b;				/* bounding box of cell */
 } CFSTART;
 
@@ -112,19 +112,19 @@ typedef struct Icgeoname
 {
 	INTBIG lay;						/* the corresponding layer number */
 	INTBIG x, y;					/* location of name */
-	char  *geoname;					/* the geo name */
+	CHAR  *geoname;					/* the geo name */
 } CGNAME;
 
 typedef struct Iclabel
 {
 	INTBIG x, y;					/* location of label */
-	char  *label;					/* the label */
+	CHAR  *label;					/* the label */
 } CLABEL;
 
 typedef struct Iccall
 {
 	INTBIG          cindex;			/* index of cell called */
-	char           *name;			/* name of cell called */
+	CHAR           *name;			/* name of cell called */
 	struct Ictrans *list;			/* list of transformations */
 } CCALL;
 
@@ -147,13 +147,13 @@ static CTRANS *io_curctrans;				/* current transformation description */
 
 /**************************** MISCELLANEOUS ****************************/
 
-static char       *io_curnodeprotoname;		/* name of the current cell */
+static CHAR       *io_curnodeprotoname;		/* name of the current cell */
 static NODEPROTO  *io_incell;				/* address of facet being defined */
 static NODEPROTO **io_cifnodes = 0;			/* nodeprotos associated with CIF names */
 static INTBIG      io_varlength;			/* the length of all attribute arrays */
 static VARIABLE   *io_cifnames;				/* cif names for the current technology */
 static INTBIG      io_cifnotfoundcount;		/* number of unknown layer names */
-static char      **io_cifnotfoundlist;		/* unknown layer name list */
+static CHAR      **io_cifnotfoundlist;		/* unknown layer name list */
 static INTBIG      io_cifnotfoundlimit = 0;	/* size of unknown layer name list */
 
 /* prototypes for local routines */
@@ -182,13 +182,13 @@ void io_freecifinmemory(void)
 {
 	io_ciffreeciflist();
 	io_ciffreecifcells();
-	if (io_cifnodes != 0) efree((char *)io_cifnodes);
+	if (io_cifnodes != 0) efree((CHAR *)io_cifnodes);
 }
 
 BOOLEAN io_readciflibrary(LIBRARY *lib)
 {
 	REGISTER FILE *f;
-	char *filename;
+	CHAR *filename;
 	REGISTER INTBIG i, *curstate;
 
 	curstate = io_getstatebits();
@@ -202,7 +202,7 @@ BOOLEAN io_readciflibrary(LIBRARY *lib)
 	if (io_initfind()) return(TRUE);
 
 	/* get the cif file */
-	f = xopen(lib->libfile, io_filetypecif, "", &filename);
+	f = xopen(lib->libfile, io_filetypecif, x_(""), &filename);
 	if (f == NULL)
 	{
 		ttyputerr(_("File %s not found"), lib->libfile);
@@ -226,7 +226,7 @@ BOOLEAN io_readciflibrary(LIBRARY *lib)
 
 	/* clean up */
 	(void)io_doneinterpreter();
-	for(i=0; i<io_cifnotfoundcount; i++) efree((char *)io_cifnotfoundlist[i]);
+	for(i=0; i<io_cifnotfoundcount; i++) efree((CHAR *)io_cifnotfoundlist[i]);
 
 	return(FALSE);
 }
@@ -329,7 +329,7 @@ NODEPROTO *io_nodes_start(LIBRARY *lib, void *dia)
 {
 	CIFCELL *cifcell;
 	CFSTART *cs;
-	char *opt;
+	CHAR *opt;
 	REGISTER void *infstr;
 
 	cs = (CFSTART *)io_curlist->member;
@@ -362,7 +362,7 @@ BOOLEAN io_nodes_box(void)
 {
 	NODEPROTO *node;
 	CBOX *cb;
-	char *layname;
+	CHAR *layname;
 	INTBIG l, w, lx, ly, hx, hy, r;
 
 	cb = (CBOX *)io_curlist->member;
@@ -433,8 +433,8 @@ BOOLEAN io_nodes_poly(void)
 		VINTEGER|VISARRAY|((cp->lim*2)<<VLENGTHSH));
 
 	/* free the polygon memory */
-	efree((char *)trace);
-	efree((char *)cp->x);   efree((char *)cp->y);
+	efree((CHAR *)trace);
+	efree((CHAR *)cp->x);   efree((CHAR *)cp->y);
 	cp->lim = 0;
 	return(FALSE);
 }
@@ -536,7 +536,7 @@ void io_rotatelayer(INTBIG *cenx, INTBIG *ceny, INTBIG deg)
 
 BOOLEAN io_initfind(void)
 {
-	REGISTER char *ch, *ch2;
+	REGISTER CHAR *ch, *ch2;
 	REGISTER NODEPROTO *np;
 	REGISTER NODEINST *ni;
 	NODEINST nodeinst;
@@ -544,7 +544,7 @@ BOOLEAN io_initfind(void)
 	static POLYGON *poly = NOPOLYGON;
 
 	/* get the array of CIF names */
-	io_cifnames = getval((INTBIG)el_curtech, VTECHNOLOGY, VSTRING|VISARRAY, "IO_cif_layer_names");
+	io_cifnames = getval((INTBIG)el_curtech, VTECHNOLOGY, VSTRING|VISARRAY, x_("IO_cif_layer_names"));
 	if (io_cifnames == NOVARIABLE)
 	{
 		ttyputerr(_("There are no CIF layer names assigned in the %s technology"),
@@ -561,7 +561,7 @@ BOOLEAN io_initfind(void)
 
 	/* create the array of nodes associated with the array of CIF names */
 	total = el_curtech->layercount;
-	if (io_cifnodes != 0) efree((char *)io_cifnodes);
+	if (io_cifnodes != 0) efree((CHAR *)io_cifnodes);
 	io_cifnodes = (NODEPROTO **)emalloc((total * (sizeof (NODEPROTO *))), io_tool->cluster);
 	if (io_cifnodes == 0) return(TRUE);
 	for(i=0; i<total; i++) io_cifnodes[i] = NONODEPROTO;
@@ -582,14 +582,14 @@ BOOLEAN io_initfind(void)
 		if (i != 1) continue;
 		shapenodepoly(ni, 0, poly);
 		if (poly->layer < 0) continue;
-		ch = ((char **)io_cifnames->addr)[poly->layer];
+		ch = ((CHAR **)io_cifnames->addr)[poly->layer];
 		if (*ch != 0) io_cifnodes[poly->layer] = np;
 	}
 
 	/* make sure every CIF string has an equivalent node */
 	for(i=0; i<total; i++)
 	{
-		ch = ((char **)io_cifnames->addr)[i];
+		ch = ((CHAR **)io_cifnames->addr)[i];
 		if (*ch == 0) continue;
 		if (io_cifnodes[i] != NONODEPROTO) continue;
 
@@ -606,8 +606,8 @@ BOOLEAN io_initfind(void)
 			ni->highy = np->highy;
 			(void)nodepolys(ni, 0, NOWINDOWPART);
 			shapenodepoly(ni, 0, poly);
-			ch2 = ((char **)io_cifnames->addr)[poly->layer];
-			if (strcmp(ch, ch2) != 0) continue;
+			ch2 = ((CHAR **)io_cifnames->addr)[poly->layer];
+			if (estrcmp(ch, ch2) != 0) continue;
 			io_cifnodes[i] = np;
 			break;
 		}
@@ -637,17 +637,17 @@ BOOLEAN io_initfind(void)
 	return(FALSE);
 }
 
-INTBIG io_findlayernum(char *name)
+INTBIG io_findlayernum(CHAR *name)
 {
 	REGISTER INTBIG i, newlimit;
-	REGISTER char **newlist;
+	REGISTER CHAR **newlist;
 
 	for(i=0; i<io_varlength; i++)
-		if (strcmp(name, ((char **)io_cifnames->addr)[i]) == 0) return(i);
+		if (estrcmp(name, ((CHAR **)io_cifnames->addr)[i]) == 0) return(i);
 
 	/* CIF name not found: see if it is in the list of unfound layers */
 	for(i=0; i<io_cifnotfoundcount; i++)
-		if (strcmp(name, io_cifnotfoundlist[i]) == 0) return(-1);
+		if (estrcmp(name, io_cifnotfoundlist[i]) == 0) return(-1);
 
 	/* add to the list */
 	if (io_cifnotfoundcount >= io_cifnotfoundlimit)
@@ -655,11 +655,11 @@ INTBIG io_findlayernum(char *name)
 		newlimit = io_cifnotfoundlimit * 2;
 		if (newlimit <= 0) newlimit = 10;
 		if (newlimit < io_cifnotfoundcount) newlimit = io_cifnotfoundcount;
-		newlist = (char **)emalloc(newlimit * (sizeof (char *)), io_tool->cluster);
+		newlist = (CHAR **)emalloc(newlimit * (sizeof (CHAR *)), io_tool->cluster);
 		if (newlist == 0) return(-1);
 		for(i=0; i<io_cifnotfoundcount; i++)
 			newlist[i] = io_cifnotfoundlist[i];
-		if (io_cifnotfoundlimit > 0) efree((char *)io_cifnotfoundlist);
+		if (io_cifnotfoundlimit > 0) efree((CHAR *)io_cifnotfoundlist);
 		io_cifnotfoundlist = newlist;
 		io_cifnotfoundlimit = newlimit;
 	}
@@ -741,7 +741,7 @@ CIFCELL *io_newcifcell(INTBIG cindex)
 			cc = old_cifcells[i];
 			if (cc != NOCIFCELL) io_insertcifcell(cc);	
 		}
-		if (old_cifcells_size > 0) efree((char *) old_cifcells);
+		if (old_cifcells_size > 0) efree((CHAR *) old_cifcells);
 	}
 	newcc->addr = NONODEPROTO;
 	newcc->cindex = cindex;
@@ -760,9 +760,9 @@ void io_ciffreecifcells(void)
 	{
 		cc = io_cifcells[i];
 		if (cc != NOCIFCELL)
-			efree((char *)cc);
+			efree((CHAR *)cc);
 	}
-	if (io_cifcells_size > 0) efree((char *)io_cifcells);
+	if (io_cifcells_size > 0) efree((CHAR *)io_cifcells);
 	io_cifcells_size = 0;
 	io_cifcells_num = 0;
 	io_cifcells = (CIFCELL **)NOSTRING;
@@ -787,29 +787,29 @@ CIFLIST *io_newciflist(INTBIG id)
 		case C_START:
 			cs = (CFSTART *)emalloc((sizeof (CFSTART)), io_tool->cluster);
 			if (cs == 0) return(NOCIFLIST);
-			newcl->member = (char *)cs;
+			newcl->member = (CHAR *)cs;
 			cs->name = 0;
 			break;
 		case C_BOX:
-			newcl->member = (char *)emalloc((sizeof (CBOX)), io_tool->cluster);
-			if (newcl->member == (char *) 0) return(NOCIFLIST);
+			newcl->member = (CHAR *)emalloc((sizeof (CBOX)), io_tool->cluster);
+			if (newcl->member == (CHAR *) 0) return(NOCIFLIST);
 			break;
 		case C_POLY:
-			newcl->member = (char *)emalloc((sizeof (CPOLY)), io_tool->cluster);
-			if (newcl->member == (char *) 0) return(NOCIFLIST);
+			newcl->member = (CHAR *)emalloc((sizeof (CPOLY)), io_tool->cluster);
+			if (newcl->member == (CHAR *) 0) return(NOCIFLIST);
 			break;
 		case C_GNAME:
-			newcl->member = (char *)emalloc((sizeof (CGNAME)), io_tool->cluster);
-			if (newcl->member == (char *) 0) return(NOCIFLIST);
+			newcl->member = (CHAR *)emalloc((sizeof (CGNAME)), io_tool->cluster);
+			if (newcl->member == (CHAR *) 0) return(NOCIFLIST);
 			break;
 		case C_LABEL:
-			newcl->member = (char *)emalloc((sizeof (CLABEL)), io_tool->cluster);
-			if (newcl->member == (char *) 0) return(NOCIFLIST);
+			newcl->member = (CHAR *)emalloc((sizeof (CLABEL)), io_tool->cluster);
+			if (newcl->member == (CHAR *) 0) return(NOCIFLIST);
 			break;
 		case C_CALL:
 			cc = (CCALL *)emalloc((sizeof (CCALL)), io_tool->cluster);
 			if (cc == 0) return(NOCIFLIST);
-			newcl->member = (char *)cc;
+			newcl->member = (CHAR *)cc;
 			cc->name = 0;
 			break;
 	}
@@ -835,24 +835,24 @@ void io_ciffreeciflist(void)
 				{
 					cct = cc->list;
 					cc->list = cc->list->next;
-					efree((char *)cct);
+					efree((CHAR *)cct);
 				}
-				if (cc->name != 0) efree((char *)cc->name);
-				efree((char *)cc);
+				if (cc->name != 0) efree((CHAR *)cc->name);
+				efree((CHAR *)cc);
 				break;
 			case C_START:
 				cs = (CFSTART *)cl->member;
-				if (cs->name != 0) efree((char *)cs->name);
-				efree((char *)cs);
+				if (cs->name != 0) efree((CHAR *)cs->name);
+				efree((CHAR *)cs);
 				break;
 			case C_BOX:
 			case C_POLY:
 			case C_GNAME:
 			case C_LABEL:
-				efree((char *)cl->member);
+				efree((CHAR *)cl->member);
 				break;
 		}
-		efree((char *)cl);
+		efree((CHAR *)cl);
 	}
 }
 
@@ -889,7 +889,7 @@ CTRANS *io_newctrans(void)
 	return(newct);
 }
 
-void io_outputwire(INTBIG lay, INTBIG width, char *wpath)
+void io_outputwire(INTBIG lay, INTBIG width, CHAR *wpath)
 {
 	/* convert wires to boxes and flashes  */
 	INTBIG i;
@@ -936,7 +936,7 @@ void io_outputflash(INTBIG lay, INTBIG diameter, point center)
 	float fcx = (float)center.x;
 	float fcy = (float)center.y;
 	float offset = (((float)diameter)/2.0f)*0.414213f;
-	char *fpath = io_makepath();
+	CHAR *fpath = io_makepath();
 	point temp;
 
 	temp.x = center.x-radius;
@@ -978,7 +978,7 @@ void io_outputbox(INTBIG lay, INTBIG length, INTBIG width, point center,
 	cb->xrot = xrotation;	cb->yrot = yrotation;
 }
 
-void io_outputpolygon(INTBIG lay, char *ppath)
+void io_outputpolygon(INTBIG lay, CHAR *ppath)
 {
 	INTBIG i;
 	INTBIG lim;
@@ -1015,11 +1015,11 @@ void io_outputpolygon(INTBIG lay, char *ppath)
 	}
 }
 
-void io_outputusercommand(INTBIG command, char *text)
+void io_outputusercommand(INTBIG command, CHAR *text)
 {
 }
 
-void io_outputgeoname(char *name, point pt, INTBIG lay)
+void io_outputgeoname(CHAR *name, point pt, INTBIG lay)
 {
 	CGNAME *cg;
 
@@ -1030,7 +1030,7 @@ void io_outputgeoname(char *name, point pt, INTBIG lay)
 	cg->x = pt.x;   cg->y = pt.y;
 }
 
-void io_outputlabel(char *name, point pt)
+void io_outputlabel(CHAR *name, point pt)
 {
 	CLABEL *cl;
 
@@ -1040,7 +1040,7 @@ void io_outputlabel(char *name, point pt)
 	cl->x = pt.x;   cl->y = pt.y;
 }
 
-void io_outputcall(INTBIG number, char *name, char *list)
+void io_outputcall(INTBIG number, CHAR *name, CHAR *list)
 {
 	CCALL *cc;
 	tentry temp;
@@ -1075,7 +1075,7 @@ void io_outputcall(INTBIG number, char *name, char *list)
 	}
 }
 
-void io_outputds(INTBIG number, char *name, INTBIG l, INTBIG r, INTBIG b, INTBIG t)
+void io_outputds(INTBIG number, CHAR *name, INTBIG l, INTBIG r, INTBIG b, INTBIG t)
 {
 	CFSTART *cs;
 
