@@ -33,6 +33,7 @@
 #include "global.h"
 #include "eio.h"
 #include "egraphics.h"
+#include "usr.h"
 #include "tecgen.h"
 #include "edialogs.h"
 #include "efunction.h"
@@ -53,7 +54,7 @@ static NODEPROTO *io_cifoutcurnp;				/* node proto of facet being written */
 static BOOLEAN    io_zero_offset;				/* Set if there is no centering */
 static BOOLEAN    io_cif_highlightreserr;		/* Set to highlight resolution errors */
 static INTBIG     io_reserr_count;				/* count the resolution errors */
-static char       io_cifoutcurlayer[200];		/* current layer name written out */
+static CHAR       io_cifoutcurlayer[200];		/* current layer name written out */
 static INTBIG     io_cifoutfacetnumber;			/* count of facets being written out */
 static INTBIG     io_cifoutjobsize;				/* number of facets to write out */
 
@@ -64,7 +65,7 @@ typedef struct Ilayerreq
 {
 	TECHNOLOGY *tech;
 	INTBIG      layer;
-	char       *layername;
+	CHAR       *layername;
 	struct Ilayerreq *nextlayerreq;
 } LAYERREQ;
 
@@ -77,7 +78,7 @@ static void      *io_cifmerge;			/* for merging geometry */
 /* prototypes for local routines */
 static void io_cifwritefacet(NODEPROTO*, BOOLEAN, void*);
 static void io_outputcifpoly(TECHNOLOGY*, POLYGON*, INTBIG, INTBIG, INTBIG, INTBIG, XARRAY, GEOM*);
-static void io_cifprintf(char *msg, ...);
+static void io_cifprintf(CHAR *msg, ...);
 static void io_cifreserror(GEOM*, INTBIG, INTBIG, INTBIG, INTBIG, XARRAY);
 static void io_cif_write_polygon(INTBIG, TECHNOLOGY*, INTBIG*, INTBIG*, INTBIG);
 static void io_cif_show_reserror(INTBIG, INTBIG, INTBIG, INTBIG);
@@ -85,7 +86,7 @@ static INTBIG io_cif_outscale(INTBIG value);
 static LAYERREQ *io_alloclayerreq(void);
 static void io_freelayerreq(LAYERREQ *req);
 static void io_includeciflayer(TECHNOLOGY *tech, INTBIG layer);
-static void io_writeciflayer(char *layername);
+static void io_writeciflayer(CHAR *layername);
 static void io_cifoptionsdlog(void);
 static INTBIG io_ciffindhighestlayer(NODEPROTO *np, INTBIG x, INTBIG y);
 static int io_ciflayerreqascending(const void *e1, const void *e2);
@@ -107,9 +108,9 @@ void io_freecifoutmemory(void)
 	{
 		req = io_ciflayerreqfree;
 		io_ciflayerreqfree = req->nextlayerreq;
-		efree((char *)req);
+		efree((CHAR *)req);
 	}
-	if (io_ciflayerreqlisttotal > 0) efree((char *)io_ciflayerreqlist);
+	if (io_ciflayerreqlisttotal > 0) efree((CHAR *)io_ciflayerreqlist);
 }
 
 /*
@@ -119,13 +120,13 @@ void io_initcif(void)
 {
 	extern COMCOMP io_cifp;
 
-	DiaDeclareHook("cifopt", &io_cifp, io_cifoptionsdlog);
+	DiaDeclareHook(x_("cifopt"), &io_cifp, io_cifoptionsdlog);
 }
 
 BOOLEAN io_writeciflibrary(LIBRARY *lib)
 {
-	char file[100], *truename;
-	REGISTER char *name;
+	CHAR file[100], *truename;
+	REGISTER CHAR *name;
 	REGISTER NODEPROTO *np;
 	REGISTER VARIABLE *var;
 	REGISTER TECHNOLOGY *tech;
@@ -141,8 +142,8 @@ BOOLEAN io_writeciflibrary(LIBRARY *lib)
 		ttyputerr(_("Must be editing a facet to generate CIF output"));
 		return(TRUE);
 	}
-	(void)strcpy(file, lib->curnodeproto->cell->cellname);
-	if (strcmp(&file[strlen(file)-4],".cif") != 0) (void)strcat(file, ".cif");
+	(void)estrcpy(file, lib->curnodeproto->cell->cellname);
+	if (estrcmp(&file[estrlen(file)-4],x_(".cif")) != 0) (void)estrcat(file, x_(".cif"));
 	name = truepath(file);
 	io_fileout = xcreate(name, io_filetypecif, _("CIF File"), &truename);
 	if (io_fileout == NULL)
@@ -151,6 +152,17 @@ BOOLEAN io_writeciflibrary(LIBRARY *lib)
 		return(TRUE);
 	}
 
+	/* write header information */
+	if ((us_useroptions&NODATEORVERSION) == 0)
+	{
+		xprintf(io_fileout, _("( Electric VLSI Design System, version %s )\n"), el_version);
+		xprintf(io_fileout, x_("( %s )\n\n"), timetostring(getcurrenttime()));
+	} else
+	{
+		xprintf(io_fileout, _("( Electric VLSI Design System )\n"));
+	}
+	us_emitcopyright(io_fileout, x_("( "), x_(" )"));
+
 	/* get current output state */
 	io_cifoutputstate = io_getstatebits();
 
@@ -161,16 +173,16 @@ BOOLEAN io_writeciflibrary(LIBRARY *lib)
 		io_cif_highlightreserr = FALSE;
 
 	/* get cif resolution */
-	var = getval((INTBIG)el_curtech, VTECHNOLOGY, VINTEGER, "IO_cif_resolution");
+	var = getval((INTBIG)el_curtech, VTECHNOLOGY, VINTEGER, x_("IO_cif_resolution"));
 	if (var == NOVARIABLE) io_cif_resolution = 0; else
 	{
 		io_cif_resolution = var->addr;
 		if (io_cif_resolution != 0 && io_cif_highlightreserr)
-			initerrorlogging("CIF Resolution");
+			initerrorlogging(x_("CIF Resolution"));
 	}
 
 	/* get the number of allowable points on a polygon */
-	var = getval((INTBIG)el_curtech, VTECHNOLOGY, VINTEGER, "IO_cif_polypoints");
+	var = getval((INTBIG)el_curtech, VTECHNOLOGY, VINTEGER, x_("IO_cif_polypoints"));
 	if (var == NOVARIABLE) io_cif_polypoints = MAXINTBIG; else
 		io_cif_polypoints = var->addr;
 
@@ -195,7 +207,7 @@ BOOLEAN io_writeciflibrary(LIBRARY *lib)
 	/* initialize cache of CIF layer information */
 	for(tech = el_technologies; tech != NOTECHNOLOGY; tech = tech->nexttechnology)
 	{
-		var = getval((INTBIG)tech, VTECHNOLOGY, VSTRING|VISARRAY, "IO_cif_layer_names");
+		var = getval((INTBIG)tech, VTECHNOLOGY, VSTRING|VISARRAY, x_("IO_cif_layer_names"));
 		if (var == NOVARIABLE) tech->temp1 = 0; else
 		{
 			tech->temp1 = var->addr;
@@ -207,7 +219,7 @@ BOOLEAN io_writeciflibrary(LIBRARY *lib)
 			}
 		}
 
-		var = getval((INTBIG)tech, VTECHNOLOGY, VSTRING|VISARRAY, "TECH_layer_names");
+		var = getval((INTBIG)tech, VTECHNOLOGY, VSTRING|VISARRAY, x_("TECH_layer_names"));
 		tech->temp2 = (var == NOVARIABLE ? 0 : var->addr);
 
 		/* if ignoring DRC mask layer, delete Generic technology layer names */
@@ -236,8 +248,8 @@ BOOLEAN io_writeciflibrary(LIBRARY *lib)
 
 	/* clean up */
 	if ((io_cifoutputstate[0]&CIFOUTNOTOPCALL) == 0)
-		io_cifprintf("C %ld;\n", io_cifbase);
-	io_cifprintf("E\n");
+		io_cifprintf(x_("C %ld;\n"), io_cifbase);
+	io_cifprintf(x_("E\n"));
 	xclose(io_fileout);
 	DiaDoneProgress(dia);
 
@@ -253,7 +265,7 @@ BOOLEAN io_writeciflibrary(LIBRARY *lib)
 	if (!io_prev_chr_sep)
 	{
 		io_check_sum = (io_check_sum << 8) ^
-			io_cifcrctab[((io_check_sum >> 24) ^ (unsigned char)' ') & 0xFF];
+			io_cifcrctab[((io_check_sum >> 24) ^ (UCHAR1)' ') & 0xFF];
 		io_nchar++;
 	}
 	bytesread = io_nchar;
@@ -289,9 +301,10 @@ void io_cifwritefacet(NODEPROTO *np, BOOLEAN fake, void *dia)
 	REGISTER NODEPROTO *subnt, *onp;
 	REGISTER PORTPROTO *pp, *subpp;
 	REGISTER PORTARCINST *pi;
-	REGISTER INTBIG i, j, total, validport, toplayer, toplayerfound;
-	REGISTER INTBIG offx, offy, fun;
+	REGISTER INTBIG i, j, total, validport, toplayer, toplayerfound, offx, offy, fun;
+	REGISTER CHAR *type;
 	REGISTER LAYERREQ *req;
+	REGISTER VARIABLE *var;
 	XARRAY trans, localtran, temp2, subrot, subt, subr, submat;
 	INTBIG rx, ry, xpos, ypos, bx, by, subcornerx, subcornery;
 	static POLYGON *poly = NOPOLYGON;
@@ -351,8 +364,8 @@ void io_cifwritefacet(NODEPROTO *np, BOOLEAN fake, void *dia)
 		offx = io_cifoutoffx = (np->lowx + np->highx) / 2;
 		offy = io_cifoutoffy = (np->lowy + np->highy) / 2;
 	}
-	io_cifprintf("DS %ld 1 1;\n", io_cifbase);
-	io_cifprintf("9 %s; (from library %s);\n", np->cell->cellname, np->cell->lib->libname);
+	io_cifprintf(x_("DS %ld 1 1;\n"), io_cifbase);
+	io_cifprintf(x_("9 %s; (from library %s);\n"), nldescribenodeproto(np), np->cell->lib->libname);
 
 	io_cifoutcurlayer[0] = 0;
 	if ((io_cifoutputstate[0]&CIFOUTMERGE) == 0)
@@ -395,7 +408,7 @@ void io_cifwritefacet(NODEPROTO *np, BOOLEAN fake, void *dia)
 		if (total > io_ciflayerreqlisttotal)
 		{
 			if (io_ciflayerreqlisttotal > 0)
-				efree((char *)io_ciflayerreqlist);
+				efree((CHAR *)io_ciflayerreqlist);
 			io_ciflayerreqlisttotal = 0;
 			io_ciflayerreqlist = (LAYERREQ **)emalloc(total * (sizeof (LAYERREQ *)),
 				io_tool->cluster);
@@ -553,19 +566,19 @@ void io_cifwritefacet(NODEPROTO *np, BOOLEAN fake, void *dia)
 			}
 
 			/* write a call to a facet */
-			io_cifprintf("C %ld R %ld %ld", subnt->temp1, rx, ry);
-			if (subni->transpose != 0) io_cifprintf(" M Y");
-			io_cifprintf(" T %ld %ld;\n", io_cif_outscale(xpos), io_cif_outscale(ypos));
+			io_cifprintf(x_("C %ld R %ld %ld"), subnt->temp1, rx, ry);
+			if (subni->transpose != 0) io_cifprintf(x_(" M Y"));
+			io_cifprintf(x_(" T %ld %ld;\n"), io_cif_outscale(xpos), io_cif_outscale(ypos));
 		} else
 		{
 			/* write the vectors that describe an unexpanded facet */
-			io_cifprintf("0V %ld %ld %ld %ld %ld %ld %ld %ld %ld %ld;\n",
+			io_cifprintf(x_("0V %ld %ld %ld %ld %ld %ld %ld %ld %ld %ld;\n"),
 				io_cif_outscale(subni->lowx-offx), io_cif_outscale(subni->lowy-offy),
 					io_cif_outscale(subni->lowx-offx), io_cif_outscale(subni->highy-offy),
 						io_cif_outscale(subni->highx-offx), io_cif_outscale(subni->highy-offy),
 							io_cif_outscale(subni->highx-offx), io_cif_outscale(subni->lowy-offy),
 								io_cif_outscale(subni->lowx-offx), io_cif_outscale(subni->lowy-offy));
-			io_cifprintf("2C \"%s\" T %ld %ld;\n", describenodeproto(subnt),
+			io_cifprintf(x_("2C \"%s\" T %ld %ld;\n"), describenodeproto(subnt),
 				io_cif_outscale(xpos), io_cif_outscale(ypos));
 		}
 	}
@@ -656,25 +669,35 @@ void io_cifwritefacet(NODEPROTO *np, BOOLEAN fake, void *dia)
 			if (toplayerfound == 0)
 				ttyputmsg(_("Warning: facet %s, export '%s' obscured by higher layer"),
 					describenodeproto(np), pp->protoname);
-			io_cifprintf("94 %s %ld %ld;\n", pp->protoname, io_cif_outscale(xpos-offx),
-				io_cif_outscale(ypos-offy));
+			var = getval((INTBIG)pp, VPORTPROTO, VSTRING, x_("EXPORT_reference_name"));
+			type = describeportbits(pp->userbits);
+			if (((pp->userbits&STATEBITS) == REFOUTPORT || (pp->userbits&STATEBITS) == REFINPORT ||
+				(pp->userbits&STATEBITS) == REFBASEPORT) && var != NOVARIABLE)
+			{
+				io_cifprintf("94 %s %ld %ld type=%s reference=%s;\n", pp->protoname,
+					io_cif_outscale(xpos-offx), io_cif_outscale(ypos-offy), type, (CHAR *)var->addr);
+			} else
+			{
+				io_cifprintf("94 %s %ld %ld type=%s;\n", pp->protoname, io_cif_outscale(xpos-offx),
+					io_cif_outscale(ypos-offy), type);
+			}
 		}
 	}
 
-	io_cifprintf("DF;\n");
+	io_cifprintf(x_("DF;\n"));
 }
 
 int io_ciflayerreqascending(const void *e1, const void *e2)
 {
 	REGISTER LAYERREQ *lr1, *lr2;
-	REGISTER char *lrname1, *lrname2;
+	REGISTER CHAR *lrname1, *lrname2;
 
 	lr1 = *((LAYERREQ **)e1);
 	lr2 = *((LAYERREQ **)e2);
 	lrname1 = lr1->layername;
-	if (lrname1 == 0) lrname1 = "";
+	if (lrname1 == 0) lrname1 = x_("");
 	lrname2 = lr2->layername;
-	if (lrname2 == 0) lrname2 = "";
+	if (lrname2 == 0) lrname2 = x_("");
 	return(namesame(lrname1, lrname2));
 }
 
@@ -740,11 +763,11 @@ INTBIG io_ciffindhighestlayer(NODEPROTO *np, INTBIG x, INTBIG y)
 /*
  * Routine to dump the layer name (if it has changed).
  */
-void io_writeciflayer(char *layername)
+void io_writeciflayer(CHAR *layername)
 {
-	if (strcmp(layername, io_cifoutcurlayer) == 0) return;
-	io_cifprintf("L %s;\n", layername);
-	strcpy(io_cifoutcurlayer, layername);
+	if (estrcmp(layername, io_cifoutcurlayer) == 0) return;
+	io_cifprintf(x_("L %s;\n"), layername);
+	estrcpy(io_cifoutcurlayer, layername);
 }
 
 /*
@@ -757,7 +780,7 @@ void io_outputcifpoly(TECHNOLOGY *tech, POLYGON *poly, INTBIG rx, INTBIG ry,
 {
 	REGISTER INTBIG r, k, bloat;
 	INTBIG xl, xh, yl, yh, xpos, ypos;
-	REGISTER char *layername;
+	REGISTER CHAR *layername;
 	REGISTER void *infstr;
 
 	/* get bloating for this layer */
@@ -765,11 +788,11 @@ void io_outputcifpoly(TECHNOLOGY *tech, POLYGON *poly, INTBIG rx, INTBIG ry,
 	infstr = initinfstr();
 	addstringtoinfstr(infstr, tech->techname);
 	addtoinfstr(infstr, ':');
-	addstringtoinfstr(infstr, ((char **)tech->temp2)[poly->layer]);
+	addstringtoinfstr(infstr, ((CHAR **)tech->temp2)[poly->layer]);
 	bloat = io_getoutputbloat(returninfstr(infstr));
 
 	/* get the CIF layer, stop if none */
-	layername = ((char **)tech->temp1)[poly->layer];
+	layername = ((CHAR **)tech->temp1)[poly->layer];
 	if (*layername == 0) return;
 
 	switch (poly->style)
@@ -783,7 +806,7 @@ void io_outputcifpoly(TECHNOLOGY *tech, POLYGON *poly, INTBIG rx, INTBIG ry,
 			io_writeciflayer(layername);
 
 			/* write the round-flash */
-			io_cifprintf(" R %ld %ld %ld;\n", r+bloat, io_cif_outscale(poly->xv[0]-offx),
+			io_cifprintf(x_(" R %ld %ld %ld;\n"), r+bloat, io_cif_outscale(poly->xv[0]-offx),
 				io_cif_outscale(poly->yv[0]-offy));
 			break;
 
@@ -838,11 +861,11 @@ void io_outputcifpoly(TECHNOLOGY *tech, POLYGON *poly, INTBIG rx, INTBIG ry,
 
 				/* want individual box output */
 				xform((xl+xh)/2, (yl+yh)/2, &xpos, &ypos, trans);
-				io_cifprintf(" B %ld %ld %ld %ld", io_cif_outscale(xh-xl+bloat),
+				io_cifprintf(x_(" B %ld %ld %ld %ld"), io_cif_outscale(xh-xl+bloat),
 					io_cif_outscale(yh-yl+bloat), io_cif_outscale(xpos-offx),
 						io_cif_outscale(ypos-offy));
-				if (rx <= 0 || ry != 0) io_cifprintf(" %ld %ld", rx, ry);
-				io_cifprintf(";\n");
+				if (rx <= 0 || ry != 0) io_cifprintf(x_(" %ld %ld"), rx, ry);
+				io_cifprintf(x_(";\n"));
 			} else
 			{
 				/* write the layer name */
@@ -855,11 +878,11 @@ void io_outputcifpoly(TECHNOLOGY *tech, POLYGON *poly, INTBIG rx, INTBIG ry,
 					io_cifprintf(_("(NEXT POLYGON CANNOT BE BLOATED);\n"));
 				}
 				if (poly->count == 1)
-					io_cifprintf(" 0V %ld %ld %ld %ld;\n", io_cif_outscale(poly->xv[0]-offx),
+					io_cifprintf(x_(" 0V %ld %ld %ld %ld;\n"), io_cif_outscale(poly->xv[0]-offx),
 						io_cif_outscale(poly->yv[0]-offy), io_cif_outscale(poly->xv[0]-offx),
 							io_cif_outscale(poly->yv[0]-offy)); else
 				if (poly->count == 2)
-					io_cifprintf(" 0V %ld %ld %ld %ld;\n", io_cif_outscale(poly->xv[0]-offx),
+					io_cifprintf(x_(" 0V %ld %ld %ld %ld;\n"), io_cif_outscale(poly->xv[0]-offx),
 						io_cif_outscale(poly->yv[0]-offy), io_cif_outscale(poly->xv[1]-offx),
 							io_cif_outscale(poly->yv[1]-offy)); else
 				{
@@ -888,10 +911,10 @@ void io_outputcifpoly(TECHNOLOGY *tech, POLYGON *poly, INTBIG rx, INTBIG ry,
 		case CLOSEDRECT:
 			xformpoly(poly, trans);
 			getbbox(poly, &xl,&xh, &yl,&yh);
-			io_cifprintf("0V %ld %ld", io_cif_outscale(xl-offx), io_cif_outscale(yl-offy));
-			io_cifprintf(" %ld %ld", io_cif_outscale(xl-offx), io_cif_outscale(yh-offy));
-			io_cifprintf(" %ld %ld", io_cif_outscale(xh-offx), io_cif_outscale(yh-offy));
-			io_cifprintf(" %ld %ld;\n", io_cif_outscale(xh-offx), io_cif_outscale(yl-offy));
+			io_cifprintf(x_("0V %ld %ld"), io_cif_outscale(xl-offx), io_cif_outscale(yl-offy));
+			io_cifprintf(x_(" %ld %ld"), io_cif_outscale(xl-offx), io_cif_outscale(yh-offy));
+			io_cifprintf(x_(" %ld %ld"), io_cif_outscale(xh-offx), io_cif_outscale(yh-offy));
+			io_cifprintf(x_(" %ld %ld;\n"), io_cif_outscale(xh-offx), io_cif_outscale(yl-offy));
 			return;
 
 		case OPENED:
@@ -900,21 +923,21 @@ void io_outputcifpoly(TECHNOLOGY *tech, POLYGON *poly, INTBIG rx, INTBIG ry,
 		case OPENEDT3:
 		case CLOSED:
 			xformpoly(poly, trans);
-			io_cifprintf("0V");
+			io_cifprintf(x_("0V"));
 			for(k=0; k<poly->count; k++)
-				io_cifprintf(" %ld %ld", io_cif_outscale(poly->xv[k]-offx), io_cif_outscale(poly->yv[k]-offy));
+				io_cifprintf(x_(" %ld %ld"), io_cif_outscale(poly->xv[k]-offx), io_cif_outscale(poly->yv[k]-offy));
 			if (poly->style == CLOSED)
-				io_cifprintf(" %ld %ld", io_cif_outscale(poly->xv[k]-offx), io_cif_outscale(poly->yv[k]-offy));
-			io_cifprintf(";\n");
+				io_cifprintf(x_(" %ld %ld"), io_cif_outscale(poly->xv[k]-offx), io_cif_outscale(poly->yv[k]-offy));
+			io_cifprintf(x_(";\n"));
 			return;
 
 		case VECTORS:
 			xformpoly(poly, trans);
 			for(k=0; k<poly->count; k += 2)
 			{
-				io_cifprintf("0V %ld %ld", io_cif_outscale(poly->xv[k]-offx),
+				io_cifprintf(x_("0V %ld %ld"), io_cif_outscale(poly->xv[k]-offx),
 					io_cif_outscale(poly->yv[k]-offy));
-				io_cifprintf(" %ld %ld;\n", io_cif_outscale(poly->xv[k+1]-offx),
+				io_cifprintf(x_(" %ld %ld;\n"), io_cif_outscale(poly->xv[k+1]-offx),
 					io_cif_outscale(poly->yv[k+1]-offy));
 			}
 			return;
@@ -926,11 +949,11 @@ void io_outputcifpoly(TECHNOLOGY *tech, POLYGON *poly, INTBIG rx, INTBIG ry,
  * routine to send a line to the CIF output file and to accumulate
  * checksum information.
  */
-void io_cifprintf(char *msg, ...)
+void io_cifprintf(CHAR *msg, ...)
 {
 	va_list ap;
-	char temp[200], *cp;
-	unsigned char c;
+	CHAR temp[200], *cp;
+	INTBIG c;
 
 	var_start(ap, msg);
 	evsnprintf(temp, 200, msg, ap);
@@ -949,13 +972,13 @@ void io_cifprintf(char *msg, ...)
 		} else if (io_prev_chr_sep == 0)
 		{
 			io_check_sum = (io_check_sum << 8) ^
-				io_cifcrctab[((io_check_sum >> 24) ^ (unsigned char)' ') & 0xFF];
+				io_cifcrctab[((io_check_sum >> 24) ^ (UCHAR1)' ') & 0xFF];
 			io_prev_chr_sep = 1;
 			io_nchar++;
 		}
 	}
 
-	xprintf(io_fileout, "%s", temp);
+	xprintf(io_fileout, x_("%s"), temp);
 }
 
 /* routine which highlights box which doesn't resolve */
@@ -982,7 +1005,7 @@ void io_cifreserror(GEOM *pos, INTBIG length, INTBIG width, INTBIG xc, INTBIG yc
 			/* highlight the object */
 			if (io_cif_highlightreserr)
 			{
-				err = logerror("Resolution error", geomparent(pos), 0);
+				err = logerror(x_("Resolution error"), geomparent(pos), 0);
 				addgeomtoerror(err, pos, TRUE, 0, 0);
 			}
 			io_reserr_count++;
@@ -996,17 +1019,17 @@ void io_cif_write_polygon(INTBIG layer, TECHNOLOGY *tech, INTBIG *xbuf, INTBIG *
 {
 	INTBIG buflen, prlen, i;
 	REGISTER INTBIG tmpx, tmpy, lasttmpx, lasttmpy;
-	char outbuf[NMCHR+2], prbuf[40], *layername; /* declare buffers */
+	CHAR outbuf[NMCHR+2], prbuf[40], *layername; /* declare buffers */
 
 	/* write the layer name */
 	if (layer < 0 || tech->temp1 == 0) return;
-	layername = ((char **)tech->temp1)[layer];
+	layername = ((CHAR **)tech->temp1)[layer];
 	if (*layername == 0) return;
 	io_writeciflayer(layername);
 
 	/* set up first line */
-	(void)sprintf(outbuf, "P ");
-	buflen = strlen(outbuf);
+	(void)esnprintf(outbuf, NMCHR+2, x_("P "));
+	buflen = estrlen(outbuf);
 
 	/* check the number of points on the polygon */
 	if (count > io_cif_polypoints)
@@ -1036,22 +1059,22 @@ void io_cif_write_polygon(INTBIG layer, TECHNOLOGY *tech, INTBIG *xbuf, INTBIG *
 
 	for(i=0; i<count; i++)
 	{
-		(void)sprintf(prbuf, " %ld %ld", io_cif_outscale(xbuf[i]),
+		(void)esnprintf(prbuf, 40, x_(" %ld %ld"), io_cif_outscale(xbuf[i]),
 			io_cif_outscale(ybuf[i]));
-		prlen = strlen(prbuf); /* get length of coord. pair */
+		prlen = estrlen(prbuf); /* get length of coord. pair */
 
 		/* if we have done the last point */
 		if (i == count-1)
 		{
 			if (prlen + buflen < NMCHR-1) /* if space in buffer */
 			{
-				(void)strcat(outbuf, prbuf); /* concatenate strings */
-				io_cifprintf("%s;\n", outbuf); /* write the buffer */
+				(void)estrcat(outbuf, prbuf); /* concatenate strings */
+				io_cifprintf(x_("%s;\n"), outbuf); /* write the buffer */
 			} else
 			{
 				/* write as two lines */
-				io_cifprintf("%s\n", outbuf);
-				io_cifprintf("  %s;\n", prbuf);
+				io_cifprintf(x_("%s\n"), outbuf);
+				io_cifprintf(x_("  %s;\n"), prbuf);
 			}
 		} else
 		{
@@ -1059,14 +1082,14 @@ void io_cif_write_polygon(INTBIG layer, TECHNOLOGY *tech, INTBIG *xbuf, INTBIG *
 			if (prlen + buflen < NMCHR) /* if small enough */
 			{
 				/* append to buffer */
-				(void)strcat(outbuf, prbuf);
-				buflen = strlen(outbuf);
+				(void)estrcat(outbuf, prbuf);
+				buflen = estrlen(outbuf);
 			} else
 			{
 				/* we must write the buffer out, and re-initialize it */
-				io_cifprintf("%s\n", outbuf);
-				(void)sprintf(outbuf, "  %s", prbuf);
-				buflen = strlen(outbuf);
+				io_cifprintf(x_("%s\n"), outbuf);
+				(void)esnprintf(outbuf, NMCHR+2, x_("  %s"), prbuf);
+				buflen = estrlen(outbuf);
 			}
 		}
 	}
@@ -1109,7 +1132,7 @@ void io_includeciflayer(TECHNOLOGY *tech, INTBIG layer)
 	req->tech = tech;
 	req->layer = layer;
 	if (layer < 0 || tech->temp1 == 0) req->layername = 0; else
-		req->layername = ((char **)tech->temp1)[layer];
+		req->layername = ((CHAR **)tech->temp1)[layer];
 	req->nextlayerreq = io_ciflayerreq;
 	io_ciflayerreq = req;
 }
@@ -1141,16 +1164,16 @@ static DIALOGITEM io_cifoptionsdialogitems[] =
 {
  /*  1 */ {0, {224,380,248,452}, BUTTON, N_("OK")},
  /*  2 */ {0, {224,240,248,312}, BUTTON, N_("Cancel")},
- /*  3 */ {0, {8,8,248,223}, SCROLL, ""},
+ /*  3 */ {0, {8,8,248,223}, SCROLL, x_("")},
  /*  4 */ {0, {8,232,24,312}, MESSAGE, N_("CIF Layer:")},
- /*  5 */ {0, {8,316,24,454}, EDITTEXT, ""},
+ /*  5 */ {0, {8,316,24,454}, EDITTEXT, x_("")},
  /*  6 */ {0, {32,232,48,454}, CHECK, N_("Output Mimics Display")},
  /*  7 */ {0, {56,232,72,454}, CHECK, N_("Output Merges Boxes")},
  /*  8 */ {0, {148,232,164,454}, CHECK, N_("Input Squares Wires")},
  /*  9 */ {0, {100,232,116,454}, CHECK, N_("Output Instantiates Top Level")},
  /* 10 */ {0, {196,240,212,384}, MESSAGE, N_("Output resolution:")},
- /* 11 */ {0, {196,388,212,454}, EDITTEXT, ""},
- /* 12 */ {0, {172,232,188,436}, POPUP, ""},
+ /* 11 */ {0, {196,388,212,454}, EDITTEXT, x_("")},
+ /* 12 */ {0, {172,232,188,436}, POPUP, x_("")},
  /* 13 */ {0, {124,232,140,454}, CHECK, N_("Normalize Coordinates")},
  /* 14 */ {0, {76,248,92,454}, MESSAGE, N_("(time consuming)")}
 };
@@ -1172,33 +1195,33 @@ void io_cifoptionsdlog(void)
 {
 	INTBIG newstate[NUMIOSTATEBITWORDS];
 	REGISTER INTBIG *curstate, oldresolution, i, itemHit, nameschanged;
-	REGISTER char **layernames, *pt;
-	char *newlang[3];
+	REGISTER CHAR **layernames, *pt;
+	CHAR *newlang[3];
 	REGISTER VARIABLE *var, *cifvar;
-	static char *whattodisplay[] = {N_("No Resolution Check"),
+	static CHAR *whattodisplay[] = {N_("No Resolution Check"),
 		N_("Report Resolution Errors"), N_("Show Resolution Errors")};
 	REGISTER void *infstr, *dia;
 
 	dia = DiaInitDialog(&io_cifoptionsdialog);
 	if (dia == 0) return;
-	for(i=0; i<3; i++) newlang[i] = _(whattodisplay[i]);
+	for(i=0; i<3; i++) newlang[i] = TRANSLATE(whattodisplay[i]);
 	DiaSetPopup(dia, DCFO_ORESOLUTIONMODE, 3, newlang);
 	DiaInitTextDialog(dia, DCFO_LAYERLIST, DiaNullDlogList, DiaNullDlogItem,
 		DiaNullDlogDone, 0, SCSELMOUSE|SCREPORT);
-	layernames = (char **)emalloc(el_curtech->layercount * (sizeof (char *)),
+	layernames = (CHAR **)emalloc(el_curtech->layercount * (sizeof (CHAR *)),
 		el_tempcluster);
 	cifvar = getval((INTBIG)el_curtech, VTECHNOLOGY, VSTRING|VISARRAY,
-		"IO_cif_layer_names");
+		x_("IO_cif_layer_names"));
 	for(i=0; i<el_curtech->layercount; i++)
 	{
-		if (cifvar == NOVARIABLE || i >= getlength(cifvar)) pt = ""; else
-			pt = ((char **)cifvar->addr)[i];
+		if (cifvar == NOVARIABLE || i >= getlength(cifvar)) pt = x_(""); else
+			pt = ((CHAR **)cifvar->addr)[i];
 		(void)allocstring(&layernames[i], pt, el_tempcluster);
 		infstr = initinfstr();
 		addstringtoinfstr(infstr, layername(el_curtech, i));
-		addstringtoinfstr(infstr, " (");
+		addstringtoinfstr(infstr, x_(" ("));
 		addstringtoinfstr(infstr, pt);
-		addstringtoinfstr(infstr, ")");
+		addstringtoinfstr(infstr, x_(")"));
 		DiaStuffLine(dia, DCFO_LAYERLIST, returninfstr(infstr));
 	}
 	DiaSelectLine(dia, DCFO_LAYERLIST, 0);
@@ -1210,11 +1233,11 @@ void io_cifoptionsdlog(void)
 	if ((curstate[0]&CIFINSQUARE) != 0) DiaSetControl(dia, DCFO_ISQUAREWIRES, 1);
 	if ((curstate[0]&CIFOUTNOTOPCALL) == 0) DiaSetControl(dia, DCFO_OINSTANTIATETOP, 1);
 	if ((curstate[0]&CIFOUTNORMALIZE) != 0) DiaSetControl(dia, DCFO_ONORMALIZECOORD, 1);
-	var = getval((INTBIG)el_curtech, VTECHNOLOGY, VINTEGER, "IO_cif_resolution");
+	var = getval((INTBIG)el_curtech, VTECHNOLOGY, VINTEGER, x_("IO_cif_resolution"));
 	if (var == NOVARIABLE) oldresolution = 0; else oldresolution = var->addr;
 	if (oldresolution == 0)
 	{
-		DiaSetText(dia, DCFO_ORESOLUTION, "");
+		DiaSetText(dia, DCFO_ORESOLUTION, x_(""));
 		DiaSetPopupEntry(dia, DCFO_ORESOLUTIONMODE, 0);
 		DiaDimItem(dia, DCFO_ORESOLUTION_L);
 		DiaDimItem(dia, DCFO_ORESOLUTION);
@@ -1264,13 +1287,13 @@ void io_cifoptionsdlog(void)
 			{
 				DiaDimItem(dia, DCFO_ORESOLUTION_L);
 				DiaDimItem(dia, DCFO_ORESOLUTION);
-				DiaSetText(dia, DCFO_ORESOLUTION, "");
+				DiaSetText(dia, DCFO_ORESOLUTION, x_(""));
 			} else
 			{
 				DiaUnDimItem(dia, DCFO_ORESOLUTION_L);
 				DiaUnDimItem(dia, DCFO_ORESOLUTION);
 				if (atola(DiaGetText(dia, DCFO_ORESOLUTION), 0) == 0)
-					DiaSetText(dia, DCFO_ORESOLUTION, "1");
+					DiaSetText(dia, DCFO_ORESOLUTION, x_("1"));
 			}
 			continue;
 		}
@@ -1278,14 +1301,14 @@ void io_cifoptionsdlog(void)
 		{
 			i = DiaGetCurLine(dia, DCFO_LAYERLIST);
 			pt = DiaGetText(dia, DCFO_NEWLAYER);
-			if (strcmp(pt, layernames[i]) == 0) continue;
+			if (estrcmp(pt, layernames[i]) == 0) continue;
 			nameschanged++;
 			(void)reallocstring(&layernames[i], pt, el_tempcluster);
 			infstr = initinfstr();
 			addstringtoinfstr(infstr, layername(el_curtech, i));
-			addstringtoinfstr(infstr, " (");
+			addstringtoinfstr(infstr, x_(" ("));
 			addstringtoinfstr(infstr, layernames[i]);
-			addstringtoinfstr(infstr, ")");
+			addstringtoinfstr(infstr, x_(")"));
 			DiaSetScrollLine(dia, DCFO_LAYERLIST, i, returninfstr(infstr));
 			continue;
 		}
@@ -1308,14 +1331,14 @@ void io_cifoptionsdlog(void)
 		for(i=0; i<NUMIOSTATEBITWORDS; i++) if (curstate[i] != newstate[i]) break;
 		if (i < NUMIOSTATEBITWORDS) io_setstatebits(newstate);
 		if (nameschanged != 0)
-			setval((INTBIG)el_curtech, VTECHNOLOGY, "IO_cif_layer_names",
+			setval((INTBIG)el_curtech, VTECHNOLOGY, x_("IO_cif_layer_names"),
 				(INTBIG)layernames, VSTRING|VISARRAY|
 					(el_curtech->layercount<<VLENGTHSH));
 		i = atola(DiaGetText(dia, DCFO_ORESOLUTION), 0);
 		if (i != oldresolution)
-			setval((INTBIG)el_curtech, VTECHNOLOGY, "IO_cif_resolution", i, VINTEGER);
+			setval((INTBIG)el_curtech, VTECHNOLOGY, x_("IO_cif_resolution"), i, VINTEGER);
 	}
 	for(i=0; i<el_curtech->layercount; i++) efree(layernames[i]);
-	efree((char *)layernames);
+	efree((CHAR *)layernames);
 	DiaDoneDialog(dia);
 }
