@@ -47,13 +47,13 @@ static stentry *io_cifcurrent;		/* current symbol being defined */
 static INTBIG io_cifinstance;		/* inst count for default names */
 static INTBIG io_cifbinst;			/* inst count for default names */
 static INTBIG io_cifstatesince;		/* # statements since 91 com */
-static char   io_cifnamepending;	/* 91 pending */
-static char   io_cifnamed;			/* symbol has been named */
-static char  *io_cifnstored;		/* name saved from 91 */
+static CHAR   io_cifnamepending;	/* 91 pending */
+static CHAR   io_cifnamed;			/* symbol has been named */
+static CHAR  *io_cifnstored;		/* name saved from 91 */
 
-static char   io_cifdefinprog;		/* definition in progress flag */
+static CHAR   io_cifdefinprog;		/* definition in progress flag */
 static INTBIG io_cifignore;			/* ignore statements until DF */
-static char   io_cifendcom;			/* end command flag */
+static CHAR   io_cifendcom;			/* end command flag */
 
 static INTBIG io_cifcurlayer;		/* current layer */
 static INTBIG io_cifbackuplayer;	/* place to save layer during def */
@@ -66,7 +66,7 @@ typedef struct ite					/* items in item tree */
 	struct ite *it_rel;				/* links for tree */
 	struct ite *it_norel;			/* links for tree */
 	struct ite *it_same;			/* links for tree */
-	char       *it_what;			/* pointer into symbol structure */
+	CHAR       *it_what;			/* pointer into symbol structure */
 	INTBIG      it_level;			/* level of nest, from root (= 0) */
 	INTBIG      it_context;			/* what trans context to use */
 	INTBIG      it_left;			/* bb on chip */
@@ -82,27 +82,27 @@ static linkedpoint  *io_cifpfree;
 static linkedtentry *io_ciftfree = NIL;
 
 /* prototypes for local routines */
-static char io_endseen(void);
+static CHAR io_endseen(void);
 static void io_idefstart(INTBIG, INTBIG, INTBIG);
 static void io_idefend(void);
 static void io_ideletedef(INTBIG);
-static void io_ilayer(char*);
-static void io_icomment(char*);
-static void io_iusercommand(INTBIG, char*);
+static void io_ilayer(CHAR*);
+static void io_icomment(CHAR*);
+static void io_iusercommand(INTBIG, CHAR*);
 static void io_iend(void);
-static void io_iwire(INTBIG, char*);
-static void io_iwire(INTBIG, char*);
+static void io_iwire(INTBIG, CHAR*);
+static void io_iwire(INTBIG, CHAR*);
 static void io_iflash(INTBIG, point);
-static void io_ipolygon(char*);
-static void io_scalepath(char*, char*);
+static void io_ipolygon(CHAR*);
+static void io_scalepath(CHAR*, CHAR*);
 static void io_ibox(INTBIG, INTBIG, point, INTBIG, INTBIG);
-static void io_icall(INTBIG, char*);
-static void io_isymname(char*);
-static void io_iinstname(char*);
-static void io_igeoname(char*, point, INTBIG);
-static void io_ilabel(char*, point);
-static void io_makesymname(char*, INTBIG);
-static void io_makeinstname(char*, INTBIG);
+static void io_icall(INTBIG, CHAR*);
+static void io_isymname(CHAR*);
+static void io_iinstname(CHAR*);
+static void io_igeoname(CHAR*, point, INTBIG);
+static void io_ilabel(CHAR*, point);
+static CHAR *io_makesymname(INTBIG);
+static CHAR *io_makeinstname(INTBIG);
 static void io_newstentry(stentry*, INTBIG);
 static stentry *io_lookupsym(INTBIG);
 static void io_freesymbols(void);
@@ -115,7 +115,7 @@ static INTBIG io_maxx(void);
 static INTBIG io_maxy(void);
 static void io_findcallbb(symcall*);
 static void io_findbb(stentry*);
-static char io_initutil(void);
+static CHAR io_initutil(void);
 static void io_freestorage(void);
 static void io_freedef(objectptr);
 static void io_clear(transform);
@@ -130,12 +130,12 @@ static void io_applylocal(transform);
 static void io_assign(transform, transform);
 static void io_rotate(INTBIG, INTBIG);
 static void io_translate(INTBIG, INTBIG);
-static void io_mirror(char);
+static void io_mirror(CHAR);
 static void io_dumpstack(void);
 static void io_printmat(transform);
 static void io_bbpolygon(INTBIG, path, INTBIG*, INTBIG*, INTBIG*, INTBIG*);
 static void io_bbwire(INTBIG, INTBIG, path, INTBIG*, INTBIG*, INTBIG*, INTBIG*);
-static char io_inititems(void);
+static CHAR io_inititems(void);
 static BOOLEAN io_doneitems(void);
 static itementry *io_newnode(void);
 static void io_freenode(itementry*);
@@ -144,16 +144,16 @@ static void io_dumpdef(stentry*);
 static void io_shipcontents(stentry*);
 static void io_outitem(itementry*);
 static void io_item(objectptr);
-static char io_initinput(void);
-static char io_doneinput(void);
-static char io_getch(void);
-static char io_peek(void);
-static char io_endoffile(void);
-static INTBIG io_flush(char);
+static CHAR io_initinput(void);
+static CHAR io_doneinput(void);
+static CHAR io_getch(void);
+static CHAR io_peek(void);
+static CHAR io_endoffile(void);
+static INTBIG io_flush(CHAR);
 static void io_identify(void);
-static char io_inittypes(void);
+static CHAR io_inittypes(void);
 static void io_freeciftfree(void);
-static char io_donetypes(void);
+static CHAR io_donetypes(void);
 static linkedpoint *io_getpnode(void);
 static void io_freepnode(linkedpoint*);
 static void io_copypath(path, path);
@@ -162,26 +162,26 @@ static void io_dupetlist(tlist, tlist);
 static linkedtentry *io_gettnode(void);
 static void io_freetnode(linkedtentry*);
 static void io_appendtentry(tlist, tentry);
-static char io_initerror(void);
-static char io_doneerror(void);
-static void io_report(char*, INTBIG);
+static CHAR io_initerror(void);
+static CHAR io_doneerror(void);
+static void io_report(CHAR*, INTBIG);
 static void io_blank(void);
 static void io_sep(void);
-static char io_semi(void);
-static char io_sp(void);
-static char *io_utext(void);
-static char *io_name(void);
+static CHAR io_semi(void);
+static CHAR io_sp(void);
+static CHAR *io_utext(void);
+static CHAR *io_name(void);
 static INTBIG io_cardinal(void);
 static INTBIG io_signed(void);
 static void io_logit(INTBIG);
 static point io_getpoint(void);
 static void io_getpath(path);
-static char io_inittrans(void);
-static char io_donetrans(void);
+static CHAR io_inittrans(void);
+static CHAR io_donetrans(void);
 static tmatrix io_getlocal(void);
 static point io_transpoint(point);
-static void io_freeonedef(struct kludge *cur);
-static char *io_maketlist(void);
+static void io_freeonedef(struct cifhack *cur);
+static CHAR *io_maketlist(void);
 static INTBIG io_parsestatement(void);
 
 /*
@@ -215,7 +215,7 @@ INTBIG io_doneinterpreter(void)
 	return(io_donetrans() || io_doneitems());
 }
 
-char io_endseen(void)
+CHAR io_endseen(void)
 {
 	return(io_cifendcom);
 }
@@ -227,8 +227,8 @@ void io_idefstart(INTBIG symbol,INTBIG mtl,INTBIG div)
 	if (io_cifcurrent->st_defined)
 	{
 		/* redefining this symbol */
-		char mess[300];
-		(void)sprintf(mess, _("attempt to redefine symbol %lu (ignored)"), symbol);
+		CHAR mess[300];
+		(void)esnprintf(mess, 300, _("attempt to redefine symbol %lu (ignored)"), symbol);
 		io_report(mess, ADVISORY);
 		io_cifignore = 1;
 		return;
@@ -249,7 +249,7 @@ void io_idefstart(INTBIG symbol,INTBIG mtl,INTBIG div)
 
 void io_idefend(void)
 {
-	char s[50];
+	CHAR *s;
 
 	io_cifstatesince++;
 	if (io_cifignore)
@@ -262,7 +262,7 @@ void io_idefend(void)
 	io_cifinstance = io_cifbinst;
 	if (!io_cifnamed)
 	{
-		io_makesymname(s, io_cifcurrent->st_symnumber);
+		s = io_makesymname(io_cifcurrent->st_symnumber);
 		(void)allocstring(&io_cifcurrent->st_name, s, io_tool->cluster);
 	}
 	io_cifcurrent->st_defined = 1;
@@ -275,7 +275,7 @@ void io_ideletedef(INTBIG n)
 	io_report(_("DD not supported (ignored)"), ADVISORY);
 }
 
-void io_ilayer(char *lname)
+void io_ilayer(CHAR *lname)
 {
 
 	io_cifstatesince++;
@@ -283,11 +283,11 @@ void io_ilayer(char *lname)
 	io_cifcurlayer = io_findlayernum(lname);
 }
 
-void io_icomment(char *contents)
+void io_icomment(CHAR *contents)
 {
 }
 
-void io_iusercommand(INTBIG command, char *text)
+void io_iusercommand(INTBIG command, CHAR *text)
 {
 	io_cifstatesince++;
 	if (io_cifignore) return;
@@ -300,7 +300,7 @@ void io_iend(void)
 	io_cifendcom = 1;
 	if (io_cifnamepending)
 	{
-		efree((char *)io_cifnstored);
+		efree((CHAR *)io_cifnstored);
 		io_report(_("no instance to match name command"), ADVISORY);
 		io_cifnamepending = 0;
 	}
@@ -310,7 +310,7 @@ void io_iend(void)
 #if CONVERT
 /* convert wires to boxes and flashes */
 
-void io_iwire(INTBIG width, char *wpath)
+void io_iwire(INTBIG width, CHAR *wpath)
 {
 	INTBIG i, lim;
 	INTBIG lt, rt, bm, tp;
@@ -345,11 +345,11 @@ void io_iwire(INTBIG width, char *wpath)
 #else
 /* regular wires */
 
-void io_iwire(INTBIG width, char *a)
+void io_iwire(INTBIG width, CHAR *a)
 {
 	wire *obj;
 	INTBIG length = io_pathlength((path)a);
-	char *bbpath, *spath, *tpath;
+	CHAR *bbpath, *spath, *tpath;
 	INTBIG i;
 
 	io_cifstatesince++;
@@ -445,11 +445,11 @@ void io_iflash(INTBIG diameter,point center)
 	} else io_item((objectptr)obj);		/* stick into item list */
 }
 
-void io_ipolygon(char *a)
+void io_ipolygon(CHAR *a)
 {
 	polygon *obj;
 	INTBIG length = io_pathlength((path)a);
-	char *bbpath,*spath,*tpath;
+	CHAR *bbpath,*spath,*tpath;
 	INTBIG i;
 
 	io_cifstatesince++;
@@ -501,7 +501,7 @@ void io_ipolygon(char *a)
 	if (spath != NIL) io_freepath((path)spath);
 }
 
-static void io_scalepath(char *src, char *dest)
+static void io_scalepath(CHAR *src, CHAR *dest)
 {
 	INTBIG i, limit;
 
@@ -617,12 +617,12 @@ void io_ibox(INTBIG length, INTBIG width, point center, INTBIG xr, INTBIG yr)
 	}
 }
 
-void io_icall(INTBIG symbol, char *list)
+void io_icall(INTBIG symbol, CHAR *list)
 {
 	INTBIG i,j;
 	tentry temp;
 	symcall *obj;		/* we need a new object */
-	char *newtlist;
+	CHAR *newtlist;
 
 	if (io_cifignore) return;
 	j = io_tlistlength((tlist)list);
@@ -678,8 +678,8 @@ void io_icall(INTBIG symbol, char *list)
 		io_cifnamepending = 0;
 	} else
 	{
-		char s[50];
-		io_makeinstname(s, io_cifinstance);
+		CHAR *s;
+		s = io_makeinstname(io_cifinstance);
 		(void)allocstring(&obj->sy_name, s, io_tool->cluster);
 	}
 	if (io_cifdefinprog)
@@ -691,7 +691,7 @@ void io_icall(INTBIG symbol, char *list)
 	} else io_item((objectptr)obj);
 }
 
-void io_isymname(char *name)
+void io_isymname(CHAR *name)
 {
 	io_cifstatesince++;
 	if (io_cifignore) return;
@@ -714,7 +714,7 @@ void io_isymname(char *name)
 	(void)allocstring(&io_cifcurrent->st_name, name, io_tool->cluster);
 }
 
-void io_iinstname(char *name)
+void io_iinstname(CHAR *name)
 {
 	if (io_cifignore) return;
 	if (*name == '\0')
@@ -724,7 +724,7 @@ void io_iinstname(char *name)
 	}
 	if (io_cifnamepending)
 	{
-		efree((char *)io_cifnstored);
+		efree((CHAR *)io_cifnstored);
 		io_report(_("there is already a name pending, new name replaces it"), ADVISORY);
 	}
 	io_cifnamepending = 1;
@@ -732,7 +732,7 @@ void io_iinstname(char *name)
 	(void)allocstring(&io_cifnstored, name, io_tool->cluster);
 }
 
-void io_igeoname(char *name, point pt, INTBIG lay)
+void io_igeoname(CHAR *name, point pt, INTBIG lay)
 {
 	gname *obj;
 	point temp;
@@ -777,7 +777,7 @@ void io_igeoname(char *name, point pt, INTBIG lay)
 	} else io_item((objectptr)obj);		/* stick into item list */
 }
 
-void io_ilabel(char *name, point pt)
+void io_ilabel(CHAR *name, point pt)
 {
 	label *obj;
 	point temp;
@@ -823,14 +823,20 @@ void io_ilabel(char *name, point pt)
 
 /********************* util.c: storage manager begin *********************/
 
-void io_makesymname(char *s, INTBIG n)
+CHAR *io_makesymname(INTBIG n)
 {
-	(void)sprintf(s, "SYM%lu", n);
+	static CHAR s[50];
+
+	(void)esnprintf(s, 50, x_("SYM%lu"), n);
+	return(s);
 }
 
-void io_makeinstname(char *s, INTBIG n)
+CHAR *io_makeinstname(INTBIG n)
 {
-	(void)sprintf(s, "INST<%lu>", n);
+	static CHAR s[50];
+
+	(void)esnprintf(s, 50, x_("INST<%lu>"), n);
+	return(s);
 }
 
 /********************* symbol table begin *********************/
@@ -907,7 +913,7 @@ void io_freesymbols(void)
 			/* deallocate name string */
 			if (cur->st_name != NIL) efree(cur->st_name);
 			io_freedef(cur->st_guts);	/* deallocate contents */
-			efree((char *)cur);	/* deallocate this symbol table entry */
+			efree((CHAR *)cur);	/* deallocate this symbol table entry */
 		}
 	}
 }
@@ -976,15 +982,15 @@ void io_findcallbb(symcall *object)		/* find the bb for this particular call */
 
 	if (!thisst->st_defined)
 	{
-		char mess[50];
-		(void)sprintf(mess, _("call to undefined symbol %lu"), thisst->st_symnumber);
+		CHAR mess[50];
+		(void)esnprintf(mess, 50, _("call to undefined symbol %lu"), thisst->st_symnumber);
 		io_report(mess, FATALSEMANTIC);
 		return;
 	}
 	if (thisst->st_expanded)
 	{
-		char mess[50];
-		(void)sprintf(mess, _("recursive call on symbol %lu"), thisst->st_symnumber);
+		CHAR mess[50];
+		(void)esnprintf(mess, 50, _("recursive call on symbol %lu"), thisst->st_symnumber);
 		io_report(mess, FATALSEMANTIC);
 		return;
 	} else thisst->st_expanded = 1;		/* mark as under expansion */
@@ -1020,14 +1026,14 @@ void io_findcallbb(symcall *object)		/* find the bb for this particular call */
 static void io_findbb(stentry *sym)		/* find bb for sym */
 {
 	point temp;
-	char first = 1;
-	struct kludge *ob = (struct kludge *)sym->st_guts;
+	CHAR first = 1;
+	struct cifhack *ob = (struct cifhack *)sym->st_guts;
 
 	if (sym->st_bbvalid) return;			/* already done */
 	if (ob == NIL)			/* empty symbol */
 	{
-		char mess[100];
-		(void)sprintf(mess, _("symbol %lu has no geometry in it"),
+		CHAR mess[100];
+		(void)esnprintf(mess, 100, _("symbol %lu has no geometry in it"),
 			sym->st_symnumber);
 		io_report(mess, ADVISORY);
 		sym->st_bb.l = 0;   sym->st_bb.r = 0;
@@ -1053,7 +1059,7 @@ static void io_findbb(stentry *sym)		/* find bb for sym */
 	io_donemm();
 }
 
-char io_initutil(void)
+CHAR io_initutil(void)
 {
 	INTBIG i;
 
@@ -1071,16 +1077,16 @@ void io_freestorage(void)
 
 void io_freedef(objectptr head)
 {
-	struct kludge *cur, *temp;
+	struct cifhack *cur, *temp;
 
-	for(cur = (struct kludge *)head; cur != NIL; cur = temp)
+	for(cur = (struct cifhack *)head; cur != NIL; cur = temp)
 	{
 		temp = cur->kl_next;
 		io_freeonedef(cur);
 	}
 }
 
-void io_freeonedef(struct kludge *cur)
+void io_freeonedef(struct cifhack *cur)
 {
 	switch (cur->kl_type)
 	{
@@ -1089,21 +1095,21 @@ void io_freeonedef(struct kludge *cur)
 		case WIRE:
 		case MBOX:
 		case FLASH:
-			efree((char *)cur);
+			efree((CHAR *)cur);
 			break;
 		case CALL:
 			if (((symcall *)cur)->sy_tlist != 0)
 				io_freetlist((tlist) ((symcall *)cur)->sy_tlist);
 			efree(((symcall *)cur)->sy_name);
-			efree((char *)cur);
+			efree((CHAR *)cur);
 			break;
 		case NAME:
 			efree(((gname *)cur)->gn_name);
-			efree((char *)cur);
+			efree((CHAR *)cur);
 			break;
 		case LABEL:
 			efree(((label *)cur)->la_name);
-			efree((char *)cur);
+			efree((CHAR *)cur);
 			break;
 		default:
 			io_report(_("unknown def contents"), FATALSEMANTIC);
@@ -1122,7 +1128,7 @@ void io_freeonedef(struct kludge *cur)
 
 typedef struct nba
 {
-	char *sn_inst, *sn_sym;
+	CHAR *sn_inst, *sn_sym;
 	struct nba *sn_prev, *sn_next;
 } snode;
 
@@ -1139,7 +1145,7 @@ static INTBIG    io_cifclength;		/* length of context array */
 static INTBIG    io_cifcurcontext;	/* current context */
 static transform io_cifstacktop;	/* the top of stack */
 
-char io_inittrans(void)
+CHAR io_inittrans(void)
 {
 	INTBIG i;
 
@@ -1178,7 +1184,7 @@ char io_inittrans(void)
 	return(0);
 }
 
-char io_donetrans(void)
+CHAR io_donetrans(void)
 {
 	transform temp, old;
 
@@ -1186,15 +1192,15 @@ char io_donetrans(void)
 	for (temp = io_cifstacktop->prev; temp != NIL; temp = old)
 	{
 		old = temp->prev;
-		efree((char *)temp);
+		efree((CHAR *)temp);
 	}
 	for (temp = io_cifstacktop->next; temp != NIL; temp = old)
 	{
 		old = temp->next;
-		efree((char *)temp);
+		efree((CHAR *)temp);
 	}
-	efree((char *)io_cifstacktop);
-	efree((char *)io_cifcarray);
+	efree((CHAR *)io_cifstacktop);
+	efree((CHAR *)io_cifcarray);
 	return(0);
 }
 
@@ -1397,7 +1403,7 @@ void io_translate(INTBIG xtrans, INTBIG ytrans)
 	}
 }
 
-void io_mirror(char xcoord)
+void io_mirror(CHAR xcoord)
 {
 	if (xcoord)
 	{
@@ -1460,10 +1466,10 @@ void io_dumpstack(void)
 
 static void io_printmat(transform t)
 {
-	ttyputmsg("type: %ld, mult: %d", t->type, t->multiplied);
-	ttyputmsg("%f %f", t->a11, t->a12);
-	ttyputmsg("%f %f", t->a21, t->a22);
-	ttyputmsg("%f %f %f", t->a31, t->a32, t->a33);
+	ttyputmsg(x_("type: %ld, mult: %d"), t->type, t->multiplied);
+	ttyputmsg(x_("%f %f"), t->a11, t->a12);
+	ttyputmsg(x_("%f %f"), t->a21, t->a22);
+	ttyputmsg(x_("%f %f %f"), t->a31, t->a32, t->a33);
 }
 
 /************ bbs.c: bounding box finder for primitive geometry ************/
@@ -1546,7 +1552,7 @@ void io_bbwire(INTBIG lay, INTBIG width, path ppath, INTBIG *l, INTBIG *r,
 
 /********************* items.c: item tree stuff *********************/
 
-char io_inititems(void)
+CHAR io_inititems(void)
 {
 	io_cifittop = NIL;
 	io_cifilist = NIL;
@@ -1560,14 +1566,14 @@ BOOLEAN io_doneitems(void)
 	for (cur = io_cifittop; cur != NIL; cur = next)
 	{
 		next = cur->it_same;
-		io_freeonedef((struct kludge *)cur->it_what);
-		efree((char *)cur);
+		io_freeonedef((struct cifhack *)cur->it_what);
+		efree((CHAR *)cur);
 	}
 	for (cur = io_cifilist; cur != NIL; cur = next)
 	{
 		next = cur->it_same;
-		io_freeonedef((struct kludge *)cur->it_what);
-		efree((char *)cur);
+		io_freeonedef((struct cifhack *)cur->it_what);
+		efree((CHAR *)cur);
 	}
 	return(FALSE);
 }
@@ -1615,14 +1621,14 @@ static void io_sendlist(itementry *list)
 
 static void io_dumpdef(stentry *sym)
 {
-	struct kludge *ro;
+	struct cifhack *ro;
 
 	if (sym->st_dumped) return;		/* already done */
 	if (sym->st_ncalls > 0)			/* dump all children */
 	{
 		INTBIG count = sym->st_ncalls;
 
-		ro = (struct kludge *) sym->st_guts;
+		ro = (struct cifhack *) sym->st_guts;
 		while ((ro != NIL) && (count > 0))
 		{
 			if (ro->kl_type == CALL)
@@ -1639,16 +1645,16 @@ static void io_dumpdef(stentry *sym)
 
 static void io_shipcontents(stentry *sym)
 {
-	struct kludge *ro;
+	struct cifhack *ro;
 
-	ro = (struct kludge *) sym->st_guts;
+	ro = (struct cifhack *) sym->st_guts;
 	io_outputds(sym->st_symnumber, sym->st_name,
 		sym->st_bb.l, sym->st_bb.r, sym->st_bb.b, sym->st_bb.t);
 	while (ro != NIL)
 	{
 		switch (ro->kl_type)
 		{
-			char *ppath, *t_list;
+			CHAR *ppath, *t_list;
 			INTBIG length, i;
 			point temp;
 
@@ -1708,10 +1714,10 @@ static void io_shipcontents(stentry *sym)
 void io_iboundbox(INTBIG *l, INTBIG *r, INTBIG *b, INTBIG *t)
 {
 	itementry *h;
-	struct kludge *obj;
+	struct cifhack *obj;
 	point temp;
 	point comperror;	/* hack for compiler error */
-	char first;
+	CHAR first;
 
 	h = io_cifilist;
 	first = 1;
@@ -1726,7 +1732,7 @@ void io_iboundbox(INTBIG *l, INTBIG *r, INTBIG *b, INTBIG *t)
 	io_pushtrans();
 	while (h != NIL)
 	{
-		obj = (struct kludge *)h->it_what;
+		obj = (struct cifhack *)h->it_what;
 		temp.x = obj->kl_bb.l;
 		temp.y = obj->kl_bb.b;
 		comperror = io_transpoint(temp);
@@ -1775,7 +1781,7 @@ static void io_outitem(itementry *thing)		/* spit out an item */
 {
 	switch (thing->it_type)
 	{
-		char *ppath, *t_list;
+		CHAR *ppath, *t_list;
 		INTBIG length, i;
 		point temp;
 
@@ -1868,7 +1874,7 @@ static void io_outitem(itementry *thing)		/* spit out an item */
 
 void io_item(objectptr object)		/* a bare item has been found */
 {
-	struct kludge *obj;
+	struct cifhack *obj;
 	itementry *newitem;
 
 	if (object == NIL)
@@ -1876,7 +1882,7 @@ void io_item(objectptr object)		/* a bare item has been found */
 		io_report(_("item: null object"), FATALINTERNAL);
 		return;
 	}
-	obj = (struct kludge *)object;
+	obj = (struct cifhack *)object;
 
 	newitem = io_newnode();
 	newitem->it_type = obj->kl_type;
@@ -1962,13 +1968,13 @@ static INTBIG  io_ciffilelength;			/* file length */
 static INTBIG  io_cifcharsread;				/* characters read from file */
 static INTBIG  io_cifnextchar;				/* lookahead character */
 static INTBIG  io_ciflinecount;				/* line count */
-static char    io_ciflinebuffer[LINELEN];	/* identify line buffer */
-static char   *io_ciflineptr;				/* where we are in line buffer */
+static CHAR    io_ciflinebuffer[LINELEN];	/* identify line buffer */
+static CHAR   *io_ciflineptr;				/* where we are in line buffer */
 static INTBIG  io_cifcharcount;				/* number of chars in buffer */
-static char    io_cifresetbuffer;			/* flag to reset buffer */
+static CHAR    io_cifresetbuffer;			/* flag to reset buffer */
 static void   *io_cifprogressdialog;		/* for showing input progress */
 
-static char io_initinput(void)
+static CHAR io_initinput(void)
 {
 	io_ciflinecount = 1;
 	io_cifcharcount = 0;
@@ -1976,7 +1982,7 @@ static char io_initinput(void)
 	return(0);
 }
 
-static char io_doneinput(void)
+static CHAR io_doneinput(void)
 {
 	xclose(io_cifinfile);
 	if (io_verbose < 0 && io_ciffilelength > 0) DiaDoneProgress(io_cifprogressdialog);
@@ -2001,7 +2007,7 @@ BOOLEAN io_infromfile(FILE *file)
 	return(FALSE);
 }
 
-static char io_getch(void)
+static CHAR io_getch(void)
 {
 	REGISTER INTBIG c;
 
@@ -2019,7 +2025,7 @@ static char io_getch(void)
 		{
 			if (c != '\n')
 			{
-				io_cifcharcount++; *io_ciflineptr++ = (char)c; *io_ciflineptr = '\0';
+				io_cifcharcount++; *io_ciflineptr++ = (CHAR)c; *io_ciflineptr = '\0';
 			} else io_cifresetbuffer = 1;
 		}
 		io_cifnextchar = xgetc(io_cifinfile);
@@ -2027,20 +2033,20 @@ static char io_getch(void)
 		if (io_verbose < 0 && io_ciffilelength > 0 && (io_cifcharsread%2000) == 0)
 			DiaSetProgress(io_cifprogressdialog, io_cifcharsread, io_ciffilelength);
 	}
-	return((char)c);
+	return((CHAR)c);
 }
 
-static char io_peek(void)
+static CHAR io_peek(void)
 {
-	return((char)io_cifnextchar);
+	return((CHAR)io_cifnextchar);
 }
 
-char io_endoffile(void)
+CHAR io_endoffile(void)
 {
 	return(io_cifnextchar == EOF);
 }
 
-static INTBIG io_flush(char breakchar)
+static INTBIG io_flush(CHAR breakchar)
 {
 	REGISTER INTBIG c;
 
@@ -2050,11 +2056,11 @@ static INTBIG io_flush(char breakchar)
 
 static void io_identify(void)
 {
-	char temp[200];
+	CHAR temp[200];
 
 	if (io_cifcharcount > 0)
 	{
-		(void)sprintf(temp, "line %ld: %s", io_ciflinecount-io_cifresetbuffer, io_ciflinebuffer);
+		(void)esnprintf(temp, 200, x_("line %ld: %s"), io_ciflinecount-io_cifresetbuffer, io_ciflinebuffer);
 		ttyputmsg(temp);
 	}
 }
@@ -2069,25 +2075,25 @@ static void io_freeciftfree(void)
 	{
 		ct = io_ciftfree;
 		io_ciftfree = io_ciftfree->tnext;
-		efree((char *)ct);
+		efree((CHAR *)ct);
 	}
 }
 
-static char io_inittypes(void)
+static CHAR io_inittypes(void)
 {
 	io_cifpfree = NIL;
 	io_freeciftfree();
 	return(0);
 }
 
-static char io_donetypes(void)
+static CHAR io_donetypes(void)
 {
 	while (io_cifpfree != NIL)
 	{
 		linkedpoint *temp;
 
 		temp = io_cifpfree->pnext;
-		efree((char *)io_cifpfree);
+		efree((CHAR *)io_cifpfree);
 		io_cifpfree = temp;
 	}
 	while (io_ciftfree != NIL)
@@ -2095,13 +2101,13 @@ static char io_donetypes(void)
 		linkedtentry *temp;
 
 		temp = io_ciftfree->tnext;
-		efree((char *)io_ciftfree);
+		efree((CHAR *)io_ciftfree);
 		io_ciftfree = temp;
 	}
 	return(0);
 }
 
-char *io_makepath(void)
+CHAR *io_makepath(void)
 {
 	path a;
 
@@ -2114,7 +2120,7 @@ char *io_makepath(void)
 	a->pfirst = NIL;
 	a->plast = NIL;
 	a->plength = 0;
-	return((char *)a);
+	return((CHAR *)a);
 }
 
 void io_freepath(path a)
@@ -2129,7 +2135,7 @@ void io_freepath(path a)
 		io_freepnode(node);
 		node = saved;
 	}
-	efree((char *)a);		/* should change to avoid overhead */
+	efree((CHAR *)a);		/* should change to avoid overhead */
 }
 
 static linkedpoint *io_getpnode(void)
@@ -2205,7 +2211,7 @@ INTBIG io_pathlength(path a)
 	return(a->plength);
 }
 
-char *io_maketlist(void)
+CHAR *io_maketlist(void)
 {
 	tlist a;
 
@@ -2218,7 +2224,7 @@ char *io_maketlist(void)
 	a->tfirst = NIL;
 	a->tlast = NIL;
 	a->tlength = 0;
-	return((char *) a);
+	return((CHAR *) a);
 }
 
 void io_freetlist(tlist a)
@@ -2233,7 +2239,7 @@ void io_freetlist(tlist a)
 		io_freetnode(node);
 		node = saved;
 	}
-	efree((char *)a);		/* should change to avoid overhead */
+	efree((CHAR *)a);		/* should change to avoid overhead */
 }
 
 void io_dupetlist(tlist src, tlist dest)
@@ -2317,7 +2323,7 @@ INTBIG io_tlistlength(tlist a)
 
 static INTBIG io_cifecounts[OTHER+1];
 
-static char io_initerror(void)
+static CHAR io_initerror(void)
 {
 	INTBIG i;
 
@@ -2325,7 +2331,7 @@ static char io_initerror(void)
 	return(0);
 }
 
-static char io_doneerror(void)
+static CHAR io_doneerror(void)
 {
 	return(0);
 }
@@ -2336,7 +2342,7 @@ INTBIG io_fatalerrors(void)
 		io_cifecounts[FATALSEMANTIC]+io_cifecounts[FATALOUTPUT]);
 }
 
-void io_report(char *mess, INTBIG kind)
+void io_report(CHAR *mess, INTBIG kind)
 {
 	io_identify();
 	io_cifecounts[kind]++;
@@ -2348,7 +2354,7 @@ void io_report(char *mess, INTBIG kind)
 		case FATALSEMANTIC: ttyputmsg(_("Error: %s"), mess);                 break;
 		case FATALOUTPUT:   ttyputmsg(_("Output error: %s"), mess);          break;
 		case ADVISORY:      ttyputmsg(_("Warning: %s"), mess);               break;
-		default:            ttyputmsg("%s", mess);                        break;
+		default:            ttyputmsg(x_("%s"), mess);                        break;
 	}
 
 	if (kind == FATALINTERNAL) longjmp(io_filerror, 1);
@@ -2387,9 +2393,9 @@ void io_report(char *mess, INTBIG kind)
 #define NOSPACE 118
 #define NONAME 119
 
-static char   io_ciferrorfound;			/* flag for error encountered */
+static CHAR   io_ciferrorfound;			/* flag for error encountered */
 static INTBIG io_ciferrortype;			/* what it was */
-static char   io_cifendisseen;			/* end command flag */
+static CHAR   io_cifendisseen;			/* end command flag */
 
 INTBIG io_initparser(void)
 {
@@ -2408,7 +2414,7 @@ INTBIG io_doneparser(void)
 
 static void io_blank(void)
 {
-	REGISTER char c;
+	REGISTER CHAR c;
 
 	for(;;)
 	{
@@ -2429,7 +2435,7 @@ static void io_blank(void)
 
 static void io_sep(void)
 {
-	REGISTER char c;
+	REGISTER CHAR c;
 
 	for(;;)
 	{
@@ -2448,18 +2454,18 @@ static void io_sep(void)
 	}
 }
 
-static char io_semi(void)
+static CHAR io_semi(void)
 {
-	char ans = 0;
+	CHAR ans = 0;
 
 	io_blank();
 	if (io_peek() == ';') {(void) io_getch(); ans = 1; io_blank();}
 	return(ans);
 }
 
-static char io_sp(void)
+static CHAR io_sp(void)
 {
-	char ans = 0; char c;
+	CHAR ans = 0; CHAR c;
 
 	while ((c = io_peek()) == ' ' || c == '\t')
 	{
@@ -2469,16 +2475,16 @@ static char io_sp(void)
 	return(ans);
 }
 
-static char *io_utext(void)
+static CHAR *io_utext(void)
 {
-	char *user, *olduser;
+	CHAR *user, *olduser;
 	INTBIG maxsize = 80;
 	INTBIG size = 0;
 
-	if ((user = (char *)emalloc(maxsize, io_tool->cluster)) == NIL)
+	if ((user = (CHAR *)emalloc(maxsize * SIZEOFCHAR, io_tool->cluster)) == NIL)
 	{
 		io_report(_("free storage exhausted"), FATALINTERNAL);
-		return((char *)0);
+		return((CHAR *)0);
 	}
 	*user = '\0';
 	while (!io_endoffile() && io_peek() != ';')
@@ -2489,7 +2495,7 @@ static char *io_utext(void)
 			INTBIG i;
 			maxsize += 80;
 			olduser = user;
-			user = (char *)emalloc(maxsize, io_tool->cluster);
+			user = (CHAR *)emalloc(maxsize * SIZEOFCHAR, io_tool->cluster);
 			if (user == NIL)
 				io_report(_("free storage exhausted"), FATALINTERNAL);
 			for(i=0; i<maxsize-80; i++) user[i] = olduser[i];
@@ -2500,17 +2506,17 @@ static char *io_utext(void)
 	return(user);
 }
 
-static char *io_name(void)
+static CHAR *io_name(void)
 {
-	char *ntext, *oldntext;
+	CHAR *ntext, *oldntext;
 	INTBIG maxsize = 80;
 	INTBIG size = 0;
-	char c; char nochar = 1;
+	CHAR c; CHAR nochar = 1;
 
-	if ((ntext = (char *)emalloc(maxsize, io_tool->cluster)) == NIL)
+	if ((ntext = (CHAR *)emalloc(maxsize * SIZEOFCHAR, io_tool->cluster)) == NIL)
 	{
 		io_report(_("free storage exhausted"), FATALINTERNAL);
-		return((char *) 0);
+		return((CHAR *) 0);
 	}
 	*ntext = '\0';
 	while (!io_endoffile() && (c = io_peek()) != ';' &&
@@ -2526,7 +2532,7 @@ static char *io_name(void)
 			INTBIG i;
 			maxsize += 80;
 			oldntext = ntext;
-			if ((ntext = (char *)emalloc(maxsize, io_tool->cluster)) == NIL)
+			if ((ntext = (CHAR *)emalloc(maxsize * SIZEOFCHAR, io_tool->cluster)) == NIL)
 				io_report(_("free storage exhausted"), FATALINTERNAL);
 			for(i=0; i<maxsize-80; i++) ntext[i] = oldntext[i];
 			efree(oldntext);
@@ -2539,7 +2545,7 @@ static char *io_name(void)
 
 static INTBIG io_cardinal(void)
 {
-	char somedigit = 0;
+	CHAR somedigit = 0;
 	REGISTER INTBIG ans = 0;
 	INTBIG c;
 
@@ -2566,10 +2572,10 @@ static INTBIG io_cardinal(void)
 
 static INTBIG io_signed(void)
 {
-	char somedigit = 0;
-	char sign = 0;
+	CHAR somedigit = 0;
+	CHAR sign = 0;
 	REGISTER INTBIG ans = 0;
-	char c;
+	CHAR c;
 
 	io_sep();
 
@@ -2607,7 +2613,7 @@ static point io_getpoint(void)
 
 static void io_getpath(path a)
 {
-	char c;
+	CHAR c;
 	point temp;
 
 	io_sep();
@@ -2623,19 +2629,19 @@ static void io_getpath(path a)
 
 INTBIG io_parsestatement(void)
 {
-	char curchar;
+	CHAR curchar;
 	INTBIG command = NULLCOMMAND;
-	char *curpath = NIL;
-	char *curtlist = NIL;
+	CHAR *curpath = NIL;
+	CHAR *curtlist = NIL;
 	INTBIG xrotate, yrotate;
 	point center;
 	INTBIG length, width;
 	INTBIG diameter;
-	char lname[5], *oldcomment;
+	CHAR lname[5], *oldcomment;
 	INTBIG symbolnumber, multiplier, divisor;
-	char *comment = NIL;
-	char *usertext = NIL;
-	char *nametext = NIL;
+	CHAR *comment = NIL;
+	CHAR *usertext = NIL;
+	CHAR *nametext = NIL;
 	INTBIG usercommand;
 	point namepoint;
 
@@ -2794,7 +2800,7 @@ INTBIG io_parsestatement(void)
 				INTBIG size = 0;
 
 				command = COMMENT;
-				if ((comment = (char *)emalloc(maxsize, io_tool->cluster)) == NIL)
+				if ((comment = (CHAR *)emalloc(maxsize * SIZEOFCHAR, io_tool->cluster)) == NIL)
 				{
 					io_report(_("free storage exhausted"), FATALINTERNAL);
 					break;
@@ -2824,7 +2830,7 @@ INTBIG io_parsestatement(void)
 
 						maxsize += 80;
 						oldcomment = comment;
-						comment = (char *)emalloc(maxsize, io_tool->cluster);
+						comment = (CHAR *)emalloc(maxsize * SIZEOFCHAR, io_tool->cluster);
 						if (comment == NIL)
 						{
 							io_report(_("free storage exhausted"), FATALINTERNAL);
@@ -2986,9 +2992,9 @@ INTBIG io_parsestatement(void)
 alldone:		/* everyone exits here */
 	if (curpath != NIL) io_freepath((path)curpath);
 	if (curtlist != NIL) io_freetlist((tlist)curtlist);
-	if (comment != NIL) efree((char *) comment);
-	if (usertext != NIL) efree((char *) usertext);
-	if (nametext != NIL) efree((char *) nametext);
+	if (comment != NIL) efree((CHAR *) comment);
+	if (usertext != NIL) efree((CHAR *) usertext);
+	if (nametext != NIL) efree((CHAR *) nametext);
 	return(command);
 
 recover:		/* errors come here */
