@@ -51,20 +51,21 @@
 #define MAXLINE 2500
 
 static COMCOMP iodefop = {NOKEYWORD,NOTOPLIST,NONEXTLIST,NOPARAMS,
-	INPUTOPT, " \t", M_("DEF options"), 0};
+	INPUTOPT, x_(" \t"), M_("DEF options"), 0};
 
 static INTBIG  io_deffilesize;
 static INTBIG  io_deflineno;
-static char    io_defline[MAXLINE];
-static char    io_deffilename[300];
+static CHAR    io_defline[MAXLINE];
+static CHAR    io_deffilename[300];
 static INTBIG  io_deflinepos;
 static INTBIG  io_defunits;
 static VIADEF *io_deffirstviadef;
 static void   *io_defprogressdialog;
 
 /* prototypes for local routines */
-static char      *io_defgetkeyword(FILE *f);
-static BOOLEAN    io_defignoretosemicolon(FILE *f, char *command);
+static CHAR      *io_defgetkeyword(FILE *f);
+static BOOLEAN    io_defignoreblock(FILE *f, CHAR *command);
+static BOOLEAN    io_defignoretosemicolon(FILE *f, CHAR *command);
 static BOOLEAN    io_defreadfile(FILE *f, LIBRARY *lib);
 static BOOLEAN    io_defreadpropertydefinitions(FILE *f);
 static BOOLEAN    io_defreadnets(FILE *f, NODEPROTO *facet, BOOLEAN special, INTBIG options);
@@ -73,15 +74,15 @@ static BOOLEAN    io_defreadcomponents(FILE *f, NODEPROTO *facet);
 static BOOLEAN    io_defreadvias(FILE *f, NODEPROTO *facet);
 static BOOLEAN    io_defreadcomponent(FILE *f, NODEPROTO *facet);
 static BOOLEAN    io_defreadcoordinate(FILE *f, INTBIG *x, INTBIG *y);
-static NODEPROTO *io_defgetnodeproto(char *name, LIBRARY *curlib);
+static NODEPROTO *io_defgetnodeproto(CHAR *name, LIBRARY *curlib);
 static BOOLEAN    io_defreadpin(FILE *f, NODEPROTO *facet);
 static BOOLEAN    io_defreadorientation(FILE *f, INTSML *rot, INTSML *trans);
-static void       io_defgetlayernodes(char *name, NODEPROTO **pin, NODEPROTO **pure, ARCPROTO **arc);
+static void       io_defgetlayernodes(CHAR *name, NODEPROTO **pin, NODEPROTO **pure, ARCPROTO **arc);
 static BOOLEAN    io_defreadunits(FILE *f);
-static char      *io_defmustgetkeyword(FILE *f, char *where);
+static CHAR      *io_defmustgetkeyword(FILE *f, CHAR *where);
 static BOOLEAN    io_defreadvia(FILE *f);
 static BOOLEAN    io_defreadnet(FILE *f, NODEPROTO *facet, BOOLEAN special, INTBIG options);
-static void       io_definerror(char *command, ...);
+static void       io_definerror(CHAR *command, ...);
 static BOOLEAN    io_defgetpin(INTBIG x, INTBIG y, ARCPROTO *ap, NODEPROTO *facet,
 					NODEINST **theni, PORTPROTO **thepp);
 static void       io_defoptionsdlog(void);
@@ -100,23 +101,23 @@ void io_freedefimemory(void)
  */
 void io_initdef(void)
 {
-	DiaDeclareHook("defopt", &iodefop, io_defoptionsdlog);
+	DiaDeclareHook(x_("defopt"), &iodefop, io_defoptionsdlog);
 }
 
 BOOLEAN io_readdeflibrary(LIBRARY *lib)
 {
 	FILE *fp;
 	REGISTER BOOLEAN ret;
-	char *filename;
+	CHAR *filename;
 
 	/* open the file */
-	fp = xopen(lib->libfile, io_filetypedef, "", &filename);
+	fp = xopen(lib->libfile, io_filetypedef, x_(""), &filename);
 	if (fp == NULL)
 	{
 		ttyputerr(_("File %s not found"), lib->libfile);
 		return(TRUE);
 	}
-	strcpy(io_deffilename, filename);
+	estrcpy(io_deffilename, filename);
 
 	/* prepare for input */
 	io_deffilesize = filesize(fp);
@@ -149,9 +150,9 @@ BOOLEAN io_readdeflibrary(LIBRARY *lib)
  */
 BOOLEAN io_defreadfile(FILE *f, LIBRARY *lib)
 {
-	REGISTER char *key, *cellname;
+	REGISTER CHAR *key, *cellname;
 	REGISTER INTBIG *options;
-	char curkey[200];
+	CHAR curkey[200];
 	REGISTER NODEPROTO *facet;
 
 	options = io_getstatebits();
@@ -161,19 +162,24 @@ BOOLEAN io_defreadfile(FILE *f, LIBRARY *lib)
 		/* get the next keyword */
 		key = io_defgetkeyword(f);
 		if (key == 0) break;
-		if (namesame(key, "VERSION") == 0 || namesame(key, "NAMESCASESENSITIVE") == 0 ||
-			namesame(key, "DIVIDERCHAR") == 0 || namesame(key, "BUSBITCHARS") == 0 ||
-			namesame(key, "DIEAREA") == 0 || namesame(key, "ROW") == 0 ||
-			namesame(key, "TRACKS") == 0 || namesame(key, "GCELLGRID") == 0 ||
-			namesame(key, "HISTORY") == 0)
+		if (namesame(key, x_("VERSION")) == 0 || namesame(key, x_("NAMESCASESENSITIVE")) == 0 ||
+			namesame(key, x_("DIVIDERCHAR")) == 0 || namesame(key, x_("BUSBITCHARS")) == 0 ||
+			namesame(key, x_("DIEAREA")) == 0 || namesame(key, x_("ROW")) == 0 ||
+			namesame(key, x_("TRACKS")) == 0 || namesame(key, x_("GCELLGRID")) == 0 ||
+			namesame(key, x_("HISTORY")) == 0 || namesame(key, x_("TECHNOLOGY")) == 0)
 		{
-			strcpy(curkey, key);
+			estrcpy(curkey, key);
 			if (io_defignoretosemicolon(f, curkey)) return(TRUE);
 			continue;
 		}
-		if (namesame(key, "DESIGN") == 0)
+		if (namesame(key, x_("DEFAULTCAP")) == 0 || namesame(key, x_("REGIONS")) == 0)
 		{
-			cellname = io_defmustgetkeyword(f, "DESIGN");
+			if (io_defignoreblock(f, key)) return(TRUE);
+			continue;
+		}
+		if (namesame(key, x_("DESIGN")) == 0)
+		{
+			cellname = io_defmustgetkeyword(f, x_("DESIGN"));
 			if (cellname == 0) return(TRUE);
 			facet = us_newnodeproto(cellname, lib);
 			if (facet == NONODEPROTO)
@@ -185,49 +191,49 @@ BOOLEAN io_defreadfile(FILE *f, LIBRARY *lib)
 			continue;
 		}
 
-		if (namesame(key, "UNITS") == 0)
+		if (namesame(key, x_("UNITS")) == 0)
 		{
 			if (io_defreadunits(f)) return(TRUE);
 			continue;
 		}
 
-		if (namesame(key, "PROPERTYDEFINITIONS") == 0)
+		if (namesame(key, x_("PROPERTYDEFINITIONS")) == 0)
 		{
 			if (io_defreadpropertydefinitions(f)) return(TRUE);
 			continue;
 		}
 
-		if (namesame(key, "VIAS") == 0)
+		if (namesame(key, x_("VIAS")) == 0)
 		{
 			if (io_defreadvias(f, facet)) return(TRUE);
 			continue;
 		}
 
-		if (namesame(key, "COMPONENTS") == 0)
+		if (namesame(key, x_("COMPONENTS")) == 0)
 		{
 			if (io_defreadcomponents(f, facet)) return(TRUE);
 			continue;
 		}
 
-		if (namesame(key, "PINS") == 0)
+		if (namesame(key, x_("PINS")) == 0)
 		{
 			if (io_defreadpins(f, facet)) return(TRUE);
 			continue;
 		}
 
-		if (namesame(key, "SPECIALNETS") == 0)
+		if (namesame(key, x_("SPECIALNETS")) == 0)
 		{
 			if (io_defreadnets(f, facet, TRUE, options[0])) return(TRUE);
 			continue;
 		}
 
-		if (namesame(key, "NETS") == 0)
+		if (namesame(key, x_("NETS")) == 0)
 		{
 			if (io_defreadnets(f, facet, FALSE, options[0])) return(TRUE);
 			continue;
 		}
 
-		if (namesame(key, "END") == 0)
+		if (namesame(key, x_("END")) == 0)
 		{
 			key = io_defgetkeyword(f);
 			break;
@@ -240,29 +246,29 @@ BOOLEAN io_defreadfile(FILE *f, LIBRARY *lib)
 
 BOOLEAN io_defreadvias(FILE *f, NODEPROTO *facet)
 {
-	REGISTER char *key;
-	char curkey[200];
+	REGISTER CHAR *key;
+	CHAR curkey[200];
 
 	if (io_defignoretosemicolon(f, _("VIAS"))) return(TRUE);
 	for(;;)
 	{
 		/* get the next keyword */
-		key = io_defmustgetkeyword(f, "VIAs");
+		key = io_defmustgetkeyword(f, x_("VIAs"));
 		if (key == 0) return(TRUE);
-		if (namesame(key, "-") == 0)
+		if (namesame(key, x_("-")) == 0)
 		{
 			if (io_defreadvia(f)) return(TRUE);
 			continue;
 		}
 
-		if (namesame(key, "END") == 0)
+		if (namesame(key, x_("END")) == 0)
 		{
 			key = io_defgetkeyword(f);
 			break;
 		}
 
 		/* ignore the keyword */
-		strcpy(curkey, key);
+		estrcpy(curkey, key);
 		if (io_defignoretosemicolon(f, curkey)) return(TRUE);
 	}
 	return(FALSE);
@@ -270,14 +276,14 @@ BOOLEAN io_defreadvias(FILE *f, NODEPROTO *facet)
 
 BOOLEAN io_defreadvia(FILE *f)
 {
-	REGISTER char *key;
+	REGISTER CHAR *key;
 	INTBIG lx, hx, ly, hy;
 	NODEPROTO *pin, *pure;
 	ARCPROTO *ap;
 	REGISTER VIADEF *vd;
 
 	/* get the via name */
-	key = io_defmustgetkeyword(f, "VIA");
+	key = io_defmustgetkeyword(f, x_("VIA"));
 	if (key == 0) return(TRUE);
 
 	/* create a new via definition */
@@ -293,16 +299,16 @@ BOOLEAN io_defreadvia(FILE *f)
 	for(;;)
 	{
 		/* get the next keyword */
-		key = io_defmustgetkeyword(f, "VIA");
+		key = io_defmustgetkeyword(f, x_("VIA"));
 		if (key == 0) return(TRUE);
-		if (namesame(key, "+") == 0)
+		if (namesame(key, x_("+")) == 0)
 		{
-			key = io_defmustgetkeyword(f, "VIA");
+			key = io_defmustgetkeyword(f, x_("VIA"));
 			if (key == 0) return(TRUE);
-			if (namesame(key, "RECT") == 0)
+			if (namesame(key, x_("RECT")) == 0)
 			{
 				/* handle definition of a via rectangle */
-				key = io_defmustgetkeyword(f, "VIA");
+				key = io_defmustgetkeyword(f, x_("VIA"));
 				if (key == 0) return(TRUE);
 				io_defgetlayernodes(key, &pin, &pure, &ap);
 				if (pure == NONODEPROTO)
@@ -310,12 +316,12 @@ BOOLEAN io_defreadvia(FILE *f)
 					io_definerror(_("Layer %s not in current technology"), key);
 					pure = NONODEPROTO;
 				}
-				if (namesamen(key, "VIA", 3) == 0)
+				if (namesamen(key, x_("VIA"), 3) == 0)
 				{
 					if (pin == NONODEPROTO) pin = gen_univpinprim;
 					vd->via = pin;
 				}
-				if (namesamen(key, "METAL", 5) == 0)
+				if (namesamen(key, x_("METAL"), 5) == 0)
 				{
 					if (ap == NOARCPROTO) ap = gen_universalarc;
 					if (vd->lay1 == NOARCPROTO) vd->lay1 = ap; else
@@ -332,7 +338,7 @@ BOOLEAN io_defreadvia(FILE *f)
 			continue;
 		}
 
-		if (namesame(key, ";") == 0)
+		if (namesame(key, x_(";")) == 0)
 			break;
 	}
 	if (vd->via != NONODEPROTO)
@@ -347,29 +353,29 @@ BOOLEAN io_defreadvia(FILE *f)
 
 BOOLEAN io_defreadcomponents(FILE *f, NODEPROTO *facet)
 {
-	REGISTER char *key;
-	char curkey[200];
+	REGISTER CHAR *key;
+	CHAR curkey[200];
 
 	if (io_defignoretosemicolon(f, _("COMPONENTS"))) return(1);
 	for(;;)
 	{
 		/* get the next keyword */
-		key = io_defmustgetkeyword(f, "COMPONENTs");
+		key = io_defmustgetkeyword(f, x_("COMPONENTs"));
 		if (key == 0) return(TRUE);
-		if (namesame(key, "-") == 0)
+		if (namesame(key, x_("-")) == 0)
 		{
 			if (io_defreadcomponent(f, facet)) return(TRUE);
 			continue;
 		}
 
-		if (namesame(key, "END") == 0)
+		if (namesame(key, x_("END")) == 0)
 		{
 			key = io_defgetkeyword(f);
 			break;
 		}
 
 		/* ignore the keyword */
-		strcpy(curkey, key);
+		estrcpy(curkey, key);
 		if (io_defignoretosemicolon(f, curkey)) return(TRUE);
 	}
 	return(FALSE);
@@ -377,7 +383,7 @@ BOOLEAN io_defreadcomponents(FILE *f, NODEPROTO *facet)
 
 BOOLEAN io_defreadcomponent(FILE *f, NODEPROTO *facet)
 {
-	REGISTER char *key;
+	REGISTER CHAR *key;
 	INTBIG x, y, cx, cy;
 	INTBIG sx, sy;
 	REGISTER INTBIG lx, hx, ly, hy;
@@ -385,15 +391,15 @@ BOOLEAN io_defreadcomponent(FILE *f, NODEPROTO *facet)
 	REGISTER NODEPROTO *np;
 	REGISTER VARIABLE *var;
 	INTSML rot, trans;
-	char compname[200], modelname[200];
+	CHAR compname[200], modelname[200];
 
 	/* get the component name and model name */
-	key = io_defmustgetkeyword(f, "COMPONENT");
+	key = io_defmustgetkeyword(f, x_("COMPONENT"));
 	if (key == 0) return(TRUE);
-	strcpy(compname, key);
-	key = io_defmustgetkeyword(f, "COMPONENT");
+	estrcpy(compname, key);
+	key = io_defmustgetkeyword(f, x_("COMPONENT"));
 	if (key == 0) return(TRUE);
-	strcpy(modelname, key);
+	estrcpy(modelname, key);
 
 	/* find the named facet */
 	np = io_defgetnodeproto(modelname, facet->cell->lib);
@@ -406,13 +412,13 @@ BOOLEAN io_defreadcomponent(FILE *f, NODEPROTO *facet)
 	for(;;)
 	{
 		/* get the next keyword */
-		key = io_defmustgetkeyword(f, "COMPONENT");
+		key = io_defmustgetkeyword(f, x_("COMPONENT"));
 		if (key == 0) return(TRUE);
-		if (namesame(key, "+") == 0)
+		if (namesame(key, x_("+")) == 0)
 		{
-			key = io_defmustgetkeyword(f, "COMPONENT");
+			key = io_defmustgetkeyword(f, x_("COMPONENT"));
 			if (key == 0) return(TRUE);
-			if (namesame(key, "PLACED") == 0)
+			if (namesame(key, x_("PLACED")) == 0 || namesame(key, x_("FIXED")) == 0)
 			{
 				/* handle placement */
 				if (io_defreadcoordinate(f, &x, &y)) return(TRUE);
@@ -439,7 +445,7 @@ BOOLEAN io_defreadcomponent(FILE *f, NODEPROTO *facet)
 			continue;
 		}
 
-		if (namesame(key, ";") == 0)
+		if (namesame(key, x_(";")) == 0)
 			break;
 	}
 	return(FALSE);
@@ -449,29 +455,29 @@ BOOLEAN io_defreadcomponent(FILE *f, NODEPROTO *facet)
 
 BOOLEAN io_defreadpins(FILE *f, NODEPROTO *facet)
 {
-	REGISTER char *key;
-	char curkey[200];
+	REGISTER CHAR *key;
+	CHAR curkey[200];
 
 	if (io_defignoretosemicolon(f, _("PINS"))) return(TRUE);
 	for(;;)
 	{
 		/* get the next keyword */
-		key = io_defmustgetkeyword(f, "PINs");
+		key = io_defmustgetkeyword(f, x_("PINs"));
 		if (key == 0) return(TRUE);
-		if (namesame(key, "-") == 0)
+		if (namesame(key, x_("-")) == 0)
 		{
 			if (io_defreadpin(f, facet)) return(TRUE);
 			continue;
 		}
 
-		if (namesame(key, "END") == 0)
+		if (namesame(key, x_("END")) == 0)
 		{
 			key = io_defgetkeyword(f);
 			break;
 		}
 
 		/* ignore the keyword */
-		strcpy(curkey, key);
+		estrcpy(curkey, key);
 		if (io_defignoretosemicolon(f, curkey)) return(TRUE);
 	}
 	return(FALSE);
@@ -479,7 +485,7 @@ BOOLEAN io_defreadpins(FILE *f, NODEPROTO *facet)
 
 BOOLEAN io_defreadpin(FILE *f, NODEPROTO *facet)
 {
-	REGISTER char *key;
+	REGISTER CHAR *key;
 	INTBIG lx, hx, ly, hy, x, y;
 	REGISTER INTBIG portbits, i, havecoord;
 	REGISTER NODEINST *ni;
@@ -487,64 +493,64 @@ BOOLEAN io_defreadpin(FILE *f, NODEPROTO *facet)
 	ARCPROTO *ap;
 	REGISTER PORTPROTO *pp;
 	INTSML rot, trn;
-	char pinname[200];
+	CHAR pinname[200];
 	XARRAY trans;
 
 	/* get the pin name */
-	key = io_defmustgetkeyword(f, "PIN");
+	key = io_defmustgetkeyword(f, x_("PIN"));
 	if (key == 0) return(TRUE);
-	strcpy(pinname, key);
+	estrcpy(pinname, key);
 	portbits = havecoord = 0;
 	np = NONODEPROTO;
 
 	for(;;)
 	{
 		/* get the next keyword */
-		key = io_defmustgetkeyword(f, "PIN");
+		key = io_defmustgetkeyword(f, x_("PIN"));
 		if (key == 0) return(TRUE);
-		if (namesame(key, "+") == 0)
+		if (namesame(key, x_("+")) == 0)
 		{
-			key = io_defmustgetkeyword(f, "PIN");
+			key = io_defmustgetkeyword(f, x_("PIN"));
 			if (key == 0) return(TRUE);
-			if (namesame(key, "NET") == 0)
+			if (namesame(key, x_("NET")) == 0)
 			{
 				key = io_defmustgetkeyword(f, _("net name"));
 				if (key == 0) return(TRUE);
 				continue;
 			}
-			if (namesame(key, "DIRECTION") == 0)
+			if (namesame(key, x_("DIRECTION")) == 0)
 			{
-				key = io_defmustgetkeyword(f, "DIRECTION");
+				key = io_defmustgetkeyword(f, x_("DIRECTION"));
 				if (key == 0) return(TRUE);
-				if (namesame(key, "INPUT") == 0) portbits = INPORT; else
-				if (namesame(key, "OUTPUT") == 0) portbits = OUTPORT; else
-				if (namesame(key, "INOUT") == 0) portbits = BIDIRPORT; else
-				if (namesame(key, "FEEDTHRU") == 0) portbits = BIDIRPORT; else
+				if (namesame(key, x_("INPUT")) == 0) portbits = INPORT; else
+				if (namesame(key, x_("OUTPUT")) == 0) portbits = OUTPORT; else
+				if (namesame(key, x_("INOUT")) == 0) portbits = BIDIRPORT; else
+				if (namesame(key, x_("FEEDTHRU")) == 0) portbits = BIDIRPORT; else
 				{
 					io_definerror(_("Unknown direction (%s)"), key);
 					return(TRUE);
 				}
 				continue;
 			}
-			if (namesame(key, "USE") == 0)
+			if (namesame(key, x_("USE")) == 0)
 			{
-				key = io_defmustgetkeyword(f, "USE");
+				key = io_defmustgetkeyword(f, x_("USE"));
 				if (key == 0) return(TRUE);
-				if (namesame(key, "SIGNAL") == 0) portbits = portbits; else
-				if (namesame(key, "POWER") == 0) portbits = PWRPORT; else
-				if (namesame(key, "GROUND") == 0) portbits = GNDPORT; else
-				if (namesame(key, "CLOCK") == 0) portbits = CLKPORT; else
-				if (namesame(key, "TIEOFF") == 0) portbits = portbits; else
-				if (namesame(key, "ANALOG") == 0) portbits = portbits; else
+				if (namesame(key, x_("SIGNAL")) == 0) portbits = portbits; else
+				if (namesame(key, x_("POWER")) == 0) portbits = PWRPORT; else
+				if (namesame(key, x_("GROUND")) == 0) portbits = GNDPORT; else
+				if (namesame(key, x_("CLOCK")) == 0) portbits = CLKPORT; else
+				if (namesame(key, x_("TIEOFF")) == 0) portbits = portbits; else
+				if (namesame(key, x_("ANALOG")) == 0) portbits = portbits; else
 				{
 					io_definerror(_("Unknown usage (%s)"), key);
 					return(TRUE);
 				}
 				continue;
 			}
-			if (namesame(key, "LAYER") == 0)
+			if (namesame(key, x_("LAYER")) == 0)
 			{
-				key = io_defmustgetkeyword(f, "LAYER");
+				key = io_defmustgetkeyword(f, x_("LAYER"));
 				if (key == 0) return(TRUE);
 				io_defgetlayernodes(key, &np, &pure, &ap);
 				if (np == NONODEPROTO)
@@ -556,7 +562,7 @@ BOOLEAN io_defreadpin(FILE *f, NODEPROTO *facet)
 				if (io_defreadcoordinate(f, &hx, &hy)) return(TRUE);
 				continue;
 			}
-			if (namesame(key, "PLACED") == 0)
+			if (namesame(key, x_("PLACED")) == 0)
 			{
 				/* get pin location and orientation */
 				if (io_defreadcoordinate(f, &x, &y)) return(TRUE);
@@ -567,7 +573,7 @@ BOOLEAN io_defreadpin(FILE *f, NODEPROTO *facet)
 			continue;
 		}
 
-		if (namesame(key, ";") == 0)
+		if (namesame(key, x_(";")) == 0)
 			break;
 	}
 
@@ -607,27 +613,27 @@ BOOLEAN io_defreadpin(FILE *f, NODEPROTO *facet)
 
 BOOLEAN io_defreadnets(FILE *f, NODEPROTO *facet, BOOLEAN special, INTBIG options)
 {
-	REGISTER char *key;
-	char curkey[200];
+	REGISTER CHAR *key;
+	CHAR curkey[200];
 
 	for(;;)
 	{
 		/* get the next keyword */
-		key = io_defmustgetkeyword(f, "NETs");
+		key = io_defmustgetkeyword(f, x_("NETs"));
 		if (key == 0) return(TRUE);
-		if (namesame(key, "-") == 0)
+		if (namesame(key, x_("-")) == 0)
 		{
 			if (io_defreadnet(f, facet, special, options)) return(TRUE);
 			continue;
 		}
-		if (namesame(key, "END") == 0)
+		if (namesame(key, x_("END")) == 0)
 		{
 			key = io_defgetkeyword(f);
 			break;
 		}
 
 		/* ignore the keyword */
-		strcpy(curkey, key);
+		estrcpy(curkey, key);
 		if (io_defignoretosemicolon(f, curkey)) return(TRUE);
 	}
 	return(FALSE);
@@ -635,13 +641,14 @@ BOOLEAN io_defreadnets(FILE *f, NODEPROTO *facet, BOOLEAN special, INTBIG option
 
 BOOLEAN io_defreadnet(FILE *f, NODEPROTO *facet, BOOLEAN special, INTBIG options)
 {
-	REGISTER char *key;
+	REGISTER CHAR *key;
 	INTBIG lx, hx, ly, hy, plx, ply, phx, phy, sx, sy, fx, fy, tx, ty;
 	REGISTER INTBIG i, curx, cury, lastx, lasty, pathstart, placedvia, width,
 		wantpinpairs, specialwidth, bits;
 	NODEINST *ni, *lastni, *nextni;
 	REGISTER NODEINST *lastlogni;
 	REGISTER ARCINST *ai;
+	REGISTER BOOLEAN foundcoord;
 	PORTPROTO *pp, *lastpp, *nextpp;
 	REGISTER PORTPROTO *lastlogpp;
 	REGISTER NODEPROTO *np;
@@ -649,16 +656,16 @@ BOOLEAN io_defreadnet(FILE *f, NODEPROTO *facet, BOOLEAN special, INTBIG options
 	ARCPROTO *routap;
 	REGISTER VARIABLE *var;
 	float v;
-	char netname[200];
+	CHAR netname[200];
 	REGISTER VIADEF *vd;
 
 	/* get the net name */
-	key = io_defmustgetkeyword(f, "NET");
+	key = io_defmustgetkeyword(f, x_("NET"));
 	if (key == 0) return(TRUE);
-	strcpy(netname, key);
+	estrcpy(netname, key);
 
 	/* get the next keyword */
-	key = io_defmustgetkeyword(f, "NET");
+	key = io_defmustgetkeyword(f, x_("NET"));
 	if (key == 0) return(TRUE);
 
 	/* scan the "net" statement */
@@ -669,23 +676,23 @@ BOOLEAN io_defreadnet(FILE *f, NODEPROTO *facet, BOOLEAN special, INTBIG options
 	for(;;)
 	{
 		/* examine the next keyword */
-		if (namesame(key, ";") == 0) break;
+		if (namesame(key, x_(";")) == 0) break;
 
-		if (namesame(key, "+") == 0)
+		if (namesame(key, x_("+")) == 0)
 		{
 			wantpinpairs = 0;
-			key = io_defmustgetkeyword(f, "NET");
+			key = io_defmustgetkeyword(f, x_("NET"));
 			if (key == 0) return(TRUE);
 
-			if (namesame(key, "USE") == 0)
+			if (namesame(key, x_("USE")) == 0)
 			{
 				/* ignore "USE" keyword */
-				key = io_defmustgetkeyword(f, "NET");
+				key = io_defmustgetkeyword(f, x_("NET"));
 				if (key == 0) return(TRUE);
-			} else if (namesame(key, "ROUTED") == 0)
+			} else if (namesame(key, x_("ROUTED")) == 0)
 			{
 				/* handle "ROUTED" keyword */
-				key = io_defmustgetkeyword(f, "NET");
+				key = io_defmustgetkeyword(f, x_("NET"));
 				if (key == 0) return(TRUE);
 				io_defgetlayernodes(key, &pin, &pure, &routap);
 				if (pin == NONODEPROTO)
@@ -697,15 +704,15 @@ BOOLEAN io_defreadnet(FILE *f, NODEPROTO *facet, BOOLEAN special, INTBIG options
 				if (special)
 				{
 					/* specialnets have width here */
-					key = io_defmustgetkeyword(f, "NET");
+					key = io_defmustgetkeyword(f, x_("NET"));
 					if (key == 0) return(TRUE);
-					v = (float)atof(key) / (float)io_defunits;
+					v = (float)eatof(key) / (float)io_defunits;
 					specialwidth = scalefromdispunit(v, DISPUNITMIC);
 				}
-			} else if (namesame(key, "FIXED") == 0)
+			} else if (namesame(key, x_("FIXED")) == 0)
 			{
 				/* handle "FIXED" keyword */
-				key = io_defmustgetkeyword(f, "NET");
+				key = io_defmustgetkeyword(f, x_("NET"));
 				if (key == 0) return(TRUE);
 				io_defgetlayernodes(key, &pin, &pure, &routap);
 				if (pin == NONODEPROTO)
@@ -714,6 +721,11 @@ BOOLEAN io_defreadnet(FILE *f, NODEPROTO *facet, BOOLEAN special, INTBIG options
 					return(TRUE);
 				}
 				pathstart = 1;
+			} else if (namesame(key, x_("SHAPE")) == 0)
+			{
+				/* handle "SHAPE" keyword */
+				key = io_defmustgetkeyword(f, x_("NET"));
+				if (key == 0) return(TRUE);
 			} else
 			{
 				io_definerror(_("Cannot handle '%s' nets"), key);
@@ -721,7 +733,7 @@ BOOLEAN io_defreadnet(FILE *f, NODEPROTO *facet, BOOLEAN special, INTBIG options
 			}
 
 			/* get next keyword */
-			key = io_defmustgetkeyword(f, "NET");
+			key = io_defmustgetkeyword(f, x_("NET"));
 			if (key == 0) return(TRUE);
 			continue;
 		}
@@ -730,25 +742,26 @@ BOOLEAN io_defreadnet(FILE *f, NODEPROTO *facet, BOOLEAN special, INTBIG options
 		if (wantpinpairs != 0)
 		{
 			/* it must be the "(" of a pin pair */
-			if (namesame(key, "(") != 0)
+			if (namesame(key, x_("(")) != 0)
 			{
 				io_definerror(_("Expected '(' of pin pair"));
 				return(TRUE);
 			}
 
 			/* get the pin names */
-			key = io_defmustgetkeyword(f, "NET");
+			key = io_defmustgetkeyword(f, x_("NET"));
 			if (key == 0) return(TRUE);
-			if (namesame(key, "PIN") == 0)
+			if (namesame(key, x_("PIN")) == 0)
 			{
 				/* find the export */
-				key = io_defmustgetkeyword(f, "NET");
+				key = io_defmustgetkeyword(f, x_("NET"));
 				if (key == 0) return(TRUE);
 				pp = getportproto(facet, key);
 				if (pp == NOPORTPROTO)
 				{
-					io_definerror(_("Unknown pin '%s'"), key);
-					return(TRUE);
+					io_definerror(_("Warning: unknown pin '%s'"), key);
+					if (io_defignoretosemicolon(f, _("NETS"))) return(TRUE);
+					return(FALSE);
 				}
 				ni = pp->subnodeinst;
 				pp = pp->subportproto;
@@ -758,7 +771,7 @@ BOOLEAN io_defreadnet(FILE *f, NODEPROTO *facet, BOOLEAN special, INTBIG options
 				{
 					var = getvalkey((INTBIG)ni, VNODEINST, VSTRING, el_node_name_key);
 					if (var == NOVARIABLE) continue;
-					if (namesame((char *)var->addr, key) == 0) break;
+					if (namesame((CHAR *)var->addr, key) == 0) break;
 				}
 				if (ni == NONODEINST)
 				{
@@ -767,21 +780,21 @@ BOOLEAN io_defreadnet(FILE *f, NODEPROTO *facet, BOOLEAN special, INTBIG options
 				}
 
 				/* get the port name */
-				key = io_defmustgetkeyword(f, "NET");
+				key = io_defmustgetkeyword(f, x_("NET"));
 				if (key == 0) return(TRUE);
 				pp = getportproto(ni->proto, key);
 				if (pp == NOPORTPROTO)
 				{
 					io_definerror(_("Unknown port '%s' on component '%s'"),
-						key, (char *)var->addr);
+						key, (CHAR *)var->addr);
 					return(TRUE);
 				}
 			}
 
 			/* get the close parentheses */
-			key = io_defmustgetkeyword(f, "NET");
+			key = io_defmustgetkeyword(f, x_("NET"));
 			if (key == 0) return(TRUE);
-			if (namesame(key, ")") != 0)
+			if (namesame(key, x_(")")) != 0)
 			{
 				io_definerror(_("Expected ')' of pin pair"));
 				return(TRUE);
@@ -807,15 +820,15 @@ BOOLEAN io_defreadnet(FILE *f, NODEPROTO *facet, BOOLEAN special, INTBIG options
 			lastlogpp = pp;
 
 			/* get the next keyword and continue parsing */
-			key = io_defmustgetkeyword(f, "NET");
+			key = io_defmustgetkeyword(f, x_("NET"));
 			if (key == 0) return(TRUE);
 			continue;
 		}
 
 		/* handle "new" start of coordinate trace */
-		if (namesame(key, "NEW") == 0)
+		if (namesame(key, x_("NEW")) == 0)
 		{
-			key = io_defmustgetkeyword(f, "NET");
+			key = io_defmustgetkeyword(f, x_("NET"));
 			if (key == 0) return(TRUE);
 			io_defgetlayernodes(key, &pin, &pure, &routap);
 			if (pin == NONODEPROTO)
@@ -824,56 +837,55 @@ BOOLEAN io_defreadnet(FILE *f, NODEPROTO *facet, BOOLEAN special, INTBIG options
 				return(TRUE);
 			}
 			pathstart = 1;
-			key = io_defmustgetkeyword(f, "NET");
+			key = io_defmustgetkeyword(f, x_("NET"));
 			if (key == 0) return(TRUE);
 			if (special)
 			{
 				/* specialnets have width here */
-				v = (float)atof(key) / (float)io_defunits;
+				v = (float)eatof(key) / (float)io_defunits;
 				specialwidth = scalefromdispunit(v, DISPUNITMIC);
 
 				/* get the next keyword */
-				key = io_defmustgetkeyword(f, "NET");
+				key = io_defmustgetkeyword(f, x_("NET"));
 				if (key == 0) return(TRUE);
 			}
 			continue;
 		}
 
-		if (namesame(key, "(") != 0)
+		foundcoord = FALSE;
+		if (namesame(key, x_("(")) == 0)
 		{
-			io_definerror(_("Expected '(' of coordinate pair"));
-			return(TRUE);
-		}
+			/* get the X coordinate */
+			foundcoord = TRUE;
+			key = io_defmustgetkeyword(f, x_("NET"));
+			if (key == 0) return(TRUE);
+			if (estrcmp(key, x_("*")) == 0) curx = lastx; else
+			{
+				v = (float)eatof(key) / (float)io_defunits;
+				curx = scalefromdispunit(v, DISPUNITMIC);
+			}
 
-		/* get the X coordinate */
-		key = io_defmustgetkeyword(f, "NET");
-		if (key == 0) return(TRUE);
-		if (strcmp(key, "*") == 0) curx = lastx; else
-		{
-			v = (float)atof(key) / (float)io_defunits;
-			curx = scalefromdispunit(v, DISPUNITMIC);
-		}
+			/* get the Y coordinate */
+			key = io_defmustgetkeyword(f, x_("NET"));
+			if (key == 0) return(TRUE);
+			if (estrcmp(key, x_("*")) == 0) cury = lasty; else
+			{
+				v = (float)eatof(key) / (float)io_defunits;
+				cury = scalefromdispunit(v, DISPUNITMIC);
+			}
 
-		/* get the Y coordinate */
-		key = io_defmustgetkeyword(f, "NET");
-		if (key == 0) return(TRUE);
-		if (strcmp(key, "*") == 0) cury = lasty; else
-		{
-			v = (float)atof(key) / (float)io_defunits;
-			cury = scalefromdispunit(v, DISPUNITMIC);
-		}
-
-		/* get the close parentheses */
-		key = io_defmustgetkeyword(f, "NET");
-		if (key == 0) return(TRUE);
-		if (namesame(key, ")") != 0)
-		{
-			io_definerror(_("Expected ')' of coordinate pair"));
-			return(TRUE);
+			/* get the close parentheses */
+			key = io_defmustgetkeyword(f, x_("NET"));
+			if (key == 0) return(TRUE);
+			if (namesame(key, x_(")")) != 0)
+			{
+				io_definerror(_("Expected ')' of coordinate pair"));
+				return(TRUE);
+			}
 		}
 
 		/* get the next keyword */
-		key = io_defmustgetkeyword(f, "NET");
+		key = io_defmustgetkeyword(f, x_("NET"));
 		if (key == 0) return(TRUE);
 
 		/* see if it is a via name */
@@ -892,7 +904,7 @@ BOOLEAN io_defreadnet(FILE *f, NODEPROTO *facet, BOOLEAN special, INTBIG options
 			/* ignore the next keyword if a via name is coming */
 			if (vd != NOVIADEF)
 			{
-				key = io_defmustgetkeyword(f, "NET");
+				key = io_defmustgetkeyword(f, x_("NET"));
 				if (key == 0) return(TRUE);
 			}
 			continue;
@@ -920,7 +932,7 @@ BOOLEAN io_defreadnet(FILE *f, NODEPROTO *facet, BOOLEAN special, INTBIG options
 			}
 
 			/* create the via */
-			nodeprotosizeoffset(vd->via, &plx, &ply, &phx, &phy);
+			nodeprotosizeoffset(vd->via, &plx, &ply, &phx, &phy, facet);
 			ni = newnodeinst(vd->via, lx-plx, hx+phx, ly-ply, hy+phy, 0, 0, facet);
 			if (ni == NONODEINST)
 			{
@@ -931,11 +943,11 @@ BOOLEAN io_defreadnet(FILE *f, NODEPROTO *facet, BOOLEAN special, INTBIG options
 			pp = ni->proto->firstportproto;
 
 			/* if the path starts with a via, wire it */
-			if (pathstart != 0 && lastni != NONODEINST)
+			if (pathstart != 0 && lastni != NONODEINST && foundcoord)
 			{
 				if (special) width = specialwidth; else
 				{
-					var = getval((INTBIG)routap, VARCPROTO, VINTEGER, "IO_lef_width");
+					var = getval((INTBIG)routap, VARCPROTO, VINTEGER, x_("IO_lef_width"));
 					if (var == NOVARIABLE) width = defaultarcwidth(routap); else
 						width = var->addr;
 				}
@@ -953,7 +965,7 @@ BOOLEAN io_defreadnet(FILE *f, NODEPROTO *facet, BOOLEAN special, INTBIG options
 			placedvia = 1;
 
 			/* get the next keyword */
-			key = io_defmustgetkeyword(f, "NET");
+			key = io_defmustgetkeyword(f, x_("NET"));
 			if (key == 0) return(TRUE);
 		} else
 		{
@@ -961,6 +973,7 @@ BOOLEAN io_defreadnet(FILE *f, NODEPROTO *facet, BOOLEAN special, INTBIG options
 			if (io_defgetpin(curx, cury, routap, facet, &ni, &pp)) return(TRUE);
 			placedvia = 0;
 		}
+		if (!foundcoord) continue;
 
 		/* run the wire */
 		if (pathstart == 0)
@@ -987,7 +1000,7 @@ BOOLEAN io_defreadnet(FILE *f, NODEPROTO *facet, BOOLEAN special, INTBIG options
 			/* run the wire */
 			if (special) width = specialwidth; else
 			{
-				var = getval((INTBIG)routap, VARCPROTO, VINTEGER, "IO_lef_width");
+				var = getval((INTBIG)routap, VARCPROTO, VINTEGER, x_("IO_lef_width"));
 				if (var == NOVARIABLE) width = defaultarcwidth(routap); else
 					width = var->addr;
 			}
@@ -1019,7 +1032,7 @@ BOOLEAN io_defreadnet(FILE *f, NODEPROTO *facet, BOOLEAN special, INTBIG options
 		}
 
 		/* if the path ends here, connect it */
-		if (namesame(key, "NEW") == 0 || namesame(key, ";") == 0)
+		if (namesame(key, x_("NEW")) == 0 || namesame(key, x_(";")) == 0)
 		{
 			/* see if there is a connection point here when starting a path */
 			if (!io_deffindconnection(curx, cury, routap, facet, ni, &nextni, &nextpp))
@@ -1030,7 +1043,7 @@ BOOLEAN io_defreadnet(FILE *f, NODEPROTO *facet, BOOLEAN special, INTBIG options
 			{
 				if (special) width = specialwidth; else
 				{
-					var = getval((INTBIG)routap, VARCPROTO, VINTEGER, "IO_lef_width");
+					var = getval((INTBIG)routap, VARCPROTO, VINTEGER, x_("IO_lef_width"));
 					if (var == NOVARIABLE) width = defaultarcwidth(routap); else
 						width = var->addr;
 				}
@@ -1128,30 +1141,30 @@ BOOLEAN io_defgetpin(INTBIG x, INTBIG y, ARCPROTO *ap, NODEPROTO *facet,
 
 BOOLEAN io_defreadunits(FILE *f)
 {
-	REGISTER char *key;
+	REGISTER CHAR *key;
 
 	/* get the "DISTANCE" keyword */
-	key = io_defmustgetkeyword(f, "UNITS");
+	key = io_defmustgetkeyword(f, x_("UNITS"));
 	if (key == 0) return(TRUE);
-	if (namesame(key, "DISTANCE") != 0)
+	if (namesame(key, x_("DISTANCE")) != 0)
 	{
 		io_definerror(_("Expected 'DISTANCE' after 'UNITS'"));
 		return(TRUE);
 	}
 
 	/* get the "MICRONS" keyword */
-	key = io_defmustgetkeyword(f, "UNITS");
+	key = io_defmustgetkeyword(f, x_("UNITS"));
 	if (key == 0) return(TRUE);
-	if (namesame(key, "MICRONS") != 0)
+	if (namesame(key, x_("MICRONS")) != 0)
 	{
 		io_definerror(_("Expected 'MICRONS' after 'UNITS'"));
 		return(TRUE);
 	}
 
 	/* get the amount */
-	key = io_defmustgetkeyword(f, "UNITS");
+	key = io_defmustgetkeyword(f, x_("UNITS"));
 	if (key == 0) return(TRUE);
-	io_defunits = atoi(key);
+	io_defunits = eatoi(key);
 
 	/* ignore the keyword */
 	if (io_defignoretosemicolon(f, _("UNITS"))) return(TRUE);
@@ -1162,22 +1175,22 @@ BOOLEAN io_defreadunits(FILE *f)
 
 BOOLEAN io_defreadpropertydefinitions(FILE *f)
 {
-	REGISTER char *key;
-	char curkey[200];
+	REGISTER CHAR *key;
+	CHAR curkey[200];
 
 	for(;;)
 	{
 		/* get the next keyword */
-		key = io_defmustgetkeyword(f, "PROPERTYDEFINITION");
+		key = io_defmustgetkeyword(f, x_("PROPERTYDEFINITION"));
 		if (key == 0) return(TRUE);
-		if (namesame(key, "END") == 0)
+		if (namesame(key, x_("END")) == 0)
 		{
 			key = io_defgetkeyword(f);
 			break;
 		}
 
 		/* ignore the keyword */
-		strcpy(curkey, key);
+		estrcpy(curkey, key);
 		if (io_defignoretosemicolon(f, curkey)) return(TRUE);
 	}
 	return(FALSE);
@@ -1185,7 +1198,7 @@ BOOLEAN io_defreadpropertydefinitions(FILE *f)
 
 /*************** DATABASE SUPPORT ***************/
 
-NODEPROTO *io_defgetnodeproto(char *name, LIBRARY *curlib)
+NODEPROTO *io_defgetnodeproto(CHAR *name, LIBRARY *curlib)
 {
 	REGISTER NODEPROTO *np, *newnp;
 	REGISTER LIBRARY *lib;
@@ -1204,7 +1217,7 @@ NODEPROTO *io_defgetnodeproto(char *name, LIBRARY *curlib)
 		{
 			/* must copy the facet */
 			newnp = us_copyrecursively(np, np->cell->cellname, curlib, np->cellview,
-				FALSE, FALSE, "", FALSE, FALSE);
+				FALSE, FALSE, x_(""), FALSE, FALSE, FALSE);
 			return(newnp);
 		}
 	}
@@ -1212,7 +1225,7 @@ NODEPROTO *io_defgetnodeproto(char *name, LIBRARY *curlib)
 }
 
 /* returns nonzero on error */
-void io_defgetlayernodes(char *name, NODEPROTO **pin, NODEPROTO **pure, ARCPROTO **arc)
+void io_defgetlayernodes(CHAR *name, NODEPROTO **pin, NODEPROTO **pure, ARCPROTO **arc)
 {
 	REGISTER INTBIG laynum, i, j, lfunc;
 	REGISTER INTBIG afunc, afunc1, afunc2, ap1found, ap2found, vialayer;
@@ -1230,11 +1243,25 @@ void io_defgetlayernodes(char *name, NODEPROTO **pin, NODEPROTO **pure, ARCPROTO
 	*arc = NOARCPROTO;
 
 	/* handle via layers */
-	if (namesamen(name, "VIA", 3) == 0)
+	j = 0;
+	if (namesamen(name, x_("VIA"), 3) == 0) j = 3; else
+		if (namesamen(name, x_("V"), 1) == 0) j = 1;
+	if (j != 0)
 	{
 		/* find the two layer functions */
-		afunc1 = name[3] - '1' + APMETAL1;
-		afunc2 = name[4] - '1' + APMETAL1;
+		if (name[j] == 0)
+		{
+			afunc1 = APMETAL1;
+			afunc2 = APMETAL2;
+		} else if (name[j+1] == 0)
+		{
+			afunc1 = name[j] - '1' + APMETAL1;
+			afunc2 = afunc1 + 1;
+		} else
+		{
+			afunc1 = name[j] - '1' + APMETAL1;
+			afunc2 = name[j+1] - '1' + APMETAL1;
+		}
 
 		/* find the arcprotos that embody these layers */
 		for(ap1 = el_curtech->firstarcproto; ap1 != NOARCPROTO; ap1 = ap1->nextarcproto)
@@ -1288,9 +1315,13 @@ void io_defgetlayernodes(char *name, NODEPROTO **pin, NODEPROTO **pure, ARCPROTO
 	}
 
 	/* handle metal layers */
-	if (namesamen(name, "METAL", 5) == 0)
+	j = 0;
+	if (namesamen(name, x_("METAL"), 5) == 0) j = 5; else
+		if (namesamen(name, x_("MET"), 3) == 0) j = 3; else
+			if (namesamen(name, x_("M"), 1) == 0) j = 1;
+	if (j != 0)
 	{
-		laynum = atoi(&name[5]);
+		laynum = eatoi(&name[j]);
 		afunc = APUNKNOWN;
 		lfunc = LFUNKNOWN;
 		switch (laynum)
@@ -1330,13 +1361,13 @@ void io_defgetlayernodes(char *name, NODEPROTO **pin, NODEPROTO **pure, ARCPROTO
 
 BOOLEAN io_defreadcoordinate(FILE *f, INTBIG *x, INTBIG *y)
 {
-	char *key;
+	CHAR *key;
 	float v;
 
 	/* get "(" */
 	key = io_defmustgetkeyword(f, _("coordinate"));
 	if (key == 0) return(TRUE);
-	if (strcmp(key, "(") != 0)
+	if (estrcmp(key, x_("(")) != 0)
 	{
 		io_definerror(_("Expected '(' in coordinate"));
 		return(TRUE);
@@ -1345,19 +1376,19 @@ BOOLEAN io_defreadcoordinate(FILE *f, INTBIG *x, INTBIG *y)
 	/* get X */
 	key = io_defmustgetkeyword(f, _("coordinate"));
 	if (key == 0) return(TRUE);
-	v = (float)atof(key) / (float)io_defunits;
+	v = (float)eatof(key) / (float)io_defunits;
 	*x = scalefromdispunit(v, DISPUNITMIC);
 
 	/* get Y */
 	key = io_defmustgetkeyword(f, _("coordinate"));
 	if (key == 0) return(TRUE);
-	v = (float)atof(key) / (float)io_defunits;
+	v = (float)eatof(key) / (float)io_defunits;
 	*y = scalefromdispunit(v, DISPUNITMIC);
 
 	/* get ")" */
 	key = io_defmustgetkeyword(f, _("coordinate"));
 	if (key == 0) return(TRUE);
-	if (strcmp(key, ")") != 0)
+	if (estrcmp(key, x_(")")) != 0)
 	{
 		io_definerror(_("Expected ')' in coordinate"));
 		return(TRUE);
@@ -1367,18 +1398,18 @@ BOOLEAN io_defreadcoordinate(FILE *f, INTBIG *x, INTBIG *y)
 
 BOOLEAN io_defreadorientation(FILE *f, INTSML *rot, INTSML *trans)
 {
-	REGISTER char *key;
+	REGISTER CHAR *key;
 
 	key = io_defmustgetkeyword(f, _("orientation"));
 	if (key == 0) return(TRUE);
-	if (namesame(key, "N")  == 0) { *rot = 0;    *trans = 0; } else
-	if (namesame(key, "S")  == 0) { *rot = 1800; *trans = 0; } else
-	if (namesame(key, "E")  == 0) { *rot = 2700; *trans = 0; } else
-	if (namesame(key, "W")  == 0) { *rot = 900;  *trans = 0; } else
-	if (namesame(key, "FN") == 0) { *rot = 900;  *trans = 1; } else
-	if (namesame(key, "FS") == 0) { *rot = 2700; *trans = 1; } else
-	if (namesame(key, "FE") == 0) { *rot = 1800; *trans = 1; } else
-	if (namesame(key, "FW") == 0) { *rot = 0;    *trans = 1; } else
+	if (namesame(key, x_("N"))  == 0) { *rot = 0;    *trans = 0; } else
+	if (namesame(key, x_("S"))  == 0) { *rot = 1800; *trans = 0; } else
+	if (namesame(key, x_("E"))  == 0) { *rot = 2700; *trans = 0; } else
+	if (namesame(key, x_("W"))  == 0) { *rot = 900;  *trans = 0; } else
+	if (namesame(key, x_("FN")) == 0) { *rot = 900;  *trans = 1; } else
+	if (namesame(key, x_("FS")) == 0) { *rot = 2700; *trans = 1; } else
+	if (namesame(key, x_("FE")) == 0) { *rot = 1800; *trans = 1; } else
+	if (namesame(key, x_("FW")) == 0) { *rot = 0;    *trans = 1; } else
 	{
 		io_definerror(_("Unknown orientation (%s)"), key);
 		return(TRUE);
@@ -1386,32 +1417,51 @@ BOOLEAN io_defreadorientation(FILE *f, INTSML *rot, INTSML *trans)
 	return(FALSE);
 }
 
-BOOLEAN io_defignoretosemicolon(FILE *f, char *command)
+BOOLEAN io_defignoretosemicolon(FILE *f, CHAR *command)
 {
-	REGISTER char *key;
+	REGISTER CHAR *key;
 
 	/* ignore up to the next semicolon */
 	for(;;)
 	{
 		key = io_defmustgetkeyword(f, command);
 		if (key == 0) return(TRUE);
-		if (strcmp(key, ";") == 0) break;
+		if (estrcmp(key, x_(";")) == 0) break;
 	}
 	return(FALSE);
 }
 
-char *io_defmustgetkeyword(FILE *f, char *where)
+BOOLEAN io_defignoreblock(FILE *f, CHAR *command)
 {
-	char *key;
+	REGISTER CHAR *key;
+
+	for(;;)
+	{
+		/* get the next keyword */
+		key = io_defmustgetkeyword(f, command);
+		if (key == 0) return(TRUE);
+
+		if (namesame(key, x_("END")) == 0)
+		{
+			(void)io_defgetkeyword(f);
+			break;
+		}
+	}
+	return(FALSE);
+}
+
+CHAR *io_defmustgetkeyword(FILE *f, CHAR *where)
+{
+	CHAR *key;
 
 	key = io_defgetkeyword(f);
 	if (key == 0) io_definerror(_("EOF parsing %s"), where);
 	return(key);
 }
 
-char *io_defgetkeyword(FILE *f)
+CHAR *io_defgetkeyword(FILE *f)
 {
-	REGISTER char *ret;
+	REGISTER CHAR *ret;
 	REGISTER INTBIG filepos;
 
 	/* keep reading from file until something is found on a line */
@@ -1446,10 +1496,10 @@ char *io_defgetkeyword(FILE *f)
 	return(ret);
 }
 
-void io_definerror(char *command, ...)
+void io_definerror(CHAR *command, ...)
 {
 	va_list ap;
-	char line[500];
+	CHAR line[500];
 
 	var_start(ap, command);
 	evsnprintf(line, 500, command, ap);
