@@ -68,23 +68,23 @@ Net_name : ref_des pad; \
 
 typedef struct Inextecadnet
 {
-	char *netname;
-	char *packagename;
-	char *pinname;
+	CHAR *netname;
+	CHAR *packagename;
+	CHAR *pinname;
 	struct Inextecadnet *nextecadnet;
 } ECADNET;
 
 static ECADNET *io_ecadfirstnet;
 
 /* prototypes for local routines */
-static INTBIG io_ecaddumpfacet(NODEPROTO *curfacet, char *prefix);
+static INTBIG io_ecaddumpfacet(NODEPROTO *curfacet, CHAR *prefix);
 static void io_ecadmarkfacets(NODEPROTO *curfacet);
 
 BOOLEAN io_writeecadlibrary(LIBRARY *lib)
 {
-	char file[100], *truename;
+	CHAR file[100], *truename;
 	REGISTER INTBIG i, sorted, maxnetname, maxpackagename;
-	REGISTER char *name;
+	REGISTER CHAR *name;
 	REGISTER NODEPROTO *curfacet;
 	REGISTER ECADNET *en, *lasten, *nexten;
 	REGISTER PORTPROTO *pp;
@@ -96,8 +96,8 @@ BOOLEAN io_writeecadlibrary(LIBRARY *lib)
 		ttyputerr(_("Must be editing a facet to generate ECAD output"));
 		return(TRUE);
 	}
-	(void)strcpy(file, curfacet->cell->cellname);
-	(void)strcat(file, ".enl");
+	(void)estrcpy(file, curfacet->cell->cellname);
+	(void)estrcat(file, x_(".enl"));
 	name = truepath(file);
 	io_fileout = xcreate(name, io_filetypeecad, _("ECAD File"), &truename);
 	if (io_fileout == NULL)
@@ -110,9 +110,9 @@ BOOLEAN io_writeecadlibrary(LIBRARY *lib)
 	io_ecadfirstnet = NOECADNET;
 	for(pp = curfacet->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
 		pp->temp1 = 0;
-	if (io_ecaddumpfacet(curfacet, "") != 0)
+	if (io_ecaddumpfacet(curfacet, x_("")) != 0)
 		ttyputmsg(_("Back-annotation information has been added (library must be saved)"));
-	xprintf(io_fileout, "| end of part list\n");  /* cm - removed before netlist */
+	xprintf(io_fileout, x_("| end of part list\n"));  /* cm - removed before netlist */
 
 	/* warn the user if nets not found */
 	if (io_ecadfirstnet == NOECADNET)
@@ -147,9 +147,9 @@ BOOLEAN io_writeecadlibrary(LIBRARY *lib)
 	maxnetname = maxpackagename = 0;
 	for(en = io_ecadfirstnet; en != NOECADNET; en = en->nextecadnet)
 	{
-		i = strlen(en->netname);
+		i = estrlen(en->netname);
 		if (i > maxnetname) maxnetname = i;
-		i = strlen(en->packagename);
+		i = estrlen(en->packagename);
 		if (i > maxpackagename) maxpackagename = i;
 	}
 	maxnetname += 4;
@@ -162,28 +162,28 @@ BOOLEAN io_writeecadlibrary(LIBRARY *lib)
 		if (lasten == NOECADNET || namesame(lasten->netname, en->netname) != 0)
 		   {
 			if (lasten != NOECADNET)
-			xprintf(io_fileout, ";\n");
-			xprintf(io_fileout, "%s : ", en->netname);            /* cm - write netname on first line of net */
+			xprintf(io_fileout, x_(";\n"));
+			xprintf(io_fileout, x_("%s : "), en->netname);            /* cm - write netname on first line of net */
 		   }
 		else
 		   {
-			xprintf(io_fileout, "      ");                           /* cm - was net name on each line */
+			xprintf(io_fileout, x_("      "));                           /* cm - was net name on each line */
 		   }
-		for(i=strlen(en->netname); i<maxnetname; i++)
-			xprintf(io_fileout, " ");
+		for(i=estrlen(en->netname); i<maxnetname; i++)
+			xprintf(io_fileout, x_(" "));
 
 		/* write "Part" column */
-		xprintf(io_fileout, "%s", en->packagename);                 /* cm - removed single quotes */
-		for(i=strlen(en->packagename); i<maxpackagename; i++)
-			xprintf(io_fileout, " ");
+		xprintf(io_fileout, x_("%s"), en->packagename);                 /* cm - removed single quotes */
+		for(i=estrlen(en->packagename); i<maxpackagename; i++)
+			xprintf(io_fileout, x_(" "));
 
 		/* write "Pad" column (an attribute with a number) */
-		xprintf(io_fileout, "%s \\\n", en->pinname);                   /* cm - removed single quotes */
+		xprintf(io_fileout, x_("%s \\\n"), en->pinname);                   /* cm - removed single quotes */
 
       lasten = en;
 	}
 
-	if (lasten != NOECADNET) xprintf(io_fileout, ";    |end of net section.\n"); /* cm - end of net section */
+	if (lasten != NOECADNET) xprintf(io_fileout, x_(";    |end of net section.\n")); /* cm - end of net section */
 
 	/* free memory */
 	while (io_ecadfirstnet != NOECADNET)
@@ -193,7 +193,7 @@ BOOLEAN io_writeecadlibrary(LIBRARY *lib)
 		efree(en->netname);
 		efree(en->packagename);
 		efree(en->pinname);
-		efree((char *)en);
+		efree((CHAR *)en);
 	   }
 
 	/* clean up */
@@ -208,10 +208,10 @@ BOOLEAN io_writeecadlibrary(LIBRARY *lib)
  * Routine to write out all facets in the current library that are marked (temp1 != 0).
  * Returns nonzero if backannotation has been added.
  */
-INTBIG io_ecaddumpfacet(NODEPROTO *curfacet, char *prefix)
+INTBIG io_ecaddumpfacet(NODEPROTO *curfacet, CHAR *prefix)
 {
-	char *name;
-	char line[50], *newprefix, *tempname;
+	CHAR *name;
+	CHAR line[50], *newprefix, *tempname;
 	REGISTER NODEPROTO *np, *subnp, *subcnp;
 	REGISTER NETWORK *net;
 	REGISTER NODEINST *ni;
@@ -224,7 +224,7 @@ INTBIG io_ecaddumpfacet(NODEPROTO *curfacet, char *prefix)
 
 	/* make sure that all arcs have network names on them */
 	backannotate = 0;
-	if (asktool(net_tool, "name-nets", (INTBIG)curfacet) != 0) backannotate++;
+	if (asktool(net_tool, x_("name-nets"), (INTBIG)curfacet) != 0) backannotate++;
 
 	/* mark those facets that will be included in this dump */
 	io_ecadmarkfacets(curfacet);
@@ -256,7 +256,7 @@ INTBIG io_ecaddumpfacet(NODEPROTO *curfacet, char *prefix)
 			/* ignore recursive references (showing icon in contents) */
 			if (subnp->cell == np->cell) continue;
 
-			varpart = getval((INTBIG)ni, VNODEINST, -1, "ATTR_ref_des");   /* cm - changed for ecad */
+			varpart = getval((INTBIG)ni, VNODEINST, -1, x_("ATTR_ref_des"));   /* cm - changed for ecad */
 			if (varpart == NOVARIABLE)
 			{
 				subcnp = contentsview(subnp);
@@ -268,11 +268,11 @@ INTBIG io_ecaddumpfacet(NODEPROTO *curfacet, char *prefix)
 				var = getvalkey((INTBIG)ni, VNODEINST, VSTRING, el_node_name_key);
 				if (var == NOVARIABLE)
 				{
-					sprintf(line, "NODE%ld.", (INTBIG)ni);
+					esnprintf(line, 50, x_("NODE%ld."), (INTBIG)ni);
 					addstringtoinfstr(infstr, line);
 				} else
 				{
-					addstringtoinfstr(infstr, (char *)var->addr);
+					addstringtoinfstr(infstr, (CHAR *)var->addr);
 					addtoinfstr(infstr, '.');
 				}
 				(void)allocstring(&newprefix, returninfstr(infstr), el_tempcluster);
@@ -287,7 +287,7 @@ INTBIG io_ecaddumpfacet(NODEPROTO *curfacet, char *prefix)
 					net = pi->conarcinst->network;
 					infstr = initinfstr();
 					addstringtoinfstr(infstr, prefix);
-					addstringtoinfstr(infstr, net->netname);
+					addstringtoinfstr(infstr, networkname(net, 0));
 					(void)allocstring(&tempname, returninfstr(infstr), io_tool->cluster);
 					pp->temp1 = (INTBIG)tempname;
 				}
@@ -299,35 +299,35 @@ INTBIG io_ecaddumpfacet(NODEPROTO *curfacet, char *prefix)
 				io_ecadmarkfacets(curfacet);
 				efree(newprefix);
 				for(pp = subnp->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
-					if (pp->temp1 != 0) efree((char *)pp->temp1);
+					if (pp->temp1 != 0) efree((CHAR *)pp->temp1);
 			} else
 			{
 				/* found package at bottom of hierarchy */
 				(void)allocstring(&name, describevariable(varpart, -1, -1), el_tempcluster);
-				varpackagetype = getval((INTBIG)ni, VNODEINST, -1, "ATTR_pkg_type");
+				varpackagetype = getval((INTBIG)ni, VNODEINST, -1, x_("ATTR_pkg_type"));
 				if (varpackagetype == NOVARIABLE)
 				{
-					xprintf(io_fileout, "Error no pkg_type attribute for %s%s", prefix, name);
+					xprintf(io_fileout, x_("Error no pkg_type attribute for %s%s"), prefix, name);
 				} else
 				{
-					xprintf(io_fileout, ".cmp (t=%s) %s%s (x=0, y=0)", describevariable(varpackagetype, -1, -1),
+					xprintf(io_fileout, x_(".cmp (t=%s) %s%s (x=0, y=0)"), describevariable(varpackagetype, -1, -1),
 						prefix, name);
 				}
-				xprintf(io_fileout, "\n");
+				xprintf(io_fileout, x_("\n"));
 
 				/* record all networks */
 				for(pi = ni->firstportarcinst; pi != NOPORTARCINST; pi = pi->nextportarcinst)
 				{
 					/* get "Pad" information */
 					infstr = initinfstr();
-					addstringtoinfstr(infstr, "ATTRP_");
+					addstringtoinfstr(infstr, x_("ATTRP_"));
 					addstringtoinfstr(infstr, pi->proto->protoname);
-					addstringtoinfstr(infstr, "_pin");
+					addstringtoinfstr(infstr, x_("_pin"));
 					var = getval((INTBIG)ni, VNODEINST, -1, returninfstr(infstr));
 					if (var == NOVARIABLE)
                   {
 						/* "Pad" not found on instance: look for it inside of prototype */
-						var = getval((INTBIG)pi->proto, VPORTPROTO, -1, "ATTR_pin");
+						var = getval((INTBIG)pi->proto, VPORTPROTO, -1, x_("ATTR_pin"));
 						if (var == NOVARIABLE) continue;
                   }
 					/* create a new net connection */
@@ -336,17 +336,17 @@ INTBIG io_ecaddumpfacet(NODEPROTO *curfacet, char *prefix)
 					net = pi->conarcinst->network;
 					if (net->temp1 != 0)
 					{
-						(void)allocstring(&en->netname, (char *)net->temp1, io_tool->cluster);
+						(void)allocstring(&en->netname, (CHAR *)net->temp1, io_tool->cluster);
 					} else if (net->namecount > 0)
 					{
 						infstr = initinfstr();
 						addstringtoinfstr(infstr, prefix);
-						addstringtoinfstr(infstr, net->netname);
+						addstringtoinfstr(infstr, networkname(net, 0));
 						(void)allocstring(&en->netname, returninfstr(infstr), io_tool->cluster);
 					} else
 					{
 						infstr = initinfstr();
-						formatinfstr(infstr, "%sNET%ld", prefix, (INTBIG)net);
+						formatinfstr(infstr, x_("%sNET%ld"), prefix, (INTBIG)net);
 						(void)allocstring(&en->netname, returninfstr(infstr), io_tool->cluster);
 					}
 					infstr = initinfstr();
@@ -357,7 +357,7 @@ INTBIG io_ecaddumpfacet(NODEPROTO *curfacet, char *prefix)
 					en->nextecadnet = io_ecadfirstnet;
 					io_ecadfirstnet = en;
 				}
-				efree((char *)name);
+				efree((CHAR *)name);
 			}
 		}
 	}
@@ -378,7 +378,7 @@ void io_ecadmarkfacets(NODEPROTO *curfacet)
 	{
 		np->temp1 = 0;
 		if ((curfacet->cellview->viewstate&MULTIPAGEVIEW) != 0 ||
-			namesamen(curfacet->cellview->viewname, "schematic-page-", 15) == 0)
+			namesamen(curfacet->cellview->viewname, x_("schematic-page-"), 15) == 0)
 		{
 			/* original facet is a multipage: allow all multipage in this cell */
 			if (curfacet->cell != np->cell) continue;
