@@ -102,23 +102,26 @@ static INTBIG          io_gdsrecordcount;
 static INTBIG          io_gdsbufferindex;
 static INTBIG          io_gdsblockcount;
 static gsymbol         io_gdstoken;
-static bit_array       io_gdstokenflags;
+static UINTSML         io_gdstokenflags;
 static INTSML          io_gdstokenvalue16;
 static INTBIG          io_gdstokenvalue32;
 static float           io_gdsrealtokensp;
 static double          io_gdsrealtokendp;
-static char            io_gdstokenstring[TEXTLINE+1];
+static CHAR            io_gdstokenstring[TEXTLINE+1];
 static point_type      io_gdsvertex[MAXPOINTS];
 static point_type      io_gdsboundarydelta[MAXPOINTS];
 static INTBIG          io_gdscurlayer, io_gdscursublayer;
 static double          io_gdsscale;
 static INTBIG          io_gdsfilesize;
+static INTBIG         *io_gdsIlayerlist;
+static INTBIG          io_gdsIlayerlisttotal = 0;
+
 
 /* these are not really used */
-static char            io_gdsversionstring[IDSTRING+1];
-static char            io_gdslibraryname[IDSTRING+1];
+static CHAR            io_gdsversionstring[IDSTRING+1];
+static CHAR            io_gdslibraryname[IDSTRING+1];
 
-static char *io_gdsIerror_string[] =
+static CHAR *io_gdsIerror_string[] =
 {
 	N_("success"),											/* 0 */
 	N_("Invalid GDS II datatype"),							/* 1 */
@@ -281,24 +284,24 @@ static void            io_gdsIdetermine_property(void);
 static void            io_gdsIdetermine_shape(void);
 static void            io_gdsIdetermine_sref(void);
 static void            io_gdsIdetermine_text(void);
-static void            io_gdsIdetermine_time(char*);
+static void            io_gdsIdetermine_time(CHAR*);
 static void            io_gdsIelement(BOOLEAN*);
 static void            io_gdsIerror(INTBIG);
-static NODEPROTO      *io_gdsIfindproto(char *name);
+static NODEPROTO      *io_gdsIfindproto(CHAR *name);
 static void            io_gdsIfonts(void);
 static void            io_gdsIgetdouble(double*);
 static void            io_gdsIgetfloat(float*);
 static void            io_gdsIgetinteger(INTBIG*);
-static void            io_gdsIgetproto(char*);
-static unsigned char   io_gdsIgetrawbyte(void);
+static void            io_gdsIgetproto(CHAR*);
+static UCHAR1          io_gdsIgetrawbyte(void);
 static gsymbol         io_gdsIgetrecord(datatype_symbol*);
 static datatype_symbol io_gdsIgetrecordtype(void);
-static void            io_gdsIgetstring(char*);
+static void            io_gdsIgetstring(CHAR*);
 static void            io_gdsIgettoken(void);
 static void            io_gdsIgetword(UINTSML*);
 static void            io_gdsIheader(void);
 static void            io_gdsIinit(void);
-static void            io_gdsIitoa(char*, INTBIG);
+static void            io_gdsIitoa(CHAR*, INTBIG, INTBIG);
 static void            io_gdsIlibrary(void);
 static BOOLEAN         io_gdsIload(FILE*);
 static BOOLEAN         io_gdsImember(gsymbol, gsymbol[]);
@@ -310,14 +313,23 @@ static void            io_gdsIreflibs(void);
 static void            io_gdsIshape(INTBIG, shape_type, shape_type);
 static void            io_gdsIstep(INTBIG, INTBIG, INTBIG, INTBIG);
 static void            io_gdsIstructure(void);
-static void            io_gdsItext(char*, INTBIG, INTBIG, INTBIG, INTBIG, double);
+static void            io_gdsItext(CHAR*, INTBIG, INTBIG, INTBIG, INTBIG, double);
 static void            io_gdsItransform(point_type, INTBIG, INTBIG);
 static void            io_gdsItranslate(INTBIG*, INTBIG*, double, BOOLEAN);
 static void            io_gdsIunits(void);
 static void            io_gdsIunsupported(gsymbol[]);
+static void            io_gdsIparselayernumbers(CHAR *layernumbers, INTBIG **layers, INTBIG *total);
 
 /* modules */
 
+/*
+ * Routine to free all memory associated with this module.
+ */
+void io_freegdsinmemory(void)
+{
+	if (io_gdsIlayerlisttotal > 0) efree((CHAR *)io_gdsIlayerlist);
+}
+
 double io_gdsIpower(INTBIG val, INTBIG power)
 {
 	double result;
@@ -362,7 +374,7 @@ void io_gdsIappendset(gsymbol set[], gsymbol item)
 	*pos++ = item; *pos = GDS_BADFIELD;
 }
 
-unsigned char io_gdsIgetrawbyte(void)
+UCHAR1 io_gdsIgetrawbyte(void)
 {
 	if (io_gdsbufferindex >= BLOCKSIZE || io_gdsbufferindex < 0)
 	{
@@ -384,10 +396,10 @@ unsigned char io_gdsIgetrawbyte(void)
 
 void io_gdsIgetword(UINTSML *dataword)
 {
-	unsigned char	lowbyte, highbyte;
+	UINTSML lowbyte, highbyte;
 
-	highbyte = io_gdsIgetrawbyte();
-	lowbyte = io_gdsIgetrawbyte();
+	highbyte = io_gdsIgetrawbyte() & 0xFF;
+	lowbyte = io_gdsIgetrawbyte() & 0xFF;
 	(*dataword) = (highbyte << 8) + lowbyte;
 }
 
@@ -400,9 +412,9 @@ void io_gdsIgetinteger(INTBIG *datavalue)
 	(*datavalue) = (highword << 16) + lowword;
 }
 
-void io_gdsIgetstring(char *streamstring)
+void io_gdsIgetstring(CHAR *streamstring)
 {
-	char letter, *pos;
+	CHAR letter, *pos;
 
 	pos = streamstring;
 	while (io_gdsrecordcount != 0)
@@ -413,9 +425,9 @@ void io_gdsIgetstring(char *streamstring)
 	*pos = '\0';
 }
 
-void io_gdsIitoa(char *nstring, INTBIG number)
+void io_gdsIitoa(CHAR *nstring, INTBIG leng, INTBIG number)
 {
-	(void)sprintf(nstring, "%ld", number);
+	(void)esnprintf(nstring, leng, x_("%ld"), number);
 }
 
 void io_gdsIgetfloat(float *realvalue)
@@ -426,14 +438,14 @@ void io_gdsIgetfloat(float *realvalue)
 	INTBIG	binary_exponent;
 	INTBIG	shift_count;
 
-	reg = io_gdsIgetrawbyte();
+	reg = io_gdsIgetrawbyte() & 0xFF;
 	if (reg & 0x00000080) sign = -1;
 		else sign = 1;
 	reg = reg & 0x0000007F;
 
 	/* generate the exponent, currently in Excess-64 representation */
 	binary_exponent = (reg - 64) << 2;
-	reg = (unsigned long)io_gdsIgetrawbyte() << 16;
+	reg = (unsigned long)(io_gdsIgetrawbyte() & 0xFF) << 16;
 	io_gdsIgetword(&dataword);
 	reg = reg + dataword;
 	shift_count = 0;
@@ -478,7 +490,7 @@ void io_gdsIgetdouble(double *realvalue)
 	}
 
 	/* first byte is the exponent field (hex) */
-	register1 = io_gdsIgetrawbyte();
+	register1 = io_gdsIgetrawbyte() & 0xFF;
 
 	/* plus sign bit */
 	if (register1 & 0x00000080) *realvalue = -1.0; else
@@ -489,7 +501,7 @@ void io_gdsIgetdouble(double *realvalue)
 	exponent = register1 - 64;
 
 	/* bytes 2-4 are the high ordered bits of the mantissa */
-	register1 = (UINTBIG)io_gdsIgetrawbyte() << 16;
+	register1 = (UINTBIG)(io_gdsIgetrawbyte() & 0xFF) << 16;
 	io_gdsIgetword(&dataword);
 	register1 = register1 + dataword;
 
@@ -551,7 +563,7 @@ gsymbol io_gdsIgetrecord(datatype_symbol *gds_type)
 
 	io_gdsIgetword(&dataword);
 	io_gdsrecordcount = dataword - 2;
-	recordtype = io_gdsIgetrawbyte();
+	recordtype = io_gdsIgetrawbyte() & 0xFF;
 	temp = GDS_NULLSYM;
 	switch (recordtype)
 	{
@@ -620,7 +632,7 @@ gsymbol io_gdsIgetrecord(datatype_symbol *gds_type)
 
 void io_gdsIerror(INTBIG n)
 {
-	ttyputerr(_("Error: %s, block %ld, index %ld"), _(io_gdsIerror_string[n]),
+	ttyputerr(_("Error: %s, block %ld, index %ld"), TRANSLATE(io_gdsIerror_string[n]),
 		io_gdsblockcount, io_gdsbufferindex);
 	longjmp(io_gdsenv, 1);
 }
@@ -639,7 +651,7 @@ void io_gdsIgettoken(void)
 			case GDS_NONE:
 				break;
 			case GDS_FLAGS:
-				io_gdsIgetword(&io_gdstokenflags.u.value);
+				io_gdsIgetword(&io_gdstokenflags);
 				io_gdstoken = GDS_FLAGSYM;
 				break;
 			case GDS_SHORT_WORD:
@@ -866,14 +878,14 @@ void io_gdsIshape(INTBIG npts, shape_type perimeter, shape_type oclass)
 					io_gdsIerror(35);
 
 			/* free the polygon memory */
-			efree((char *)trace);
+			efree((CHAR *)trace);
 			break;
 		default:
 			break;
 	}
 }
 
-void io_gdsItext(char *charstring, INTBIG vjust, INTBIG hjust, INTBIG angle,
+void io_gdsItext(CHAR *charstring, INTBIG vjust, INTBIG hjust, INTBIG angle,
 	INTBIG trans, double scale)
 {
 	NODEINST *ni;
@@ -884,19 +896,18 @@ void io_gdsItext(char *charstring, INTBIG vjust, INTBIG hjust, INTBIG angle,
 	if (!io_gdslayerused || !(io_gdscurstate[0]&GDSINTEXT)) return;
 	io_gdslayertext[io_gdslayerwhich]++;
 
-	io_gdsvertex[1].px = io_gdsvertex[0].px + MINFONTWIDTH * strlen(charstring);
+	io_gdsvertex[1].px = io_gdsvertex[0].px + MINFONTWIDTH * estrlen(charstring);
 	io_gdsvertex[1].py = io_gdsvertex[0].py + MINFONTHEIGHT;
 
 	/* create a holding node */
-	if ((ni = newnodeinst(io_gdslayernode, io_gdsvertex[0].px, io_gdsvertex[0].px,
-		io_gdsvertex[0].py, io_gdsvertex[0].py, trans, angle,
-			io_gdsstructure)) == NONODEINST)
-				io_gdsIerror(36);
+	ni = newnodeinst(io_gdslayernode, io_gdsvertex[0].px, io_gdsvertex[0].px,
+		io_gdsvertex[0].py, io_gdsvertex[0].py, trans, angle, io_gdsstructure);
+	if (ni == NONODEINST) io_gdsIerror(36);
 
 	/* now add the text */
-	if ((var = setvalkey((INTBIG)ni, VNODEINST, el_node_name_key, (INTBIG)charstring,
-		VSTRING|VDISPLAY)) == NOVARIABLE)
-			io_gdsIerror(37);
+	var = setvalkey((INTBIG)ni, VNODEINST, el_node_name_key, (INTBIG)charstring,
+		VSTRING|VDISPLAY);
+	if (var == NOVARIABLE) io_gdsIerror(37);
 
 	/* set the text size and orientation */
 	size = rounddouble(scale);
@@ -942,7 +953,7 @@ void io_gdsItext(char *charstring, INTBIG vjust, INTBIG hjust, INTBIG angle,
  */
 void io_gdsIOnceinit(void)
 {
-	INTBIG i, *layer_numbers, j, count, which;
+	INTBIG i, j, k, count, which, *layers, numlayers, fakelayer[1];
 	VARIABLE *var;
 	static POLYGON *poly = NOPOLYGON;
 	REGISTER NODEINST *ni;
@@ -966,16 +977,32 @@ void io_gdsIOnceinit(void)
 		io_gdslayerpoly[i] = 0;
 		io_gdslayervisible[i] = TRUE;
 	}
-	if ((var = getval((INTBIG)el_curtech, VTECHNOLOGY, VINTEGER|VISARRAY,
-		"IO_gds_layer_numbers")) != NOVARIABLE)
+	var = getval((INTBIG)el_curtech, VTECHNOLOGY, -1, x_("IO_gds_layer_numbers"));
+	if (var != NOVARIABLE && (var->type&VISARRAY) == 0) var = NOVARIABLE;
+	if (var != NOVARIABLE)
 	{
-		layer_numbers = (INTBIG *)var->addr;
 		count = getlength(var);
 		for (i=0; i<count; i++)
 		{
-			which = layer_numbers[i];
-			if (which >= 0 && which < MAXLAYERS)
+			if ((var->type&VTYPE) == VSTRING)
 			{
+				io_gdsIparselayernumbers(((CHAR **)var->addr)[i], &layers, &numlayers);
+			} else
+			{
+				fakelayer[0] = ((INTBIG *)var->addr)[i];
+				layers = fakelayer;
+				if (fakelayer[0] < 0) numlayers = 0; else
+					numlayers = 1;
+			}
+			for(k=0; k<numlayers; k++)
+			{
+				which = layers[k];
+				if (which < 0) continue;
+				if (which >= MAXLAYERS)
+				{
+					ttyputmsg(_("GDS layer %ld is too large (limit is %ld)"), which, MAXLAYERS-1);
+					continue;
+				}
 				for(np = el_curtech->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
 				{
 					if (((np->userbits&NFUNCTION)>>NFUNCTIONSH) != NPNODE) continue;
@@ -1000,16 +1027,47 @@ void io_gdsIOnceinit(void)
 					io_gdslayernodes[which] = np;
 					continue;
 				}
-				if (io_gdslayernodes[which] != NONODEPROTO) continue;
-				for(j=i+1; j<count; j++) if (which == layer_numbers[j]) break;
-				if (j < count) continue;
-				ttyputmsg(_("Cannot read GDS layer %ld (%s)"), which,
-					layername(el_curtech, i));
 			}
 		}
 	} else ttyputmsg(_("Technology has no GDSII layer numbers"));
 }
 
+/*
+ * Routine to parse a string of layer numbers in "layernumbers" and return those layers
+ * in the array "layers", with the size of the array in "total".
+ */
+void io_gdsIparselayernumbers(CHAR *layernumbers, INTBIG **layers, INTBIG *total)
+{
+	REGISTER CHAR *pt;
+	REGISTER INTBIG count, i, newtotal, *newlist, number;
+
+	count = 0;
+	pt = layernumbers;
+	for(;;)
+	{
+		while (*pt == ' ') pt++;
+		if (*pt == 0) break;
+		number = myatoi(pt);
+		if (count >= io_gdsIlayerlisttotal)
+		{
+			newtotal = io_gdsIlayerlisttotal * 2;
+			if (count >= newtotal) newtotal = count+5;
+			newlist = (INTBIG *)emalloc(newtotal * SIZEOFINTBIG, io_tool->cluster);
+			if (newlist == 0) return;
+			for(i=0; i<count; i++)
+				newlist[i] = io_gdsIlayerlist[i];
+			if (io_gdsIlayerlisttotal > 0) efree((CHAR *)io_gdsIlayerlist);
+			io_gdsIlayerlist = newlist;
+			io_gdsIlayerlisttotal = newtotal;
+		}
+		io_gdsIlayerlist[count++] = number;
+		while (*pt != 0 && *pt != ',') pt++;
+		if (*pt == ',') pt++;
+	}
+	*layers = io_gdsIlayerlist;
+	*total = count;
+}
+
 /*
  * Routine to initialize the input of a GDS file
  */
@@ -1021,10 +1079,10 @@ void io_gdsIinit(void)
 	io_gdscurlayer = io_gdscursublayer = 0;
 }
 
-void io_gdsIdetermine_time(char *time_string)
+void io_gdsIdetermine_time(CHAR *time_string)
 {
 	REGISTER INTBIG i;
-	char time_array[7][IDSTRING+1];
+	CHAR time_array[7][IDSTRING+1];
 
 	for (i = 0; i < 6; i++)
 	{
@@ -1036,7 +1094,7 @@ void io_gdsIdetermine_time(char *time_string)
 				if (io_gdstokenvalue16 > 60) io_gdstokenvalue16 += 1900; else
 					io_gdstokenvalue16 += 2000;
 			}
-			(void)sprintf(time_array[i], "%02d", io_gdstokenvalue16);
+			(void)esnprintf(time_array[i], IDSTRING+1, x_("%02d"), io_gdstokenvalue16);
 			io_gdsIgettoken();
 		} else
 		{
@@ -1044,7 +1102,7 @@ void io_gdsIdetermine_time(char *time_string)
 			io_gdsIerror(6);
 		}
 	}
-	(void)sprintf(time_string, "%s-%s-%s at %s:%s:%s", time_array[1], time_array[2],
+	(void)esnprintf(time_string, IDSTRING+1, x_("%s-%s-%s at %s:%s:%s"), time_array[1], time_array[2],
 		time_array[0], time_array[3], time_array[4], time_array[5]);
 }
 
@@ -1055,7 +1113,7 @@ void io_gdsIheader(void)
 		io_gdsIgettoken();
 		if (io_gdstoken == GDS_SHORT_NUMBER)
 		{
-			io_gdsIitoa(io_gdsversionstring, io_gdstokenvalue16);
+			io_gdsIitoa(io_gdsversionstring, 129, io_gdstokenvalue16);
 		} else
 		{
 			io_gdsIonlyone(io_gdsIrecovery_set, GDS_BGNLIB);
@@ -1070,7 +1128,7 @@ void io_gdsIheader(void)
 
 void io_gdsIlibrary(void)
 {
-	char mod_time[IDSTRING+1], create_time[IDSTRING+1];
+	CHAR mod_time[IDSTRING+1], create_time[IDSTRING+1];
 
 	if (io_gdstoken == GDS_BGNLIB)
 	{
@@ -1082,7 +1140,7 @@ void io_gdsIlibrary(void)
 			io_gdsIgettoken();
 			if (io_gdstoken == GDS_IDENT)
 			{
-				(void)strcpy(io_gdslibraryname, io_gdstokenstring);
+				(void)estrcpy(io_gdslibraryname, io_gdstokenstring);
 			} else
 			{
 				io_gdsIonlyone(io_gdsIrecovery_set, GDS_UNITS);
@@ -1113,12 +1171,12 @@ void io_gdsIfonts(void)
 
 void io_gdsIbackup(void)
 {
-	char backup_string[IDSTRING+1];
+	CHAR backup_string[IDSTRING+1];
 
 	io_gdsIgettoken();
 	if (io_gdstoken == GDS_SHORT_NUMBER)
 	{
-		io_gdsIitoa(backup_string, io_gdstokenvalue16);
+		io_gdsIitoa(backup_string, 129, io_gdstokenvalue16);
 	} else
 	{
 		io_gdsIcopyset(io_gdsIbackup_set, io_gdsIrecovery_set);
@@ -1140,7 +1198,7 @@ void io_gdsIunits(void)
 {
 	double meter_unit, db_unit;
 	double microns_per_user_unit;
-	char realstring[IDSTRING+1];
+	CHAR realstring[IDSTRING+1];
 
 	if (io_gdstoken == GDS_UNITS)
 	{
@@ -1152,7 +1210,7 @@ void io_gdsIunits(void)
 			io_gdsIgettoken();
 			meter_unit = io_gdsrealtokendp;
 			microns_per_user_unit = (meter_unit / db_unit) * 1.0e6;
-			(void)sprintf(realstring, "%6.3f", microns_per_user_unit);
+			(void)esnprintf(realstring, IDSTRING+1, x_("%6.3f"), microns_per_user_unit);
 
 			/* don't change the cast in this equation - roundoff error! */
 			io_gdsscale = meter_unit  * (double)(1000000 * scalefromdispunit(1.0, DISPUNITMIC));
@@ -1206,13 +1264,12 @@ void io_gdsIdetermine_orientation(INTBIG *angle, INTBIG *trans, double *scale)
 	double anglevalue;
 
 	anglevalue = 0.0;
+	*scale = 1.0;
 	mirror_x = FALSE;
 	io_gdsIgettoken();
 	if (io_gdstoken == GDS_FLAGSYM)
 	{
-		if (io_gdstokenflags.u.f.flag0) mirror_x = TRUE;
-		/* if (io_gdstokenflags.u.f.flag13) abs_scale = 1; */
-		/* if (io_gdstokenflags.u.f.flag14) abs_angle = 1; */
+		if ((io_gdstokenflags&0100000) != 0) mirror_x = TRUE;
 		io_gdsIgettoken();
 	} else
 	{
@@ -1299,13 +1356,13 @@ void io_gdsIdetermine_layer(INTBIG *layer, INTBIG *sublayer)
 	}
 }
 
-NODEPROTO *io_gdsIfindproto(char *name)
+NODEPROTO *io_gdsIfindproto(CHAR *name)
 {
 	CELL *c;
 
 	c = db_findcellname(name, io_gdslibrary);
 	if (c == NOCELL) return(NONODEPROTO);
-	if (strcmp(c->cellname, name))
+	if (estrcmp(c->cellname, name))
 		ttyputmsg(_("Cell %s is used instead of cell %s"),
 			c->cellname, name);
 	return(c->firstincell);
@@ -1313,9 +1370,8 @@ NODEPROTO *io_gdsIfindproto(char *name)
 
 void io_gdsIbeginstructure(void)
 {
-	char create_time[IDSTRING+1], mod_time[IDSTRING+1];
+	CHAR create_time[IDSTRING+1], mod_time[IDSTRING+1];
 	REGISTER void *infstr;
-	REGISTER NODEINST *ni;
 
 	if (io_gdstoken == GDS_BGNSTR)
 	{
@@ -1341,17 +1397,6 @@ void io_gdsIbeginstructure(void)
 						formatinfstr(infstr, _("Reading %s"), io_gdstokenstring);
 						DiaSetTextProgress(io_gdsprogressdialog, returninfstr(infstr));
 					} else if (io_verbose != 0) ttyputmsg(_("Reading %s"), io_gdstokenstring);
-
-					if ((us_useroptions&FACETCENTERALWAYS) != 0)
-					{
-						/* add the facet center */
-						ni = newnodeinst(gen_facetcenterprim, gen_facetcenterprim->lowx,
-							gen_facetcenterprim->highx, gen_facetcenterprim->lowy,
-							gen_facetcenterprim->highy, 0, 0, io_gdsstructure);
-						if (ni == NONODEINST)
-							io_gdsIerror(39);
-						ni->userbits |= HARDSELECTN|NVISIBLEINSIDE;
-					}
 					if (io_gdslibrary->curnodeproto == NONODEPROTO)
 						io_gdslibrary->curnodeproto = io_gdsstructure;
 				}
@@ -1377,14 +1422,14 @@ void io_gdsIbeginstructure(void)
 
 void io_gdsIdetermine_property(void)
 {
-	char propvalue[IDSTRING+1];
+	CHAR propvalue[IDSTRING+1];
 
 	io_gdsIgettoken();
 	io_gdsIgettoken();
 	if (io_gdstoken == GDS_PROPVALUE)
 	{
 		io_gdsIgettoken();
-		(void)strcpy(propvalue, io_gdstokenstring);
+		(void)estrcpy(propvalue, io_gdstokenstring);
 
 		/* add to the current structure as a variable? */
 		io_gdsIgettoken();
@@ -1653,11 +1698,10 @@ void io_gdsIdetermine_path(void)
 	}
 }
 
-void io_gdsIgetproto(char *name)
+void io_gdsIgetproto(CHAR *name)
 {
 	NODEPROTO *np;
 	REGISTER void *infstr;
-	NODEINST *ni;
 
 	/* scan for this proto */
 	np = io_gdsIfindproto(name);
@@ -1672,17 +1716,6 @@ void io_gdsIgetproto(char *name)
 			formatinfstr(infstr, _("Reading %s"), io_gdstokenstring);
 			DiaSetTextProgress(io_gdsprogressdialog, returninfstr(infstr));
 		} else if (io_verbose != 0) ttyputmsg(_("Reading %s"), io_gdstokenstring);
-
-		if ((us_useroptions&FACETCENTERALWAYS) != 0)
-		{
-			/* add the facet center */
-			ni = newnodeinst(gen_facetcenterprim, gen_facetcenterprim->lowx,
-				gen_facetcenterprim->highx, gen_facetcenterprim->lowy,
-					gen_facetcenterprim->highy, 0, 0, np);
-			if (ni == NONODEINST)
-				io_gdsIerror(39);
-			ni->userbits |= HARDSELECTN|NVISIBLEINSIDE;
-		}
 	}
 
 	/* set the reference node proto */
@@ -1801,11 +1834,11 @@ void io_gdsIdetermine_justification(INTBIG *vert_just, INTBIG *horiz_just)
 	io_gdsIgettoken();
 	if (io_gdstoken == GDS_FLAGSYM)
 	{
-		font_libno = io_gdstokenflags.u.value & 0x0030;
+		font_libno = io_gdstokenflags & 0x0030;
 		font_libno = font_libno >> 4;
-		(*vert_just) = io_gdstokenflags.u.value & 0x000C;
+		(*vert_just) = io_gdstokenflags & 0x000C;
 		(*vert_just) = (*vert_just) >> 2;
-		(*horiz_just) = io_gdstokenflags.u.value & 0x0003;
+		(*horiz_just) = io_gdstokenflags & 0x0003;
 		io_gdsIgettoken();
 	} else
 	{
@@ -1817,7 +1850,7 @@ void io_gdsIdetermine_justification(INTBIG *vert_just, INTBIG *horiz_just)
 void io_gdsIdetermine_text(void)
 {
 	INTBIG vert_just, horiz_just, layer, sublayer;
-	char textstring[TEXTLINE+1];
+	CHAR textstring[TEXTLINE+1];
 	INTBIG n, angle, trans;
 	double scale;
 
@@ -1828,7 +1861,7 @@ void io_gdsIdetermine_text(void)
 	vert_just = -1;
 	horiz_just = -1;
 	if (io_gdstoken == GDS_PRESENTATION)
-	io_gdsIdetermine_justification(&vert_just, &horiz_just);
+		io_gdsIdetermine_justification(&vert_just, &horiz_just);
 	if (io_gdstoken == GDS_PATHTYPE)
 	{
 		io_gdsIgettoken();
@@ -1842,6 +1875,7 @@ void io_gdsIdetermine_text(void)
 		io_gdsIgettoken();
 	}
 	angle = trans = 0;
+	scale = 1.0;
 	for(;;)
 	{
 		if (io_gdstoken == GDS_STRANS)
@@ -1867,7 +1901,7 @@ void io_gdsIdetermine_text(void)
 			if (io_gdsrecordcount == 0) textstring[0] = '\0'; else
 			{
 				io_gdsIgettoken();
-				(void)strcpy(textstring, io_gdstokenstring);
+				(void)estrcpy(textstring, io_gdstokenstring);
 			}
 			io_gdsIgettoken();
 			break;
@@ -1920,7 +1954,7 @@ void io_gdsIstructure(void)
 	}
 	if (empty_structure)
 	{
-		ttyputmsg("%s", _(io_gdsIerror_string[11]));
+		ttyputmsg(x_("%s"), TRANSLATE(io_gdsIerror_string[11]));
 		ttyputerr(_("Error at block number %5d and offset %4d"),
 			io_gdsblockcount, io_gdsbufferindex);
 		return;
@@ -1979,7 +2013,7 @@ BOOLEAN io_readgdslibrary(LIBRARY *lib, INTBIG position)
 	BOOLEAN err;
 	INTBIG i;
 	INTBIG count;
-	char *filename;
+	CHAR *filename;
 	NODEPROTO *np;
 
 	io_gdslibrary = lib;
@@ -1988,7 +2022,7 @@ BOOLEAN io_readgdslibrary(LIBRARY *lib, INTBIG position)
 	io_gdscurstate = io_getstatebits();
 
 	/* get the gds file */
-	if ((input = xopen(io_gdslibrary->libfile, io_filetypegds, "", &filename)) == NULL)
+	if ((input = xopen(io_gdslibrary->libfile, io_filetypegds, x_(""), &filename)) == NULL)
 	{
 		ttyputerr(_("File %s not found"), io_gdslibrary->libfile);
 		return(TRUE);
@@ -2034,7 +2068,7 @@ BOOLEAN io_readgdslibrary(LIBRARY *lib, INTBIG position)
 			if (position == 0)
 				ttyputmsg(_("%s information:"), skippath(io_gdslibrary->libfile)); else
 					ttyputmsg(_("Summary information:"));
-			ttyputmsg("  %ld %s", io_gdssrefcount, makeplural("SREF", io_gdssrefcount));
+			ttyputmsg(x_("  %ld %s"), io_gdssrefcount, makeplural(x_("SREF"), io_gdssrefcount));
 			for (i = 0; i < MAXLAYERS; i++)
 			{
 				if (io_gdslayertext[i] || io_gdslayerpoly[i])
@@ -2084,7 +2118,7 @@ BOOLEAN io_readgdslibrary(LIBRARY *lib, INTBIG position)
 void io_gdsIrecompute(NODEPROTO *np, INTBIG count)
 {
 	REGISTER INTBIG cx, cy;
-	char numsofar[50];
+	CHAR numsofar[50];
 	INTBIG ox, oy;
 	XARRAY trans;
 	REGISTER NODEINST *ni;
@@ -2101,21 +2135,26 @@ void io_gdsIrecompute(NODEPROTO *np, INTBIG count)
 			if (ni->proto->temp1 == 0)
 				io_gdsIrecompute(ni->proto, count);
 			if ((ni->highx-ni->lowx) != (ni->proto->highx-ni->proto->lowx) ||
-				(ni->highx-ni->lowx) != (ni->proto->highx-ni->proto->lowx))
+				(ni->highy-ni->lowy) != (ni->proto->highy-ni->proto->lowy))
 			{
-				makeangle(ni->rotation, ni->transpose, trans);
+#if 0
+				if (ni->lowx == ni->highx || ni->lowy == ni->highy)
+#endif
+				{
+					makeangle(ni->rotation, ni->transpose, trans);
 
-				/* now transform the center */
-				cx = (ni->proto->highx + ni->proto->lowx) / 2;
-				cy = (ni->proto->highy + ni->proto->lowy) / 2;
-				xform(cx, cy, &ox, &oy, trans);
+					/* now transform the center */
+					cx = (ni->proto->highx + ni->proto->lowx) / 2;
+					cy = (ni->proto->highy + ni->proto->lowy) / 2;
+					xform(cx, cy, &ox, &oy, trans);
 
-				/* calculate the offset from the original center */
-				ox -= cx;   oy -= cy;
-				ni->lowx += (ni->proto->lowx + ox);
-				ni->highx += (ni->proto->highx + ox);
-				ni->lowy += (ni->proto->lowy + oy);
-				ni->highy += (ni->proto->highy + oy);
+					/* calculate the offset from the original center */
+					ox -= cx;   oy -= cy;
+					ni->lowx += (ni->proto->lowx + ox);
+					ni->highx += (ni->proto->highx + ox);
+					ni->lowy += (ni->proto->lowy + oy);
+					ni->highy += (ni->proto->highy + oy);
+				}
 				boundobj(ni->geom, &(ni->geom->lowx), &(ni->geom->highx),
 					&(ni->geom->lowy), &(ni->geom->highy));
 			}
@@ -2127,7 +2166,7 @@ void io_gdsIrecompute(NODEPROTO *np, INTBIG count)
 		io_gdsrecomputed++;
 		if ((io_gdsrecomputed%1000) == 0 && io_verbose < 0 && io_gdsfilesize > 0)
 		{
-			(void)sprintf(numsofar, _("Cleaned up %ld instances..."), io_gdsrecomputed);
+			(void)esnprintf(numsofar, 50, _("Cleaned up %ld instances..."), io_gdsrecomputed);
 			DiaSetTextProgress(io_gdsprogressdialog, numsofar);
 			if (count > 0)
 				DiaSetProgress(io_gdsprogressdialog, io_gdsrecomputed, count);
