@@ -64,13 +64,13 @@ static void io_hparc(INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG);
 static void io_hpcircle(INTBIG, INTBIG, INTBIG, INTBIG, INTBIG);
 static void io_hpdisc(INTBIG, INTBIG, INTBIG, INTBIG, GRAPHICS*);
 static void io_hpfilledpolygon(INTBIG*, INTBIG*, INTBIG, INTBIG);
-static void io_hptext(INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, char*, INTBIG);
+static void io_hptext(INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, CHAR*, INTBIG);
 static void io_hpparsepenfile(void);
 static INTBIG io_hpchoosecolorentry(INTBIG);
 static void io_hppenselect(INTBIG);
 static void io_hpmove(INTBIG, INTBIG);
 static void io_hpdraw(INTBIG, INTBIG);
-static void io_hpcmd(char[]);
+static void io_hpcmd(CHAR[]);
 
 void io_hpwritepolygon(INTBIG layer, TECHNOLOGY *tech, INTBIG *x, INTBIG *y, INTBIG count)
 {
@@ -82,7 +82,7 @@ void io_hpwritepolygon(INTBIG layer, TECHNOLOGY *tech, INTBIG *x, INTBIG *y, INT
  */
 BOOLEAN io_writehpgllibrary(LIBRARY *lib)
 {
-	char file[100], buff[MAXSTR], *truename;
+	CHAR file[100], buff[MAXSTR], *truename;
 	REGISTER NODEPROTO *np;
 	INTBIG lx, hx, ly, hy, i, *curstate,
 		sulx, suhx, suly, suhy, sslx, sshx, ssly, sshy;
@@ -111,11 +111,11 @@ BOOLEAN io_writehpgllibrary(LIBRARY *lib)
 	/* create the output file */
 	if (io_hpgl2 != 0)
 	{
-		(void)sprintf(file, "%s.hpgl2", np->cell->cellname);
-		io_hpout = xcreate(file, io_filetypehpgl, _("HPGL/2 File"), &truename);
+		(void)esnprintf(file, 100, x_("%s.hpgl2"), np->cell->cellname);
+		io_hpout = xcreate(file, io_filetypehpgl2, _("HPGL/2 File"), &truename);
 	} else
 	{
-		(void)sprintf(file, "%s.hpgl", np->cell->cellname);
+		(void)esnprintf(file, 100, x_("%s.hpgl"), np->cell->cellname);
 		io_hpout = xcreate(file, io_filetypehpgl, _("HPGL File"), &truename);
 	}
 	if (io_hpout == NULL)
@@ -141,14 +141,14 @@ BOOLEAN io_writehpgllibrary(LIBRARY *lib)
 	if (io_hpgl2 != 0)
 	{
 		/* HPGL/2 setup and defaults */
-		io_hpcmd("\033%0BBPIN");
-		io_hpcmd("LA1,4,2,4QLMC0");
+		io_hpcmd(x_("\033%0BBPIN"));
+		io_hpcmd(x_("LA1,4,2,4QLMC0"));
 
 		/* setup pens */
-		io_hpcmd("NP256");
-		varred = getval((INTBIG)us_tool, VTOOL, VINTEGER|VISARRAY, "USER_colormap_red");
-		vargreen = getval((INTBIG)us_tool, VTOOL, VINTEGER|VISARRAY, "USER_colormap_green");
-		varblue = getval((INTBIG)us_tool, VTOOL, VINTEGER|VISARRAY, "USER_colormap_blue");
+		io_hpcmd(x_("NP256"));
+		varred = getval((INTBIG)us_tool, VTOOL, VINTEGER|VISARRAY, x_("USER_colormap_red"));
+		vargreen = getval((INTBIG)us_tool, VTOOL, VINTEGER|VISARRAY, x_("USER_colormap_green"));
+		varblue = getval((INTBIG)us_tool, VTOOL, VINTEGER|VISARRAY, x_("USER_colormap_blue"));
 		if (varred == NOVARIABLE || vargreen == NOVARIABLE || varblue == NOVARIABLE)
 		{
 			ttyputmsg(_("Cannot get colors!"));
@@ -157,47 +157,47 @@ BOOLEAN io_writehpgllibrary(LIBRARY *lib)
 		for(i=0; i<256; i++)
 		{
 			if ((i&(LAYERG|LAYERH|LAYEROE)) != LAYEROE) continue;
-			(void)sprintf(buff, "PC%ld,%ld,%ld,%ld", i&LAYERO, ((INTBIG *)varred->addr)[i],
+			(void)esnprintf(buff, MAXSTR, x_("PC%ld,%ld,%ld,%ld"), i&LAYERO, ((INTBIG *)varred->addr)[i],
 				((INTBIG *)vargreen->addr)[i], ((INTBIG *)varblue->addr)[i]);
 			io_hpcmd(buff);
 		}
-		(void)sprintf(buff, "PC%d,%ld,%ld,%ld", LAYERT1, ((INTBIG *)varred->addr)[LAYERT1],
+		(void)esnprintf(buff, MAXSTR, x_("PC%d,%ld,%ld,%ld"), LAYERT1, ((INTBIG *)varred->addr)[LAYERT1],
 			((INTBIG *)vargreen->addr)[LAYERT1], ((INTBIG *)varblue->addr)[LAYERT1]);
 		io_hpcmd(buff);
-		(void)sprintf(buff, "PC%d,%ld,%ld,%ld", LAYERT2, ((INTBIG *)varred->addr)[LAYERT2],
+		(void)esnprintf(buff, MAXSTR, x_("PC%d,%ld,%ld,%ld"), LAYERT2, ((INTBIG *)varred->addr)[LAYERT2],
 			((INTBIG *)vargreen->addr)[LAYERT2], ((INTBIG *)varblue->addr)[LAYERT2]);
 		io_hpcmd(buff);
-		(void)sprintf(buff, "PC%d,%ld,%ld,%ld", LAYERT3, ((INTBIG *)varred->addr)[LAYERT3],
+		(void)esnprintf(buff, MAXSTR, x_("PC%d,%ld,%ld,%ld"), LAYERT3, ((INTBIG *)varred->addr)[LAYERT3],
 			((INTBIG *)vargreen->addr)[LAYERT3], ((INTBIG *)varblue->addr)[LAYERT3]);
 		io_hpcmd(buff);
-		(void)sprintf(buff, "PC%d,%ld,%ld,%ld", LAYERT4, ((INTBIG *)varred->addr)[LAYERT4],
+		(void)esnprintf(buff, MAXSTR, x_("PC%d,%ld,%ld,%ld"), LAYERT4, ((INTBIG *)varred->addr)[LAYERT4],
 			((INTBIG *)vargreen->addr)[LAYERT4], ((INTBIG *)varblue->addr)[LAYERT4]);
 		io_hpcmd(buff);
-		(void)sprintf(buff, "PC%d,%ld,%ld,%ld", LAYERT5, ((INTBIG *)varred->addr)[LAYERT5],
+		(void)esnprintf(buff, MAXSTR, x_("PC%d,%ld,%ld,%ld"), LAYERT5, ((INTBIG *)varred->addr)[LAYERT5],
 			((INTBIG *)vargreen->addr)[LAYERT5], ((INTBIG *)varblue->addr)[LAYERT5]);
 		io_hpcmd(buff);
 	} else
 	{
 		/* HPGL setup and defaults */
-		io_hpcmd("\033.(\033.@;14:\033.I80;0;17:\033.N;19:");
-		io_hpcmd("DF;IN;");
+		io_hpcmd(x_("\033.(\033.@;14:\033.I80;0;17:\033.N;19:"));
+		io_hpcmd(x_("DF;IN;"));
 	}
 
 	/* set default location of "P1" and "P2" points on the plotter */
-	io_hpcmd("IP;");
+	io_hpcmd(x_("IP;"));
 
 	/* see if fixed scale specification has been made */
-	varscale = getval((INTBIG)io_tool, VTOOL, VINTEGER, "IO_hpgl2_scale");
+	varscale = getval((INTBIG)io_tool, VTOOL, VINTEGER, x_("IO_hpgl2_scale"));
 	if (io_hpgl2 != 0 && varscale != NOVARIABLE)
 	{
 		/* in HPGL/2, can handle fixed scale specification in internal units per pixel */
 		scale = 1.0f / (float)varscale->addr;
-		(void)sprintf(buff, "SC%ld,%g,%ld,%g,2;", io_hpwindow.screenlx, scale, io_hpwindow.screenly, scale);
+		(void)esnprintf(buff, MAXSTR, x_("SC%ld,%g,%ld,%g,2;"), io_hpwindow.screenlx, scale, io_hpwindow.screenly, scale);
 		io_hpcmd(buff);
 	} else
 	{
 		/* no fixed scale or HPGL: fill the page while maintaining isotropic scaling */
-		(void)sprintf(buff, "SC %ld,%ld,%ld,%ld,1;", io_hpwindow.screenlx, io_hpwindow.screenhx,
+		(void)esnprintf(buff, MAXSTR, x_("SC %ld,%ld,%ld,%ld,1;"), io_hpwindow.screenlx, io_hpwindow.screenhx,
 			io_hpwindow.screenly, io_hpwindow.screenhy);
 		io_hpcmd(buff);
 	}
@@ -218,7 +218,7 @@ BOOLEAN io_writehpgllibrary(LIBRARY *lib)
 	el_curwindowpart->screenly = io_hpwindow.screenly;
 	el_curwindowpart->screenhy = io_hpwindow.screenhy;
 	computewindowscale(el_curwindowpart);
-	(void)asktool(us_tool, "display-to-routine", io_hppoly);
+	(void)asktool(us_tool, x_("display-to-routine"), io_hppoly);
 	el_curwindowpart->uselx = sulx;      el_curwindowpart->usehx = suhx;
 	el_curwindowpart->usely = suly;      el_curwindowpart->usehy = suhy;
 	el_curwindowpart->screenlx = sslx;   el_curwindowpart->screenhx = sshx;
@@ -235,11 +235,11 @@ BOOLEAN io_writehpgllibrary(LIBRARY *lib)
 	if (io_hpgl2 != 0)
 	{
 		/* HPGL/2 termination */
-		io_hpcmd("PUSP0PG;");
+		io_hpcmd(x_("PUSP0PG;"));
 	} else
 	{
 		/* HPGL termination */
-		io_hpcmd(";SP0;PU;DF;NR;\033.)");
+		io_hpcmd(x_(";SP0;PU;DF;NR;\033.)"));
 	}
 	xclose(io_hpout);
 	ttyputmsg(_("%s written"), truename);
@@ -381,7 +381,7 @@ void io_hpline(INTBIG x1, INTBIG y1, INTBIG x2, INTBIG y2, INTBIG color)
 void io_hparc(INTBIG centerx, INTBIG centery, INTBIG x1, INTBIG y1, INTBIG x2,
 	INTBIG y2, INTBIG color)
 {
-	char buff[MAXSTR];
+	CHAR buff[MAXSTR];
 	INTBIG startangle, endangle, amt;
 
 	startangle = figureangle(centerx, centery, x1, y1);
@@ -390,29 +390,29 @@ void io_hparc(INTBIG centerx, INTBIG centery, INTBIG x1, INTBIG y1, INTBIG x2,
 		amt = (startangle - endangle + 3600 + 5) / 10;
 	io_hppenselect(color);
 	io_hpmove(x1, y1);
-	io_hpcmd("PD;");
-	(void)sprintf(buff, "AA %ld %ld %ld;", centerx, centery, -amt);
+	io_hpcmd(x_("PD;"));
+	(void)esnprintf(buff, MAXSTR, x_("AA %ld %ld %ld;"), centerx, centery, -amt);
 	io_hpcmd(buff);
-	io_hpcmd("PU;");
+	io_hpcmd(x_("PU;"));
 }
 
 void io_hpcircle(INTBIG atx, INTBIG aty, INTBIG ex, INTBIG ey, INTBIG color)
 {
-	char buff[MAXSTR];
+	CHAR buff[MAXSTR];
 	INTBIG radius;
 
 	radius = computedistance(atx, aty, ex, ey);
 	io_hppenselect(color);
 	io_hpmove(atx, aty);
-	io_hpcmd("PD;");
-	(void)sprintf(buff, "CI %ld;", radius);
+	io_hpcmd(x_("PD;"));
+	(void)esnprintf(buff, MAXSTR, x_("CI %ld;"), radius);
 	io_hpcmd(buff);
-	io_hpcmd("PU;");
+	io_hpcmd(x_("PU;"));
 }
 
 void io_hpdisc(INTBIG atx, INTBIG aty, INTBIG ex, INTBIG ey, GRAPHICS *desc)
 {
-	char buff[MAXSTR];
+	CHAR buff[MAXSTR];
 	INTBIG radius;
 	INTBIG cindex, ftype, fangle, fdist, color;
 
@@ -424,23 +424,23 @@ void io_hpdisc(INTBIG atx, INTBIG aty, INTBIG ex, INTBIG ey, GRAPHICS *desc)
 
 	radius = computedistance(atx, aty, ex, ey);
 	io_hppenselect(color);
-	(void)sprintf(buff, "FT %ld,%ld,%ld;", ftype, fdist, fangle);
+	(void)esnprintf(buff, MAXSTR, x_("FT %ld,%ld,%ld;"), ftype, fdist, fangle);
 	io_hpcmd(buff);
 
 	io_hpmove(atx, aty);
-	io_hpcmd("PD;");
-	io_hpcmd("PM;");
-	(void)sprintf(buff, "CI %ld;", radius);
+	io_hpcmd(x_("PD;"));
+	io_hpcmd(x_("PM;"));
+	(void)esnprintf(buff, MAXSTR, x_("CI %ld;"), radius);
 	io_hpcmd(buff);
-	io_hpcmd("PM2;");
-	if (ftype != 0) io_hpcmd("FP;");
-	if (ftype != 1) io_hpcmd("EP;");
-	io_hpcmd("PU;");
+	io_hpcmd(x_("PM2;"));
+	if (ftype != 0) io_hpcmd(x_("FP;"));
+	if (ftype != 1) io_hpcmd(x_("EP;"));
+	io_hpcmd(x_("PU;"));
 }
 
 void io_hpfilledpolygon(INTBIG *xlist, INTBIG *ylist, INTBIG count, INTBIG color)
 {
-	char buff[MAXSTR];
+	CHAR buff[MAXSTR];
 	INTBIG cindex, ftype, fangle, fdist, i;
 	INTBIG firstx, firsty;
 
@@ -451,27 +451,27 @@ void io_hpfilledpolygon(INTBIG *xlist, INTBIG *ylist, INTBIG count, INTBIG color
 	fdist = pen_color_table[cindex].fdist;
 
 	io_hppenselect(color);	/* color */
-	(void)sprintf(buff, "FT %ld,%ld,%ld;", ftype, fdist, fangle);
+	(void)esnprintf(buff, MAXSTR, x_("FT %ld,%ld,%ld;"), ftype, fdist, fangle);
 	io_hpcmd(buff);
 
 	firstx = xlist[0];		/* save the end point */
 	firsty = ylist[0];
 	io_hpmove(firstx, firsty);	/* move to the start */
-	io_hpcmd("PM;");
+	io_hpcmd(x_("PM;"));
 	for(i=1; i<count; i++) io_hpdraw(xlist[i], ylist[i]);
 	io_hpdraw(firstx, firsty);	/* close the polygon */
 
-	io_hpcmd("PM2;");
-	if (ftype != 0) io_hpcmd("FP;");
-	if (ftype != 1) io_hpcmd("EP;");
+	io_hpcmd(x_("PM2;"));
+	if (ftype != 0) io_hpcmd(x_("FP;"));
+	if (ftype != 1) io_hpcmd(x_("EP;"));
 }
 
 void io_hptext(INTBIG type, INTBIG xl, INTBIG xh, INTBIG yl, INTBIG yh, INTBIG size,
-	char *text, INTBIG color)
+	CHAR *text, INTBIG color)
 {
-	char s[MAXSTR];
+	CHAR s[MAXSTR];
 
-	(void)sprintf(s, "SI %f,%f;", size*0.02f/1.3f, size*0.02f);
+	(void)esnprintf(s, MAXSTR, x_("SI %f,%f;"), size*0.02f/1.3f, size*0.02f);
 	io_hpcmd(s);
 	io_hppenselect(color);
 
@@ -479,44 +479,44 @@ void io_hptext(INTBIG type, INTBIG xl, INTBIG xh, INTBIG yl, INTBIG yh, INTBIG s
 	{
 		case TEXTBOTLEFT:
 			io_hpmove(xl, yl);
-			io_hpcmd("LO1;");
+			io_hpcmd(x_("LO1;"));
 			break;
 		case TEXTLEFT:
 			io_hpmove(xl, (yl+yh)/2);
-			io_hpcmd("LO2;");
+			io_hpcmd(x_("LO2;"));
 			break;
 		case TEXTTOPLEFT:
 			io_hpmove(xh, yl);
-			io_hpcmd("LO3;");
+			io_hpcmd(x_("LO3;"));
 			break;
 		case TEXTBOT:
 			io_hpmove((xl+xh)/2, yl);
-			io_hpcmd("LO4;");
+			io_hpcmd(x_("LO4;"));
 			break;
 		case TEXTCENT:
 		case TEXTBOX:
 			io_hpmove((xl+xh)/2, (yl+yh)/2);
-			io_hpcmd("LO5;");
+			io_hpcmd(x_("LO5;"));
 			break;
 		case TEXTTOP:
 			io_hpmove((xl+xh)/2, yh);
-			io_hpcmd("LO6;");
+			io_hpcmd(x_("LO6;"));
 			break;
 		case TEXTBOTRIGHT:
 			io_hpmove(xh, yl);
-			io_hpcmd("LO7;");
+			io_hpcmd(x_("LO7;"));
 			break;
 		case TEXTRIGHT:
 			io_hpmove(xh, (yl+yh)/2);
-			io_hpcmd("LO8;");
+			io_hpcmd(x_("LO8;"));
 			break;
 		case TEXTTOPRIGHT:
 			io_hpmove(xh, yh);
-			io_hpcmd("LO9;");
+			io_hpcmd(x_("LO9;"));
 			break;
 	}
 
-	(void)sprintf(s, "LB %s\003", text);
+	(void)esnprintf(s, MAXSTR, x_("LB %s\003"), text);
 	io_hpcmd(s);
 }
 
@@ -556,44 +556,44 @@ void io_hptext(INTBIG type, INTBIG xl, INTBIG xh, INTBIG yl, INTBIG yh, INTBIG s
  *
  *   Color	Pen#	Line	Fill	Dist	Angle
  */
-static char *io_hppendata[] =
+static CHAR *io_hppendata[] =
 {
-	"0000	0	0	0	0	0	no color ",
-	"0010	4	0	3	500	0	transparent color 1 (blue)",
-	"0020	3	0	3	500	30	transparent color 2 (red)",
-	"0040	5	0	3	500	60	transparent color 3 (green)",
-	"0100	7	0	3	500	90	transparent color 4 (purple)",
-	"0200	2	0	3	500	120	transparent color 5 (yellow)",
-	"0004	0	0	0	0	0	white",
-	"0014	1	0	1	0	0	black ",
-	"0024	3	0	1	0	0	red ",
-	"0034	4	0	1	0	0	blue",
-	"0044	5	0	1	0	0	green",
-	"0054	4	2	1	0	0	cyan",
-	"0064	8	0	1	0	0	magenta",
-	"0074	2	0	1	0	0	yellow",
-	"0104	1	0	0	0	0	facet and port names",
-	"0114	1	0	0	0	0	facet outline",
-	"0124	0	0	0	0	0	window border color - never used",
-	"0134	0	0	0	0	0	highlighted window border color - never used",
-	"0144	0	0	0	0	0	menu border color - never used",
-	"0154	0	0	0	0	0	highlighted menu border color - never used",
-	"0164	0	0	0	0	0	menu text color - never used",
-	"0174	0	0	0	0	0	menu glyph color - never used",
-	"0204	0	0	0	0	0	cursor color - never used",
-	"0214	1	3	1	0	0	gray",
-	"0224	6	0	1	0	0	orange",
-	"0234	7	4	1	0	0	purple",
-	"0244	7	0	1	0	0	brown",
-	"0254	1	2	1	0	0	light gray",
-	"0264	1	4	1	0	0	dark gray",
-	"0274	3	0	1	0	0	light red",
-	"0304	3	0	1	0	0	dark red",
-	"0314	5	0	1	0	0	light green",
-	"0324	5	0	1	0	0	dark green",
-	"0334	4	4	1	0	0	light blue",
-	"0344	4	0	1	0	0	dark blue",
-	(char *)0
+	x_("0000	0	0	0	0	0	no color "),
+	x_("0004	1	0	3	300	0	transparent color 1 (blue)"),
+	x_("0010	2	0	3	300	30	transparent color 2 (red)"),
+	x_("0020	3	0	3	300	60	transparent color 3 (green)"),
+	x_("0040	4	0	3	300	90	transparent color 4 (purple)"),
+	x_("0100	5	0	3	300	120	transparent color 5 (yellow)"),
+	x_("0002	0	0	0	0	0	white"),
+	x_("0006	6	0	1	0	0	black "),
+	x_("0012	7	0	1	0	0	red "),
+	x_("0016	8	0	1	0	0	blue"),
+	x_("0022	9	0	1	0	0	green"),
+	x_("0026	10	2	1	0	0	cyan"),
+	x_("0032	11	0	1	0	0	magenta"),
+	x_("0036	12	0	1	0	0	yellow"),
+	x_("0042	13	0	0	0	0	facet and port names"),
+	x_("0046	1	0	0	0	0	facet outline"),
+	x_("0052	0	0	0	0	0	window border color - never used"),
+	x_("0056	0	0	0	0	0	highlighted window border color - never used"),
+	x_("0062	0	0	0	0	0	menu border color - never used"),
+	x_("0066	0	0	0	0	0	highlighted menu border color - never used"),
+	x_("0072	0	0	0	0	0	menu text color - never used"),
+	x_("0076	0	0	0	0	0	menu glyph color - never used"),
+	x_("0102	0	0	0	0	0	cursor color - never used"),
+	x_("0106	15	3	1	0	0	gray"),
+	x_("0112	16	0	1	0	0	orange"),
+	x_("0116	17	4	1	0	0	purple"),
+	x_("0122	18	0	1	0	0	brown"),
+	x_("0126	19	2	1	0	0	light gray"),
+	x_("0132	20	4	1	0	0	dark gray"),
+	x_("0136	21	0	1	0	0	light red"),
+	x_("0142	22	0	1	0	0	dark red"),
+	x_("0146	23	0	1	0	0	light green"),
+	x_("0152	24	0	1	0	0	dark green"),
+	x_("0156	25	4	1	0	0	light blue"),
+	x_("0162	26	0	1	0	0	dark blue"),
+	(CHAR *)0
 };
 
 /*
@@ -602,7 +602,7 @@ static char *io_hppendata[] =
  */
 void io_hpparsepenfile(void)
 {
-	char *pt;
+	CHAR *pt;
 	INTBIG in_color, in_pnum, in_ltype, in_ftype, in_fdist, in_fangle, i;
 
 	for(i=0; i<256; i++)
@@ -627,6 +627,7 @@ void io_hpparsepenfile(void)
 		while (*pt == ' ' || *pt == '\t') pt++;
 		if (*pt == 0) continue;
 		in_pnum = myatoi(pt);
+in_pnum = in_color;
 
 		/* skip to type field */
 		while (*pt != 0 && *pt != ' ' && *pt != '\t') pt++;
@@ -691,7 +692,7 @@ INTBIG io_hpchoosecolorentry(INTBIG c)
  */
 void io_hppenselect(INTBIG color)
 {
-	char pbuff[10];
+	CHAR pbuff[10];
 	INTBIG desired_pen, line_type, cindex;
 
 	cindex = io_hpchoosecolorentry(color);
@@ -704,7 +705,7 @@ void io_hppenselect(INTBIG color)
 	/* select new pen, pen 0 returns pen to carousel and does not get new pen */
 	if (desired_pen != io_hpcurrent_pen_color)
 	{
-		(void)sprintf(pbuff, "SP%ld;", desired_pen);
+		(void)esnprintf(pbuff, 10, x_("SP%ld;"), desired_pen);
 		io_hpcmd(pbuff);
 		io_hpcurrent_pen_color = desired_pen;
 	}
@@ -712,8 +713,8 @@ void io_hppenselect(INTBIG color)
 	/* set line type, line type 0 defaults to solid */
 	if (line_type != io_hpcurrent_line_type)
 	{
-		if (line_type == 0) (void)sprintf(pbuff, "LT;"); else
-			(void)sprintf(pbuff, "LT%ld;", line_type);
+		if (line_type == 0) (void)esnprintf(pbuff, 10, x_("LT;")); else
+			(void)esnprintf(pbuff, 10, x_("LT%ld;"), line_type);
 		io_hpcurrent_line_type = line_type;
 		io_hpcmd(pbuff);
 	}
@@ -728,9 +729,9 @@ void io_hppenselect(INTBIG color)
  */
 void io_hpmove(INTBIG x, INTBIG y)
 {
-	char buff[MAXSTR];
+	CHAR buff[MAXSTR];
 
-	(void)sprintf(buff, "PU%ld,%ld;", x, y);
+	(void)esnprintf(buff, MAXSTR, x_("PU%ld,%ld;"), x, y);
 	io_hpcmd(buff);
 }
 
@@ -741,14 +742,14 @@ void io_hpmove(INTBIG x, INTBIG y)
  */
 void io_hpdraw(INTBIG x, INTBIG y)
 {
-	char buff[MAXSTR];
+	CHAR buff[MAXSTR];
 
-	(void)sprintf(buff, "PD%ld,%ld ", x, y);
+	(void)esnprintf(buff, MAXSTR, x_("PD%ld,%ld "), x, y);
 	io_hpcmd(buff);
 }
 
 /* routine to send a command to the plotter */
-void io_hpcmd(char string[])
+void io_hpcmd(CHAR string[])
 {
-	(void)xprintf(io_hpout, "%s\n", string);
+	(void)xprintf(io_hpout, x_("%s\n"), string);
 }
