@@ -67,7 +67,7 @@ LEFPATH *io_leffreepath = NOLEFPATH;
 
 static INTBIG  io_leffilesize;
 static INTBIG  io_leflineno;
-static char    io_lefline[MAXLINE];
+static CHAR    io_lefline[MAXLINE];
 static INTBIG  io_leflinepos;
        VIADEF *io_leffirstviadef = NOVIADEF;
 static void   *io_lefprogressdialog;
@@ -75,20 +75,20 @@ static void   *io_lefprogressdialog;
 /* prototypes for local routines */
 static void       io_leffreepaths(LEFPATH *firstlp);
 static ARCPROTO  *io_lefgetarc(INTBIG afunc);
-static char      *io_lefgetkeyword(FILE *f);
+static CHAR      *io_lefgetkeyword(FILE *f);
 static NODEPROTO *io_lefgetnode(INTBIG lfunc);
-static BOOLEAN    io_lefignoretosemicolon(FILE *f, char *command);
+static BOOLEAN    io_lefignoretosemicolon(FILE *f, CHAR *command);
 static void       io_lefkillpath(LEFPATH *lp);
 static LEFPATH   *io_lefnewpath(void);
-static PORTPROTO *io_lefnewport(NODEPROTO *facet, NODEINST *ni, PORTPROTO *pp, char *thename);
-static void       io_lefparselayer(char *layername, INTBIG *arcfunc, INTBIG *layerfunc);
+static PORTPROTO *io_lefnewport(NODEPROTO *facet, NODEINST *ni, PORTPROTO *pp, CHAR *thename);
+static void       io_lefparselayer(CHAR *layername, INTBIG *arcfunc, INTBIG *layerfunc);
 static BOOLEAN    io_lefreadfile(FILE *f, LIBRARY *lib);
 static BOOLEAN    io_lefreadlayer(FILE *f, LIBRARY *lib);
 static BOOLEAN    io_lefreadmacro(FILE *f, LIBRARY *lib);
 static BOOLEAN    io_lefreadvia(FILE *f, LIBRARY *lib);
 static BOOLEAN    io_lefreadobs(FILE *f, NODEPROTO *facet);
 static BOOLEAN    io_lefreadpin(FILE *f, NODEPROTO *facet);
-static BOOLEAN    io_lefreadport(FILE *f, NODEPROTO *facet, char *portname, INTBIG portbits);
+static BOOLEAN    io_lefreadport(FILE *f, NODEPROTO *facet, CHAR *portname, INTBIG portbits);
 static void       io_leffreevias(void);
 
 /*
@@ -103,10 +103,10 @@ BOOLEAN io_readleflibrary(LIBRARY *lib)
 {
 	FILE *fp;
 	REGISTER BOOLEAN ret;
-	char *filename;
+	CHAR *filename;
 
 	/* open the file */
-	fp = xopen(lib->libfile, io_filetypelef, "", &filename);
+	fp = xopen(lib->libfile, io_filetypelef, x_(""), &filename);
 	if (fp == NULL)
 	{
 		ttyputerr(_("File %s not found"), lib->libfile);
@@ -148,8 +148,8 @@ void io_leffreevias(void)
 	{
 		vd = io_leffirstviadef;
 		io_leffirstviadef = io_leffirstviadef->nextviadef;
-		efree((char *)vd->vianame);
-		efree((char *)vd);
+		efree((CHAR *)vd->vianame);
+		efree((CHAR *)vd);
 	}
 }
 
@@ -158,22 +158,22 @@ void io_leffreevias(void)
  */
 BOOLEAN io_lefreadfile(FILE *f, LIBRARY *lib)
 {
-	REGISTER char *key;
+	REGISTER CHAR *key;
 
 	for(;;)
 	{
 		/* get the next keyword */
 		key = io_lefgetkeyword(f);
 		if (key == 0) break;
-		if (namesame(key, "LAYER") == 0)
+		if (namesame(key, x_("LAYER")) == 0)
 		{
 			if (io_lefreadlayer(f, lib)) return(TRUE);
 		}
-		if (namesame(key, "MACRO") == 0)
+		if (namesame(key, x_("MACRO")) == 0)
 		{
 			if (io_lefreadmacro(f, lib)) return(TRUE);
 		}
-		if (namesame(key, "VIA") == 0)
+		if (namesame(key, x_("VIA")) == 0)
 		{
 			if (io_lefreadvia(f, lib)) return(TRUE);
 		}
@@ -181,16 +181,19 @@ BOOLEAN io_lefreadfile(FILE *f, LIBRARY *lib)
 	return(FALSE);
 }
 
-void io_lefparselayer(char *layername, INTBIG *arcfunc, INTBIG *layerfunc)
+void io_lefparselayer(CHAR *layername, INTBIG *arcfunc, INTBIG *layerfunc)
 {
-	REGISTER INTBIG laynum;
+	REGISTER INTBIG laynum, j;
 
 	*arcfunc = APUNKNOWN;
 	*layerfunc = LFUNKNOWN;
 
-	if (namesamen(layername, "METAL", 5) == 0)
+	j = 0;
+	if (namesamen(layername, x_("METAL"), 5) == 0) j = 5; else
+		if (namesamen(layername, x_("MET"), 3) == 0) j = 3;
+	if (j != 0)
 	{
-		laynum = atoi(&layername[5]);
+		laynum = eatoi(&layername[j]);
 		switch (laynum)
 		{
 			case 1:  *arcfunc = APMETAL1;   *layerfunc = LFMETAL1;   break;
@@ -209,9 +212,9 @@ void io_lefparselayer(char *layername, INTBIG *arcfunc, INTBIG *layerfunc)
 		return;
 	}
 
-	if (namesamen(layername, "POLY", 4) == 0)
+	if (namesamen(layername, x_("POLY"), 4) == 0)
 	{
-		laynum = atoi(&layername[4]);
+		laynum = eatoi(&layername[4]);
 		switch (laynum)
 		{
 			case 1: *arcfunc = APPOLY1;   *layerfunc = LFPOLY1;   break;
@@ -221,35 +224,36 @@ void io_lefparselayer(char *layername, INTBIG *arcfunc, INTBIG *layerfunc)
 		return;
 	}
 
-	if (namesame(layername, "PDIFF") == 0)
+	if (namesame(layername, x_("PDIFF")) == 0)
 	{
 		*arcfunc = APDIFFP;
 		*layerfunc = LFDIFF | LFPTYPE;
 		return;
 	}
-	if (namesame(layername, "NDIFF") == 0)
+	if (namesame(layername, x_("NDIFF")) == 0)
 	{
 		*arcfunc = APDIFFN;
 		*layerfunc = LFDIFF | LFNTYPE;
 		return;
 	}
-	if (namesame(layername, "DIFF") == 0)
+	if (namesame(layername, x_("DIFF")) == 0)
 	{
 		*arcfunc = APDIFF;
 		*layerfunc = LFDIFF;
 		return;
 	}
 
-	if (namesame(layername, "CONT") == 0)
+	if (namesame(layername, x_("CONT")) == 0)
 	{
 		*layerfunc = LFCONTACT1;
 		return;
 	}
-	if (namesamen(layername, "VIA", 3) == 0)
+	if (namesamen(layername, x_("VIA"), 3) == 0)
 	{
-		laynum = atoi(&layername[3]);
+		laynum = eatoi(&layername[3]);
 		switch (laynum)
 		{
+			case 0:
 			case 1:
 			case 12: *layerfunc = LFCONTACT2;   break;
 
@@ -264,14 +268,29 @@ void io_lefparselayer(char *layername, INTBIG *arcfunc, INTBIG *layerfunc)
 
 			case 5:
 			case 56: *layerfunc = LFCONTACT6;   break;
+
+			case 6:
+			case 67: *layerfunc = LFCONTACT7;   break;
+
+			case 7:
+			case 78: *layerfunc = LFCONTACT8;   break;
+
+			case 8:
+			case 89: *layerfunc = LFCONTACT9;   break;
+
+			case 9:  *layerfunc = LFCONTACT10;  break;
+
+			case 10: *layerfunc = LFCONTACT11;  break;
+
+			case 11: *layerfunc = LFCONTACT12;  break;
 		}
 	}
 }
 
 BOOLEAN io_lefreadlayer(FILE *f, LIBRARY *lib)
 {
-	REGISTER char *layername, *key;
-	char curkey[200];
+	REGISTER CHAR *layername, *key;
+	CHAR curkey[200];
 	REGISTER INTBIG defwidth;
 	INTBIG afunc, layerfunc;
 	REGISTER ARCPROTO *ap;
@@ -300,13 +319,13 @@ BOOLEAN io_lefreadlayer(FILE *f, LIBRARY *lib)
 			return(TRUE);
 		}
 
-		if (namesame(key, "END") == 0)
+		if (namesame(key, x_("END")) == 0)
 		{
 			key = io_lefgetkeyword(f);
 			break;
 		}
 
-		if (namesame(key, "WIDTH") == 0)
+		if (namesame(key, x_("WIDTH")) == 0)
 		{
 			key = io_lefgetkeyword(f);
 			if (key == 0)
@@ -314,21 +333,21 @@ BOOLEAN io_lefreadlayer(FILE *f, LIBRARY *lib)
 				ttyputerr(_("EOF reading WIDTH"));
 				return(TRUE);
 			}
-			v = (float)atof(key);
+			v = (float)eatof(key);
 			defwidth = scalefromdispunit(v, DISPUNITMIC);
 			if (ap != NOARCPROTO)
 			{
-				setval((INTBIG)ap, VARCPROTO, "IO_lef_width", defwidth, VINTEGER);
+				setval((INTBIG)ap, VARCPROTO, x_("IO_lef_width"), defwidth, VINTEGER);
 			}
-			if (io_lefignoretosemicolon(f, "WIDTH")) return(TRUE);
+			if (io_lefignoretosemicolon(f, x_("WIDTH"))) return(TRUE);
 			continue;
 		}
 
-		if (namesame(key, "TYPE") == 0 || namesame(key, "SPACING") == 0 ||
-			namesame(key, "PITCH") == 0 || namesame(key, "DIRECTION") == 0 ||
-			namesame(key, "CAPACITANCE") == 0 || namesame(key, "RESISTANCE") == 0)
+		if (namesame(key, x_("TYPE")) == 0 || namesame(key, x_("SPACING")) == 0 ||
+			namesame(key, x_("PITCH")) == 0 || namesame(key, x_("DIRECTION")) == 0 ||
+			namesame(key, x_("CAPACITANCE")) == 0 || namesame(key, x_("RESISTANCE")) == 0)
 		{
-			strcpy(curkey, key);
+			estrcpy(curkey, key);
 			if (io_lefignoretosemicolon(f, curkey)) return(TRUE);
 			continue;
 		}
@@ -338,13 +357,13 @@ BOOLEAN io_lefreadlayer(FILE *f, LIBRARY *lib)
 
 BOOLEAN io_lefreadmacro(FILE *f, LIBRARY *lib)
 {
-	REGISTER char *cellname, *key;
-	REGISTER INTBIG ox, oy, blx, bhx, bly, bhy;
+	REGISTER CHAR *cellname, *key;
+	REGISTER INTBIG ox, oy, blx, bhx, bly, bhy, dx, dy;
 	INTBIG sx, sy;
 	float x, y;
 	REGISTER NODEPROTO *facet;
 	REGISTER NODEINST *ni;
-	char curkey[200];
+	CHAR curkey[200];
 	REGISTER void *infstr;
 
 	cellname = io_lefgetkeyword(f);
@@ -355,7 +374,7 @@ BOOLEAN io_lefreadmacro(FILE *f, LIBRARY *lib)
 	}
 	infstr = initinfstr();
 	addstringtoinfstr(infstr, cellname);
-	addstringtoinfstr(infstr, "{sk}");
+	addstringtoinfstr(infstr, x_("{sk}"));
 	cellname = returninfstr(infstr);
 	facet = us_newnodeproto(cellname, lib);
 	if (facet == NONODEPROTO)
@@ -374,22 +393,23 @@ BOOLEAN io_lefreadmacro(FILE *f, LIBRARY *lib)
 			return(TRUE);
 		}
 
-		if (namesame(key, "END") == 0)
+		if (namesame(key, x_("END")) == 0)
 		{
 			key = io_lefgetkeyword(f);
 			break;
 		}
 
-		if (namesame(key, "SOURCE") == 0 || namesame(key, "FOREIGN") == 0 ||
-			namesame(key, "SYMMETRY") == 0 || namesame(key, "SITE") == 0 ||
-			namesame(key, "CLASS") == 0 || namesame(key, "LEQ") == 0)
+		if (namesame(key, x_("SOURCE")) == 0 || namesame(key, x_("FOREIGN")) == 0 ||
+			namesame(key, x_("SYMMETRY")) == 0 || namesame(key, x_("SITE")) == 0 ||
+			namesame(key, x_("CLASS")) == 0 || namesame(key, x_("LEQ")) == 0 ||
+			namesame(key, x_("POWER")) == 0)
 		{
-			strcpy(curkey, key);
+			estrcpy(curkey, key);
 			if (io_lefignoretosemicolon(f, curkey)) return(TRUE);
 			continue;
 		}
 
-		if (namesame(key, "ORIGIN") == 0)
+		if (namesame(key, x_("ORIGIN")) == 0)
 		{
 			key = io_lefgetkeyword(f);
 			if (key == 0)
@@ -397,7 +417,7 @@ BOOLEAN io_lefreadmacro(FILE *f, LIBRARY *lib)
 				ttyputerr(_("EOF reading ORIGIN X"));
 				return(TRUE);
 			}
-			x = (float)atof(key);
+			x = (float)eatof(key);
 			ox = scalefromdispunit(x, DISPUNITMIC);
 
 			key = io_lefgetkeyword(f);
@@ -406,26 +426,37 @@ BOOLEAN io_lefreadmacro(FILE *f, LIBRARY *lib)
 				ttyputerr(_("EOF reading ORIGIN Y"));
 				return(TRUE);
 			}
-			y = (float)atof(key);
+			y = (float)eatof(key);
 			oy = scalefromdispunit(y, DISPUNITMIC);
-			if (io_lefignoretosemicolon(f, "ORIGIN")) return(TRUE);
+			if (io_lefignoretosemicolon(f, x_("ORIGIN"))) return(TRUE);
 
-			/* create the facet-center node */
-			defaultnodesize(gen_facetcenterprim, &sx, &sy);
-			blx = ox - sx/2;   bhx = blx + sx;
-			bly = oy - sy/2;   bhy = bly + sy;
-			ni = newnodeinst(gen_facetcenterprim, blx, bhx, bly, bhy, 0, 0, facet);
+			/* create or move the facet-center node */
+			for(ni = facet->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
+				if (ni->proto == gen_facetcenterprim) break;
 			if (ni == NONODEINST)
 			{
-				ttyputerr(_("Line %ld: Cannot create facet center node"), io_leflineno);
-				return(TRUE);
+				defaultnodesize(gen_facetcenterprim, &sx, &sy);
+				blx = ox - sx/2;   bhx = blx + sx;
+				bly = oy - sy/2;   bhy = bly + sy;
+				ni = newnodeinst(gen_facetcenterprim, blx, bhx, bly, bhy, 0, 0, facet);
+				if (ni == NONODEINST)
+				{
+					ttyputerr(_("Line %ld: Cannot create facet center node"), io_leflineno);
+					return(TRUE);
+				}
+				ni->userbits |= HARDSELECTN|NVISIBLEINSIDE;
+			} else
+			{
+				startobjectchange((INTBIG)ni, VNODEINST);
+				dx = ox - (ni->lowx + ni->highx) / 2;
+				dy = oy - (ni->lowy + ni->highy) / 2;
+				modifynodeinst(ni, dx, dy, dx, dy, 0, 0);
 			}
-			ni->userbits |= HARDSELECTN|NVISIBLEINSIDE;
 			endobjectchange((INTBIG)ni, VNODEINST);
 			continue;
 		}
 
-		if (namesame(key, "SIZE") == 0)
+		if (namesame(key, x_("SIZE")) == 0)
 		{
 			key = io_lefgetkeyword(f);
 			if (key == 0)
@@ -433,7 +464,7 @@ BOOLEAN io_lefreadmacro(FILE *f, LIBRARY *lib)
 				ttyputerr(_("EOF reading SIZE X"));
 				return(TRUE);
 			}
-			x = (float)atof(key);
+			x = (float)eatof(key);
 			sx = scalefromdispunit(x, DISPUNITMIC);
 
 			key = io_lefgetkeyword(f);
@@ -442,7 +473,7 @@ BOOLEAN io_lefreadmacro(FILE *f, LIBRARY *lib)
 				ttyputerr(_("EOF reading SIZE 'BY'"));
 				return(TRUE);
 			}
-			if (namesame(key, "BY") != 0)
+			if (namesame(key, x_("BY")) != 0)
 			{
 				ttyputerr(_("Line %ld: Expected 'by' in SIZE"), io_leflineno);
 				return(TRUE);
@@ -454,19 +485,19 @@ BOOLEAN io_lefreadmacro(FILE *f, LIBRARY *lib)
 				ttyputerr(_("EOF reading SIZE Y"));
 				return(TRUE);
 			}
-			y = (float)atof(key);
+			y = (float)eatof(key);
 			sy = scalefromdispunit(y, DISPUNITMIC);
-			if (io_lefignoretosemicolon(f, "SIZE")) return(TRUE);
+			if (io_lefignoretosemicolon(f, x_("SIZE"))) return(TRUE);
 			continue;
 		}
 
-		if (namesame(key, "PIN") == 0)
+		if (namesame(key, x_("PIN")) == 0)
 		{
 			if (io_lefreadpin(f, facet)) return(TRUE);
 			continue;
 		}
 
-		if (namesame(key, "OBS") == 0)
+		if (namesame(key, x_("OBS")) == 0)
 		{
 			if (io_lefreadobs(f, facet)) return(TRUE);
 			continue;
@@ -480,12 +511,13 @@ BOOLEAN io_lefreadmacro(FILE *f, LIBRARY *lib)
 
 BOOLEAN io_lefreadvia(FILE *f, LIBRARY *lib)
 {
-	REGISTER char *vianame, *key;
+	REGISTER CHAR *vianame, *key;
 	REGISTER INTBIG lx, hx, ly, hy, i, lay1found, lay2found;
 	INTBIG afunc, layerfunc;
 	NODEPROTO *np;
 	ARCPROTO *ap;
 	float v;
+	BOOLEAN ignoredefault;
 	REGISTER PORTPROTO *pp;
 	REGISTER VIADEF *vd;
 
@@ -503,31 +535,28 @@ BOOLEAN io_lefreadvia(FILE *f, LIBRARY *lib)
 	vd->nextviadef = io_leffirstviadef;
 	io_leffirstviadef = vd;
 
-	/* ignore the "DEFAULT" keyword */
-	key = io_lefgetkeyword(f);
-	if (key == 0) return(TRUE);
-	if (namesame(key, "DEFAULT") != 0)
-	{
-		ttyputerr(_("Expected 'DEFAULT' after VIA name"));
-		return(TRUE);
-	}
-
+	ignoredefault = TRUE;
 	for(;;)
 	{
 		/* get the next keyword */
 		key = io_lefgetkeyword(f);
 		if (key == 0) return(TRUE);
-		if (namesame(key, "END") == 0)
+		if (ignoredefault)
+		{
+			ignoredefault = FALSE;
+			if (namesame(key, x_("DEFAULT")) == 0) continue;
+		}
+		if (namesame(key, x_("END")) == 0)
 		{
 			key = io_lefgetkeyword(f);
 			break;
 		}
-		if (namesame(key, "RESISTANCE") == 0)
+		if (namesame(key, x_("RESISTANCE")) == 0)
 		{
 			if (io_lefignoretosemicolon(f, key)) return(TRUE);
 			continue;
 		}
-		if (namesame(key, "LAYER") == 0)
+		if (namesame(key, x_("LAYER")) == 0)
 		{
 			key = io_lefgetkeyword(f);
 			if (key == 0) return(TRUE);
@@ -542,37 +571,37 @@ BOOLEAN io_lefreadvia(FILE *f, LIBRARY *lib)
 				if (vd->lay1 == NOARCPROTO) vd->lay1 = ap; else
 					vd->lay2 = ap;
 			}
-			if (io_lefignoretosemicolon(f, "LAYER")) return(TRUE);
+			if (io_lefignoretosemicolon(f, x_("LAYER"))) return(TRUE);
 			continue;
 		}
-		if (namesame(key, "RECT") == 0)
+		if (namesame(key, x_("RECT")) == 0)
 		{
 			/* handle definition of a via rectangle */
 			key = io_lefgetkeyword(f);
 			if (key == 0) return(TRUE);
-			v = (float)atof(key);
+			v = (float)eatof(key);
 			lx = scalefromdispunit(v, DISPUNITMIC);
 
 			key = io_lefgetkeyword(f);
 			if (key == 0) return(TRUE);
-			v = (float)atof(key);
+			v = (float)eatof(key);
 			ly = scalefromdispunit(v, DISPUNITMIC);
 
 			key = io_lefgetkeyword(f);
 			if (key == 0) return(TRUE);
-			v = (float)atof(key);
+			v = (float)eatof(key);
 			hx = scalefromdispunit(v, DISPUNITMIC);
 
 			key = io_lefgetkeyword(f);
 			if (key == 0) return(TRUE);
-			v = (float)atof(key);
+			v = (float)eatof(key);
 			hy = scalefromdispunit(v, DISPUNITMIC);
 
 			/* accumulate largest layer size */
 			if (hx-lx > vd->sx) vd->sx = hx - lx;
 			if (hy-ly > vd->sy) vd->sy = hy - ly;
 
-			if (io_lefignoretosemicolon(f, "RECT")) return(TRUE);
+			if (io_lefignoretosemicolon(f, x_("RECT"))) return(TRUE);
 			continue;
 		}
 	}
@@ -597,9 +626,9 @@ BOOLEAN io_lefreadvia(FILE *f, LIBRARY *lib)
 
 BOOLEAN io_lefreadpin(FILE *f, NODEPROTO *facet)
 {
-	REGISTER char *key;
+	REGISTER CHAR *key;
 	REGISTER INTBIG portbits, usebits;
-	char curkey[200], pinname[200];
+	CHAR curkey[200], pinname[200];
 
 	/* get the pin name */
 	key = io_lefgetkeyword(f);
@@ -608,7 +637,7 @@ BOOLEAN io_lefreadpin(FILE *f, NODEPROTO *facet)
 		ttyputerr(_("EOF parsing PIN name"));
 		return(TRUE);
 	}
-	strcpy(pinname, key);
+	estrcpy(pinname, key);
 
 	portbits = usebits = 0;
 	for(;;)
@@ -620,21 +649,21 @@ BOOLEAN io_lefreadpin(FILE *f, NODEPROTO *facet)
 			return(TRUE);
 		}
 
-		if (namesame(key, "END") == 0)
+		if (namesame(key, x_("END")) == 0)
 		{
 			key = io_lefgetkeyword(f);
 			break;
 		}
 
-		if (namesame(key, "SHAPE") == 0 || namesame(key, "CAPACITANCE") == 0 ||
-			namesame(key, "ANTENNASIZE") == 0)
+		if (namesame(key, x_("SHAPE")) == 0 || namesame(key, x_("CAPACITANCE")) == 0 ||
+			namesame(key, x_("ANTENNASIZE")) == 0)
 		{
-			strcpy(curkey, key);
+			estrcpy(curkey, key);
 			if (io_lefignoretosemicolon(f, curkey)) return(TRUE);
 			continue;
 		}
 
-		if (namesame(key, "USE") == 0)
+		if (namesame(key, x_("USE")) == 0)
 		{
 			key = io_lefgetkeyword(f);
 			if (key == 0)
@@ -642,18 +671,18 @@ BOOLEAN io_lefreadpin(FILE *f, NODEPROTO *facet)
 				ttyputerr(_("EOF reading USE clause"));
 				return(TRUE);
 			}
-			if (namesame(key, "POWER") == 0) usebits = PWRPORT; else
-			if (namesame(key, "GROUND") == 0) usebits = GNDPORT; else
-			if (namesame(key, "CLOCK") == 0) usebits = CLKPORT; else
+			if (namesame(key, x_("POWER")) == 0) usebits = PWRPORT; else
+			if (namesame(key, x_("GROUND")) == 0) usebits = GNDPORT; else
+			if (namesame(key, x_("CLOCK")) == 0) usebits = CLKPORT; else
 			{
 				ttyputerr(_("Line %ld: Unknown USE keyword (%s)"),
 					io_leflineno, key);
 			}
-			if (io_lefignoretosemicolon(f, "USE")) return(TRUE);
+			if (io_lefignoretosemicolon(f, x_("USE"))) return(TRUE);
 			continue;
 		}
 
-		if (namesame(key, "DIRECTION") == 0)
+		if (namesame(key, x_("DIRECTION")) == 0)
 		{
 			key = io_lefgetkeyword(f);
 			if (key == 0)
@@ -661,18 +690,18 @@ BOOLEAN io_lefreadpin(FILE *f, NODEPROTO *facet)
 				ttyputerr(_("EOF reading DIRECTION clause"));
 				return(TRUE);
 			}
-			if (namesame(key, "INPUT") == 0) portbits = INPORT; else
-			if (namesame(key, "OUTPUT") == 0) portbits = OUTPORT; else
-			if (namesame(key, "INOUT") == 0) portbits = BIDIRPORT; else
+			if (namesame(key, x_("INPUT")) == 0) portbits = INPORT; else
+			if (namesame(key, x_("OUTPUT")) == 0) portbits = OUTPORT; else
+			if (namesame(key, x_("INOUT")) == 0) portbits = BIDIRPORT; else
 			{
 				ttyputerr(_("Line %ld: Unknown DIRECTION keyword (%s)"),
 					io_leflineno, key);
 			}
-			if (io_lefignoretosemicolon(f, "DIRECTION")) return(TRUE);
+			if (io_lefignoretosemicolon(f, x_("DIRECTION"))) return(TRUE);
 			continue;
 		}
 
-		if (namesame(key, "PORT") == 0)
+		if (namesame(key, x_("PORT")) == 0)
 		{
 			if (usebits != 0) portbits = usebits;
 			if (io_lefreadport(f, facet, pinname, portbits))
@@ -686,9 +715,9 @@ BOOLEAN io_lefreadpin(FILE *f, NODEPROTO *facet)
 	return(FALSE);
 }
 
-BOOLEAN io_lefreadport(FILE *f, NODEPROTO *facet, char *portname, INTBIG portbits)
+BOOLEAN io_lefreadport(FILE *f, NODEPROTO *facet, CHAR *portname, INTBIG portbits)
 {
-	REGISTER char *key;
+	REGISTER CHAR *key;
 	REGISTER INTBIG i, j, lx, hx, ly, hy, intx, inty, first,
 		intwidth, lastintx, lastinty, sea, cx, cy;
 	INTBIG afunc, layerfunc, sx, sy;
@@ -715,12 +744,12 @@ BOOLEAN io_lefreadport(FILE *f, NODEPROTO *facet, char *portname, INTBIG portbit
 			return(TRUE);
 		}
 
-		if (namesame(key, "END") == 0)
+		if (namesame(key, x_("END")) == 0)
 		{
 			break;
 		}
 
-		if (namesame(key, "LAYER") == 0)
+		if (namesame(key, x_("LAYER")) == 0)
 		{
 			key = io_lefgetkeyword(f);
 			if (key == 0)
@@ -732,11 +761,11 @@ BOOLEAN io_lefreadport(FILE *f, NODEPROTO *facet, char *portname, INTBIG portbit
 			if (afunc == APUNKNOWN) ap = NOARCPROTO; else
 				ap = io_lefgetarc(afunc);
 			plnp = io_lefgetnode(layerfunc);
-			if (io_lefignoretosemicolon(f, "LAYER")) return(TRUE);
+			if (io_lefignoretosemicolon(f, x_("LAYER"))) return(TRUE);
 			continue;
 		}
 
-		if (namesame(key, "WIDTH") == 0)
+		if (namesame(key, x_("WIDTH")) == 0)
 		{
 			key = io_lefgetkeyword(f);
 			if (key == 0)
@@ -744,13 +773,13 @@ BOOLEAN io_lefreadport(FILE *f, NODEPROTO *facet, char *portname, INTBIG portbit
 				ttyputerr(_("EOF reading WIDTH clause"));
 				return(TRUE);
 			}
-			width = (float)atof(key);
+			width = (float)eatof(key);
 			intwidth = scalefromdispunit(width, DISPUNITMIC);
-			if (io_lefignoretosemicolon(f, "WIDTH")) return(TRUE);
+			if (io_lefignoretosemicolon(f, x_("WIDTH"))) return(TRUE);
 			continue;
 		}
 
-		if (namesame(key, "RECT") == 0)
+		if (namesame(key, x_("RECT")) == 0)
 		{
 			if (plnp == NONODEPROTO)
 			{
@@ -763,7 +792,7 @@ BOOLEAN io_lefreadport(FILE *f, NODEPROTO *facet, char *portname, INTBIG portbit
 				ttyputerr(_("EOF reading RECT low X"));
 				return(TRUE);
 			}
-			x = (float)atof(key);
+			x = (float)eatof(key);
 			lx = scalefromdispunit(x, DISPUNITMIC);
 
 			key = io_lefgetkeyword(f);
@@ -772,7 +801,7 @@ BOOLEAN io_lefreadport(FILE *f, NODEPROTO *facet, char *portname, INTBIG portbit
 				ttyputerr(_("EOF reading RECT low Y"));
 				return(TRUE);
 			}
-			y = (float)atof(key);
+			y = (float)eatof(key);
 			ly = scalefromdispunit(y, DISPUNITMIC);
 
 			key = io_lefgetkeyword(f);
@@ -781,7 +810,7 @@ BOOLEAN io_lefreadport(FILE *f, NODEPROTO *facet, char *portname, INTBIG portbit
 				ttyputerr(_("EOF reading RECT high X"));
 				return(TRUE);
 			}
-			x = (float)atof(key);
+			x = (float)eatof(key);
 			hx = scalefromdispunit(x, DISPUNITMIC);
 
 			key = io_lefgetkeyword(f);
@@ -790,10 +819,10 @@ BOOLEAN io_lefreadport(FILE *f, NODEPROTO *facet, char *portname, INTBIG portbit
 				ttyputerr(_("EOF reading RECT high Y"));
 				return(TRUE);
 			}
-			y = (float)atof(key);
+			y = (float)eatof(key);
 			hy = scalefromdispunit(y, DISPUNITMIC);
 
-			if (io_lefignoretosemicolon(f, "RECT")) return(TRUE);
+			if (io_lefignoretosemicolon(f, x_("RECT"))) return(TRUE);
 
 			/* make the pin */
 			if (hx < lx) { j = hx;   hx = lx;   lx = j; }
@@ -816,7 +845,7 @@ BOOLEAN io_lefreadport(FILE *f, NODEPROTO *facet, char *portname, INTBIG portbit
 			continue;
 		}
 
-		if (namesame(key, "PATH") == 0)
+		if (namesame(key, x_("PATH")) == 0)
 		{
 			if (ap == NOARCPROTO)
 			{
@@ -831,8 +860,8 @@ BOOLEAN io_lefreadport(FILE *f, NODEPROTO *facet, char *portname, INTBIG portbit
 					ttyputerr(_("EOF reading PATH clause"));
 					return(TRUE);
 				}
-				if (strcmp(key, ";") == 0) break;
-				x = (float)atof(key);
+				if (estrcmp(key, x_(";")) == 0) break;
+				x = (float)eatof(key);
 
 				key = io_lefgetkeyword(f);
 				if (key == 0)
@@ -840,7 +869,7 @@ BOOLEAN io_lefreadport(FILE *f, NODEPROTO *facet, char *portname, INTBIG portbit
 					ttyputerr(_("EOF reading PATH clause"));
 					return(TRUE);
 				}
-				y = (float)atof(key);
+				y = (float)eatof(key);
 
 				/* plot this point */
 				intx = scalefromdispunit(x, DISPUNITMIC);
@@ -867,7 +896,7 @@ BOOLEAN io_lefreadport(FILE *f, NODEPROTO *facet, char *portname, INTBIG portbit
 			continue;
 		}
 
-		if (namesame(key, "VIA") == 0)
+		if (namesame(key, x_("VIA")) == 0)
 		{
 			/* get the coordinates */
 			key = io_lefgetkeyword(f);
@@ -876,7 +905,7 @@ BOOLEAN io_lefreadport(FILE *f, NODEPROTO *facet, char *portname, INTBIG portbit
 				ttyputerr(_("EOF reading VIA clause"));
 				return(TRUE);
 			}
-			x = (float)atof(key);
+			x = (float)eatof(key);
 			intx = scalefromdispunit(x, DISPUNITMIC);
 
 			key = io_lefgetkeyword(f);
@@ -885,25 +914,25 @@ BOOLEAN io_lefreadport(FILE *f, NODEPROTO *facet, char *portname, INTBIG portbit
 				ttyputerr(_("EOF reading VIA clause"));
 				return(TRUE);
 			}
-			y = (float)atof(key);
+			y = (float)eatof(key);
 			inty = scalefromdispunit(y, DISPUNITMIC);
 
 			/* find the proper via */
 			key = io_lefgetkeyword(f);
 			afunc1 = afunc2 = APUNKNOWN;
-			if (namesame(key, "via1") == 0)
+			if (namesame(key, x_("via1")) == 0)
 			{
 				afunc1 = APMETAL1;
 				afunc2 = APMETAL2;
-			} else if (namesame(key, "via2") == 0)
+			} else if (namesame(key, x_("via2")) == 0)
 			{
 				afunc1 = APMETAL2;
 				afunc2 = APMETAL3;
-			} else if (namesame(key, "via3") == 0)
+			} else if (namesame(key, x_("via3")) == 0)
 			{
 				afunc1 = APMETAL3;
 				afunc2 = APMETAL4;
-			} else if (namesame(key, "via4") == 0)
+			} else if (namesame(key, x_("via4")) == 0)
 			{
 				afunc1 = APMETAL4;
 				afunc2 = APMETAL5;
@@ -935,7 +964,7 @@ BOOLEAN io_lefreadport(FILE *f, NODEPROTO *facet, char *portname, INTBIG portbit
 					arcfunctionname(afunc2));
 				return(TRUE);
 			}
-			if (io_lefignoretosemicolon(f, "VIA")) return(TRUE);
+			if (io_lefignoretosemicolon(f, x_("VIA"))) return(TRUE);
 
 			/* create the via */
 			defaultnodesize(pin, &sx, &sy);
@@ -1042,11 +1071,11 @@ BOOLEAN io_lefreadport(FILE *f, NODEPROTO *facet, char *portname, INTBIG portbit
  * Routine to create a port called "thename" on port "pp" of node "ni" in facet "facet".
  * The name is modified if it already exists.
  */
-PORTPROTO *io_lefnewport(NODEPROTO *facet, NODEINST *ni, PORTPROTO *pp, char *thename)
+PORTPROTO *io_lefnewport(NODEPROTO *facet, NODEINST *ni, PORTPROTO *pp, CHAR *thename)
 {
 	REGISTER PORTPROTO *ppt;
-	REGISTER INTBIG i;
-	REGISTER char *newname, *portname;
+	REGISTER INTBIG i, leng;
+	REGISTER CHAR *newname, *portname;
 
 	portname = thename;
 	newname = 0;
@@ -1060,8 +1089,12 @@ PORTPROTO *io_lefnewport(NODEPROTO *facet, NODEINST *ni, PORTPROTO *pp, char *th
 		}
 
 		/* make space for modified name */
-		if (newname == 0) newname = (char *)emalloc(strlen(thename)+10, el_tempcluster);
-		sprintf(newname, "%s-%ld", thename, i);
+		if (newname == 0)
+		{
+			leng = estrlen(thename)+10;
+			newname = (CHAR *)emalloc(leng * SIZEOFCHAR, el_tempcluster);
+		}
+		esnprintf(newname, leng, x_("%s-%ld"), thename, i);
 		portname = newname;
 	}
 	if (newname != 0) efree(newname);
@@ -1070,7 +1103,7 @@ PORTPROTO *io_lefnewport(NODEPROTO *facet, NODEINST *ni, PORTPROTO *pp, char *th
 
 BOOLEAN io_lefreadobs(FILE *f, NODEPROTO *facet)
 {
-	REGISTER char *key;
+	REGISTER CHAR *key;
 	INTBIG lfunc, arcfunc;
 	REGISTER INTBIG lx, hx, ly, hy, j;
 	float x, y;
@@ -1087,9 +1120,9 @@ BOOLEAN io_lefreadobs(FILE *f, NODEPROTO *facet)
 			return(TRUE);
 		}
 
-		if (namesame(key, "END") == 0) break;
+		if (namesame(key, x_("END")) == 0) break;
 
-		if (namesame(key, "LAYER") == 0)
+		if (namesame(key, x_("LAYER")) == 0)
 		{
 			key = io_lefgetkeyword(f);
 			if (key == 0)
@@ -1105,11 +1138,11 @@ BOOLEAN io_lefreadobs(FILE *f, NODEPROTO *facet)
 			}
 			np = io_lefgetnode(lfunc);
 			if (np == NONODEPROTO) return(TRUE);
-			if (io_lefignoretosemicolon(f, "LAYER")) return(TRUE);
+			if (io_lefignoretosemicolon(f, x_("LAYER"))) return(TRUE);
 			continue;
 		}
 
-		if (namesame(key, "RECT") == 0)
+		if (namesame(key, x_("RECT")) == 0)
 		{
 			if (np == NONODEPROTO)
 			{
@@ -1122,7 +1155,7 @@ BOOLEAN io_lefreadobs(FILE *f, NODEPROTO *facet)
 				ttyputerr(_("EOF reading RECT low X"));
 				return(TRUE);
 			}
-			x = (float)atof(key);
+			x = (float)eatof(key);
 			lx = scalefromdispunit(x, DISPUNITMIC);
 
 			key = io_lefgetkeyword(f);
@@ -1131,7 +1164,7 @@ BOOLEAN io_lefreadobs(FILE *f, NODEPROTO *facet)
 				ttyputerr(_("EOF reading RECT low Y"));
 				return(TRUE);
 			}
-			y = (float)atof(key);
+			y = (float)eatof(key);
 			ly = scalefromdispunit(y, DISPUNITMIC);
 
 			key = io_lefgetkeyword(f);
@@ -1140,7 +1173,7 @@ BOOLEAN io_lefreadobs(FILE *f, NODEPROTO *facet)
 				ttyputerr(_("EOF reading RECT high X"));
 				return(TRUE);
 			}
-			x = (float)atof(key);
+			x = (float)eatof(key);
 			hx = scalefromdispunit(x, DISPUNITMIC);
 
 			key = io_lefgetkeyword(f);
@@ -1149,10 +1182,10 @@ BOOLEAN io_lefreadobs(FILE *f, NODEPROTO *facet)
 				ttyputerr(_("EOF reading RECT high Y"));
 				return(TRUE);
 			}
-			y = (float)atof(key);
+			y = (float)eatof(key);
 			hy = scalefromdispunit(y, DISPUNITMIC);
 
-			if (io_lefignoretosemicolon(f, "RECT")) return(TRUE);
+			if (io_lefignoretosemicolon(f, x_("RECT"))) return(TRUE);
 
 			/* make the pin */
 			if (hx < lx) { j = hx;   hx = lx;   lx = j; }
@@ -1170,9 +1203,9 @@ BOOLEAN io_lefreadobs(FILE *f, NODEPROTO *facet)
 	return(FALSE);
 }
 
-BOOLEAN io_lefignoretosemicolon(FILE *f, char *command)
+BOOLEAN io_lefignoretosemicolon(FILE *f, CHAR *command)
 {
-	REGISTER char *key;
+	REGISTER CHAR *key;
 
 	/* ignore up to the next semicolon */
 	for(;;)
@@ -1183,14 +1216,14 @@ BOOLEAN io_lefignoretosemicolon(FILE *f, char *command)
 			ttyputerr(_("EOF parsing %s"), command);
 			return(TRUE);
 		}
-		if (strcmp(key, ";") == 0) break;
+		if (estrcmp(key, x_(";")) == 0) break;
 	}
 	return(FALSE);
 }
 
-char *io_lefgetkeyword(FILE *f)
+CHAR *io_lefgetkeyword(FILE *f)
 {
-	REGISTER char *ret;
+	REGISTER CHAR *ret;
 	REGISTER INTBIG filepos, i;
 
 	/* keep reading from file until something is found on a line */
