@@ -44,16 +44,16 @@
 static struct
 {
 	INTBIG arcfunct;
-	char *portname;
+	CHAR *portname;
 } io_lports[] =
 {
-	{APMETAL1, "MET1"},
-	{APMETAL2, "MET2"},
-	{APPOLY1,  "POLY"},
-	{APDIFFP,  "PDIFF"},
-	{APDIFFN,  "NDIFF"},
-	{APDIFFS,  "NWELL"},
-	{APDIFFW,  "PWELL"},
+	{APMETAL1, x_("MET1")},
+	{APMETAL2, x_("MET2")},
+	{APPOLY1,  x_("POLY")},
+	{APDIFFP,  x_("PDIFF")},
+	{APDIFFN,  x_("NDIFF")},
+	{APDIFFS,  x_("NWELL")},
+	{APDIFFW,  x_("PWELL")},
 	{0, NULL}  /* 0 */
 };
 
@@ -61,26 +61,26 @@ static struct
 static struct
 {
 	INTBIG arcfunct[3];
-	char *contactname;
+	CHAR *contactname;
 } io_lcontacts[] =
 {
-	{{APMETAL1, APDIFFP,  0}, "MPDIFF"},
-	{{APMETAL1, APDIFFN,  0}, "MNDIFF"},
-	{{APMETAL1, APPOLY1,  0}, "MPOLY"},
-	{{APMETAL1, APMETAL2, 0}, "M1M2"},
+	{{APMETAL1, APDIFFP,  0}, x_("MPDIFF")},
+	{{APMETAL1, APDIFFN,  0}, x_("MNDIFF")},
+	{{APMETAL1, APPOLY1,  0}, x_("MPOLY")},
+	{{APMETAL1, APMETAL2, 0}, x_("M1M2")},
 	{{0,0,0}, NULL}  /* 0 */
 };
 
 /* prototypes for local routines */
 static INTBIG io_l_writefacet(NODEPROTO*);
-static char *io_l_name(NODEINST*);
-static char *io_l_fixname(char*);
+static CHAR *io_l_name(NODEINST*);
+static CHAR *io_l_fixname(CHAR*);
 static INTBIG io_l_nodetype(NODEINST*);
 
 BOOLEAN io_writellibrary(LIBRARY *lib)
 {
-	char file[100], *truename;
-	REGISTER char *name;
+	CHAR file[100], *truename;
+	REGISTER CHAR *name;
 	REGISTER NODEPROTO *np;
 	REGISTER LIBRARY *olib;
 
@@ -90,8 +90,8 @@ BOOLEAN io_writellibrary(LIBRARY *lib)
 		ttyputerr(_("Must be editing a facet to generate L output"));
 		return(TRUE);
 	}
-	(void)strcpy(file, lib->curnodeproto->cell->cellname);
-	(void)strcat(file, ".L");
+	(void)estrcpy(file, lib->curnodeproto->cell->cellname);
+	(void)estrcat(file, x_(".L"));
 	name = truepath(file);
 	io_fileout = xcreate(name, io_filetypel, _("L File"), &truename);
 	if (io_fileout == NULL)
@@ -100,7 +100,7 @@ BOOLEAN io_writellibrary(LIBRARY *lib)
 		return(TRUE);
 	}
 
-	xprintf(io_fileout, "L:: TECH ANY\n");
+	xprintf(io_fileout, x_("L:: TECH ANY\n"));
 
 	/* write the L */
 	for(olib = el_curlib; olib != NOLIBRARY; olib = olib->nextlibrary)
@@ -131,8 +131,8 @@ INTBIG io_l_writefacet(NODEPROTO *np)
 	REGISTER PORTARCINST *pi, *opi;
 	REGISTER INTBIG i, j, k, l, r, thisend, thatend, tot, nature, enature, ot, segcount, backannotate;
 	REGISTER INTBIG segdist;
-	REGISTER char *type, *lay, *dir, *lastdir;
-	char line[50];
+	REGISTER CHAR *type, *lay, *dir, *lastdir;
+	CHAR line[50];
 	INTBIG xpos, ypos, len, wid, lx, hx, ly, hy;
 	REGISTER ARCPROTO **aplist;
 
@@ -159,18 +159,18 @@ INTBIG io_l_writefacet(NODEPROTO *np)
 	np->temp1 = 1;
 
 	/* make sure that all nodes have names on them */
-	if (asktool(net_tool, "name-nodes", (INTBIG)np) != 0) backannotate++;
+	if (asktool(net_tool, x_("name-nodes"), (INTBIG)np) != 0) backannotate++;
 
 	/* write the facet header */
-	xprintf(io_fileout, "\n");
-	if (np->cellview == el_layoutview) xprintf(io_fileout, "LAYOUT ");
-	if (np->cellview == el_schematicview) xprintf(io_fileout, "SCHEMATIC ");
-	if (np->cellview == el_iconview) xprintf(io_fileout, "ICON ");
-	if (np->cellview == el_skeletonview) xprintf(io_fileout, "BBOX ");
-	xprintf(io_fileout, "CELL %s ( )\n{\n", io_l_fixname(np->cell->cellname));
+	xprintf(io_fileout, x_("\n"));
+	if (np->cellview == el_layoutview) xprintf(io_fileout, x_("LAYOUT "));
+	if (np->cellview == el_schematicview) xprintf(io_fileout, x_("SCHEMATIC "));
+	if (np->cellview == el_iconview) xprintf(io_fileout, x_("ICON "));
+	if (np->cellview == el_skeletonview) xprintf(io_fileout, x_("BBOX "));
+	xprintf(io_fileout, x_("CELL %s ( )\n{\n"), io_l_fixname(np->cell->cellname));
 
 	/* write the bounding box */
-	xprintf(io_fileout, "#bbox: ll= (%s,%s) ur= (%s,%s)\n",
+	xprintf(io_fileout, x_("#bbox: ll= (%s,%s) ur= (%s,%s)\n"),
 		latoa(np->lowx, 0), latoa(np->lowy, 0), latoa(np->highx, 0), latoa(np->highy, 0));
 
 	/* write the ports */
@@ -179,12 +179,12 @@ INTBIG io_l_writefacet(NODEPROTO *np)
 		portposition(pp->subnodeinst, pp->subportproto, &xpos, &ypos);
 		switch (pp->userbits&STATEBITS)
 		{
-			case GNDPORT:   type = "GND";    break;
-			case PWRPORT:   type = "VDD";    break;
-			case INPORT:    type = "IN";     break;
-			case OUTPORT:   type = "OUT";    break;
-			case BIDIRPORT: type = "INOUT";  break;
-			default:        type = "";       break;
+			case GNDPORT:   type = x_("GND");    break;
+			case PWRPORT:   type = x_("VDD");    break;
+			case INPORT:    type = x_("IN");     break;
+			case OUTPORT:   type = x_("OUT");    break;
+			case BIDIRPORT: type = x_("INOUT");  break;
+			default:        type = x_("");       break;
 		}
 		lay = pp->connects[0]->protoname;
 		for(i=0; io_lports[i].arcfunct != 0; i++)
@@ -192,10 +192,10 @@ INTBIG io_l_writefacet(NODEPROTO *np)
 		{
 			lay = io_lports[i].portname;   break;
 		}
-		xprintf(io_fileout, "\t%s %s %s (%s,%s) ;\n", type, lay,
+		xprintf(io_fileout, x_("\t%s %s %s (%s,%s) ;\n"), type, lay,
 			io_l_fixname(pp->protoname), latoa(xpos, 0), latoa(ypos, 0));
 	}
-	xprintf(io_fileout, "\n");
+	xprintf(io_fileout, x_("\n"));
 
 	/* number all components in the facet */
 	i = 1;
@@ -219,7 +219,7 @@ INTBIG io_l_writefacet(NODEPROTO *np)
 			onp = contentsview(subnt);
 			if (onp != NONODEPROTO) subnt = onp;
 			type = subnt->cell->cellname;
-			xprintf(io_fileout, "\tINST %s %s", type, io_l_name(subno));
+			xprintf(io_fileout, x_("\tINST %s %s"), type, io_l_name(subno));
 		} else
 		{
 			i = nodefunction(subno);
@@ -231,14 +231,14 @@ INTBIG io_l_writefacet(NODEPROTO *np)
 					if ((INTBIG)(((subno->proto->firstportproto->connects[0]->userbits&
 						AFUNCTION)>>AFUNCTIONSH)) == io_lports[j].arcfunct) break;
 				if (io_lports[j].arcfunct != 0) type = io_lports[j].portname; else
-					type = "???";
-				(void)sprintf(line, "NODE %s", type);
+					type = x_("???");
+				(void)esnprintf(line, 50, x_("NODE %s"), type);
 				type = line;
 			}
 
 			/* special type names for well/substrate contacts */
-			if (i == NPWELL) type = "MNSUB";
-			if (i == NPSUBSTRATE) type = "MPSUB";
+			if (i == NPWELL) type = x_("MNSUB");
+			if (i == NPSUBSTRATE) type = x_("MPSUB");
 
 			/* special type names for contacts */
 			if (i == NPCONTACT || i == NPCONNECT)
@@ -261,12 +261,12 @@ INTBIG io_l_writefacet(NODEPROTO *np)
 			}
 
 			/* special type names for transistors */
-			if (i == NPTRANMOS) type = "TN";
-			if (i == NPTRADMOS) type = "TD";
-			if (i == NPTRAPMOS) type = "TP";
+			if (i == NPTRANMOS) type = x_("TN");
+			if (i == NPTRADMOS) type = x_("TD");
+			if (i == NPTRAPMOS) type = x_("TP");
 
 			/* write the type and name */
-			xprintf(io_fileout, "\t%s %s", type, io_l_name(subno));
+			xprintf(io_fileout, x_("\t%s %s"), type, io_l_name(subno));
 		}
 
 		/* write rotation */
@@ -275,10 +275,10 @@ INTBIG io_l_writefacet(NODEPROTO *np)
 			r = subno->rotation;
 			if (subno->transpose != 0)
 			{
-				xprintf(io_fileout, " RX");
+				xprintf(io_fileout, x_(" RX"));
 				r = (r+2700) % 3600;
 			}
-			xprintf(io_fileout, " R%s", frtoa(r*WHOLE/10));
+			xprintf(io_fileout, x_(" R%s"), frtoa(r*WHOLE/10));
 		}
 
 		/* write size if nonstandard */
@@ -292,22 +292,22 @@ INTBIG io_l_writefacet(NODEPROTO *np)
 				len = subno->highy-hy - (subno->lowy+ly);
 				wid = subno->highx-hx - (subno->lowx+lx);
 			}
-			xprintf(io_fileout, " W=%s L=%s", latoa(wid, 0), latoa(len, 0));
+			xprintf(io_fileout, x_(" W=%s L=%s"), latoa(wid, 0), latoa(len, 0));
 		}
 
 		/* write location */
 		if (subnt->primindex != 0)
 		{
-			xprintf(io_fileout, " AT (%s,%s) ;\n",
+			xprintf(io_fileout, x_(" AT (%s,%s) ;\n"),
 				latoa((subno->lowx+subno->highx)/2, 0), latoa((subno->lowy+subno->highy)/2, 0));
 		} else
 		{
-			xprintf(io_fileout, " AT (%s,%s) ;\n",
+			xprintf(io_fileout, x_(" AT (%s,%s) ;\n"),
 				latoa((subno->lowx+subno->highx-subnt->lowx-subnt->highx)/2, 0),
 					latoa((subno->lowy+subno->highy-subnt->lowy-subnt->highy)/2, 0));
 		}
 	}
-	xprintf(io_fileout, "\n");
+	xprintf(io_fileout, x_("\n"));
 
 	/* write all arcs connected to nodes */
 	for(subar = np->firstarcinst; subar != NOARCINST; subar = subar->nextarcinst)
@@ -320,38 +320,38 @@ INTBIG io_l_writefacet(NODEPROTO *np)
 		{
 			subar = pi->conarcinst;
 			if (subar->temp1 != 0) continue;
-			xprintf(io_fileout, "\tWIRE");
+			xprintf(io_fileout, x_("\tWIRE"));
 			for(i=0; io_lports[i].arcfunct != 0; i++)
 				if ((INTBIG)(((subar->proto->userbits&AFUNCTION)>>AFUNCTIONSH)) == io_lports[i].arcfunct)
 			{
-				xprintf(io_fileout, " %s", io_lports[i].portname);
+				xprintf(io_fileout, x_(" %s"), io_lports[i].portname);
 				break;
 			}
 
 			/* write the wire width if nonstandard */
 			if (subar->width != defaultarcwidth(subar->proto))
-				xprintf(io_fileout, " W=%s", latoa(subar->width-arcwidthoffset(subar), 0));
+				xprintf(io_fileout, x_(" W=%s"), latoa(subar->width-arcwidthoffset(subar), 0));
 
 			/* write the starting node name (use port name if pin is an export) */
 			if (subno->firstportexpinst != NOPORTEXPINST && nodefunction(subno) == NPPIN)
-				xprintf(io_fileout, " %s",
+				xprintf(io_fileout, x_(" %s"),
 						io_l_fixname(subno->firstportexpinst->exportproto->protoname)); else
-							xprintf(io_fileout, " %s", io_l_name(subno));
+							xprintf(io_fileout, x_(" %s"), io_l_name(subno));
 
 			/* qualify node name with port name if a transistor or instance */
 			if (nature == TRANSISTOR)
 			{
 				transistorports(subno, &gateleft, &gateright, &activetop, &activebottom);
-				if (pi->proto == gateleft) xprintf(io_fileout, ".gl");
-				if (pi->proto == activetop) xprintf(io_fileout, ".d");
-				if (pi->proto == gateright) xprintf(io_fileout, ".gr");
-				if (pi->proto == activebottom) xprintf(io_fileout, ".s");
+				if (pi->proto == gateleft) xprintf(io_fileout, x_(".gl"));
+				if (pi->proto == activetop) xprintf(io_fileout, x_(".d"));
+				if (pi->proto == gateright) xprintf(io_fileout, x_(".gr"));
+				if (pi->proto == activebottom) xprintf(io_fileout, x_(".s"));
 			} else if (nature == INSTANCE)
-				xprintf(io_fileout, ".%s", io_l_fixname(pi->proto->protoname));
+				xprintf(io_fileout, x_(".%s"), io_l_fixname(pi->proto->protoname));
 
 			/* prepare to run along the wire to a terminating node */
 			if (subar->end[0].portarcinst == pi) thatend = 1; else thatend = 0;
-			lastdir = "";
+			lastdir = x_("");
 			segdist = -1;
 			segcount = 0;
 			for(;;)
@@ -362,19 +362,19 @@ INTBIG io_l_writefacet(NODEPROTO *np)
 				dir = lastdir;
 				if (subar->end[thatend].xpos == subar->end[thisend].xpos)
 				{
-					if (subar->end[thatend].ypos > subar->end[thisend].ypos) dir = "UP"; else
-						if (subar->end[thatend].ypos < subar->end[thisend].ypos) dir = "DOWN";
+					if (subar->end[thatend].ypos > subar->end[thisend].ypos) dir = x_("UP"); else
+						if (subar->end[thatend].ypos < subar->end[thisend].ypos) dir = x_("DOWN");
 				} else if (subar->end[thatend].ypos == subar->end[thisend].ypos)
 				{
-					if (subar->end[thatend].xpos > subar->end[thisend].xpos) dir = "RIGHT"; else
-						if (subar->end[thatend].xpos < subar->end[thisend].xpos) dir = "LEFT";
+					if (subar->end[thatend].xpos > subar->end[thisend].xpos) dir = x_("RIGHT"); else
+						if (subar->end[thatend].xpos < subar->end[thisend].xpos) dir = x_("LEFT");
 				}
 
 				/* if segment is different from last, write out last one */
-				if (strcmp(dir, lastdir) != 0 && *lastdir != 0)
+				if (estrcmp(dir, lastdir) != 0 && *lastdir != 0)
 				{
-					xprintf(io_fileout, " %s", lastdir);
-					if (segdist >= 0) xprintf(io_fileout, "=%s", latoa(segdist, 0));
+					xprintf(io_fileout, x_(" %s"), lastdir);
+					if (segdist >= 0) xprintf(io_fileout, x_("=%s"), latoa(segdist, 0));
 					segdist = -1;
 					segcount++;
 				}
@@ -407,28 +407,28 @@ INTBIG io_l_writefacet(NODEPROTO *np)
 			}
 			if (*lastdir != 0)
 			{
-				xprintf(io_fileout, " %s", lastdir);
-				if (segdist >= 0) xprintf(io_fileout, "=%s", latoa(segdist, 0));
-			} else xprintf(io_fileout, " TO");
+				xprintf(io_fileout, x_(" %s"), lastdir);
+				if (segdist >= 0) xprintf(io_fileout, x_("=%s"), latoa(segdist, 0));
+			} else xprintf(io_fileout, x_(" TO"));
 
 			/* write the terminating node name (use port name if pin is an export) */
 			if (oni->firstportexpinst != NOPORTEXPINST && nodefunction(oni) == NPPIN)
-				xprintf(io_fileout, " %s",
+				xprintf(io_fileout, x_(" %s"),
 					io_l_fixname(oni->firstportexpinst->exportproto->protoname)); else
-						xprintf(io_fileout, " %s", io_l_name(oni));
+						xprintf(io_fileout, x_(" %s"), io_l_name(oni));
 
 			/* qualify node name with port name if a transistor or an instance */
 			opi = subar->end[thatend].portarcinst;
 			if (enature == TRANSISTOR)
 			{
 				transistorports(oni, &gateleft, &gateright, &activetop, &activebottom);
-				if (opi->proto == gateleft) xprintf(io_fileout, ".gl");
-				if (opi->proto == activetop) xprintf(io_fileout, ".d");
-				if (opi->proto == gateright) xprintf(io_fileout, ".gr");
-				if (opi->proto == activebottom) xprintf(io_fileout, ".s");
+				if (opi->proto == gateleft) xprintf(io_fileout, x_(".gl"));
+				if (opi->proto == activetop) xprintf(io_fileout, x_(".d"));
+				if (opi->proto == gateright) xprintf(io_fileout, x_(".gr"));
+				if (opi->proto == activebottom) xprintf(io_fileout, x_(".s"));
 			} else if (enature == INSTANCE)
-				xprintf(io_fileout, ".%s", io_l_fixname(opi->proto->protoname));
-			xprintf(io_fileout, " ;\n");
+				xprintf(io_fileout, x_(".%s"), io_l_fixname(opi->proto->protoname));
+			xprintf(io_fileout, x_(" ;\n"));
 		}
 	}
 
@@ -436,39 +436,39 @@ INTBIG io_l_writefacet(NODEPROTO *np)
 	for(subar = np->firstarcinst; subar != NOARCINST; subar = subar->nextarcinst)
 	{
 		if (subar->temp1 != 0) continue;
-		xprintf(io_fileout, "# WIRE %s not described!!\n", describearcinst(subar));
+		xprintf(io_fileout, x_("# WIRE %s not described!!\n"), describearcinst(subar));
 	}
-	xprintf(io_fileout, "}\n");
+	xprintf(io_fileout, x_("}\n"));
 	return(backannotate);
 }
 
-char *io_l_name(NODEINST *ni)
+CHAR *io_l_name(NODEINST *ni)
 {
 	REGISTER VARIABLE *var;
-	static char line[30];
+	static CHAR line[30];
 
 	var = getvalkey((INTBIG)ni, VNODEINST, VSTRING, el_node_name_key);
-	if (var != NOVARIABLE) return(io_l_fixname((char *)var->addr));
+	if (var != NOVARIABLE) return(io_l_fixname((CHAR *)var->addr));
 	ttyputerr(_("L generation warning: no name on node %s"), describenodeinst(ni));
-	(void)sprintf(line, "c%ld", ni->temp1);
+	(void)esnprintf(line, 30, x_("c%ld"), ni->temp1);
 	return(line);
 }
 
-char *io_l_fixname(char *name)
+CHAR *io_l_fixname(CHAR *name)
 {
-	REGISTER char *pt;
+	REGISTER CHAR *pt;
 	REGISTER INTBIG i;
-	static char *badname[] = {"VDD", "GND", 0};
+	static CHAR *badname[] = {x_("VDD"), x_("GND"), 0};
 	REGISTER void *infstr;
 
 	/* check for reserved names */
 	for(i=0; badname[i] != 0; i++)
-		if (strcmp(name, badname[i]) == 0)
+		if (estrcmp(name, badname[i]) == 0)
 	{
 		/* this is a reserved name: change it */
 		infstr = initinfstr();
 		addstringtoinfstr(infstr, name);
-		addstringtoinfstr(infstr, "XXX");
+		addstringtoinfstr(infstr, x_("XXX"));
 		return(returninfstr(infstr));
 	}
 
