@@ -72,7 +72,7 @@ void io_plotpoly(POLYGON*, WINDOWPART*);
 void io_plotdot(INTBIG, INTBIG);
 void io_plotline(INTBIG, INTBIG, INTBIG, INTBIG, INTBIG);
 void io_plotpolygon(INTBIG*, INTBIG*, INTBIG, INTBIG, GRAPHICS*);
-void io_plottext(INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, char*);
+void io_plottext(INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, CHAR*);
 void io_xform(INTBIG*, INTBIG*);
 void io_maccopyhighlighted(void);
 
@@ -296,7 +296,7 @@ BOOLEAN io_writequickdrawlibrary(LIBRARY *lib)
 		} else
 		{
 			grabpoint(np, &gridlx, &gridly);
-			gridalign(&gridlx, &gridly, 1);
+			gridalign(&gridlx, &gridly, 1, np);
 			gridlx += gridlx / gridx * gridx;
 			gridly += gridly / gridy * gridy;
 		}
@@ -316,16 +316,16 @@ BOOLEAN io_writequickdrawlibrary(LIBRARY *lib)
 	{
 		/* first plot outlines around stipple layers */
 		io_setplotlayer(-(io_nextplotlayer(ix) + 1));
-		(void)asktool(us_tool, "display-to-routine", io_plotpoly);
+		(void)asktool(us_tool, x_("display-to-routine"), io_plotpoly);
 
 		/* next plot layers */
 		io_setplotlayer(io_nextplotlayer(ix) + 1);
-		(void)asktool(us_tool, "display-to-routine", io_plotpoly);
+		(void)asktool(us_tool, x_("display-to-routine"), io_plotpoly);
 	}
 
 	/* finally plot layers not in the technology */
 	io_setplotlayer(0);
-	(void)asktool(us_tool, "display-to-routine", io_plotpoly);
+	(void)asktool(us_tool, x_("display-to-routine"), io_plotpoly);
 
 	/* put out dates if requested */
 	if ((curstate[0]&PLOTDATES) != 0)
@@ -419,7 +419,7 @@ void io_plotpoly(POLYGON *poly, WINDOWPART *win)
 	INTBIG xl, xh, yl, yh, x, y, listx[4], listy[4], size,
 		centerx, centery, x1p, y1p, x2p, y2p, xa, ya, xb, yb, radius;
 	INTBIG startangle, endangle, amt, style;
-	unsigned char pat[8];
+	UCHAR1 pat[8];
 	Rect r;
 	static POLYGON *polyspline = NOPOLYGON;
 	REGISTER TECHNOLOGY *tech;
@@ -697,13 +697,13 @@ void io_plotdot(INTBIG x, INTBIG y)
 /* draw a line */
 void io_plotline(INTBIG x1, INTBIG y1, INTBIG x2, INTBIG y2, INTBIG pattern)
 {
-	static unsigned char pat0[] = {0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF};
-	static unsigned char pat1h[] = {0xFF, 0, 0, 0, 0xFF, 0, 0, 0};
-	static unsigned char pat1v[] = {0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88};
-	static unsigned char pat2h[] = {0xFF, 0xFF, 0xFF, 0, 0, 0xFF, 0xFF, 0xFF};
-	static unsigned char pat2v[] = {0xE7, 0xE7, 0xE7, 0xE7, 0xE7, 0xE7, 0xE7, 0xE7};
-	static unsigned char *patlisth[] = {pat0, pat1h, pat2h, pat0};
-	static unsigned char *patlistv[] = {pat0, pat1v, pat2v, pat0};
+	static UCHAR1 pat0[] = {0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF};
+	static UCHAR1 pat1h[] = {0xFF, 0, 0, 0, 0xFF, 0, 0, 0};
+	static UCHAR1 pat1v[] = {0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88};
+	static UCHAR1 pat2h[] = {0xFF, 0xFF, 0xFF, 0, 0, 0xFF, 0xFF, 0xFF};
+	static UCHAR1 pat2v[] = {0xE7, 0xE7, 0xE7, 0xE7, 0xE7, 0xE7, 0xE7, 0xE7};
+	static UCHAR1 *patlisth[] = {pat0, pat1h, pat2h, pat0};
+	static UCHAR1 *patlistv[] = {pat0, pat1v, pat2v, pat0};
 
 	io_xform(&x1, &y1);
 	io_xform(&x2, &y2);
@@ -722,7 +722,7 @@ void io_plotline(INTBIG x1, INTBIG y1, INTBIG x2, INTBIG y2, INTBIG pattern)
 void io_plotpolygon(INTBIG *x, INTBIG *y, INTBIG count, INTBIG style, GRAPHICS *desc)
 {
 	INTBIG i;
-	unsigned char pat[8];
+	UCHAR1 pat[8];
 	PolyHandle polyhandle;
 	static INTBIG *myx, *myy;
 	static INTBIG len = 0;
@@ -761,16 +761,16 @@ void io_plotpolygon(INTBIG *x, INTBIG *y, INTBIG count, INTBIG style, GRAPHICS *
 }
 
 void io_plottext(INTBIG type, INTBIG lx, INTBIG ux, INTBIG ly, INTBIG uy, INTBIG size,
-	char *text)
+	CHAR *text)
 {
-	char localstring[256];
+	CHAR localstring[256];
 	INTBIG len, i, tsx, tsy, px, py, truesize;
 	FontInfo fontinfo;
 
 	io_xform(&lx, &ly);
 	io_xform(&ux, &uy);
 
-	len = strlen(text);
+	len = estrlen(text);
 	for(i=0; i<len; i++) localstring[i] = text[i];
 	TextFont(HFONT);
 	if (type == TEXTBOX)
@@ -935,16 +935,16 @@ void io_maccopyhighlighted(void)
 	{
 		/* first plot outlines around stipple layers */
 		io_setplotlayer(-(io_nextplotlayer(ix) + 1));
-		(void)asktool(us_tool, "display-highlighted-to-routine", io_plotpoly);
+		(void)asktool(us_tool, x_("display-highlighted-to-routine"), io_plotpoly);
 
 		/* next plot layers */
 		io_setplotlayer(io_nextplotlayer(ix) + 1);
-		(void)asktool(us_tool, "display-highlighted-to-routine", io_plotpoly);
+		(void)asktool(us_tool, x_("display-highlighted-to-routine"), io_plotpoly);
 	}
 
 	/* finally plot layers not in the technology */
 	io_setplotlayer(0);
-	(void)asktool(us_tool, "display-highlighted-to-routine", io_plotpoly);
+	(void)asktool(us_tool, x_("display-highlighted-to-routine"), io_plotpoly);
 
 	ClosePicture();
 	HLock((Handle)picture);
