@@ -96,7 +96,7 @@ typedef struct
 	INTBIG      filelength;
 	INTBIG      fileposition;
 	INTBIG      curfacetnumber;
-	char       *version;
+	CHAR       *version;
 	NODEINST   *curnodeinst;
 	ARCINST    *curarcinst;
 	PORTPROTO  *curportproto;
@@ -123,13 +123,13 @@ static TXTINPUTDATA io_txtindata;			/* all data pertaining to reading a file */
 
 /* input string buffer */
 static INTBIG io_maxinputline = 0;
-static char *io_keyword;
+static CHAR *io_keyword;
 
 /* prototypes for local routines */
 static void io_newlib(void);
 static BOOLEAN io_getkeyword(void);
 static BOOLEAN io_grabbuffers(INTBIG);
-static PORTPROTO *io_getport(char*, NODEPROTO*);
+static PORTPROTO *io_getport(CHAR*, NODEPROTO*);
 static void io_null(void);
 static void io_newlib(void);
 static void io_versn(void);
@@ -142,7 +142,7 @@ static void io_libte(void);
 static void io_libten(void);
 static void io_lambda(void);
 static void io_getvar(void);
-static INTBIG io_decode(char*, INTBIG);
+static INTBIG io_decode(CHAR*, INTBIG);
 static void io_libcc(void);
 static void io_libms(void);
 static void io_libvie(void);
@@ -206,160 +206,160 @@ static void io_ptkse(void);
 static void io_ptbit(void);
 static void io_ptusb(void);
 static void io_ptnet(void);
-static TECHNOLOGY *io_gettechnology(char*);
+static TECHNOLOGY *io_gettechnology(CHAR*);
 
 struct keyroutine
 {
-	char *matchstring;
+	CHAR *matchstring;
 	void (*routine)(void);
 };
 
 /* possible keywords while reading libraries */
 static struct keyroutine io_libraryroutines[] =
 {
-	{"****library",     io_newlib},
-	{"bits",            io_libbit},
-	{"lambda",          io_lambda},
-	{"version",         io_versn},
-	{"aids",            io_libkno},
-	{"aidname",         io_libain},
-	{"aidbits",         io_libaib},
-	{"userbits",        io_libusb},
-	{"techcount",       io_libte},
-	{"techname",        io_libten},
-	{"cellcount",       io_libcc},
-	{"maincell",        io_libms},
-	{"view",            io_libvie},
-	{"***cell",         io_newcel},
-	{"variables",       io_getvar},
+	{x_("****library"),     io_newlib},
+	{x_("bits"),            io_libbit},
+	{x_("lambda"),          io_lambda},
+	{x_("version"),         io_versn},
+	{x_("aids"),            io_libkno},
+	{x_("aidname"),         io_libain},
+	{x_("aidbits"),         io_libaib},
+	{x_("userbits"),        io_libusb},
+	{x_("techcount"),       io_libte},
+	{x_("techname"),        io_libten},
+	{x_("cellcount"),       io_libcc},
+	{x_("maincell"),        io_libms},
+	{x_("view"),            io_libvie},
+	{x_("***cell"),         io_newcel},
+	{x_("variables"),       io_getvar},
    {NULL, NULL}
 };
 
 /* possible keywords while reading facets */
 static struct keyroutine io_facetroutines[] =
 {
-	{"bits",            io_celbit},
-	{"userbits",        io_celusb},
-	{"netnum",          io_celnet},
-	{"name",            io_celnam},
-	{"version",         io_celver},
-	{"creationdate",    io_celcre},
-	{"revisiondate",    io_celrev},
-	{"lowx",            io_cellx},
-	{"highx",           io_celhx},
-	{"lowy",            io_celly},
-	{"highy",           io_celhy},
-	{"externallibrary", io_celext},
-	{"aadirty",         io_celaad},
-	{"nodes",           io_celnoc},
-	{"arcs",            io_celarc},
-	{"porttypes",       io_celptc},
-	{"celldone",        io_celdon},
-	{"technology",      io_tech},
-	{"**node",          io_newno},
-	{"**arc",           io_newar},
-	{"***cell",         io_newcel},
-	{"variables",       io_getvar},
+	{x_("bits"),            io_celbit},
+	{x_("userbits"),        io_celusb},
+	{x_("netnum"),          io_celnet},
+	{x_("name"),            io_celnam},
+	{x_("version"),         io_celver},
+	{x_("creationdate"),    io_celcre},
+	{x_("revisiondate"),    io_celrev},
+	{x_("lowx"),            io_cellx},
+	{x_("highx"),           io_celhx},
+	{x_("lowy"),            io_celly},
+	{x_("highy"),           io_celhy},
+	{x_("externallibrary"), io_celext},
+	{x_("aadirty"),         io_celaad},
+	{x_("nodes"),           io_celnoc},
+	{x_("arcs"),            io_celarc},
+	{x_("porttypes"),       io_celptc},
+	{x_("celldone"),        io_celdon},
+	{x_("technology"),      io_tech},
+	{x_("**node"),          io_newno},
+	{x_("**arc"),           io_newar},
+	{x_("***cell"),         io_newcel},
+	{x_("variables"),       io_getvar},
    {NULL, NULL}
 };
 
 /* possible keywords while reading ports */
 static struct keyroutine io_portroutines[] =
 {
-	{"bits",            io_ptbit},
-	{"userbits",        io_ptusb},
-	{"netnum",          io_ptnet},
-	{"subnode",         io_ptsno},
-	{"subport",         io_ptspt},
-	{"name",            io_ptnam},
-	{"descript",        io_ptdes},
-	{"aseen",           io_ptkse},
-	{"**porttype",      io_newpt},
-	{"**arc",           io_newar},
-	{"**node",          io_newno},
-	{"celldone",        io_celdon},
-	{"***cell",         io_newcel},
-	{"variables",       io_getvar},
-	{"arcbits",         io_null},	/* used no more: ignored for compatibility */
+	{x_("bits"),            io_ptbit},
+	{x_("userbits"),        io_ptusb},
+	{x_("netnum"),          io_ptnet},
+	{x_("subnode"),         io_ptsno},
+	{x_("subport"),         io_ptspt},
+	{x_("name"),            io_ptnam},
+	{x_("descript"),        io_ptdes},
+	{x_("aseen"),           io_ptkse},
+	{x_("**porttype"),      io_newpt},
+	{x_("**arc"),           io_newar},
+	{x_("**node"),          io_newno},
+	{x_("celldone"),        io_celdon},
+	{x_("***cell"),         io_newcel},
+	{x_("variables"),       io_getvar},
+	{x_("arcbits"),         io_null},	/* used no more: ignored for compatibility */
    {NULL, NULL}
 };
 
 /* possible keywords while reading nodes */
 static struct keyroutine io_noderoutines[] =
 {
-	{"bits",            io_nodbit},
-	{"userbits",        io_nodusb},
-	{"type",            io_nodtyp},
-	{"lowx",            io_nodlx},
-	{"highx",           io_nodhx},
-	{"lowy",            io_nodly},
-	{"highy",           io_nodhy},
-	{"rotation",        io_nodrot},
-	{"transpose",       io_nodtra},
-	{"aseen",           io_nodkse},
-	{"name",            io_nodnam},
-	{"descript",        io_noddes},
-	{"*port",           io_newpor},
-	{"**node",          io_newno},
-	{"**porttype",      io_newpt},
-	{"**arc",           io_newar},
-	{"celldone",        io_celdon},
-	{"variables",       io_getvar},
-	{"***cell",         io_newcel},
-	{"ports",           io_nodpoc},
-	{"exportcount",     io_null},	/* used no more: ignored for compatibility */
+	{x_("bits"),            io_nodbit},
+	{x_("userbits"),        io_nodusb},
+	{x_("type"),            io_nodtyp},
+	{x_("lowx"),            io_nodlx},
+	{x_("highx"),           io_nodhx},
+	{x_("lowy"),            io_nodly},
+	{x_("highy"),           io_nodhy},
+	{x_("rotation"),        io_nodrot},
+	{x_("transpose"),       io_nodtra},
+	{x_("aseen"),           io_nodkse},
+	{x_("name"),            io_nodnam},
+	{x_("descript"),        io_noddes},
+	{x_("*port"),           io_newpor},
+	{x_("**node"),          io_newno},
+	{x_("**porttype"),      io_newpt},
+	{x_("**arc"),           io_newar},
+	{x_("celldone"),        io_celdon},
+	{x_("variables"),       io_getvar},
+	{x_("***cell"),         io_newcel},
+	{x_("ports"),           io_nodpoc},
+	{x_("exportcount"),     io_null},	/* used no more: ignored for compatibility */
    {NULL, NULL}
 };
 
 /* possible keywords while reading portinsts */
 static struct keyroutine io_portinstroutines[] =
 {
-	{"arc",             io_porarc},
-	{"exported",        io_porexp},
-	{"*port",           io_newpor},
-	{"**node",          io_newno},
-	{"**porttype",      io_newpt},
-	{"**arc",           io_newar},
-	{"variables",       io_getvar},
-	{"celldone",        io_celdon},
-	{"***cell",         io_newcel},
+	{x_("arc"),             io_porarc},
+	{x_("exported"),        io_porexp},
+	{x_("*port"),           io_newpor},
+	{x_("**node"),          io_newno},
+	{x_("**porttype"),      io_newpt},
+	{x_("**arc"),           io_newar},
+	{x_("variables"),       io_getvar},
+	{x_("celldone"),        io_celdon},
+	{x_("***cell"),         io_newcel},
    {NULL, NULL}
 };
 
 /* possible keywords while reading arcs */
 static struct keyroutine io_arcroutines[] =
 {
-	{"bits",            io_arcbit},
-	{"userbits",        io_arcusb},
-	{"netnum",          io_arcnet},
-	{"type",            io_arctyp},
-	{"width",           io_arcwid},
-	{"length",          io_arclen},
-	{"signals",         io_arcsig},
-	{"aseen",           io_arckse},
-	{"name",            io_arcnam},
-	{"*end",            io_newend},
-	{"**arc",           io_newar},
-	{"**node",          io_newno},
-	{"variables",       io_getvar},
-	{"celldone",        io_celdon},
-	{"***cell",         io_newcel},
+	{x_("bits"),            io_arcbit},
+	{x_("userbits"),        io_arcusb},
+	{x_("netnum"),          io_arcnet},
+	{x_("type"),            io_arctyp},
+	{x_("width"),           io_arcwid},
+	{x_("length"),          io_arclen},
+	{x_("signals"),         io_arcsig},
+	{x_("aseen"),           io_arckse},
+	{x_("name"),            io_arcnam},
+	{x_("*end"),            io_newend},
+	{x_("**arc"),           io_newar},
+	{x_("**node"),          io_newno},
+	{x_("variables"),       io_getvar},
+	{x_("celldone"),        io_celdon},
+	{x_("***cell"),         io_newcel},
    {NULL, NULL}
 };
 
 /* possible keywords while reading arc ends */
 static struct keyroutine io_arcendroutines[] =
 {
-	{"node",            io_endnod},
-	{"nodeport",        io_endpt},
-	{"xpos",            io_endxp},
-	{"ypos",            io_endyp},
-	{"*end",            io_newend},
-	{"**arc",           io_newar},
-	{"**node",          io_newno},
-	{"variables",       io_getvar},
-	{"celldone",        io_celdon},
-	{"***cell",         io_newcel},
+	{x_("node"),            io_endnod},
+	{x_("nodeport"),        io_endpt},
+	{x_("xpos"),            io_endxp},
+	{x_("ypos"),            io_endyp},
+	{x_("*end"),            io_newend},
+	{x_("**arc"),           io_newar},
+	{x_("**node"),          io_newno},
+	{x_("variables"),       io_getvar},
+	{x_("celldone"),        io_celdon},
+	{x_("***cell"),         io_newcel},
    {NULL, NULL}
 };
 
@@ -390,7 +390,7 @@ BOOLEAN io_readtextlibrary(LIBRARY *lib)
 BOOLEAN io_doreadtextlibrary(LIBRARY *lib, BOOLEAN newprogress)
 {
 	struct keyroutine *table;
-	REGISTER char *pp;
+	REGISTER CHAR *pp;
 	REGISTER INTBIG i, j, reportcount, lambda, errcode;
 	INTBIG num, den;
 	REGISTER INTBIG oldunit;
@@ -399,7 +399,7 @@ BOOLEAN io_doreadtextlibrary(LIBRARY *lib, BOOLEAN newprogress)
 	REGISTER NODEINST *ni;
 	REGISTER ARCINST *ai;
 	REGISTER CELL *c;
-	char *filename;
+	CHAR *filename;
 	REGISTER void *infstr;
 
 	/* initialize the input string buffers */
@@ -415,7 +415,7 @@ BOOLEAN io_doreadtextlibrary(LIBRARY *lib, BOOLEAN newprogress)
 	}
 
 	/* update the library file name if the true location is different */
-	if (strcmp(filename, lib->libfile) != 0)
+	if (estrcmp(filename, lib->libfile) != 0)
 		(void)reallocstring(&lib->libfile, filename, lib->cluster);
 
 	reportcount = io_txtindata.fileposition = 0;
@@ -426,7 +426,7 @@ BOOLEAN io_doreadtextlibrary(LIBRARY *lib, BOOLEAN newprogress)
 		{
 			if (newprogress)
 			{
-				io_inputprogressdialog = DiaInitProgress("", _("Reading library"));
+				io_inputprogressdialog = DiaInitProgress(x_(""), _("Reading library"));
 				if (io_inputprogressdialog == 0)
 				{
 					xclose(io_txtindata.textfilein);
@@ -475,10 +475,10 @@ BOOLEAN io_doreadtextlibrary(LIBRARY *lib, BOOLEAN newprogress)
 
 	/* force the library name to be the proper file name without the "txt" */
 	infstr = initinfstr();
-	for(i=strlen(lib->libfile)-1; i>=0; i--) if (lib->libfile[i] == DIRSEP) break;
+	for(i=estrlen(lib->libfile)-1; i>=0; i--) if (lib->libfile[i] == DIRSEP) break;
 	pp = &lib->libfile[i+1];
-	j = strlen(pp);
-	if (j > 4 && namesame(&pp[j-4], ".txt") == 0) j -= 4;
+	j = estrlen(pp);
+	if (j > 4 && namesame(&pp[j-4], x_(".txt")) == 0) j -= 4;
 	for(i=0; i<j; i++) addtoinfstr(infstr, pp[i]);
 	if (reallocstring(&lib->libname, returninfstr(infstr), lib->cluster))
 		longjmp(io_filerror, LONGJMPNOMEM);
@@ -523,7 +523,7 @@ BOOLEAN io_doreadtextlibrary(LIBRARY *lib, BOOLEAN newprogress)
 
 		/* parse keyword and argument */
 		for(i=0; table[i].matchstring != 0; i++)
-			if (strcmp(table[i].matchstring, io_keyword) == 0) break;
+			if (estrcmp(table[i].matchstring, io_keyword) == 0) break;
 		if (table[i].matchstring == 0)
 			longjmp(io_filerror, LONGJMPUKNKEY);
 
@@ -540,7 +540,7 @@ BOOLEAN io_doreadtextlibrary(LIBRARY *lib, BOOLEAN newprogress)
 
 	/* set the former version number on the library */
 	nextchangequiet();
-	(void)setval((INTBIG)io_txtindata.curlib, VLIBRARY, "LIB_former_version",
+	(void)setval((INTBIG)io_txtindata.curlib, VLIBRARY, x_("LIB_former_version"),
 		(INTBIG)io_txtindata.version, VSTRING|VDONTSAVE);
 	efree(io_txtindata.version);
 
@@ -616,7 +616,7 @@ BOOLEAN io_doreadtextlibrary(LIBRARY *lib, BOOLEAN newprogress)
 	if (io_txtindata.mainfacet != -1 && io_txtindata.mainfacet < io_txtindata.facetcount)
 		io_txtindata.curlib->curnodeproto = io_txtindata.nodeprotolist[io_txtindata.mainfacet]; else
 			io_txtindata.curlib->curnodeproto = NONODEPROTO;
-	if (io_txtindata.facetcount != 0) efree((char *)io_txtindata.nodeprotolist);
+	if (io_txtindata.facetcount != 0) efree((CHAR *)io_txtindata.nodeprotolist);
 	if (io_verbose < 0 && io_txtindata.filelength > 0 && newprogress) DiaDoneProgress(io_inputprogressdialog);
 
 	/* clean up the library */
@@ -652,7 +652,7 @@ BOOLEAN io_getkeyword(void)
 	/* collect the word */
 	cindex = 0;
 	if (c == '"') inquote = 1; else inquote = 0;
-	io_keyword[cindex++] = (char)c;
+	io_keyword[cindex++] = (CHAR)c;
 	for(;;)
 	{
 		c = xgetc(io_txtindata.textfilein);
@@ -666,7 +666,7 @@ BOOLEAN io_getkeyword(void)
 		}
 		if (c == '"' && (cindex == 0 || io_keyword[cindex-1] != '^'))
 			inquote = 1 - inquote;
-		io_keyword[cindex++] = (char)c;
+		io_keyword[cindex++] = (CHAR)c;
 	}
 	if (c == '\n')
 	{
@@ -683,11 +683,11 @@ BOOLEAN io_getkeyword(void)
  */
 BOOLEAN io_grabbuffers(INTBIG size)
 {
-	REGISTER char *p;
+	REGISTER CHAR *p;
 	REGISTER INTBIG i;
 
 	/* first get the new buffer */
-	p = (char *)emalloc((size+1), io_tool->cluster);
+	p = (CHAR *)emalloc((size+1) * SIZEOFCHAR, io_tool->cluster);
 	if (p == 0)
 	{
 		ttyputnomemory();
@@ -712,7 +712,7 @@ BOOLEAN io_grabbuffers(INTBIG size)
  * in node prototype "np".  The routine returns NOPORTPROTO if it cannot
  * figure out what port this name refers to.
  */
-PORTPROTO *io_getport(char *line, NODEPROTO *np)
+PORTPROTO *io_getport(CHAR *line, NODEPROTO *np)
 {
 	REGISTER PORTPROTO *pp;
 	REGISTER INTBIG i;
@@ -730,15 +730,15 @@ PORTPROTO *io_getport(char *line, NODEPROTO *np)
 		/* see if database uses shortened name */
 		for(pp = np->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
 		{
-			i = strlen(pp->protoname);
+			i = estrlen(pp->protoname);
 			if (namesamen(line, pp->protoname, i) == 0) return(pp);
 		}
 
 		/* see if the port name ends in a digit, fake with that */
-		i = strlen(line);
+		i = estrlen(line);
 		if (line[i-2] == '-' && line[i-1] >= '0' && line[i-1] <= '9')
 		{
-			i = (atoi(&line[i-1])-1) / 3;
+			i = (eatoi(&line[i-1])-1) / 3;
 			for(pp = np->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
 				if (i-- == 0) return(pp);
 		}
@@ -765,7 +765,7 @@ void io_newlib(void)
 
 	/* set defaults */
 	io_txtindata.mainfacet = -1;
-	(void)allocstring(&io_txtindata.version, "1.00", el_tempcluster);
+	(void)allocstring(&io_txtindata.version, x_("1.00"), el_tempcluster);
 	io_txtindata.varpos = INVTOOL;
 	io_txtindata.curtech = NOTECHNOLOGY;
 	for(tech = el_technologies; tech != NOTECHNOLOGY; tech = tech->nexttechnology)
@@ -789,13 +789,13 @@ void io_versn(void)
 		(emajor == 6 && eminor < 3) ||
 		(emajor == 6 && eminor == 3 && edetail < 17))
 	{
-		if ((asktech(mocmossub_tech, "get-state")&MOCMOSSUBNOCONV) == 0)
+		if ((asktech(mocmossub_tech, x_("get-state"))&MOCMOSSUBNOCONV) == 0)
 			io_txtindata.convertmosiscmostechnologies = 1;
 	}
 #ifdef REPORTCONVERSION
-	ttyputmsg("Library is version %s (%ld.%ld.%ld)", io_txtindata.version, emajor, eminor, edetail);
+	ttyputmsg(x_("Library is version %s (%ld.%ld.%ld)"), io_txtindata.version, emajor, eminor, edetail);
 	if (io_txtindata.convertmosiscmostechnologies != 0)
-		ttyputmsg("   Converting MOSIS CMOS technologies (mocmossub => mocmos)");
+		ttyputmsg(x_("   Converting MOSIS CMOS technologies (mocmossub => mocmos)"));
 #endif
 }
 
@@ -833,7 +833,7 @@ void io_libaib(void)
 void io_libbit(void)
 {
 	if (io_txtindata.bitcount == 0)
-		io_txtindata.curlib->userbits = atoi(io_keyword);
+		io_txtindata.curlib->userbits = eatoi(io_keyword);
 	io_txtindata.bitcount++;
 }
 
@@ -842,7 +842,7 @@ void io_libbit(void)
  */
 void io_libusb(void)
 {
-	io_txtindata.curlib->userbits = atoi(io_keyword);
+	io_txtindata.curlib->userbits = eatoi(io_keyword);
 
 	/* this library came as readable dump, so don't automatically save it to disk */
 	io_txtindata.curlib->userbits &= ~READFROMDISK;
@@ -878,10 +878,10 @@ void io_lambda(void)
 
 	if (io_txtindata.bitcount >= el_maxtech ||
 		io_txtindata.bitcount < 0) return;
-	lam = atoi(io_keyword);
+	lam = eatoi(io_keyword);
 
 	/* for version 4.0 and earlier, scale lambda by 20 */
-	if (atoi(io_txtindata.version) <= 4) lam *= 20;
+	if (eatoi(io_txtindata.version) <= 4) lam *= 20;
 	io_txtindata.curlib->lambda[io_txtindata.bitcount++] = lam;
 }
 
@@ -894,7 +894,7 @@ void io_getvar(void)
 	REGISTER float *fstore;
 	REGISTER INTSML *sstore;
 	UINTBIG descript[TEXTDESCRIPTSIZE];
-	REGISTER char *pt, *start;
+	REGISTER CHAR *pt, *start;
 	REGISTER VARIABLE *var;
 	REGISTER TECHNOLOGY *t;
 	REGISTER void *infstr;
@@ -939,12 +939,12 @@ void io_getvar(void)
 	}
 
 	/* find out how many variables to read */
-	count = atoi(io_keyword);
+	count = eatoi(io_keyword);
 	for(i=0; i<count; i++)
 	{
 		/* read the first keyword with the name, type, and descriptor */
 		if (io_getkeyword()) longjmp(io_filerror, LONGJMPEOFVAR);
-		if (io_keyword[strlen(io_keyword)-1] != ':')
+		if (io_keyword[estrlen(io_keyword)-1] != ':')
 			longjmp(io_filerror, LONGJMPMISCOLVAR);
 
 		/* get the variable name */
@@ -1070,7 +1070,7 @@ void io_getvar(void)
 				if (ntype == VTECHNOLOGY)
 					changedtechnologyvariable(key);
 			}
-			efree((char *)store);
+			efree((CHAR *)store);
 		} else
 		{
 			ret = io_decode(io_keyword, type);
@@ -1089,10 +1089,10 @@ void io_getvar(void)
 	}
 }
 
-INTBIG io_decode(char *name, INTBIG type)
+INTBIG io_decode(CHAR *name, INTBIG type)
 {
 	REGISTER INTBIG thistype, cindex;
-	REGISTER char *out, *retur;
+	REGISTER CHAR *out, *retur;
 	REGISTER NODEPROTO *np;
 
 	thistype = type;
@@ -1123,10 +1123,14 @@ INTBIG io_decode(char *name, INTBIG type)
 				*out++ = *name;
 			}
 			*out = 0;
+#if 0 /* Dump language code */
+			if ((type&(VCODE1|VCODE2)) != 0)
+				printf("Code <%s>\n", retur);
+#endif
 			return((INTBIG)retur);
 		case VFLOAT:
 		case VDOUBLE:
-			return(castint((float)atof(name)));
+			return(castint((float)eatof(name)));
 		case VNODEINST:
 			cindex = myatoi(name);
 			if (cindex >= 0 && cindex < io_txtindata.nodeinstcount)
@@ -1141,7 +1145,7 @@ INTBIG io_decode(char *name, INTBIG type)
 			for(out = name; *out != 0; out++) if (*out == ':') break;
 			if (*out == 0)
 			{
-				cindex = atoi(name);
+				cindex = eatoi(name);
 				if (cindex == -1) return(-1);
 				return((INTBIG)io_txtindata.nodeprotolist[cindex]);
 			}
@@ -1194,7 +1198,7 @@ void io_libcc(void)
 
 	io_txtindata.varpos = INVLIBRARY;
 
-	io_txtindata.facetcount = atoi(io_keyword);
+	io_txtindata.facetcount = eatoi(io_keyword);
 	if (io_txtindata.facetcount == 0)
 	{
 		io_txtindata.curlib->firstnodeproto = NONODEPROTO;
@@ -1228,7 +1232,7 @@ void io_libcc(void)
  */
 void io_libms(void)
 {
-	io_txtindata.mainfacet = atoi(io_keyword);
+	io_txtindata.mainfacet = eatoi(io_keyword);
 }
 
 /*
@@ -1236,7 +1240,7 @@ void io_libms(void)
  */
 void io_libvie(void)
 {
-	REGISTER char *pt;
+	REGISTER CHAR *pt;
 	REGISTER INTBIG len;
 	REGISTER VIEW *v;
 
@@ -1244,7 +1248,7 @@ void io_libvie(void)
 	while (*pt != 0 && *pt != '{') pt++;
 	if (*pt != '{') longjmp(io_filerror, LONGJMPMISVIEWABR);
 	*pt++ = 0;
-	len = strlen(pt);
+	len = estrlen(pt);
 	if (pt[len-1] != '}') longjmp(io_filerror, LONGJMPBADVIEWABR);
 	pt[len-1] = 0;
 	v = getview(io_keyword);
@@ -1254,7 +1258,7 @@ void io_libvie(void)
 		if (v == NOVIEW) longjmp(io_filerror, LONGJMPNOMEM);
 		(void)allocstring(&v->viewname, io_keyword, db_cluster);
 		(void)allocstring(&v->sviewname, pt, db_cluster);
-		if (namesamen(io_keyword, "Schematic-Page-", 15) == 0)
+		if (namesamen(io_keyword, x_("Schematic-Page-"), 15) == 0)
 			v->viewstate |= MULTIPAGEVIEW;
 		v->nextview = el_views;
 		el_views = v;
@@ -1273,7 +1277,7 @@ void io_libvie(void)
  */
 void io_newcel(void)
 {
-	io_txtindata.curfacetnumber = atoi(io_keyword);
+	io_txtindata.curfacetnumber = eatoi(io_keyword);
 	io_txtindata.curnodeproto = io_txtindata.nodeprotolist[io_txtindata.curfacetnumber];
 	io_txtindata.textlevel = INFACET;
 	io_txtindata.varpos = INVNODEPROTO;
@@ -1284,9 +1288,9 @@ void io_newcel(void)
  */
 void io_celnam(void)
 {
-	REGISTER char *pt;
+	REGISTER CHAR *pt;
 	REGISTER VIEW *v;
-	char *cellname;
+	CHAR *cellname;
 	REGISTER CELL *cell;
 	REGISTER void *infstr;
 
@@ -1311,7 +1315,7 @@ void io_celnam(void)
 			io_txtindata.curlib->cluster))
 				longjmp(io_filerror, LONGJMPNOMEM);
 		pt++;
-		pt[strlen(pt)-1] = 0;
+		pt[estrlen(pt)-1] = 0;
 		for(v = el_views; v != NOVIEW; v = v->nextview)
 			if (*v->sviewname != 0 && namesame(pt, v->sviewname) == 0) break;
 		if (v != NOVIEW) io_txtindata.curnodeproto->cellview = v;
@@ -1339,7 +1343,7 @@ void io_celnam(void)
  */
 void io_celver(void)
 {
-	io_txtindata.curnodeproto->version = atoi(io_keyword);
+	io_txtindata.curnodeproto->version = eatoi(io_keyword);
 }
 
 /*
@@ -1347,7 +1351,7 @@ void io_celver(void)
  */
 void io_celcre(void)
 {
-	io_txtindata.curnodeproto->creationdate = atoi(io_keyword);
+	io_txtindata.curnodeproto->creationdate = eatoi(io_keyword);
 }
 
 /*
@@ -1355,7 +1359,7 @@ void io_celcre(void)
  */
 void io_celrev(void)
 {
-	io_txtindata.curnodeproto->revisiondate = atoi(io_keyword);
+	io_txtindata.curnodeproto->revisiondate = eatoi(io_keyword);
 }
 
 /*
@@ -1365,12 +1369,12 @@ void io_celext(void)
 {
 	INTBIG len, filetype, filelen;
 	REGISTER LIBRARY *elib;
-	REGISTER char *libname, *pt;
-	char *filename, *libfile, *oldline2, *libfilename, *libfilepath;
+	REGISTER CHAR *libname, *pt;
+	CHAR *filename, *libfile, *oldline2, *libfilename, *libfilepath;
 	FILE *io;
 	REGISTER BOOLEAN failed;
 	REGISTER CELL *cell;
-	char *cellname;
+	CHAR *cellname;
 	REGISTER NODEPROTO *np, *onp;
 	REGISTER NODEINST *ni;
 	TXTINPUTDATA savetxtindata;
@@ -1381,7 +1385,7 @@ void io_celext(void)
 	if (libfile[0] == '"')
 	{
 		libfile++;
-		len = strlen(libfile) - 1;
+		len = estrlen(libfile) - 1;
 		if (libfile[len] == '"') libfile[len] = 0;
 	}
 
@@ -1389,8 +1393,8 @@ void io_celext(void)
 	infstr = initinfstr();
 	addstringtoinfstr(infstr, skippath(libfile));
 	libname = returninfstr(infstr);
-	len = strlen(libname);
-	filelen = strlen(libfile);
+	len = estrlen(libname);
+	filelen = estrlen(libfile);
 	if (len < filelen)
 	{
 		libfilename = &libfile[filelen-len-1];
@@ -1399,17 +1403,17 @@ void io_celext(void)
 	} else
 	{
 		libfilename = libfile;
-		libfilepath = "";
+		libfilepath = x_("");
 	}
 
 	filetype = io_filetypetlib;
-	if (len > 5 && namesame(&libname[len-5], ".elib") == 0)
+	if (len > 5 && namesame(&libname[len-5], x_(".elib")) == 0)
 	{
 		libname[len-5] = 0;
 		filetype = io_filetypeblib;
 	} else
 	{
-		if (len > 4 && namesame(&libname[len-4], ".txt") == 0) libname[len-4] = 0;
+		if (len > 4 && namesame(&libname[len-4], x_(".txt")) == 0) libname[len-4] = 0;
 	}
 	elib = getlibrary(libname);
 	if (elib == NOLIBRARY)
@@ -1429,10 +1433,10 @@ void io_celext(void)
 		{
 			infstr = initinfstr();
 			formatinfstr(infstr, _("Reference library '%s'"), libname);
-			pt = fileselect(returninfstr(infstr), filetype, "");
+			pt = fileselect(returninfstr(infstr), filetype, x_(""));
 			if (pt != 0)
 			{
-				strcpy(libfile, pt);
+				estrcpy(libfile, pt);
 				filename = libfile;
 			}
 		}
@@ -1446,10 +1450,10 @@ void io_celext(void)
 			(void)allocstring(&oldline2, DiaGetTextProgress(io_inputprogressdialog), el_tempcluster);
 		}
 
-		len = strlen(libfilename);
+		len = estrlen(libfilename);
 		io_libinputrecursivedepth++;
 		io_libinputreadmany++;
-		if (len > 4 && namesame(&libfilename[len-4], ".txt") == 0)
+		if (len > 4 && namesame(&libfilename[len-4], x_(".txt")) == 0)
 		{
 			/* ends in ".txt", presume text file */
 			failed = io_doreadtextlibrary(elib, FALSE);
@@ -1520,7 +1524,7 @@ void io_celext(void)
 		if (cell->firstincell == NONODEPROTO)
 		{
 			efree(cell->cellname);
-			efree((char *)cell);
+			efree((CHAR *)cell);
 		}
 		freenodeproto(onp);
 		io_txtindata.nodeprotolist[io_txtindata.curfacetnumber] = np;
@@ -1529,15 +1533,13 @@ void io_celext(void)
 		/* rename the cell */
 		np = io_txtindata.curnodeproto;
 		infstr = initinfstr();
-		addstringtoinfstr(infstr, np->cell->cellname);
-		addstringtoinfstr(infstr, "FROM");
-		addstringtoinfstr(infstr, elib->libname);
+		formatinfstr(infstr, x_("%sFROM%s"), np->cell->cellname, elib->libname);
 		cell = np->cell;
 		db_retractnodeproto(np);
 		if (cell->firstincell == NONODEPROTO)
 		{
 			efree(cell->cellname);
-			efree((char *)cell);
+			efree((CHAR *)cell);
 		}
 
 		cellname = returninfstr(infstr);
@@ -1571,22 +1573,22 @@ void io_celext(void)
  */
 void io_cellx(void)
 {
-	io_txtindata.curnodeproto->lowx = atoi(io_keyword);
+	io_txtindata.curnodeproto->lowx = eatoi(io_keyword);
 }
 
 void io_celhx(void)
 {
-	io_txtindata.curnodeproto->highx = atoi(io_keyword);
+	io_txtindata.curnodeproto->highx = eatoi(io_keyword);
 }
 
 void io_celly(void)
 {
-	io_txtindata.curnodeproto->lowy = atoi(io_keyword);
+	io_txtindata.curnodeproto->lowy = eatoi(io_keyword);
 }
 
 void io_celhy(void)
 {
-	io_txtindata.curnodeproto->highy = atoi(io_keyword);
+	io_txtindata.curnodeproto->highy = eatoi(io_keyword);
 }
 
 /*
@@ -1606,7 +1608,7 @@ void io_tech(void)
  */
 void io_celaad(void)
 {
-	io_txtindata.curnodeproto->adirty = atoi(io_keyword);
+	io_txtindata.curnodeproto->adirty = eatoi(io_keyword);
 	io_txtindata.bitcount = 0;
 }
 
@@ -1615,7 +1617,7 @@ void io_celaad(void)
  */
 void io_celbit(void)
 {
-	if (io_txtindata.bitcount == 0) io_txtindata.curnodeproto->userbits = atoi(io_keyword);
+	if (io_txtindata.bitcount == 0) io_txtindata.curnodeproto->userbits = eatoi(io_keyword);
 	io_txtindata.bitcount++;
 }
 
@@ -1624,7 +1626,7 @@ void io_celbit(void)
  */
 void io_celusb(void)
 {
-	io_txtindata.curnodeproto->userbits = atoi(io_keyword);
+	io_txtindata.curnodeproto->userbits = eatoi(io_keyword);
 }
 
 /*
@@ -1641,7 +1643,7 @@ void io_celnoc(void)
 	REGISTER NODEINST *ni;
 	REGISTER GEOM **geomlist;
 
-	io_txtindata.nodeinstcount = atoi(io_keyword);
+	io_txtindata.nodeinstcount = eatoi(io_keyword);
 	if (io_txtindata.nodeinstcount == 0) return;
 	io_txtindata.nodelist = (NODEINST **)emalloc(((sizeof (NODEINST *)) * io_txtindata.nodeinstcount),
 		el_tempcluster);
@@ -1667,7 +1669,7 @@ void io_celnoc(void)
 		ni->prevnodeinst = NONODEINST;
 		io_txtindata.curnodeproto->firstnodeinst = ni;
 	}
-	efree((char *)geomlist);
+	efree((CHAR *)geomlist);
 }
 
 /*
@@ -1679,7 +1681,7 @@ void io_celarc(void)
 	REGISTER ARCINST *ai;
 	REGISTER GEOM **geomlist;
 
-	io_txtindata.arcinstcount = atoi(io_keyword);
+	io_txtindata.arcinstcount = eatoi(io_keyword);
 	if (io_txtindata.arcinstcount == 0) return;
 	io_txtindata.arclist = (ARCINST **)emalloc(((sizeof (ARCINST *)) * io_txtindata.arcinstcount),
 		el_tempcluster);
@@ -1703,7 +1705,7 @@ void io_celarc(void)
 		ai->prevarcinst = NOARCINST;
 		io_txtindata.curnodeproto->firstarcinst = ai;
 	}
-	efree((char *)geomlist);
+	efree((CHAR *)geomlist);
 }
 
 /*
@@ -1713,7 +1715,7 @@ void io_celptc(void)
 {
 	REGISTER INTBIG i;
 
-	io_txtindata.portprotocount = atoi(io_keyword);
+	io_txtindata.portprotocount = eatoi(io_keyword);
 	io_txtindata.curnodeproto->numportprotos = io_txtindata.portprotocount;
 	if (io_txtindata.portprotocount == 0) return;
 	io_txtindata.portprotolist = (PORTPROTO **)emalloc(((sizeof (PORTPROTO *)) *
@@ -1796,9 +1798,9 @@ void io_celdon(void)
 	}
 
 	/* free the lists of objects in this facet */
-	if (io_txtindata.nodeinstcount != 0) efree((char *)io_txtindata.nodelist);
-	if (io_txtindata.portprotocount != 0) efree((char *)io_txtindata.portprotolist);
-	if (io_txtindata.arcinstcount != 0) efree((char *)io_txtindata.arclist);
+	if (io_txtindata.nodeinstcount != 0) efree((CHAR *)io_txtindata.nodelist);
+	if (io_txtindata.portprotocount != 0) efree((CHAR *)io_txtindata.portprotolist);
+	if (io_txtindata.arcinstcount != 0) efree((CHAR *)io_txtindata.arclist);
 }
 
 /******************** NODE INSTANCE PARSING ROUTINES ********************/
@@ -1808,7 +1810,7 @@ void io_celdon(void)
  */
 void io_newno(void)
 {
-	io_txtindata.curnodeinst = io_txtindata.nodelist[atoi(io_keyword)];
+	io_txtindata.curnodeinst = io_txtindata.nodelist[eatoi(io_keyword)];
 	io_txtindata.textlevel = INNODEINST;
 	io_txtindata.varpos = INVNODEINST;
 }
@@ -1820,14 +1822,14 @@ void io_nodtyp(void)
 {
 	REGISTER NODEPROTO *np;
 	REGISTER TECHNOLOGY *tech;
-	REGISTER char *pt, *line;
-	char orig[50];
+	REGISTER CHAR *pt, *line;
+	CHAR orig[50];
 	static INTBIG orignodenamekey = 0;
 
 	line = io_keyword;
 	if (*line == '[')
 	{
-		io_txtindata.curnodeinst->proto = io_txtindata.nodeprotolist[atoi(&line[1])];
+		io_txtindata.curnodeinst->proto = io_txtindata.nodeprotolist[eatoi(&line[1])];
 	} else
 	{
 		for(pt = line; *pt != 0; pt++) if (*pt == ':') break;
@@ -1848,10 +1850,10 @@ void io_nodtyp(void)
 		}
 
 		/* convert "Active-Node" to "P-Active-Node" (MOSIS CMOS) */
-		if (strcmp(line, "Active-Node") == 0)
+		if (estrcmp(line, x_("Active-Node")) == 0)
 		{
 			for(np = tech->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
-				if (strcmp(np->primname, "P-Active-Node") == 0)
+				if (estrcmp(np->primname, x_("P-Active-Node")) == 0)
 			{
 				io_txtindata.curnodeinst->proto = np;
 				return;
@@ -1862,9 +1864,9 @@ void io_nodtyp(void)
 		io_txtindata.curnodeinst->proto = io_convertoldprimitives(tech, line);
 		if (io_txtindata.curnodeinst->proto == gen_invispinprim)
 		{
-			(void)strcpy(orig, "artwork:");
-			(void)strcat(orig, line);
-			if (orignodenamekey == 0) orignodenamekey = makekey("NODE_original_name");
+			(void)estrcpy(orig, x_("artwork:"));
+			(void)estrcat(orig, line);
+			if (orignodenamekey == 0) orignodenamekey = makekey(x_("NODE_original_name"));
 			nextchangequiet();
 			(void)setvalkey((INTBIG)io_txtindata.curnodeinst, VNODEINST,
 				orignodenamekey, (INTBIG)orig, VSTRING|VDONTSAVE);
@@ -1880,22 +1882,22 @@ void io_nodtyp(void)
  */
 void io_nodlx(void)
 {
-	io_txtindata.curnodeinst->lowx = atoi(io_keyword);
+	io_txtindata.curnodeinst->lowx = eatoi(io_keyword);
 }
 
 void io_nodhx(void)
 {
-	io_txtindata.curnodeinst->highx = atoi(io_keyword);
+	io_txtindata.curnodeinst->highx = eatoi(io_keyword);
 }
 
 void io_nodly(void)
 {
-	io_txtindata.curnodeinst->lowy = atoi(io_keyword);
+	io_txtindata.curnodeinst->lowy = eatoi(io_keyword);
 }
 
 void io_nodhy(void)
 {
-	io_txtindata.curnodeinst->highy = atoi(io_keyword);
+	io_txtindata.curnodeinst->highy = eatoi(io_keyword);
 }
 
 /*
@@ -1913,16 +1915,16 @@ void io_nodnam(void)
  */
 void io_noddes(void)
 {
-	REGISTER char *pt;
+	REGISTER CHAR *pt;
 
-	io_txtindata.curnodeinst->textdescript[0] = atoi(io_keyword);
+	io_txtindata.curnodeinst->textdescript[0] = eatoi(io_keyword);
 	for(pt = io_keyword; *pt != 0 && *pt != '/'; pt++) ;
 	if (*pt == 0)
 	{
 		io_txtindata.curnodeinst->textdescript[1] = 0;
 	} else
 	{
-		io_txtindata.curnodeinst->textdescript[1] = atoi(pt+1);
+		io_txtindata.curnodeinst->textdescript[1] = eatoi(pt+1);
 	}
 }
 
@@ -1931,7 +1933,7 @@ void io_noddes(void)
  */
 void io_nodrot(void)
 {
-	io_txtindata.curnodeinst->rotation = atoi(io_keyword);
+	io_txtindata.curnodeinst->rotation = eatoi(io_keyword);
 }
 
 /*
@@ -1939,7 +1941,7 @@ void io_nodrot(void)
  */
 void io_nodtra(void)
 {
-	io_txtindata.curnodeinst->transpose = atoi(io_keyword);
+	io_txtindata.curnodeinst->transpose = eatoi(io_keyword);
 }
 
 /*
@@ -1955,7 +1957,7 @@ void io_nodkse(void)
  */
 void io_nodpoc(void)
 {
-	io_txtindata.curportcount = atoi(io_keyword);
+	io_txtindata.curportcount = eatoi(io_keyword);
 }
 
 /*
@@ -1963,7 +1965,7 @@ void io_nodpoc(void)
  */
 void io_nodbit(void)
 {
-	if (io_txtindata.bitcount == 0) io_txtindata.curnodeinst->userbits = atoi(io_keyword);
+	if (io_txtindata.bitcount == 0) io_txtindata.curnodeinst->userbits = eatoi(io_keyword);
 	io_txtindata.bitcount++;
 }
 
@@ -1972,7 +1974,7 @@ void io_nodbit(void)
  */
 void io_nodusb(void)
 {
-	io_txtindata.curnodeinst->userbits = atoi(io_keyword);
+	io_txtindata.curnodeinst->userbits = eatoi(io_keyword);
 }
 
 /*
@@ -1986,7 +1988,7 @@ void io_newpor(void)
 	if (io_txtindata.version[0] == '1')
 	{
 		/* version 1 files used an index here */
-		cindex = atoi(io_keyword);
+		cindex = eatoi(io_keyword);
 
 		/* dividing is a heuristic used to decypher version 1 files */
 		for(pp = io_txtindata.curnodeinst->proto->firstportproto, i=0; pp != NOPORTPROTO;
@@ -2023,7 +2025,7 @@ void io_porarc(void)
 	if (pi == NOPORTARCINST) longjmp(io_filerror, LONGJMPNOMEM);
 	pi->proto = io_txtindata.curportproto;
 	db_addportarcinst(io_txtindata.curnodeinst, pi);
-	pi->conarcinst = io_txtindata.arclist[atoi(io_keyword)];
+	pi->conarcinst = io_txtindata.arclist[eatoi(io_keyword)];
 	io_txtindata.varpos = INVPORTARCINST;
 	io_txtindata.varaddr = (INTBIG)pi;
 }
@@ -2039,7 +2041,7 @@ void io_porexp(void)
 	if (pe == NOPORTEXPINST) longjmp(io_filerror, LONGJMPNOMEM);
 	pe->proto = io_txtindata.curportproto;
 	db_addportexpinst(io_txtindata.curnodeinst, pe);
-	pe->exportproto = io_txtindata.portprotolist[atoi(io_keyword)];
+	pe->exportproto = io_txtindata.portprotolist[eatoi(io_keyword)];
 	io_txtindata.varpos = INVPORTEXPINST;
 	io_txtindata.varaddr = (INTBIG)pe;
 }
@@ -2051,7 +2053,7 @@ void io_porexp(void)
  */
 void io_newar(void)
 {
-	io_txtindata.curarcinst = io_txtindata.arclist[atoi(io_keyword)];
+	io_txtindata.curarcinst = io_txtindata.arclist[eatoi(io_keyword)];
 	io_txtindata.textlevel = INARCINST;
 	io_txtindata.varpos = INVARCINST;
 }
@@ -2062,7 +2064,7 @@ void io_newar(void)
 void io_arctyp(void)
 {
 	REGISTER ARCPROTO *ap;
-	REGISTER char *pt, *line;
+	REGISTER CHAR *pt, *line;
 	REGISTER TECHNOLOGY *tech;
 
 	line = io_keyword;
@@ -2086,17 +2088,17 @@ void io_arctyp(void)
 	/* convert old Artwork names */
 	if (tech == art_tech)
 	{
-		if (strcmp(line, "Dash-1") == 0)
+		if (estrcmp(line, x_("Dash-1")) == 0)
 		{
 			io_txtindata.curarcinst->proto = art_dottedarc;
 			return;
 		}
-		if (strcmp(line, "Dash-2") == 0)
+		if (estrcmp(line, x_("Dash-2")) == 0)
 		{
 			io_txtindata.curarcinst->proto = art_dashedarc;
 			return;
 		}
-		if (strcmp(line, "Dash-3") == 0)
+		if (estrcmp(line, x_("Dash-3")) == 0)
 		{
 			io_txtindata.curarcinst->proto = art_thickerarc;
 			return;
@@ -2129,7 +2131,7 @@ void io_arcnam(void)
  */
 void io_arcwid(void)
 {
-	io_txtindata.curarcinst->width = atoi(io_keyword);
+	io_txtindata.curarcinst->width = eatoi(io_keyword);
 }
 
 /*
@@ -2137,7 +2139,7 @@ void io_arcwid(void)
  */
 void io_arclen(void)
 {
-	io_txtindata.curarcinst->length = atoi(io_keyword);
+	io_txtindata.curarcinst->length = eatoi(io_keyword);
 }
 
 /*
@@ -2150,7 +2152,7 @@ void io_arcsig(void) {}
  */
 void io_newend(void)
 {
-	io_txtindata.curarcend = atoi(io_keyword);
+	io_txtindata.curarcend = eatoi(io_keyword);
 	io_txtindata.textlevel = INARCEND;
 }
 
@@ -2159,7 +2161,7 @@ void io_newend(void)
  */
 void io_endnod(void)
 {
-	io_txtindata.curarcinst->end[io_txtindata.curarcend].nodeinst = io_txtindata.nodelist[atoi(io_keyword)];
+	io_txtindata.curarcinst->end[io_txtindata.curarcend].nodeinst = io_txtindata.nodelist[eatoi(io_keyword)];
 }
 
 /*
@@ -2179,12 +2181,12 @@ void io_endpt(void)
  */
 void io_endxp(void)
 {
-	io_txtindata.curarcinst->end[io_txtindata.curarcend].xpos = atoi(io_keyword);
+	io_txtindata.curarcinst->end[io_txtindata.curarcend].xpos = eatoi(io_keyword);
 }
 
 void io_endyp(void)
 {
-	io_txtindata.curarcinst->end[io_txtindata.curarcend].ypos = atoi(io_keyword);
+	io_txtindata.curarcinst->end[io_txtindata.curarcend].ypos = eatoi(io_keyword);
 }
 
 /*
@@ -2200,7 +2202,7 @@ void io_arckse(void)
  */
 void io_arcbit(void)
 {
-	if (io_txtindata.bitcount == 0) io_txtindata.curarcinst->userbits = atoi(io_keyword);
+	if (io_txtindata.bitcount == 0) io_txtindata.curarcinst->userbits = eatoi(io_keyword);
 	io_txtindata.bitcount++;
 }
 
@@ -2209,7 +2211,7 @@ void io_arcbit(void)
  */
 void io_arcusb(void)
 {
-	io_txtindata.curarcinst->userbits = atoi(io_keyword);
+	io_txtindata.curarcinst->userbits = eatoi(io_keyword);
 }
 
 /*
@@ -2224,7 +2226,7 @@ void io_arcnet(void) {}
  */
 void io_newpt(void)
 {
-	io_txtindata.curportproto = io_txtindata.portprotolist[atoi(io_keyword)];
+	io_txtindata.curportproto = io_txtindata.portprotolist[eatoi(io_keyword)];
 	io_txtindata.textlevel = INPORTPROTO;
 	io_txtindata.varpos = INVPORTPROTO;
 }
@@ -2243,16 +2245,16 @@ void io_ptnam(void)
  */
 void io_ptdes(void)
 {
-	REGISTER char *pt;
+	REGISTER CHAR *pt;
 
-	io_txtindata.curportproto->textdescript[0] = atoi(io_keyword);
+	io_txtindata.curportproto->textdescript[0] = eatoi(io_keyword);
 	for(pt = io_keyword; *pt != 0 && *pt != '/'; pt++) ;
 	if (*pt == 0)
 	{
 		io_txtindata.curportproto->textdescript[1] = 0;
 	} else
 	{
-		io_txtindata.curportproto->textdescript[1] = atoi(pt+1);
+		io_txtindata.curportproto->textdescript[1] = eatoi(pt+1);
 	}
 }
 
@@ -2261,7 +2263,7 @@ void io_ptdes(void)
  */
 void io_ptsno(void)
 {
-	io_txtindata.curportproto->subnodeinst = io_txtindata.nodelist[atoi(io_keyword)];
+	io_txtindata.curportproto->subnodeinst = io_txtindata.nodelist[eatoi(io_keyword)];
 }
 
 /*
@@ -2289,7 +2291,7 @@ void io_ptkse(void)
  */
 void io_ptbit(void)
 {
-	if (io_txtindata.bitcount == 0) io_txtindata.curportproto->userbits = atoi(io_keyword);
+	if (io_txtindata.bitcount == 0) io_txtindata.curportproto->userbits = eatoi(io_keyword);
 	io_txtindata.bitcount++;
 }
 
@@ -2298,7 +2300,7 @@ void io_ptbit(void)
  */
 void io_ptusb(void)
 {
-	io_txtindata.curportproto->userbits = atoi(io_keyword);
+	io_txtindata.curportproto->userbits = eatoi(io_keyword);
 }
 
 /*
@@ -2310,19 +2312,19 @@ void io_ptnet(void) {}
  * routine to convert the technology name in "line" to a technology.
  * also handles conversion of the old technology name "logic"
  */
-TECHNOLOGY *io_gettechnology(char *line)
+TECHNOLOGY *io_gettechnology(CHAR *line)
 {
 	REGISTER TECHNOLOGY *tech;
 
 	tech = NOTECHNOLOGY;
 	if (io_txtindata.convertmosiscmostechnologies != 0)
 	{
-		if (namesame(line, "mocmossub") == 0) tech = gettechnology("mocmos"); else
-			if (namesame(line, "mocmos") == 0) tech = gettechnology("mocmosold");
+		if (namesame(line, x_("mocmossub")) == 0) tech = gettechnology(x_("mocmos")); else
+			if (namesame(line, x_("mocmos")) == 0) tech = gettechnology(x_("mocmosold"));
 	}
 	if (tech == NOTECHNOLOGY) tech = gettechnology(line);
 	if (tech != NOTECHNOLOGY) return(tech);
-	if (namesame(line, "logic") == 0) tech = sch_tech;
+	if (namesame(line, x_("logic")) == 0) tech = sch_tech;
 	return(tech);
 }
 
