@@ -39,15 +39,15 @@ static INTBIG io_facetnumber, io_nodeinsterror, io_portarcinsterror, io_portexpi
 static void    io_textrecurse(NODEPROTO*);
 static INTBIG  io_countvars(INTBIG, VARIABLE*);
 static void    io_writevars(INTBIG, VARIABLE*, NODEPROTO*);
-static char   *io_makestring(VARIABLE*, NODEPROTO*);
+static CHAR   *io_makestring(VARIABLE*, NODEPROTO*);
 static void    io_makestringvar(void*, INTBIG, INTBIG, NODEPROTO*);
-static void    io_addstring(void*, char*);
-static void    io_printname(char*, FILE*);
+static void    io_addstring(void*, CHAR*);
+static void    io_printname(CHAR*, FILE*);
 
 BOOLEAN io_writetextlibrary(LIBRARY *lib)
 {
-	REGISTER char *name;
-	char file[256], *truename;
+	REGISTER CHAR *name;
+	CHAR file[256], *truename;
 	REGISTER INTBIG i, j, noc, arcinst, poc, facet;
 	REGISTER NODEPROTO *np;
 	REGISTER PORTPROTO *pp;
@@ -60,11 +60,11 @@ BOOLEAN io_writetextlibrary(LIBRARY *lib)
 	REGISTER VIEW *v;
 	REGISTER NODEPROTO **facets;
 
-	(void)strcpy(file, lib->libfile);
-	name = &file[strlen(file)-5];
-	if (strcmp(name, ".elib") == 0) *name = 0;
-	name = &file[strlen(file)-4];
-	if (strcmp(name, ".txt") != 0) (void)strcat(file, ".txt");
+	(void)estrcpy(file, lib->libfile);
+	name = &file[estrlen(file)-5];
+	if (estrcmp(name, x_(".elib")) == 0) *name = 0;
+	name = &file[estrlen(file)-4];
+	if (estrcmp(name, x_(".txt")) != 0) (void)estrcat(file, x_(".txt"));
 	name = truepath(file);
 	io_fileout = xcreate(name, io_filetypetlib, _("Readable Dump File"), &truename);
 	if (io_fileout == NULL)
@@ -107,27 +107,27 @@ BOOLEAN io_writetextlibrary(LIBRARY *lib)
 	}
 
 	/* write header information */
-	xprintf(io_fileout, "****library: \"%s\"\n", lib->libname);
-	xprintf(io_fileout, "version: %s\n", el_version);
-	xprintf(io_fileout, "aids: %ld\n", el_maxtools);
+	xprintf(io_fileout, x_("****library: \"%s\"\n"), lib->libname);
+	xprintf(io_fileout, x_("version: %s\n"), el_version);
+	xprintf(io_fileout, x_("aids: %ld\n"), el_maxtools);
 	for(i=0; i<el_maxtools; i++)
 	{
-		xprintf(io_fileout, "aidname: %s\n", el_tools[i].toolname);
+		xprintf(io_fileout, x_("aidname: %s\n"), el_tools[i].toolname);
 		if (io_countvars(el_tools[i].numvar, el_tools[i].firstvar) != 0)
 			io_writevars(el_tools[i].numvar, el_tools[i].firstvar, NONODEPROTO);
 	}
-	xprintf(io_fileout, "userbits: %ld\n", lib->userbits);
-	xprintf(io_fileout, "techcount: %ld\n", el_maxtech);
+	xprintf(io_fileout, x_("userbits: %ld\n"), lib->userbits);
+	xprintf(io_fileout, x_("techcount: %ld\n"), el_maxtech);
 	for(tech = el_technologies; tech != NOTECHNOLOGY; tech = tech->nexttechnology)
 	{
-		xprintf(io_fileout, "techname: %s lambda: %ld\n", tech->techname, lib->lambda[tech->techindex]);
+		xprintf(io_fileout, x_("techname: %s lambda: %ld\n"), tech->techname, lib->lambda[tech->techindex]);
 		io_writevars(tech->numvar, tech->firstvar, NONODEPROTO);
 	}
 	for(v = el_views; v != NOVIEW; v = v->nextview)
-		xprintf(io_fileout, "view: %s{%s}\n", v->viewname, v->sviewname);
-	xprintf(io_fileout, "cellcount: %ld\n", io_facetnumber);
+		xprintf(io_fileout, x_("view: %s{%s}\n"), v->viewname, v->sviewname);
+	xprintf(io_fileout, x_("cellcount: %ld\n"), io_facetnumber);
 	if (lib->curnodeproto != NONODEPROTO)
-		xprintf(io_fileout, "maincell: %ld\n", lib->curnodeproto->temp1);
+		xprintf(io_fileout, x_("maincell: %ld\n"), lib->curnodeproto->temp1);
 
 	/* write variables on the library */
 	io_writevars(lib->numvar, lib->firstvar, NONODEPROTO);
@@ -137,30 +137,30 @@ BOOLEAN io_writetextlibrary(LIBRARY *lib)
 	{
 		/* write the nodeproto name */
 		np = facets[facet];
-		xprintf(io_fileout, "***cell: %ld\n", np->temp1);
-		xprintf(io_fileout, "name: %s", np->cell->cellname);
+		xprintf(io_fileout, x_("***cell: %ld\n"), np->temp1);
+		xprintf(io_fileout, x_("name: %s"), np->cell->cellname);
 		if (*np->cellview->sviewname != 0)
-			xprintf(io_fileout, "{%s}", np->cellview->sviewname);
-		xprintf(io_fileout, "\n");
-		xprintf(io_fileout, "version: %ld\n", np->version);
-		xprintf(io_fileout, "creationdate: %ld\n", np->creationdate);
-		xprintf(io_fileout, "revisiondate: %ld\n", np->revisiondate);
+			xprintf(io_fileout, x_("{%s}"), np->cellview->sviewname);
+		xprintf(io_fileout, x_("\n"));
+		xprintf(io_fileout, x_("version: %ld\n"), np->version);
+		xprintf(io_fileout, x_("creationdate: %ld\n"), np->creationdate);
+		xprintf(io_fileout, x_("revisiondate: %ld\n"), np->revisiondate);
 
 		/* write the nodeproto bounding box */
-		xprintf(io_fileout, "lowx: %ld highx: %ld lowy: %ld highy: %ld\n",
+		xprintf(io_fileout, x_("lowx: %ld highx: %ld lowy: %ld highy: %ld\n"),
 			np->lowx, np->highx, np->lowy, np->highy);
 
 		/* facets in external libraries mention the library and stop */
 		if (np->cell->lib != lib)
 		{
-			xprintf(io_fileout, "externallibrary: \"%s\"\n",
+			xprintf(io_fileout, x_("externallibrary: \"%s\"\n"),
 				np->cell->lib->libfile);
 			continue;
 		}
 
 		/* write tool information */
-		xprintf(io_fileout, "aadirty: %ld\n", np->adirty);
-		xprintf(io_fileout, "userbits: %ld\n", np->userbits);
+		xprintf(io_fileout, x_("aadirty: %ld\n"), np->adirty);
+		xprintf(io_fileout, x_("userbits: %ld\n"), np->userbits);
 
 		/* count and number the nodes, arcs, and ports */
 		noc = arcinst = poc = 0;
@@ -170,7 +170,7 @@ BOOLEAN io_writetextlibrary(LIBRARY *lib)
 			ai->temp1 = arcinst++;
 		for(pp = np->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
 			pp->temp1 = poc++;
-		xprintf(io_fileout, "nodes: %ld arcs: %ld porttypes: %ld\n", noc, arcinst, poc);
+		xprintf(io_fileout, x_("nodes: %ld arcs: %ld porttypes: %ld\n"), noc, arcinst, poc);
 
 		/* write variables on the facet */
 		io_writevars(np->numvar, np->firstvar, np);
@@ -178,20 +178,20 @@ BOOLEAN io_writetextlibrary(LIBRARY *lib)
 		/* write the nodes in this facet */
 		for(ni = np->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
 		{
-			xprintf(io_fileout, "**node: %ld\n", ni->temp1);
+			xprintf(io_fileout, x_("**node: %ld\n"), ni->temp1);
 			if (ni->proto->primindex == 0)
-				xprintf(io_fileout, "type: [%ld]\n", ni->proto->temp1); else
-					xprintf(io_fileout, "type: %s:%s\n",
+				xprintf(io_fileout, x_("type: [%ld]\n"), ni->proto->temp1); else
+					xprintf(io_fileout, x_("type: %s:%s\n"),
 						ni->proto->tech->techname, ni->proto->primname);
-			xprintf(io_fileout, "lowx: %ld highx: %ld lowy: %ld highy: %ld\n", ni->lowx,
+			xprintf(io_fileout, x_("lowx: %ld highx: %ld lowy: %ld highy: %ld\n"), ni->lowx,
 				ni->highx, ni->lowy, ni->highy);
-			xprintf(io_fileout, "rotation: %d transpose: %d\n", ni->rotation, ni->transpose);
+			xprintf(io_fileout, x_("rotation: %d transpose: %d\n"), ni->rotation, ni->transpose);
 			if (ni->proto->primindex == 0)
 			{
-				xprintf(io_fileout, "descript: %ld/%ld\n", ni->textdescript[0],
+				xprintf(io_fileout, x_("descript: %ld/%ld\n"), ni->textdescript[0],
 					ni->textdescript[1]);
 			}
-			xprintf(io_fileout, "userbits: %ld\n", ni->userbits);
+			xprintf(io_fileout, x_("userbits: %ld\n"), ni->userbits);
 			io_writevars(ni->numvar, ni->firstvar, np);
 
 			pi = ni->firstportarcinst;   pe = ni->firstportexpinst;
@@ -200,17 +200,17 @@ BOOLEAN io_writetextlibrary(LIBRARY *lib)
 				j = 0;
 				while (pi != NOPORTARCINST && pi->proto == pp)
 				{
-					if (j == 0) xprintf(io_fileout, "*port: %s\n", pp->protoname);
+					if (j == 0) xprintf(io_fileout, x_("*port: %s\n"), pp->protoname);
 					j++;
-					xprintf(io_fileout, "arc: %ld\n", pi->conarcinst->temp1);
+					xprintf(io_fileout, x_("arc: %ld\n"), pi->conarcinst->temp1);
 					io_writevars(pi->numvar, pi->firstvar, np);
 					pi = pi->nextportarcinst;
 				}
 				while (pe != NOPORTEXPINST && pe->proto == pp)
 				{
-					if (j == 0) xprintf(io_fileout, "*port: %s\n", pp->protoname);
+					if (j == 0) xprintf(io_fileout, x_("*port: %s\n"), pp->protoname);
 					j++;
-					xprintf(io_fileout, "exported: %ld\n", pe->exportproto->temp1);
+					xprintf(io_fileout, x_("exported: %ld\n"), pe->exportproto->temp1);
 					io_writevars(pe->numvar, pe->firstvar, np);
 					pe = pe->nextportexpinst;
 				}
@@ -221,60 +221,60 @@ BOOLEAN io_writetextlibrary(LIBRARY *lib)
 		poc = 0;
 		for(pp = np->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
 		{
-			xprintf(io_fileout, "**porttype: %ld\n", poc++);
-			xprintf(io_fileout, "subnode: %ld\n", pp->subnodeinst->temp1);
-			xprintf(io_fileout, "subport: %s\n", pp->subportproto->protoname);
-			xprintf(io_fileout, "name: %s\n", pp->protoname);
+			xprintf(io_fileout, x_("**porttype: %ld\n"), poc++);
+			xprintf(io_fileout, x_("subnode: %ld\n"), pp->subnodeinst->temp1);
+			xprintf(io_fileout, x_("subport: %s\n"), pp->subportproto->protoname);
+			xprintf(io_fileout, x_("name: %s\n"), pp->protoname);
 
 			/* need to write both words */
-			xprintf(io_fileout, "descript: %ld/%ld\n", pp->textdescript[0],
+			xprintf(io_fileout, x_("descript: %ld/%ld\n"), pp->textdescript[0],
 				pp->textdescript[1]);
-			xprintf(io_fileout, "userbits: %ld\n", pp->userbits);
+			xprintf(io_fileout, x_("userbits: %ld\n"), pp->userbits);
 			io_writevars(pp->numvar, pp->firstvar, np);
 		}
 
 		/* write the arcs in this facet */
 		for(ai = np->firstarcinst; ai != NOARCINST; ai = ai->nextarcinst)
 		{
-			xprintf(io_fileout, "**arc: %ld\n", ai->temp1);
-			xprintf(io_fileout, "type: %s:%s\n", ai->proto->tech->techname, ai->proto->protoname);
-			xprintf(io_fileout, "width: %ld length: %ld\n", ai->width, ai->length);
-			xprintf(io_fileout, "userbits: %ld\n", ai->userbits);
+			xprintf(io_fileout, x_("**arc: %ld\n"), ai->temp1);
+			xprintf(io_fileout, x_("type: %s:%s\n"), ai->proto->tech->techname, ai->proto->protoname);
+			xprintf(io_fileout, x_("width: %ld length: %ld\n"), ai->width, ai->length);
+			xprintf(io_fileout, x_("userbits: %ld\n"), ai->userbits);
 			for(i=0; i<2; i++)
 			{
-				xprintf(io_fileout, "*end: %ld\n", i);
-				xprintf(io_fileout, "node: %ld\n", ai->end[i].nodeinst->temp1);
-				xprintf(io_fileout, "nodeport: %s\n", ai->end[i].portarcinst->proto->protoname);
-				xprintf(io_fileout, "xpos: %ld ypos: %ld\n", ai->end[i].xpos, ai->end[i].ypos);
+				xprintf(io_fileout, x_("*end: %ld\n"), i);
+				xprintf(io_fileout, x_("node: %ld\n"), ai->end[i].nodeinst->temp1);
+				xprintf(io_fileout, x_("nodeport: %s\n"), ai->end[i].portarcinst->proto->protoname);
+				xprintf(io_fileout, x_("xpos: %ld ypos: %ld\n"), ai->end[i].xpos, ai->end[i].ypos);
 			}
 			io_writevars(ai->numvar, ai->firstvar, np);
 		}
-		xprintf(io_fileout, "celldone: %s\n", np->cell->cellname);
+		xprintf(io_fileout, x_("celldone: %s\n"), np->cell->cellname);
 	}
 
 	/* print any variable-related error messages */
 	if (io_nodeinsterror != 0)
-		ttyputmsg("Warning: %ld NODEINST pointers point outside facet: not saved", io_nodeinsterror);
+		ttyputmsg(x_("Warning: %ld NODEINST pointers point outside facet: not saved"), io_nodeinsterror);
 	if (io_arcinsterror != 0)
-		ttyputmsg("Warning: %ld ARCINST pointers point outside facet: not saved", io_arcinsterror);
+		ttyputmsg(x_("Warning: %ld ARCINST pointers point outside facet: not saved"), io_arcinsterror);
 	if (io_portprotoerror != 0)
-		ttyputmsg("Warning: %ld PORTPROTO pointers point outside facet: not saved", io_portprotoerror);
+		ttyputmsg(x_("Warning: %ld PORTPROTO pointers point outside facet: not saved"), io_portprotoerror);
 	if (io_portarcinsterror != 0)
-		ttyputmsg("Warning: %ld PORTARCINST pointers could not be saved", io_portarcinsterror);
+		ttyputmsg(x_("Warning: %ld PORTARCINST pointers could not be saved"), io_portarcinsterror);
 	if (io_portexpinsterror != 0)
-		ttyputmsg("Warning: %ld PORTEXPINST pointers could not be saved", io_portexpinsterror);
+		ttyputmsg(x_("Warning: %ld PORTEXPINST pointers could not be saved"), io_portexpinsterror);
 	if (io_geomerror != 0)
-		ttyputmsg("Warning: %ld GEOM pointers could not be saved", io_geomerror);
+		ttyputmsg(x_("Warning: %ld GEOM pointers could not be saved"), io_geomerror);
 	if (io_rtnodeerror != 0)
-		ttyputmsg("Warning: %ld RTNODE pointers could not be saved", io_rtnodeerror);
+		ttyputmsg(x_("Warning: %ld RTNODE pointers could not be saved"), io_rtnodeerror);
 	if (io_libraryerror != 0)
-		ttyputmsg("Warning: LIBRARY pointers could not be saved", io_libraryerror);
+		ttyputmsg(x_("Warning: LIBRARY pointers could not be saved"), io_libraryerror);
 
 	/* clean up and return */
 	xclose(io_fileout);
 	ttyputmsg(_("%s written"), truename);
 	lib->userbits &= ~(LIBCHANGEDMAJOR | LIBCHANGEDMINOR);
-	if (io_facetnumber > 0) efree((char *)facets);
+	if (io_facetnumber > 0) efree((CHAR *)facets);
 	return(FALSE);
 }
 
@@ -316,31 +316,31 @@ INTBIG io_countvars(INTBIG numvar, VARIABLE *firstvar)
  */
 void io_writevars(INTBIG numvar, VARIABLE *firstvar, NODEPROTO *curnodeproto)
 {
-	REGISTER char *pt;
+	REGISTER CHAR *pt;
 	REGISTER INTBIG i;
 	REGISTER VARIABLE *var;
 
 	i = io_countvars(numvar, firstvar);
 	if (i == 0) return;
 
-	xprintf(io_fileout, "variables: %ld\n", i);
+	xprintf(io_fileout, x_("variables: %ld\n"), i);
 	for(i=0; i<numvar; i++)
 	{
 		var = &firstvar[i];
 		if ((var->type & VDONTSAVE) != 0) continue;
 		pt = io_makestring(var, curnodeproto);
-		if (pt == 0) pt = "";
-		io_printname((char *)var->key, io_fileout);
+		if (pt == 0) pt = x_("");
+		io_printname((CHAR *)var->key, io_fileout);
 		if ((var->type&(VLENGTH|VISARRAY)) != VISARRAY)
 		{
-			xprintf(io_fileout, "[0%o,0%o/0%o]: ", var->type, var->textdescript[0],
+			xprintf(io_fileout, x_("[0%o,0%o/0%o]: "), var->type, var->textdescript[0],
 				var->textdescript[1]);
 		} else
 		{
-			xprintf(io_fileout, "(%ld)[0%o,0%o/0%o]: ", getlength(var), var->type,
+			xprintf(io_fileout, x_("(%ld)[0%o,0%o/0%o]: "), getlength(var), var->type,
 				var->textdescript[0], var->textdescript[1]);
 		}
-		xprintf(io_fileout, "%s\n", pt);
+		xprintf(io_fileout, x_("%s\n"), pt);
 	}
 }
 
@@ -348,11 +348,11 @@ void io_writevars(INTBIG numvar, VARIABLE *firstvar, NODEPROTO *curnodeproto)
  * routine to convert variable "var" to a string for printing in the text file.
  * returns zero on error
  */
-char *io_makestring(VARIABLE *var, NODEPROTO *curnodeproto)
+CHAR *io_makestring(VARIABLE *var, NODEPROTO *curnodeproto)
 {
 	REGISTER INTBIG i, len;
-	char line[50];
-	REGISTER char *pt;
+	CHAR line[50];
+	REGISTER CHAR *pt;
 	REGISTER void *infstr;
 
 	if (var == NOVARIABLE) return(0);
@@ -370,7 +370,7 @@ char *io_makestring(VARIABLE *var, NODEPROTO *curnodeproto)
 			{
 				if ((i&1) == 0)
 				{
-					(void)sprintf(line, "0%lo", ((INTBIG *)var->addr)[i+1]);
+					(void)esnprintf(line, 50, x_("0%lo"), ((INTBIG *)var->addr)[i+1]);
 					addstringtoinfstr(infstr, line);
 				} else
 				{
@@ -382,7 +382,7 @@ char *io_makestring(VARIABLE *var, NODEPROTO *curnodeproto)
 				switch ((var->type&VTYPE))
 				{
 					case VCHAR:
-						io_makestringvar(infstr, var->type, ((INTBIG)((char *)var->addr)[i]),
+						io_makestringvar(infstr, var->type, ((INTBIG)((CHAR *)var->addr)[i]),
 							curnodeproto);
 						break;
 
@@ -414,7 +414,7 @@ char *io_makestring(VARIABLE *var, NODEPROTO *curnodeproto)
  */
 void io_makestringvar(void *infstr, INTBIG type, INTBIG addr, NODEPROTO *curnodeproto)
 {
-	char line[100];
+	CHAR line[100];
 	REGISTER INTBIG cindex;
 	REGISTER NODEINST *ni;
 	REGISTER NODEPROTO *np;
@@ -436,27 +436,27 @@ void io_makestringvar(void *infstr, INTBIG type, INTBIG addr, NODEPROTO *curnode
 		case VSHORT:
 		case VBOOLEAN:
 		case VFRACT:
-			(void)sprintf(line, "%ld", addr);
+			(void)esnprintf(line, 100, x_("%ld"), addr);
 			addstringtoinfstr(infstr, line);
 			break;
 		case VADDRESS:
-			(void)sprintf(line, "0%lo", addr);
+			(void)esnprintf(line, 100, x_("0%lo"), addr);
 			addstringtoinfstr(infstr, line);
 			break;
 		case VCHAR:
-			addtoinfstr(infstr, (char)addr);
+			addtoinfstr(infstr, (CHAR)addr);
 			break;
 		case VSTRING:
 			addtoinfstr(infstr, '"');
-			io_addstring(infstr, (char *)addr);
+			io_addstring(infstr, (CHAR *)addr);
 			addtoinfstr(infstr, '"');
 			break;
 		case VFLOAT:
-			(void)sprintf(line, "%f", castfloat(addr));
+			(void)esnprintf(line, 100, x_("%f"), castfloat(addr));
 			addstringtoinfstr(infstr, line);
 			break;
 		case VDOUBLE:
-			(void)sprintf(line, "%f", castfloat(addr));
+			(void)esnprintf(line, 100, x_("%f"), castfloat(addr));
 			addstringtoinfstr(infstr, line);
 			break;
 		case VNODEINST:
@@ -467,19 +467,19 @@ void io_makestringvar(void *infstr, INTBIG type, INTBIG addr, NODEPROTO *curnode
 				if (ni->parent == curnodeproto) cindex = ni->temp1; else
 					io_nodeinsterror++;
 			}
-			(void)sprintf(line, "%ld", cindex);
+			(void)esnprintf(line, 100, x_("%ld"), cindex);
 			addstringtoinfstr(infstr, line);
 			break;
 		case VNODEPROTO:
 			np = (NODEPROTO *)addr;
 			if (np == NONODEPROTO)
 			{
-				addstringtoinfstr(infstr, "-1");
+				addstringtoinfstr(infstr, x_("-1"));
 				break;
 			}
 			if (np->primindex == 0)
 			{
-				(void)sprintf(line, "%ld", np->temp1);
+				(void)esnprintf(line, 100, x_("%ld"), np->temp1);
 				addstringtoinfstr(infstr, line);
 			} else
 			{
@@ -493,10 +493,10 @@ void io_makestringvar(void *infstr, INTBIG type, INTBIG addr, NODEPROTO *curnode
 			pi = (PORTARCINST *)addr;
 			if (pi == NOPORTARCINST)
 			{
-				addstringtoinfstr(infstr, "NOPORTARCINST");
+				addstringtoinfstr(infstr, x_("NOPORTARCINST"));
 				break;
 			}
-			(void)sprintf(line, "portarc%ld", (INTBIG)pi);
+			(void)esnprintf(line, 100, x_("portarc%ld"), (INTBIG)pi);
 			addstringtoinfstr(infstr, line);
 			break;
 		case VPORTEXPINST:
@@ -504,10 +504,10 @@ void io_makestringvar(void *infstr, INTBIG type, INTBIG addr, NODEPROTO *curnode
 			pe = (PORTEXPINST *)addr;
 			if (pe == NOPORTEXPINST)
 			{
-				addstringtoinfstr(infstr, "NOPORTEXPINST");
+				addstringtoinfstr(infstr, x_("NOPORTEXPINST"));
 				break;
 			}
-			(void)sprintf(line, "portexp%ld", (INTBIG)pe);
+			(void)esnprintf(line, 100, x_("portexp%ld"), (INTBIG)pe);
 			addstringtoinfstr(infstr, line);
 			break;
 		case VPORTPROTO:
@@ -518,7 +518,7 @@ void io_makestringvar(void *infstr, INTBIG type, INTBIG addr, NODEPROTO *curnode
 				if (pp->parent == curnodeproto) cindex = pp->temp1; else
 					io_portprotoerror++;
 			}
-			(void)sprintf(line, "%ld", cindex);
+			(void)esnprintf(line, 100, x_("%ld"), cindex);
 			addstringtoinfstr(infstr, line);
 			break;
 		case VARCINST:
@@ -529,14 +529,14 @@ void io_makestringvar(void *infstr, INTBIG type, INTBIG addr, NODEPROTO *curnode
 				if (ai->parent == curnodeproto) cindex = ai->temp1; else
 					io_arcinsterror++;
 			}
-			(void)sprintf(line, "%ld", cindex);
+			(void)esnprintf(line, 100, x_("%ld"), cindex);
 			addstringtoinfstr(infstr, line);
 			break;
 		case VARCPROTO:
 			ap = (ARCPROTO *)addr;
 			if (ap == NOARCPROTO)
 			{
-				addstringtoinfstr(infstr, "NOARCPROTO");
+				addstringtoinfstr(infstr, x_("NOARCPROTO"));
 				break;
 			}
 			io_addstring(infstr, ap->tech->techname);
@@ -548,10 +548,10 @@ void io_makestringvar(void *infstr, INTBIG type, INTBIG addr, NODEPROTO *curnode
 			geom = (GEOM *)addr;
 			if (geom == NOGEOM)
 			{
-				addstringtoinfstr(infstr, "NOGEOM");
+				addstringtoinfstr(infstr, x_("NOGEOM"));
 				break;
 			}
-			(void)sprintf(line, "geom%ld", (INTBIG)geom);
+			(void)esnprintf(line, 100, x_("geom%ld"), (INTBIG)geom);
 			addstringtoinfstr(infstr, line);
 			break;
 		case VLIBRARY:
@@ -559,7 +559,7 @@ void io_makestringvar(void *infstr, INTBIG type, INTBIG addr, NODEPROTO *curnode
 			lib = (LIBRARY *)addr;
 			if (lib == NOLIBRARY)
 			{
-				addstringtoinfstr(infstr, "NOLIBRARY");
+				addstringtoinfstr(infstr, x_("NOLIBRARY"));
 				break;
 			}
 			addtoinfstr(infstr, '"');
@@ -570,7 +570,7 @@ void io_makestringvar(void *infstr, INTBIG type, INTBIG addr, NODEPROTO *curnode
 			tech = (TECHNOLOGY *)addr;
 			if (tech == NOTECHNOLOGY)
 			{
-				addstringtoinfstr(infstr, "NOTECHNOLOGY");
+				addstringtoinfstr(infstr, x_("NOTECHNOLOGY"));
 				break;
 			}
 			io_addstring(infstr, tech->techname);
@@ -579,7 +579,7 @@ void io_makestringvar(void *infstr, INTBIG type, INTBIG addr, NODEPROTO *curnode
 			tool = (TOOL *)addr;
 			if (tool == NOTOOL)
 			{
-				addstringtoinfstr(infstr, "NOTOOL");
+				addstringtoinfstr(infstr, x_("NOTOOL"));
 				break;
 			}
 			io_addstring(infstr, tool->toolname);
@@ -589,10 +589,10 @@ void io_makestringvar(void *infstr, INTBIG type, INTBIG addr, NODEPROTO *curnode
 			rtn = (RTNODE *)addr;
 			if (rtn == NORTNODE)
 			{
-				addstringtoinfstr(infstr, "NORTNODE");
+				addstringtoinfstr(infstr, x_("NORTNODE"));
 				break;
 			}
-			(void)sprintf(line, "rtn%ld", (INTBIG)rtn);
+			(void)esnprintf(line, 100, x_("rtn%ld"), (INTBIG)rtn);
 			addstringtoinfstr(infstr, line);
 			break;
 		case VNETWORK:
@@ -612,7 +612,7 @@ void io_makestringvar(void *infstr, INTBIG type, INTBIG addr, NODEPROTO *curnode
  * routine to add the string "str" to the infinite string and to quote the
  * special characters '[', ']', '"', and '^'.
  */
-void io_addstring(void *infstr, char *str)
+void io_addstring(void *infstr, CHAR *str)
 {
 
 	while (*str != 0)
@@ -628,9 +628,9 @@ void io_addstring(void *infstr, char *str)
  * conversion performed is to quote with a backslash any of the characters
  * '(', '[', or '^'.
  */
-void io_printname(char *name, FILE *file)
+void io_printname(CHAR *name, FILE *file)
 {
-	REGISTER char *pt;
+	REGISTER CHAR *pt;
 
 	for(pt = name; *pt != 0; pt++)
 	{
