@@ -49,11 +49,11 @@ static void io_vhdlreadfile(LIBRARY *lib, FILE *io, void *dia);
 BOOLEAN io_readvhdllibrary(LIBRARY *lib)
 {
 	REGISTER FILE *io;
-	char *pt;
+	CHAR *pt;
 	void *dia;
 
 	/* get the VHDL file */
-	if ((io = xopen(lib->libfile, io_filetypevhdl, "", &pt)) == NULL)
+	if ((io = xopen(lib->libfile, io_filetypevhdl, x_(""), &pt)) == NULL)
 	{
 		ttyputerr(_("File %s not found"), lib->libfile);
 		return(TRUE);
@@ -85,8 +85,8 @@ BOOLEAN io_readvhdllibrary(LIBRARY *lib)
 
 void io_vhdlreadfile(LIBRARY *lib, FILE *io, void *dia)
 {
-	char *pt, *start, text[MAXCHARS], facetname[256], endtag[256];
-	REGISTER char save;
+	CHAR *pt, *start, text[MAXCHARS], facetname[256], endtag[256];
+	REGISTER CHAR save;
 	enum {SECTIONNONE, SECTIONCOMPONENT, SECTIONENTITY, SECTIONARCHITECTURE} sectiontype;
 	REGISTER INTBIG i, len, curLength, sectionnamelen;
 	REGISTER NODEPROTO *storagefacet;
@@ -113,11 +113,11 @@ void io_vhdlreadfile(LIBRARY *lib, FILE *io, void *dia)
 			pt = text;
 			while (*pt == ' ' || *pt == '\t') pt++;
 			sectiontype = SECTIONNONE;
-			if (namesamen(pt, "component", (sectionnamelen = 9)) == 0)
+			if (namesamen(pt, x_("component"), (sectionnamelen = 9)) == 0)
 				sectiontype = SECTIONCOMPONENT;
-			else if (namesamen(pt, "entity", (sectionnamelen = 6)) == 0)
+			else if (namesamen(pt, x_("entity"), (sectionnamelen = 6)) == 0)
 				sectiontype = SECTIONENTITY;
-			else if (namesamen(pt, "architecture", (sectionnamelen = 12)) == 0)
+			else if (namesamen(pt, x_("architecture"), (sectionnamelen = 12)) == 0)
 				sectiontype = SECTIONARCHITECTURE;
 			if (sectiontype != SECTIONNONE)
 			{
@@ -129,14 +129,14 @@ void io_vhdlreadfile(LIBRARY *lib, FILE *io, void *dia)
 					while (*pt != 0 && *pt != ' ' && *pt != '\t') pt++;
 					save = *pt;
 					*pt = 0;
-					strcpy(endtag, start);
-					strcpy(facetname, start);
+					estrcpy(endtag, start);
+					estrcpy(facetname, start);
 					*pt = save;
 
 					if (sectiontype == SECTIONARCHITECTURE)
 					{
 						while (*pt == ' ' || *pt == '\t') pt++;
-						if (namesamen(pt, "of", 2) == 0)
+						if (namesamen(pt, x_("of"), 2) == 0)
 						{
 							pt += 2;
 							while (*pt == ' ' || *pt == '\t') pt++;
@@ -144,7 +144,7 @@ void io_vhdlreadfile(LIBRARY *lib, FILE *io, void *dia)
 							while (*pt != 0 && *pt != ' ' && *pt != '\t') pt++;
 							save = *pt;
 							*pt = 0;
-							strcpy(facetname, start);
+							estrcpy(facetname, start);
 							*pt = save;
 						}
 					}
@@ -165,12 +165,12 @@ void io_vhdlreadfile(LIBRARY *lib, FILE *io, void *dia)
 						{
 							len = getlength(var);
 							for(i=0; i<len; i++)
-								addtostringarray(stringarray, ((char **)var->addr)[i]);
-							addtostringarray(stringarray, "");
+								addtostringarray(stringarray, ((CHAR **)var->addr)[i]);
+							addtostringarray(stringarray, x_(""));
 						}
 					} else
 					{
-						strcat(facetname, "{vhdl}");
+						estrcat(facetname, x_("{vhdl}"));
 						storagefacet = newnodeproto(facetname, lib);
 						if (storagefacet == NONODEPROTO)
 						{
@@ -190,7 +190,7 @@ void io_vhdlreadfile(LIBRARY *lib, FILE *io, void *dia)
 		/* see if this is the last line */
 		pt = text;
 		while (*pt == ' ' || *pt == '\t') pt++;
-		if (namesamen(pt, "end", 3) == 0)
+		if (namesamen(pt, x_("end"), 3) == 0)
 		{
 			pt += 3;
 			if (*pt == ' ' || *pt == '\t')
@@ -199,7 +199,7 @@ void io_vhdlreadfile(LIBRARY *lib, FILE *io, void *dia)
 				switch (sectiontype)
 				{
 					case SECTIONCOMPONENT:
-						if (namesamen(pt, "component", 9) == 0)
+						if (namesamen(pt, x_("component"), 9) == 0)
 						{
 							stringarraytotextfacet(stringarray, storagefacet, TRUE);
 							killstringarray(stringarray);
