@@ -129,9 +129,9 @@ static void com_add_object_to_object(OBJECT**, OBJECT*);
 static LINE *com_make_object_line(LINE*, OBJECT*);
 static void com_clearspace(LINE*);
 static void com_freeobject(OBJECT*);
-static char *com_describeline(LINE*);
+static CHAR *com_describeline(LINE*);
 static void com_addlinedescription(void*, LINE*);
-static char *com_describeobject(OBJECT*);
+static CHAR *com_describeobject(OBJECT*);
 static void com_createobjects(NODEINST*, INTBIG, OBJECT**, OBJECT**);
 static OBJECT *com_make_ai_object(ARCINST*, OBJECT*, XARRAY, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG);
 static BOOLEAN com_examineonefacet(NODEPROTO*, INTBIG, BOOLEAN);
@@ -139,32 +139,32 @@ static void comp_optionsdlog(void);
 
 /* the COMPACTOR tool table */
 static COMCOMP comcp = {NOKEYWORD, topoffacets, nextfacets, NOPARAMS,
-	0, " \t", M_("facet to be rechecked"), M_("default is current facet")};
+	0, x_(" \t"), M_("facet to be rechecked"), M_("default is current facet")};
 static KEYWORD comnotopt[] =
 {
-	{"spread",         0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
+	{x_("spread"),         0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
 	TERMKEY
 };
 static COMCOMP comnotp = {comnotopt, NOTOPLIST, NONEXTLIST, NOPARAMS,
-	0, " \t", M_("Compactor negative action"), 0};
+	0, x_(" \t"), M_("Compactor negative action"), 0};
 static KEYWORD comhvopt[] =
 {
-	{"horizontal",       0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
-	{"vertical",         0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
+	{x_("horizontal"),       0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
+	{x_("vertical"),         0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
 	TERMKEY
 };
 static COMCOMP comhvp = {comhvopt, NOTOPLIST, NONEXTLIST, NOPARAMS,
-	0, " \t", M_("Compactor direction"), 0};
+	0, x_(" \t"), M_("Compactor direction"), 0};
 static KEYWORD comopt[] =
 {
-	{"check",          2,{&comhvp,&comcp,NOKEY,NOKEY,NOKEY}},
-	{"not",            1,{&comnotp,NOKEY,NOKEY,NOKEY,NOKEY}},
-	{"debug-toggle",   0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
-	{"spread",         0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
+	{x_("check"),          2,{&comhvp,&comcp,NOKEY,NOKEY,NOKEY}},
+	{x_("not"),            1,{&comnotp,NOKEY,NOKEY,NOKEY,NOKEY}},
+	{x_("debug-toggle"),   0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
+	{x_("spread"),         0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
 	TERMKEY
 };
 COMCOMP com_compactp = {comopt, NOTOPLIST, NONEXTLIST, NOPARAMS,
-	0, " \t", M_("Compactor action"), M_("show defaults")};
+	0, x_(" \t"), M_("Compactor action"), M_("show defaults")};
 
        TOOL     *com_tool;
 static INTBIG    com_spread_key;		/* variable key for "COM_spread" */
@@ -175,7 +175,7 @@ static INTBIG    com_do_axis;
 
 /************************ CONTROL ***********************/
 
-void com_init(INTBIG *argc, char *argv[], TOOL *thistool)
+void com_init(INTBIG *argc, CHAR1 *argv[], TOOL *thistool)
 {
 	/* ignore pass 3 initialization */
 	if (thistool == 0) return;
@@ -183,14 +183,14 @@ void com_init(INTBIG *argc, char *argv[], TOOL *thistool)
 	/* miscellaneous initialization during pass 2 */
 	if (thistool == NOTOOL)
 	{
-		com_spread_key = makekey("COM_spread");
+		com_spread_key = makekey(x_("COM_spread"));
 		nextchangequiet();
 		(void)setvalkey((INTBIG)com_tool, VTOOL, com_spread_key, 0, VINTEGER|VDONTSAVE);
 		com_debug = FALSE;
 		com_do_axis = VERTICAL;
 		com_conv_layer = NOTECHARRAY;
 		registertechnologycache(com_buildtechnologies, 0, 0);
-		DiaDeclareHook("compopt", &com_compactp, comp_optionsdlog);
+		DiaDeclareHook(x_("compopt"), &com_compactp, comp_optionsdlog);
 		return;
 	}
 
@@ -214,8 +214,8 @@ void com_buildtechnologies(void)
 		cur_tech_array = next_techarray)
 	{
 		next_techarray = cur_tech_array->nexttecharray;
-		efree((char *)cur_tech_array->layer);
-		efree((char *)cur_tech_array);
+		efree((CHAR *)cur_tech_array->layer);
+		efree((CHAR *)cur_tech_array);
 	}
 	com_conv_layer = NOTECHARRAY;
 
@@ -261,8 +261,8 @@ void com_done(void)
 		cur_tech_array = next_techarray)
 	{
 		next_techarray = cur_tech_array->nexttecharray;
-		efree((char *)cur_tech_array->layer);
-		efree((char *)cur_tech_array);
+		efree((CHAR *)cur_tech_array->layer);
+		efree((CHAR *)cur_tech_array);
 	}
 	com_conv_layer = NOTECHARRAY;
 #endif
@@ -297,11 +297,11 @@ void com_slice(void)
 	} else setactivity(_("Compaction"));
 }
 
-void com_set(INTBIG count, char *par[])
+void com_set(INTBIG count, CHAR *par[])
 {
 	REGISTER NODEPROTO *np;
 	REGISTER INTBIG l;
-	REGISTER char *pp;
+	REGISTER CHAR *pp;
 	REGISTER VARIABLE *var;
 
 	if (count == 0)
@@ -315,8 +315,8 @@ void com_set(INTBIG count, char *par[])
 		return;
 	}
 
-	l = strlen(pp = par[0]);
-	if (namesamen(pp, "not", l) == 0)
+	l = estrlen(pp = par[0]);
+	if (namesamen(pp, x_("not"), l) == 0)
 	{
 		if (count <= 1)
 		{
@@ -328,25 +328,25 @@ void com_set(INTBIG count, char *par[])
 				return;
 			}
 		}
-		l = strlen(pp = par[1]);
-		if (namesamen(pp, "spread", l) == 0)
+		l = estrlen(pp = par[1]);
+		if (namesamen(pp, x_("spread"), l) == 0)
 		{
 			(void)setvalkey((INTBIG)com_tool, VTOOL, com_spread_key, 0, VINTEGER|VDONTSAVE);
 			ttyputverbose(M_("Compactor will not spread designs"));
 			return;
 		}
-		ttyputbadusage("telltool compaction not");
+		ttyputbadusage(x_("telltool compaction not"));
 		return;
 	}
 
-	if (namesamen(pp, "spread", l) == 0)
+	if (namesamen(pp, x_("spread"), l) == 0)
 	{
 		(void)setvalkey((INTBIG)com_tool, VTOOL, com_spread_key, 1, VINTEGER|VDONTSAVE);
 		ttyputverbose(M_("Compactor will spread if necessary"));
 		return;
 	}
 
-	if (namesamen(pp, "check", l) == 0)
+	if (namesamen(pp, x_("check"), l) == 0)
 	{
 		/* make sure network tool is on */
 		if ((net_tool->toolstate&TOOLON) == 0)
@@ -367,11 +367,11 @@ void com_set(INTBIG count, char *par[])
 				return;
 			}
 		}
-		l = strlen(pp = par[1]);
-		if (namesamen(pp, "horizontal", l) == 0) com_do_axis = HORIZONTAL; else
-		if (namesamen(pp, "vertical", l) == 0) com_do_axis = VERTICAL; else
+		l = estrlen(pp = par[1]);
+		if (namesamen(pp, x_("horizontal"), l) == 0) com_do_axis = HORIZONTAL; else
+		if (namesamen(pp, x_("vertical"), l) == 0) com_do_axis = VERTICAL; else
 		{
-			ttyputbadusage("telltool compaction check");
+			ttyputbadusage(x_("telltool compaction check"));
 			return;
 		}
 
@@ -403,7 +403,7 @@ void com_set(INTBIG count, char *par[])
 		return;
 	}
 
-	if (namesamen(pp, "debug-toggle", l) == 0)
+	if (namesamen(pp, x_("debug-toggle"), l) == 0)
 	{
 		if (!com_debug)
 		{
@@ -416,7 +416,7 @@ void com_set(INTBIG count, char *par[])
 		}
 		return;
 	}
-	ttyputbadusage("telltool compaction");
+	ttyputbadusage(x_("telltool compaction"));
 }
 
 /************************ COMPACTION ***********************/
@@ -1102,7 +1102,7 @@ BOOLEAN com_compact(LINE *line, LINE *other_line, INTBIG axis, BOOLEAN change,
 						com_describeobject(thisoreason), com_describeobject(otheroreason),
 							layername(thispreason->poly->tech, thispreason->poly->layer));
 				}
-				ttyputmsg("%s", returninfstr(infstr));
+				ttyputmsg(x_("%s"), returninfstr(infstr));
 			}
 		}
 		if (best_motion > 0 || (spread != 0 && best_motion < 0))
@@ -1535,7 +1535,7 @@ BOOLEAN com_move(LINE *line, INTBIG movex, INTBIG movey, BOOLEAN change)
 	if (line == NOLINE) return(FALSE);
 	if (!change && move != 0)
 	{
-		(void)asktool(us_tool, "clear");
+		(void)asktool(us_tool, x_("clear"));
 		change = TRUE;
 	}
 
@@ -1733,7 +1733,7 @@ void com_clearspace(LINE *line)
 		}
 
 		/* erase the line */
-		efree((char *)cur_line);
+		efree((CHAR *)cur_line);
 	}
 }
 
@@ -1747,17 +1747,17 @@ void com_freeobject(OBJECT *cur_object)
 		polys = cur_object->firstpolylist;
 		cur_object->firstpolylist = polys->nextpolylist;
 		freepolygon(polys->poly);
-		efree((char *)polys);
+		efree((CHAR *)polys);
 	}
 
 	/* erase the object */
-	efree((char *)cur_object);
+	efree((CHAR *)cur_object);
 }
 
 /******************** DEBUGGING ********************/
 
 /* debugging routine to return a description of line "cur_line" */
-char *com_describeline(LINE *cur_line)
+CHAR *com_describeline(LINE *cur_line)
 {
 	REGISTER void *infstr;
 
@@ -1781,7 +1781,7 @@ void com_addlinedescription(void *infstr, LINE *cur_line)
 }
 
 /* debugging routine to return a description of object "cur_object" */
-char *com_describeobject(OBJECT *cur_object)
+CHAR *com_describeobject(OBJECT *cur_object)
 {
 	if (!cur_object->isnode)
 		return(describearcinst(cur_object->inst.ai));
