@@ -42,12 +42,12 @@
 /* the ERC tool table */
 static KEYWORD ercopt[] =
 {
-	{"well-check",    0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
-	{"antenna-rules", 0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
+	{x_("well-check"),    0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
+	{x_("antenna-rules"), 0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
 	TERMKEY
 };
 COMCOMP erc_tablep = {ercopt, NOTOPLIST, NONEXTLIST, NOPARAMS,
-	0, " \t", M_("Electrical Rules action"), M_("show defaults")};
+	0, x_(" \t"), M_("Electrical Rules action"), M_("show defaults")};
 
 /* well contacts */
 #define NOWELLCON ((WELLCON *)-1)
@@ -118,7 +118,7 @@ static INTBIG       erc_welllayer(TECHNOLOGY *tech, INTBIG layer);
 /*
  * tool initialization
  */
-void erc_init(INTBIG *argc, char *argv[], TOOL *thistool)
+void erc_init(INTBIG *argc, CHAR1 *argv[], TOOL *thistool)
 {
 	extern COMCOMP us_debugcp;
 
@@ -127,12 +127,12 @@ void erc_init(INTBIG *argc, char *argv[], TOOL *thistool)
 
 	/* copy tool pointer during pass 1 */
 	erc_tool = thistool;
-	erc_optionskey = makekey("ERC_options");
+	erc_optionskey = makekey(x_("ERC_options"));
 	nextchangequiet();
 	setvalkey((INTBIG)erc_tool, VTOOL, erc_optionskey, DEFERCBITS, VINTEGER|VDONTSAVE);
-	DiaDeclareHook("ercopt", &erc_tablep, erc_optionsdlog);
-	DiaDeclareHook("ercantennaopt", &us_debugcp, erc_antoptionsdlog);
-	erc_antennaarcratiokey = makekey("ERC_antenna_arc_ratio");
+	DiaDeclareHook(x_("ercopt"), &erc_tablep, erc_optionsdlog);
+	DiaDeclareHook(x_("ercantennaopt"), &us_debugcp, erc_antoptionsdlog);
+	erc_antennaarcratiokey = makekey(x_("ERC_antenna_arc_ratio"));
 }
 
 void erc_done(void)
@@ -147,21 +147,21 @@ void erc_done(void)
 /*
  * Handle commands to the tool from the user.
  */
-void erc_set(INTBIG count, char *par[])
+void erc_set(INTBIG count, CHAR *par[])
 {
 	REGISTER INTBIG l;
 	REGISTER NODEPROTO *np;
-	REGISTER char *pp;
+	REGISTER CHAR *pp;
 
 	if (count == 0)
 	{
-		ttyputusage("telltool erc analyze");
+		ttyputusage(x_("telltool erc analyze"));
 		return;
 	}
 
-	l = strlen(pp = par[0]);
+	l = estrlen(pp = par[0]);
 
-	if (namesamen(pp, "well-check", l) == 0 && l >= 3)
+	if (namesamen(pp, x_("well-check"), l) == 0 && l >= 3)
 	{
 		/* check well and substrate layers */
 		np = getcurfacet();
@@ -169,7 +169,7 @@ void erc_set(INTBIG count, char *par[])
 		return;
 	}
 
-	if (namesamen(pp, "antenna-rules", l) == 0 && l >= 3)
+	if (namesamen(pp, x_("antenna-rules"), l) == 0 && l >= 3)
 	{
 		/* do antenna-rules check */
 		np = getcurfacet();
@@ -177,7 +177,7 @@ void erc_set(INTBIG count, char *par[])
 		return;
 	}
 
-	ttyputbadusage("telltool erc");
+	ttyputbadusage(x_("telltool erc"));
 }
 
 /******************** ANALYSIS ********************/
@@ -193,8 +193,8 @@ void erc_analyzefacet(NODEPROTO *facet)
 	REGISTER TECHNOLOGY *tech;
 	REGISTER LIBRARY *lib;
 	REGISTER BOOLEAN con;
-	REGISTER char *abortseq, *errormsg, *nocontacterror;
-	char errmsg[200];
+	REGISTER CHAR *abortseq, *errormsg, *nocontacterror;
+	CHAR errmsg[200];
 	REGISTER WELLCON *wc, *owc;
 	REGISTER VARIABLE *var;
 	REGISTER PORTPROTO *pp, *opp;
@@ -224,7 +224,7 @@ void erc_analyzefacet(NODEPROTO *facet)
 
 	/* announce start of analysis */
 	infstr = initinfstr();
-	addstringtoinfstr(infstr, _("Checking electrical rules..."));
+	addstringtoinfstr(infstr, _("Checking Wells and Substrates..."));
 	abortseq = getinterruptkey();
 	if (abortseq != 0)
 		formatinfstr(infstr, _(" (type %s to abort)"), abortseq);
@@ -268,6 +268,9 @@ void erc_analyzefacet(NODEPROTO *facet)
 	for(lib = el_curlib; lib != NOLIBRARY; lib = lib->nextlibrary)
 		for(np = lib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
 			np->temp1 = np->temp2 = 0;
+	for(tech = el_technologies; tech != NOTECHNOLOGY; tech = tech->nexttechnology)
+		for(np = tech->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
+			np->temp1 = 0;
 
 	/* run through the work and count the number of polygons */
 	erc_polyscrunched = 0;
@@ -444,19 +447,19 @@ void erc_analyzefacet(NODEPROTO *facet)
 				switch (layertype)
 				{
 					case 1:
-						sprintf(errmsg, _("P-Well areas too close (are %s, should be %s)"),
+						esnprintf(errmsg, 200, _("P-Well areas too close (are %s, should be %s)"),
 							latoa(dist, lambda), latoa(minsep, lambda));
 						break;
 					case 2:
-						sprintf(errmsg, _("N-Well areas too close (are %s, should be %s)"),
+						esnprintf(errmsg, 200, _("N-Well areas too close (are %s, should be %s)"),
 							latoa(dist, lambda), latoa(minsep, lambda));
 						break;
 					case 3:
-						sprintf(errmsg, _("P-Select areas too close (are %s, should be %s)"),
+						esnprintf(errmsg, 200, _("P-Select areas too close (are %s, should be %s)"),
 							latoa(dist, lambda), latoa(minsep, lambda));
 						break;
 					case 4:
-						sprintf(errmsg, _("N-Select areas too close (are %s, should be %s)"),
+						esnprintf(errmsg, 200, _("N-Select areas too close (are %s, should be %s)"),
 							latoa(dist, lambda), latoa(minsep, lambda));
 						break;
 				}
@@ -475,16 +478,16 @@ void erc_analyzefacet(NODEPROTO *facet)
 		switch (layertype)
 		{
 			case 1:
-				err = logerror("P-Well area", erc_facet, 0);
+				err = logerror(x_("P-Well area"), erc_facet, 0);
 				break;
 			case 2:
-				err = logerror("N-Well area", erc_facet, 0);
+				err = logerror(x_("N-Well area"), erc_facet, 0);
 				break;
 			case 3:
-				err = logerror("P-Select area", erc_facet, 0);
+				err = logerror(x_("P-Select area"), erc_facet, 0);
 				break;
 			case 4:
-				err = logerror("N-Select area", erc_facet, 0);
+				err = logerror(x_("N-Select area"), erc_facet, 0);
 		}
 		addpolytoerror(err, wa->poly);
 	}
@@ -493,17 +496,18 @@ void erc_analyzefacet(NODEPROTO *facet)
 	/* show the farthest distance from a well contact */
 	if (erc_worstpwelldist > 0 || erc_worstnwelldist > 0)
 	{
-		(void)asktool(us_tool, "clear");
+		(void)asktool(us_tool, x_("clear"));
+		lambda = lambdaoffacet(facet);
 		if (erc_worstpwelldist > 0)
 		{
-			(void)asktool(us_tool, "show-line", erc_worstpwellconx, erc_worstpwellcony,
+			(void)asktool(us_tool, x_("show-line"), erc_worstpwellconx, erc_worstpwellcony,
 				erc_worstpwelledgex, erc_worstpwelledgey, erc_facet);
 			ttyputmsg(_("Farthest distance from a P-Well contact is %s"),
 				latoa(erc_worstpwelldist, lambda));
 		}
 		if (erc_worstnwelldist > 0)
 		{
-			(void)asktool(us_tool, "show-line", erc_worstnwellconx, erc_worstnwellcony,
+			(void)asktool(us_tool, x_("show-line"), erc_worstnwellconx, erc_worstnwellcony,
 				erc_worstnwelledgex, erc_worstnwelledgey, erc_facet);
 			ttyputmsg(_("Farthest distance from a N-Well contact is %s"),
 				latoa(erc_worstnwelldist, lambda));
@@ -548,10 +552,10 @@ void erc_analyzefacet(NODEPROTO *facet)
 	errors = numerrors();
 	if (errors == 0)
 	{
-		ttyputmsg(_("No ERC errors found (%s)"), explainduration(elapsed));
+		ttyputmsg(_("No Well errors found (%s)"), explainduration(elapsed));
 	} else
 	{
-		ttyputmsg(_("FOUND %ld ERC %s (%s)"), errors, makeplural(_("ERROR"), errors),
+		ttyputmsg(_("FOUND %ld WELL %s (%s)"), errors, makeplural(_("ERROR"), errors),
 			explainduration(elapsed));
 	}
 	termerrorlogging(TRUE);
@@ -691,7 +695,9 @@ void erc_gatherwells(NODEPROTO *np, XARRAY trans, void *merge, BOOLEAN gathernet
 			if (erc_realrun && gathernet)
 			{
 				nfun = nodefunction(ni);
-				/* ? */ ni->proto->temp1++;
+				
+				/* gather count of nodes found */
+				ni->proto->temp1++;
 
 				if (nfun == NPWELL || nfun == NPSUBSTRATE)
 				{
@@ -906,7 +912,7 @@ void erc_freeallwellcons(void)
 	{
 		wc = erc_firstwellcon;
 		erc_firstwellcon = wc->nextwellcon;
-		efree((char *)wc);
+		efree((CHAR *)wc);
 	}
 }
 
@@ -935,7 +941,7 @@ void erc_freeallwellareas(void)
 		wa = erc_firstwellarea;
 		erc_firstwellarea = wa->nextwellarea;
 		freepolygon(wa->poly);
-		efree((char *)wa);
+		efree((CHAR *)wa);
 	}
 }
 
