@@ -215,7 +215,7 @@ void erc_antcheckfacet(NODEPROTO *facet)
 	starttimer();
 
 	/* initialize error logging */
-	initerrorlogging("ERC antenna rules");
+	initerrorlogging(x_("ERC antenna rules"));
 
 	/* now check the facet recursively */
 	lasterrorcount = 0;
@@ -254,8 +254,8 @@ void erc_antcheckfacet(NODEPROTO *facet)
 	termerrorlogging(TRUE);
 
 	/* clean up */
-	efree((char *)erc_antlayerlevel);
-	efree((char *)erc_antlayerforlevel);
+	efree((CHAR *)erc_antlayerlevel);
+	efree((CHAR *)erc_antlayerforlevel);
 }
 
 void erc_antterm(void)
@@ -266,15 +266,15 @@ void erc_antterm(void)
 	{
 		ao = erc_antantennaobjfree;
 		erc_antantennaobjfree = ao->nextantennaobj;
-		if (ao->total > 0) efree((char *)ao->hierstack);
-		efree((char *)ao);
+		if (ao->total > 0) efree((CHAR *)ao->hierstack);
+		efree((CHAR *)ao);
 	}
 	if (erc_antpolylist != 0)
 		freepolylist(erc_antpolylist);
 	if (erc_antpathhashtablesize > 0)
-		efree((char *)erc_antpathhashtable);
+		efree((CHAR *)erc_antpathhashtable);
 	if (erc_antcachedtech != NOTECHNOLOGY)
-		efree((char *)erc_antcachedratios);
+		efree((CHAR *)erc_antcachedratios);
 }
 
 /*
@@ -372,7 +372,7 @@ void erc_antcheckthisfacet(NODEPROTO *facet, INTBIG level)
 				{
 					/* get the area of the antenna */
 #ifdef DEBUGANTENNA
-					asktool(us_tool, "clear");
+					asktool(us_tool, x_("clear"));
 #endif
 					erc_antregionarea = 0.0;
 					mergeextract(vmerge, erc_antgetpolygonarea);
@@ -395,7 +395,7 @@ void erc_antcheckthisfacet(NODEPROTO *facet, INTBIG level)
 					}
 #ifdef DEBUGANTENNA
 					infstr = initinfstr();
-					formatinfstr(infstr, "Facet %s: Level %d: Gate size %s, Region size %s, ratio=%g",
+					formatinfstr(infstr, x_("Facet %s: Level %d: Gate size %s, Region size %s, ratio=%g"),
 						describenodeproto(facet), level-1,
 						latoa((INTBIG)(erc_antgatearea/erc_antlambda), erc_antlambda),
 						latoa((INTBIG)(erc_antregionarea/erc_antlambda), erc_antlambda),
@@ -619,7 +619,7 @@ void erc_antgetpolygonarea(INTBIG layer, TECHNOLOGY *tech, INTBIG *xv, INTBIG *y
 			if (i == 0) lasti = count-1; else lasti = i-1;
 			lastx = xv[lasti];   lasty = yv[lasti];
 			x = xv[i];           y = yv[i];
-			asktool(us_tool, "show-line", lastx, lasty, x, y, (INTBIG)erc_anttopfacet);
+			asktool(us_tool, x_("show-line"), lastx, lasty, x, y, (INTBIG)erc_anttopfacet);
 		}
 	}
 #endif
@@ -695,7 +695,7 @@ void erc_antaddantennaobj(ANTENNAOBJ *ao)
 			erc_antinsertantennaobj(oao);
 		}
 
-		if (oldsize > 0) efree((char *)oldtable);
+		if (oldsize > 0) efree((CHAR *)oldtable);
 	}
 	erc_antinsertantennaobj(ao);
 	erc_antpathhashtablecount++;
@@ -732,7 +732,7 @@ void erc_antloadantennaobj(ANTENNAOBJ *ao, INTBIG depth, NODEINST **stack)
 	ao->depth = depth;
 	if (depth > ao->total)
 	{
-		if (ao->total > 0) efree((char *)ao->hierstack);
+		if (ao->total > 0) efree((CHAR *)ao->hierstack);
 		ao->total = 0;
 		ao->hierstack = (NODEINST **)emalloc(depth * (sizeof (NODEINST *)), erc_tool->cluster);
 		if (ao->hierstack == 0) return;
@@ -784,7 +784,7 @@ INTBIG erc_antratio(INTBIG level)
 		total = 0;
 		for(ap = erc_anttech->firstarcproto; ap != NOARCPROTO; ap = ap->nextarcproto) total++;
 		if (erc_antcachedtech != NOTECHNOLOGY)
-			efree((char *)erc_antcachedratios);
+			efree((CHAR *)erc_antcachedratios);
 		erc_antcachedratios = (INTBIG *)emalloc(total * SIZEOFINTBIG, erc_tool->cluster);
 		if (erc_antcachedratios == 0) return(ERCDEFMETALLIMIT);
 		for(i=0; i<total; i++) erc_antcachedratios[i] = ERCDEFMETALLIMIT;
@@ -827,10 +827,10 @@ static DIALOGITEM erc_antruldialogitems[] =
 {
  /*  1 */ {0, {204,208,228,288}, BUTTON, N_("OK")},
  /*  2 */ {0, {204,32,228,112}, BUTTON, N_("Cancel")},
- /*  3 */ {0, {24,8,168,316}, SCROLL, ""},
+ /*  3 */ {0, {24,8,168,316}, SCROLL, x_("")},
  /*  4 */ {0, {4,4,20,160}, MESSAGE, N_("Arcs in technology:")},
- /*  5 */ {0, {4,160,20,316}, MESSAGE, ""},
- /*  6 */ {0, {172,216,188,312}, EDITTEXT, ""},
+ /*  5 */ {0, {4,160,20,316}, MESSAGE, x_("")},
+ /*  6 */ {0, {172,216,188,312}, EDITTEXT, x_("")},
  /*  7 */ {0, {172,8,188,208}, MESSAGE, N_("Maximum antenna ratio:")}
 };
 static DIALOG erc_antruldialog = {{75,75,312,401}, N_("Antenna Rules Options"), 0, 7, erc_antruldialogitems, 0, 0};
@@ -844,7 +844,7 @@ void erc_antoptionsdlog(void)
 {
 	REGISTER INTBIG itemHit, fun, amt, i, total, which, *original;
 	REGISTER void *dia, *infstr;
-	char buf[50];
+	CHAR buf[50];
 	REGISTER ARCPROTO *ap, **aplist;
 	REGISTER VARIABLE *var;
 
@@ -878,13 +878,13 @@ void erc_antoptionsdlog(void)
 		original[i] = amt;
 		i++;
 		infstr = initinfstr();
-		formatinfstr(infstr, "%s (%ld)", ap->protoname, amt);
+		formatinfstr(infstr, x_("%s (%ld)"), ap->protoname, amt);
 		DiaStuffLine(dia, DANT_ARCLIST, returninfstr(infstr));
 	}
 	DiaSelectLine(dia, DANT_ARCLIST, 0);
 	if (aplist[0] != NOARCPROTO)
 	{
-		sprintf(buf, "%ld", aplist[0]->temp1);
+		esnprintf(buf, 50, x_("%ld"), aplist[0]->temp1);
 		DiaSetText(dia, DANT_NEWRATIO, buf);
 	}
 
@@ -897,7 +897,7 @@ void erc_antoptionsdlog(void)
 		{
 			which = DiaGetCurLine(dia, DANT_ARCLIST);
 			if (aplist[which] == NOARCPROTO) continue;
-			sprintf(buf, "%ld", aplist[which]->temp1);
+			esnprintf(buf, 50, x_("%ld"), aplist[which]->temp1);
 			DiaSetText(dia, DANT_NEWRATIO, buf);
 			continue;
 		}
@@ -905,9 +905,9 @@ void erc_antoptionsdlog(void)
 		{
 			which = DiaGetCurLine(dia, DANT_ARCLIST);
 			if (aplist[which] == NOARCPROTO) continue;
-			aplist[which]->temp1 = atoi(DiaGetText(dia, DANT_NEWRATIO));
+			aplist[which]->temp1 = eatoi(DiaGetText(dia, DANT_NEWRATIO));
 			infstr = initinfstr();
-			formatinfstr(infstr, "%s (%ld)", aplist[which]->protoname, aplist[which]->temp1);
+			formatinfstr(infstr, x_("%s (%ld)"), aplist[which]->protoname, aplist[which]->temp1);
 			DiaSetScrollLine(dia, DANT_ARCLIST, which, returninfstr(infstr));
 			continue;
 		}
