@@ -47,19 +47,19 @@
 /* the LOGICAL EFFORT tool table */
 static KEYWORD leopt[] =
 {
-	{"analyze-path",       0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
-	{"analyze-facet",      0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
-	{"analyze-network",    0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
-	{"show-loads",         0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
-	{"estimate-delay",     0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
-	{"set-options",        0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
-	{"set-capacitance",    0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
-	{"set-node-effort",    0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
+	{x_("analyze-path"),       0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
+	{x_("analyze-facet"),      0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
+	{x_("analyze-network"),    0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
+	{x_("show-loads"),         0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
+	{x_("estimate-delay"),     0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
+	{x_("set-options"),        0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
+	{x_("set-capacitance"),    0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
+	{x_("set-node-effort"),    0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
 	TERMKEY
 };
 extern "C" {
 COMCOMP le_tablep = {leopt, NOTOPLIST, NONEXTLIST, NOPARAMS,
-	0, " \t", M_("Logical effort action"), M_("show defaults")};
+	0, x_(" \t"), M_("Logical effort action"), M_("show defaults")};
 }
 
 #define MAXITERATIONS  10
@@ -119,7 +119,7 @@ static LENODE   *le_alloclenode(void);
 static void      le_analyzefacet(void);
 static void      le_analyzenetwork(void);
 static void      le_analyzepath(void);
-static char     *le_describenode(LENODE *le);
+static CHAR     *le_describenode(LENODE *le);
 static void      le_estimatedelay(NODEPROTO *facet);
 static void      le_figurebranching(void);
 static void      le_freealllenodes(void);
@@ -130,7 +130,7 @@ static double    le_getcapacitance(NETWORK *net);
 static INTBIG    le_getgatetype(NODEINST *ni, INTBIG *inputs);
 static double    le_getlogeffort(LENODE *le);
 static double    le_getparasitics(LENODE *le);
-static char     *le_nextarcs(void);
+static CHAR     *le_nextarcs(void);
 static NODEINST *le_propagate(NODEPROTO *facet, INTBIG edge);
 static void      le_propagatebranch(PORTARCINST *tpi, LENODE *final, double capacitance,
 					double *onpath, double *offpath);
@@ -139,7 +139,7 @@ static void      le_setlogicaleffort(void);
 static void      le_setoptions(void);
 static void      le_showloads(void);
 static int       le_sortbyproductsize(const void *e1, const void *e2);
-static BOOLEAN   le_topofarcs(char **c);
+static BOOLEAN   le_topofarcs(CHAR **c);
 static void      le_unwind(NODEINST *start, NODEINST *prev);
 
 /************************ CONTROL ***********************/
@@ -147,7 +147,7 @@ static void      le_unwind(NODEINST *start, NODEINST *prev);
 /*
  * tool initialization
  */
-void le_init(INTBIG *argc, char *argv[], TOOL *thistool)
+void le_init(INTBIG *argc, CHAR1 *argv[], TOOL *thistool)
 {
 	/* ignore pass 3 initialization */
 	if (thistool == 0) return;
@@ -155,12 +155,12 @@ void le_init(INTBIG *argc, char *argv[], TOOL *thistool)
 	/* ignore pass 2 initialization */
 	if (thistool == NOTOOL)
 	{
-		le_attrcapacitance_key = makekey("ATTR_Capacitance");
-		le_nodeeffort_key = makekey("LE_node_effort");
-		le_fanout_key = makekey("LE_fanout");
-		le_state_key = makekey("LE_state");
-		le_wire_ratio_key = makekey("LE_wire_ratio");
-		le_maximumstageeffort_key = makekey("LE_maximum_stage_effort");
+		le_attrcapacitance_key = makekey(x_("ATTR_Capacitance"));
+		le_nodeeffort_key = makekey(x_("LE_node_effort"));
+		le_fanout_key = makekey(x_("LE_fanout"));
+		le_state_key = makekey(x_("LE_state"));
+		le_wire_ratio_key = makekey(x_("LE_wire_ratio"));
+		le_maximumstageeffort_key = makekey(x_("LE_maximum_stage_effort"));
 		le_firstlenode = NOLENODE;
 		le_lenodefree = NOLENODE;
 		nextchangequiet();
@@ -183,7 +183,7 @@ void le_done(void)
 	{
 		le = le_lenodefree;
 		le_lenodefree = le_lenodefree->nextlenode;
-		efree((char *)le);
+		efree((CHAR *)le);
 	}
 #endif
 }
@@ -191,22 +191,22 @@ void le_done(void)
 /*
  * Handle commands to the tool from the user.
  */
-void le_set(INTBIG count, char *par[])
+void le_set(INTBIG count, CHAR *par[])
 {
 	REGISTER INTBIG l;
 	REGISTER VARIABLE *var;
 	REGISTER NODEPROTO *np;
 	REGISTER INTBIG state;
-	REGISTER char *pp;
+	REGISTER CHAR *pp;
 
 	if (count == 0)
 	{
-		ttyputusage("telltool logeffort (analyze-path | analyze-facet | analyze-network | show-loads | set-options | set-capacitance | set-node-effort)");
+		ttyputusage(x_("telltool logeffort (analyze-path | analyze-facet | analyze-network | show-loads | set-options | set-capacitance | set-node-effort)"));
 		return;
 	}
 
-	l = strlen(pp = par[0]);
-	if (namesamen(pp, "analyze-facet", l) == 0 && l >= 9)
+	l = estrlen(pp = par[0]);
+	if (namesamen(pp, x_("analyze-facet"), l) == 0 && l >= 9)
 	{
 		var = getvalkey((INTBIG)le_tool, VTOOL, VINTEGER, le_state_key);
 		if (var == NOVARIABLE) state = DEFAULTSTATE; else
@@ -216,7 +216,7 @@ void le_set(INTBIG count, char *par[])
 		le_analyzefacet();
 		return;
 	}
-	if (namesamen(pp, "analyze-path", l) == 0 && l >= 9)
+	if (namesamen(pp, x_("analyze-path"), l) == 0 && l >= 9)
 	{
 		var = getvalkey((INTBIG)le_tool, VTOOL, VINTEGER, le_state_key);
 		if (var == NOVARIABLE) state = DEFAULTSTATE; else
@@ -226,7 +226,7 @@ void le_set(INTBIG count, char *par[])
 		le_analyzepath();
 		return;
 	}
-	if (namesamen(pp, "estimate-delay", l) == 0)
+	if (namesamen(pp, x_("estimate-delay"), l) == 0)
 	{
 		/* analyze facet */
 		np = getcurfacet();
@@ -234,28 +234,28 @@ void le_set(INTBIG count, char *par[])
 		le_estimatedelay(np);
 		return;
 	}
-	if (namesamen(pp, "show-loads", l) == 0 && l >= 2)
+	if (namesamen(pp, x_("show-loads"), l) == 0 && l >= 2)
 	{
 		le_showloads();
 		return;
 	}
-	if (namesamen(pp, "analyze-network", l) == 0 && l >= 2)
+	if (namesamen(pp, x_("analyze-network"), l) == 0 && l >= 2)
 	{
 		le_analyzenetwork();
 		return;
 	}
-	if (namesamen(pp, "set-options", l) == 0 && l >= 5)
+	if (namesamen(pp, x_("set-options"), l) == 0 && l >= 5)
 	{
 		le_setoptions();
 		return;
 	}
-	if (namesamen(pp, "set-node-effort", l) == 0 && l >= 5)
+	if (namesamen(pp, x_("set-node-effort"), l) == 0 && l >= 5)
 	{
 		le_setlogicaleffort();
 		return;
 	}
 
-	ttyputbadusage("telltool logeffort");
+	ttyputbadusage(x_("telltool logeffort"));
 }
 
 /* Logical Effort Options dialog */
@@ -264,12 +264,12 @@ static DIALOGITEM le_leoptionsdialogitems[] =
  /*  1 */ {0, {196,204,220,268}, BUTTON, N_("OK")},
  /*  2 */ {0, {132,204,156,268}, BUTTON, N_("Cancel")},
  /*  3 */ {0, {8,8,24,160}, MESSAGE, N_("Maximum Stage Gain")},
- /*  4 */ {0, {8,168,24,220}, EDITTEXT, ""},
+ /*  4 */ {0, {8,168,24,220}, EDITTEXT, x_("")},
  /*  5 */ {0, {36,8,52,244}, CHECK, N_("Display intermediate capacitances")},
  /*  6 */ {0, {64,8,80,192}, CHECK, N_("Highlight components")},
- /*  7 */ {0, {112,8,220,180}, SCROLL, ""},
+ /*  7 */ {0, {112,8,220,180}, SCROLL, x_("")},
  /*  8 */ {0, {224,8,240,92}, MESSAGE, N_("Wire ratio:")},
- /*  9 */ {0, {224,96,240,180}, EDITTEXT, ""},
+ /*  9 */ {0, {224,96,240,180}, EDITTEXT, x_("")},
  /* 10 */ {0, {92,8,108,180}, MESSAGE, N_("Wire ratio for each layer:")}
 };
 static DIALOG le_leoptionsdialog = {{75,75,324,352}, N_("Logical Effort Options"), 0, 10, le_leoptionsdialogitems, 0, 0};
@@ -282,13 +282,13 @@ static DIALOG le_leoptionsdialog = {{75,75,324,352}, N_("Logical Effort Options"
 #define DLEO_WIRERATIO  9		/* Arc wire ratio (edit text) */
 
 static ARCPROTO *le_posarcs;
-BOOLEAN le_topofarcs(char **c)
+BOOLEAN le_topofarcs(CHAR **c)
 {
 	le_posarcs = el_curtech->firstarcproto;
 	return(TRUE);
 }
 
-char *le_nextarcs(void)
+CHAR *le_nextarcs(void)
 {
 	REGISTER ARCPROTO *ap;
 	REGISTER void *infstr;
@@ -298,7 +298,7 @@ char *le_nextarcs(void)
 	{
 		le_posarcs = ap->nextarcproto;
 		infstr = initinfstr();
-		formatinfstr(infstr, "%s (%ld)", describearcproto(ap), ap->temp1);
+		formatinfstr(infstr, x_("%s (%ld)"), describearcproto(ap), ap->temp1);
 		return(returninfstr(infstr));
 	}
 	return(0);
@@ -314,7 +314,7 @@ void le_setoptions(void)
 	float maxstageeffort, newmaxstageeffort;
 	REGISTER VARIABLE *var;
 	REGISTER ARCPROTO *ap;
-	char line[200], *pt;
+	CHAR line[200], *pt;
 	REGISTER void *infstr, *dia;
 
 	dia = DiaInitDialog(&le_leoptionsdialog);
@@ -338,7 +338,7 @@ void le_setoptions(void)
 	DiaInitTextDialog(dia, DLEO_ARCLIST, le_topofarcs, le_nextarcs,
 		DiaNullDlogDone, 0, SCSELMOUSE|SCREPORT);
 
-	sprintf(line, "%g", maxstageeffort);
+	esnprintf(line, 200, x_("%g"), maxstageeffort);
 	DiaSetText(dia, -DLEO_MAXGAIN, line);
 	for(;;)
 	{
@@ -353,12 +353,12 @@ void le_setoptions(void)
 		{
 			lineno = DiaGetCurLine(dia, DLEO_ARCLIST);
 			if (lineno < 0) continue;
-			strcpy(line, DiaGetScrollLine(dia, DLEO_ARCLIST, lineno));
+			estrcpy(line, DiaGetScrollLine(dia, DLEO_ARCLIST, lineno));
 			for(pt = line; *pt != 0; pt++) if (*pt == ' ') break;
 			*pt = 0;
 			ap = getarcproto(line);
 			if (ap == NOARCPROTO) continue;
-			sprintf(line, "%ld", ap->temp1);
+			esnprintf(line, 200, x_("%ld"), ap->temp1);
 			DiaSetText(dia, DLEO_WIRERATIO, line);
 			continue;
 		}
@@ -366,16 +366,16 @@ void le_setoptions(void)
 		{
 			lineno = DiaGetCurLine(dia, DLEO_ARCLIST);
 			if (lineno < 0) continue;
-			strcpy(line, DiaGetScrollLine(dia, DLEO_ARCLIST, lineno));
+			estrcpy(line, DiaGetScrollLine(dia, DLEO_ARCLIST, lineno));
 			for(pt = line; *pt != 0; pt++) if (*pt == ' ') break;
 			*pt = 0;
 			ap = getarcproto(line);
 			if (ap == NOARCPROTO) continue;
-			i = atoi(DiaGetText(dia, DLEO_WIRERATIO));
+			i = eatoi(DiaGetText(dia, DLEO_WIRERATIO));
 			if (i == ap->temp1) continue;
 			ap->temp1 = i;
 			infstr = initinfstr();
-			formatinfstr(infstr, "%s (%ld)", describearcproto(ap), ap->temp1);
+			formatinfstr(infstr, x_("%s (%ld)"), describearcproto(ap), ap->temp1);
 			DiaSetScrollLine(dia, DLEO_ARCLIST, lineno, returninfstr(infstr));
 			continue;
 		}
@@ -387,7 +387,7 @@ void le_setoptions(void)
 		if (DiaGetControl(dia, DLEO_HIGHCOMP) != 0) newstate |= HIGHLIGHTCOMPONENTS;
 		if (newstate != state)
 			(void)setvalkey((INTBIG)le_tool, VTOOL, le_state_key, newstate, VINTEGER);
-		newmaxstageeffort = (float)atof(DiaGetText(dia, DLEO_MAXGAIN));
+		newmaxstageeffort = (float)eatof(DiaGetText(dia, DLEO_MAXGAIN));
 		if (newmaxstageeffort != maxstageeffort)
 			(void)setvalkey((INTBIG)le_tool, VTOOL, le_maximumstageeffort_key,
 				castint(newmaxstageeffort), VFLOAT);
@@ -415,7 +415,7 @@ static DIALOGITEM le_logeffortdialogitems[] =
  /*  1 */ {0, {40,128,64,192}, BUTTON, N_("OK")},
  /*  2 */ {0, {40,12,64,76}, BUTTON, N_("Cancel")},
  /*  3 */ {0, {8,8,24,116}, MESSAGE, N_("Logical Effort:")},
- /*  4 */ {0, {8,128,24,192}, EDITTEXT, ""}
+ /*  4 */ {0, {8,128,24,192}, EDITTEXT, x_("")}
 };
 static DIALOG le_logeffortdialog = {{75,75,149,281}, N_("Logical Effort"), 0, 4, le_logeffortdialogitems, 0, 0};
 
@@ -432,11 +432,11 @@ void le_setlogicaleffort(void)
 	REGISTER NODEINST *ni;
 	REGISTER INTBIG type;
 	double e;
-	char line[50], *pt;
+	CHAR line[50], *pt;
 	LENODE statle;
 	REGISTER void *dia;
 
-	ni = (NODEINST *)asktool(us_tool, "get-node");
+	ni = (NODEINST *)asktool(us_tool, x_("get-node"));
 	if (ni == NONODEINST) return;
 	type = le_getgatetype(ni, &inputs);
 	if (type == LEUNKNOWN) return;
@@ -447,7 +447,7 @@ void le_setlogicaleffort(void)
 	dia = DiaInitDialog(&le_logeffortdialog);
 	if (dia == 0) return;
 
-	sprintf(line, "%g", e);
+	esnprintf(line, 50, x_("%g"), e);
 	DiaSetText(dia, -DLEE_EFFVALUE, line);
 	for(;;)
 	{
@@ -458,7 +458,7 @@ void le_setlogicaleffort(void)
 	{
 		pt = DiaGetText(dia, DLEE_EFFVALUE);
 		startobjectchange((INTBIG)ni, VNODEINST);
-		sprintf(line, "g=%s", pt);
+		esnprintf(line, 50, x_("g=%s"), pt);
 		setvalkey((INTBIG)ni, VNODEINST, le_nodeeffort_key, (INTBIG)line, VSTRING|VDISPLAY);
 		endobjectchange((INTBIG)ni, VNODEINST);
 	}
@@ -504,7 +504,7 @@ void le_analyzepath(void)
 	LENODE *le, *pathend;
 	REGISTER VARIABLE *var;
 	REGISTER INTBIG displaycapacitance, state;
-	char line[50];
+	CHAR line[50];
 	double g, G, B, h, H, F, P, N, fhat, Dhat, Cin, Cout, CinI, CoutI;
 
 	/* find the end of the path */
@@ -571,7 +571,7 @@ void le_analyzepath(void)
 
 		/* set fanout (h) on this node */
 		h = CoutI / CinI;
-		sprintf(line, "h=%g", h);
+		esnprintf(line, 50, x_("h=%g"), h);
 		startobjectchange((INTBIG)le->ni, VNODEINST);
 		setvalkey((INTBIG)le->ni, VNODEINST, le_fanout_key, (INTBIG)line, VSTRING|VDISPLAY);
 		endobjectchange((INTBIG)le->ni, VNODEINST);
@@ -614,8 +614,8 @@ void le_estimatedelay(NODEPROTO *facet)
 
 		/* numerator has the area of all transistors connected by their gate */
 		numerator = (float)(p_gate->area + n_gate->area);
-ttyputmsg("Network %s has numerator:", describenetwork(net));
-ttyputmsg("      N Gates = %g, P Gates = %g", n_gate->area/flambda/flambda, p_gate->area/flambda/flambda);
+ttyputmsg(x_("Network %s has numerator:"), describenetwork(net));
+ttyputmsg(x_("      N Gates = %g, P Gates = %g"), n_gate->area/flambda/flambda, p_gate->area/flambda/flambda);
 
 		/* numerator also sums area of each layer */
 		for(ap = aplist; ap != NOAREAPERIM; ap = nextap)
@@ -626,10 +626,10 @@ ttyputmsg("      N Gates = %g, P Gates = %g", n_gate->area/flambda/flambda, p_ga
 			coefficient = 1.0f;
 			if (layerismetal(fun)) coefficient = 0.1f;
 			if (layerispoly(fun)) coefficient = 0.1f;
-ttyputmsg("      Layer %s has %g x %g = %g", layername(ap->tech, ap->layer),
+ttyputmsg(x_("      Layer %s has %g x %g = %g"), layername(ap->tech, ap->layer),
 	ap->area/flambda/flambda, coefficient, ap->area*coefficient/flambda/flambda);
 			numerator += (float)ap->area * coefficient;
-			efree((char *)ap);
+			efree((CHAR *)ap);
 		}
 
 		/* save the results */
@@ -638,12 +638,12 @@ ttyputmsg("      Layer %s has %g x %g = %g", layername(ap->tech, ap->layer),
 		nd->pdenominator = (float)p_active->width / flambda;
 		nd->ndenominator = (float)n_active->width / flambda;
 		nd->numerator = numerator / flambda / flambda;
-if (n_active->width == 0) ttyputmsg("   N denominator undefined"); else
-  ttyputmsg("   N denominator = %g, ratio = %g", nd->ndenominator, nd->numerator/nd->ndenominator);
-if (p_active->width == 0) ttyputmsg("   P denominator undefined"); else
-  ttyputmsg("   P denominator = %g, ratio = %g", nd->pdenominator, nd->numerator/nd->pdenominator);
-if (n_active->width+p_active->width == 0) ttyputmsg("   Denominator undefined"); else
-  ttyputmsg("   Denominator = %g, ratio = %g", nd->ndenominator+nd->pdenominator,
+if (n_active->width == 0) ttyputmsg(x_("   N denominator undefined")); else
+  ttyputmsg(x_("   N denominator = %g, ratio = %g"), nd->ndenominator, nd->numerator/nd->ndenominator);
+if (p_active->width == 0) ttyputmsg(x_("   P denominator undefined")); else
+  ttyputmsg(x_("   P denominator = %g, ratio = %g"), nd->pdenominator, nd->numerator/nd->pdenominator);
+if (n_active->width+p_active->width == 0) ttyputmsg(x_("   Denominator undefined")); else
+  ttyputmsg(x_("   Denominator = %g, ratio = %g"), nd->ndenominator+nd->pdenominator,
 	nd->numerator/(nd->ndenominator+nd->pdenominator));
 		nd->net = net;
 		nd->nextnetdelay = firstnd;
@@ -691,7 +691,7 @@ void le_showloads(void)
 	REGISTER INTBIG lambda, gwidth, gtotal, atotal, wirelen, fun, load, wireratio, thisload, thiswl,
 		total, i;
 	float areatotal;
-	REGISTER char *lname;
+	REGISTER CHAR *lname;
 	REGISTER AREAPERIM *arpe, *firstarpe, *nextarpe;
 	TRANSISTORINFO *p_gate, *n_gate, *p_active, *n_active;
 	REGISTER void *infstr;
@@ -742,7 +742,7 @@ void le_showloads(void)
 		for(arpe = firstarpe; arpe != NOAREAPERIM; arpe = nextarpe)
 		{
 			nextarpe = arpe->nextareaperim;
-			efree((char *)arpe);
+			efree((CHAR *)arpe);
 		}
 	}
 
@@ -790,7 +790,7 @@ void le_showloads(void)
 			lname = layername(arpe->tech, arpe->layer);
 			thiswl = arpe->perimeter / 2;
 			thisload = thiswl / wireratio;
-			ttyputmsg("  Layer %s wire-length (%s) / wire ratio (%ld) = load (%s)",
+			ttyputmsg(x_("  Layer %s wire-length (%s) / wire ratio (%ld) = load (%s)"),
 				lname, latoa(thiswl, 0), wireratio, latoa(thisload, 0));
 			load += thisload;
 			wirelen += thiswl;
@@ -808,21 +808,21 @@ void le_showloads(void)
 			infstr = initinfstr();
 			formatinfstr(infstr, _("  Load = %s"), latoa(load, 0));
 			if (net_transistor_p_active.width != 0)
-				formatinfstr(infstr, "; load / P-active-width (%s) = %g", latoa(net_transistor_p_active.width, 0),
+				formatinfstr(infstr, x_("; load / P-active-width (%s) = %g"), latoa(net_transistor_p_active.width, 0),
 					(float)load / (float)net_transistor_p_active.width);
 			if (net_transistor_n_active.width != 0)
-				formatinfstr(infstr, "; load / N-active-width (%s) = %g", latoa(net_transistor_n_active.width, 0),
+				formatinfstr(infstr, x_("; load / N-active-width (%s) = %g"), latoa(net_transistor_n_active.width, 0),
 					(float)load / (float)net_transistor_n_active.width);
-			ttyputmsg("%s", returninfstr(infstr));
+			ttyputmsg(x_("%s"), returninfstr(infstr));
 		}
 
 		for(arpe = firstarpe; arpe != NOAREAPERIM; arpe = nextarpe)
 		{
 			nextarpe = arpe->nextareaperim;
-			efree((char *)arpe);
+			efree((CHAR *)arpe);
 		}
 	}
-	efree((char *)netlist);
+	efree((CHAR *)netlist);
 }
 
 /*
@@ -844,7 +844,7 @@ void le_analyzenetwork(void)
 	REGISTER ARCPROTO *ap;
 	REGISTER INTBIG i, j, k, widest, len, lambda, total, gtotal, atotal,
 		fun, metpolhalfperim, load, wireratio, additionalload;
-	REGISTER char *lname, *pad;
+	REGISTER CHAR *lname, *pad;
 	REGISTER VARIABLE *var;
 	REGISTER AREAPERIM *arpe, *firstarpe, **arpelist;
 	TRANSISTORINFO *p_gate, *n_gate, *p_active, *n_active;
@@ -888,7 +888,7 @@ void le_analyzenetwork(void)
 		{
 			arpe = arpelist[i];
 			lname = layername(arpe->tech, arpe->layer);
-			len = strlen(lname);
+			len = estrlen(lname);
 			if (len > widest) widest = len;
 		}
 		metpolhalfperim = 0;
@@ -897,7 +897,7 @@ void le_analyzenetwork(void)
 			arpe = arpelist[i];
 			lname = layername(arpe->tech, arpe->layer);
 			infstr = initinfstr();
-			for(j=strlen(lname); j<widest; j++) addtoinfstr(infstr, ' ');
+			for(j=estrlen(lname); j<widest; j++) addtoinfstr(infstr, ' ');
 			pad = returninfstr(infstr);
 			infstr = initinfstr();
 			formatinfstr(infstr, _("Layer %s:%s area=%7g  half-perimeter=%s"), lname, pad,
@@ -922,10 +922,10 @@ void le_analyzenetwork(void)
 				ratio = (arpe->area / (float)lambda) / (float)(arpe->perimeter/2);
 				formatinfstr(infstr, _("; area/half-perimeter = %g"), ratio);
 			}
-			ttyputmsg("%s", returninfstr(infstr));
-			efree((char *)arpe);
+			ttyputmsg(x_("%s"), returninfstr(infstr));
+			efree((CHAR *)arpe);
 		}
-		efree((char *)arpelist);
+		efree((CHAR *)arpelist);
 		gtotal = net_transistor_p_gate.count + net_transistor_n_gate.count;
 		if (gtotal > 0)
 		{
@@ -934,7 +934,7 @@ void le_analyzenetwork(void)
 				gtotal, makeplural(_("transistor"), gtotal),
 					latoa(net_transistor_p_gate.width+net_transistor_n_gate.width, 0),
 						latoa((net_transistor_p_gate.length+net_transistor_n_gate.length)/gtotal, 0));
-			ttyputmsg("%s", returninfstr(infstr));
+			ttyputmsg(x_("%s"), returninfstr(infstr));
 		}
 		atotal = net_transistor_p_active.count + net_transistor_n_active.count;
 		if (atotal > 0)
@@ -944,20 +944,20 @@ void le_analyzenetwork(void)
 				atotal, makeplural(_("transistor"), atotal),
 					latoa(net_transistor_p_active.width+net_transistor_n_active.width, 0),
 						latoa((net_transistor_p_active.length+net_transistor_n_active.length)/atotal, 0));
-			ttyputmsg("%s", returninfstr(infstr));
+			ttyputmsg(x_("%s"), returninfstr(infstr));
 		}
 		if (metpolhalfperim > 0 && gtotal > 0 && atotal > 0)
 		{
-			ttyputmsg("---------- Load Calculations:");
-			ttyputmsg("Sum of Metal and Poly half-perimeters / wire-ratio = %s", latoa(metpolhalfperim, 0));
+			ttyputmsg(x_("---------- Load Calculations:"));
+			ttyputmsg(x_("Sum of Metal and Poly half-perimeters / wire-ratio = %s"), latoa(metpolhalfperim, 0));
 			load = metpolhalfperim + net_transistor_p_gate.width+net_transistor_n_gate.width;
-			ttyputmsg("  Sum + gate-width (%s) = %s (Load)",
+			ttyputmsg(x_("  Sum + gate-width (%s) = %s (Load)"),
 				latoa(net_transistor_p_gate.width+net_transistor_n_gate.width, 0), latoa(load, 0));
 			if (net_transistor_p_active.width != 0)
-				ttyputmsg("  Load / P-active-width (%s) = %g", latoa(net_transistor_p_active.width, 0),
+				ttyputmsg(x_("  Load / P-active-width (%s) = %g"), latoa(net_transistor_p_active.width, 0),
 					(float)load / (float)net_transistor_p_active.width);
 			if (net_transistor_n_active.width != 0)
-				ttyputmsg("  Load / N-active-width (%s) = %g", latoa(net_transistor_n_active.width, 0),
+				ttyputmsg(x_("  Load / N-active-width (%s) = %g"), latoa(net_transistor_n_active.width, 0),
 					(float)load / (float)net_transistor_n_active.width);
 		}
 	}
@@ -1054,7 +1054,7 @@ void le_gatherfacet(INTBIG show)
 		var = getvalkey((INTBIG)ni, VNODEINST, -1, le_attrcapacitance_key);
 		if (var == NOVARIABLE) continue;
 
-		cap = atof(describesimplevariable(var));
+		cap = eatof(describesimplevariable(var));
 		le = le_alloclenode();
 		if (le == NOLENODE) continue;
 		le->ni = ni;
@@ -1140,10 +1140,10 @@ void le_gatherfacet(INTBIG show)
 	{
 		if (first) addtoinfstr(infstr, '\n');
 		first = TRUE;
-		formatinfstr(infstr, "FACET=%s FROM=0%lo;-1;0",
+		formatinfstr(infstr, x_("FACET=%s FROM=0%lo;-1;0"),
 			describenodeproto(np), (INTBIG)le->ni->geom);
 	}
-	(void)asktool(us_tool, "show-multiple", (INTBIG)returninfstr(infstr));
+	(void)asktool(us_tool, x_("show-multiple"), (INTBIG)returninfstr(infstr));
 
 	/* display the connection sites */
 	arrowsize = lambdaoffacet(np) * 2;
@@ -1155,9 +1155,9 @@ void le_gatherfacet(INTBIG show)
 			if (ai->end[0].portarcinst == le->piin) which = 0; else which = 1;
 			x = ai->end[which].xpos;
 			y = ai->end[which].ypos;
-			(void)asktool(us_tool, "show-line", x, y, x-arrowsize, y-arrowsize, ai->parent);
-			(void)asktool(us_tool, "show-line", x, y, x-arrowsize/2, y-arrowsize/5, ai->parent);
-			(void)asktool(us_tool, "show-line", x, y, x-arrowsize/5, y-arrowsize/2, ai->parent);
+			(void)asktool(us_tool, x_("show-line"), x, y, x-arrowsize, y-arrowsize, ai->parent);
+			(void)asktool(us_tool, x_("show-line"), x, y, x-arrowsize/2, y-arrowsize/5, ai->parent);
+			(void)asktool(us_tool, x_("show-line"), x, y, x-arrowsize/5, y-arrowsize/2, ai->parent);
 		}
 		for(i=0; i<le->numoutputnodes; i++)
 		{
@@ -1165,9 +1165,9 @@ void le_gatherfacet(INTBIG show)
 			if (ai->end[0].portarcinst == le->outputports[i]) which = 0; else which = 1;
 			x = ai->end[which].xpos+arrowsize;
 			y = ai->end[which].ypos+arrowsize;
-			(void)asktool(us_tool, "show-line", x, y, x-arrowsize, y-arrowsize, ai->parent);
-			(void)asktool(us_tool, "show-line", x, y, x-arrowsize/2, y-arrowsize/5, ai->parent);
-			(void)asktool(us_tool, "show-line", x, y, x-arrowsize/5, y-arrowsize/2, ai->parent);
+			(void)asktool(us_tool, x_("show-line"), x, y, x-arrowsize, y-arrowsize, ai->parent);
+			(void)asktool(us_tool, x_("show-line"), x, y, x-arrowsize/2, y-arrowsize/5, ai->parent);
+			(void)asktool(us_tool, x_("show-line"), x, y, x-arrowsize/5, y-arrowsize/2, ai->parent);
 		}
 	}
 }
@@ -1194,8 +1194,8 @@ void le_addlinkage(LENODE *out, PORTARCINST *outpi, LENODE *in, PORTARCINST *inp
 	newoutputportlist[out->numoutputnodes] = outpi;
 	if (out->numoutputnodes > 0)
 	{
-		efree((char *)out->outputnodes);
-		efree((char *)out->outputports);
+		efree((CHAR *)out->outputnodes);
+		efree((CHAR *)out->outputports);
 	}
 	out->outputnodes = newoutputnodelist;
 	out->outputports = newoutputportlist;
@@ -1213,8 +1213,8 @@ void le_addlinkage(LENODE *out, PORTARCINST *outpi, LENODE *in, PORTARCINST *inp
 	newinputportlist[in->numinputnodes] = inpi;
 	if (in->numinputnodes > 0)
 	{
-		efree((char *)in->inputnodes);
-		efree((char *)in->inputports);
+		efree((CHAR *)in->inputnodes);
+		efree((CHAR *)in->inputports);
 	}
 	in->inputnodes = newinputnodelist;
 	in->inputports = newinputportlist;
@@ -1227,7 +1227,7 @@ void le_analyzefacet(void)
 	REGISTER PORTARCINST *pi;
 	REGISTER INTBIG iteration, changeneeded, changemade, i, displaycapacitance, state;
 	REGISTER VARIABLE *var;
-	char line[50];
+	CHAR line[50];
 	double h, needed, maxstageeffort;
 
 	/* determine maximum stage effort */
@@ -1289,7 +1289,7 @@ void le_analyzefacet(void)
 			}
 		}
 		h = le->cout / le->cin;
-		sprintf(line, "h=%g", h);
+		esnprintf(line, 50, x_("h=%g"), h);
 		startobjectchange((INTBIG)le->ni, VNODEINST);
 		setvalkey((INTBIG)le->ni, VNODEINST, le_fanout_key, (INTBIG)line, VSTRING|VDISPLAY);
 		endobjectchange((INTBIG)le->ni, VNODEINST);
@@ -1321,7 +1321,7 @@ void le_gatherpath(INTBIG show)
 	if (np == NONODEPROTO) return;
 
 	/* get all selected objects (must be 2 nodes) */
-	list = (GEOM **)asktool(us_tool, "get-all-objects");
+	list = (GEOM **)asktool(us_tool, x_("get-all-objects"));
 	if (list[0] == NOGEOM || list[1] == NOGEOM || list[2] != NOGEOM)
 	{
 		ttyputerr(_("Select two objects at the ends of a path"));
@@ -1447,7 +1447,7 @@ void le_gatherpath(INTBIG show)
 	}
 
 	/* display the path between the nodes */
-	(void)asktool(us_tool, "clear");
+	(void)asktool(us_tool, x_("clear"));
 	infstr = initinfstr();
 	first = FALSE;
 	for(ni = np->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
@@ -1455,17 +1455,17 @@ void le_gatherpath(INTBIG show)
 		if (ni->temp2 == 0) continue;
 		if (first) addtoinfstr(infstr, '\n');
 		first = TRUE;
-		formatinfstr(infstr, "FACET=%s FROM=0%lo;-1;0",
+		formatinfstr(infstr, x_("FACET=%s FROM=0%lo;-1;0"),
 			describenodeproto(np), (INTBIG)ni->geom);
 	}
 	for(ai = np->firstarcinst; ai != NOARCINST; ai = ai->nextarcinst)
 	{
 		if (ai->temp2 == 0) continue;
 		addtoinfstr(infstr, '\n');
-		formatinfstr(infstr, "FACET=%s FROM=0%lo;-1;0",
+		formatinfstr(infstr, x_("FACET=%s FROM=0%lo;-1;0"),
 			describenodeproto(np), (INTBIG)ai->geom);
 	}
-	(void)asktool(us_tool, "show-multiple", (INTBIG)returninfstr(infstr));
+	(void)asktool(us_tool, x_("show-multiple"), (INTBIG)returninfstr(infstr));
 
 	arrowsize = lambdaoffacet(np) * 2;
 	for(le = le_firstlenode; le != NOLENODE; le = le->nextlenode)
@@ -1476,9 +1476,9 @@ void le_gatherpath(INTBIG show)
 			if (ai->end[0].portarcinst == le->piin) which = 0; else which = 1;
 			x = ai->end[which].xpos;
 			y = ai->end[which].ypos;
-			(void)asktool(us_tool, "show-line", x, y, x-arrowsize, y-arrowsize, ai->parent);
-			(void)asktool(us_tool, "show-line", x, y, x-arrowsize/2, y-arrowsize/5, ai->parent);
-			(void)asktool(us_tool, "show-line", x, y, x-arrowsize/5, y-arrowsize/2, ai->parent);
+			(void)asktool(us_tool, x_("show-line"), x, y, x-arrowsize, y-arrowsize, ai->parent);
+			(void)asktool(us_tool, x_("show-line"), x, y, x-arrowsize/2, y-arrowsize/5, ai->parent);
+			(void)asktool(us_tool, x_("show-line"), x, y, x-arrowsize/5, y-arrowsize/2, ai->parent);
 		}
 		if (le->piout != NOPORTARCINST)
 		{
@@ -1486,9 +1486,9 @@ void le_gatherpath(INTBIG show)
 			if (ai->end[0].portarcinst == le->piout) which = 0; else which = 1;
 			x = ai->end[which].xpos+arrowsize;
 			y = ai->end[which].ypos+arrowsize;
-			(void)asktool(us_tool, "show-line", x, y, x-arrowsize, y-arrowsize, ai->parent);
-			(void)asktool(us_tool, "show-line", x, y, x-arrowsize/2, y-arrowsize/5, ai->parent);
-			(void)asktool(us_tool, "show-line", x, y, x-arrowsize/5, y-arrowsize/2, ai->parent);
+			(void)asktool(us_tool, x_("show-line"), x, y, x-arrowsize, y-arrowsize, ai->parent);
+			(void)asktool(us_tool, x_("show-line"), x, y, x-arrowsize/2, y-arrowsize/5, ai->parent);
+			(void)asktool(us_tool, x_("show-line"), x, y, x-arrowsize/5, y-arrowsize/2, ai->parent);
 		}
 	}
 }
@@ -1714,7 +1714,7 @@ void le_propagatebranch(PORTARCINST *tpi, LENODE *final, double capacitance,
 INTBIG le_getgatetype(NODEINST *ni, INTBIG *inputs)
 {
 	REGISTER INTBIG inputnegates, outputnegates, thisend, isinput, gatetype, func;
-	char *inputport, *outputport1, *outputport2;
+	CHAR *inputport, *outputport1, *outputport2;
 	REGISTER ARCINST *ai;
 	REGISTER PORTARCINST *pi;
 	REGISTER VARIABLE *var;
@@ -1732,22 +1732,22 @@ INTBIG le_getgatetype(NODEINST *ni, INTBIG *inputs)
 		return(NPUNKNOWN);
 	}
 
-	inputport = "a";   outputport1 = outputport2 = "y";
+	inputport = x_("a");   outputport1 = outputport2 = x_("y");
 	if (func == NPTRANMOS || func == NPTRAPMOS)
 	{
-		inputport = "g";   outputport1 = "s";   outputport2 = "d";
+		inputport = x_("g");   outputport1 = x_("s");   outputport2 = x_("d");
 	}
 	for(pi = ni->firstportarcinst; pi != NOPORTARCINST; pi = pi->nextportarcinst)
 	{
 		isinput = 0;
-		if (strcmp(pi->proto->protoname, inputport) == 0)
+		if (estrcmp(pi->proto->protoname, inputport) == 0)
 		{
 			isinput = 1;
 			(*inputs)++;
 		}
-		if (strcmp(pi->proto->protoname, inputport) == 0 ||
-			strcmp(pi->proto->protoname, outputport1) == 0 ||
-			strcmp(pi->proto->protoname, outputport2) == 0)
+		if (estrcmp(pi->proto->protoname, inputport) == 0 ||
+			estrcmp(pi->proto->protoname, outputport1) == 0 ||
+			estrcmp(pi->proto->protoname, outputport2) == 0)
 		{
 			if ((pi->conarcinst->userbits&ISNEGATED) != 0)
 			{
@@ -1852,7 +1852,7 @@ INTBIG le_getgatetype(NODEINST *ni, INTBIG *inputs)
 /*
  * Routine to return a string describing LENODE "le".
  */
-char *le_describenode(LENODE *le)
+CHAR *le_describenode(LENODE *le)
 {
 	REGISTER VARIABLE *var;
 	REGISTER void *infstr;
@@ -1888,9 +1888,9 @@ char *le_describenode(LENODE *le)
 	var = getvalkey((INTBIG)le->ni, VNODEINST, VSTRING, el_node_name_key);
 	if (var != NOVARIABLE)
 	{
-		addstringtoinfstr(infstr, "[");
-		addstringtoinfstr(infstr, (char *)var->addr);
-		addstringtoinfstr(infstr, "]");
+		addstringtoinfstr(infstr, x_("["));
+		addstringtoinfstr(infstr, (CHAR *)var->addr);
+		addstringtoinfstr(infstr, x_("]"));
 	}
 	return(returninfstr(infstr));
 }
@@ -1902,13 +1902,13 @@ char *le_describenode(LENODE *le)
 double le_getlogeffort(LENODE *le)
 {
 	REGISTER VARIABLE *var;
-	REGISTER char *pt;
+	REGISTER CHAR *pt;
 
 	/* see if there is an override on the node */
 	var = getvalkey((INTBIG)le->ni, VNODEINST, VSTRING, le_nodeeffort_key);
 	if (var != NOVARIABLE)
 	{
-		pt = (char *)var->addr;
+		pt = (CHAR *)var->addr;
 		while (*pt == ' ' || *pt == '\t') pt++;
 		if (*pt == 'g' || *pt == 'G')
 		{
@@ -1920,7 +1920,7 @@ double le_getlogeffort(LENODE *le)
 			pt++;
 			while (*pt == ' ' || *pt == '\t') pt++;
 		}
-		return(atof(pt));
+		return(eatof(pt));
 	}
 
 	/* calculate the logical effort */
@@ -1989,7 +1989,7 @@ double le_getcapacitance(NETWORK *net)
 		var = getvalkey((INTBIG)ni, VNODEINST, -1, le_attrcapacitance_key);
 		if (var != NOVARIABLE)
 		{
-			return(atof(describesimplevariable(var)));
+			return(eatof(describesimplevariable(var)));
 		}
 	}
 	return(0.0);
@@ -2037,13 +2037,13 @@ void le_freelenode(LENODE *le)
 {
 	if (le->numinputnodes > 0)
 	{
-		efree((char *)le->inputnodes);
-		efree((char *)le->inputports);
+		efree((CHAR *)le->inputnodes);
+		efree((CHAR *)le->inputports);
 	}
 	if (le->numoutputnodes > 0)
 	{
-		efree((char *)le->outputnodes);
-		efree((char *)le->outputports);
+		efree((CHAR *)le->outputnodes);
+		efree((CHAR *)le->outputports);
 	}
 	le->nextlenode = le_lenodefree;
 	le_lenodefree = le;
