@@ -63,7 +63,7 @@ void net_conv_to_internal( NODEPROTO *facet )
 	ARCINST *db_arc;  /* store return of newarcinst(), use in call to endchangeobject() */
 	INTBIG nodecounter, *equivlayers, i, j;
 	VARIABLE *var;
-	char **ciflayers;
+	CHAR **ciflayers;
 	TECHNOLOGY *tech;
 
 	/* count the number of PL nodes */
@@ -103,9 +103,9 @@ void net_conv_to_internal( NODEPROTO *facet )
 	/* setup equivalent layers to handle CIF layer unification */
 	equivlayers = (INTBIG *)emalloc(tech->layercount * SIZEOFINTBIG, net_tool->cluster);
 	if (equivlayers == 0) return;
-	var = getval((INTBIG)tech, VTECHNOLOGY, VSTRING|VISARRAY, "IO_cif_layer_names");
+	var = getval((INTBIG)tech, VTECHNOLOGY, VSTRING|VISARRAY, x_("IO_cif_layer_names"));
 	if (var == NOVARIABLE) ciflayers = 0; else
-		ciflayers = (char **)var->addr;
+		ciflayers = (CHAR **)var->addr;
 	for(i=0; i<tech->layercount; i++)
 	{
 		equivlayers[i] = i;
@@ -216,8 +216,8 @@ void net_conv_to_internal( NODEPROTO *facet )
 	}
 
 	/* deallocate the list of pure-layer nodes */
-	efree((char *)plnodelist);
-	efree((char *)equivlayers);
+	efree((CHAR *)plnodelist);
+	efree((CHAR *)equivlayers);
 }
 
 /********************************** EXTRACTION CASES **********************************/
@@ -250,6 +250,7 @@ void via_to_contact( NODEINST** parselist, INTBIG *parselistcount,
 	INTBIG i, j, k, fun, thiscontact, lx, hx, ly, hy, lowx, highx, lowy, highy,
 		contactcount, totlayers, otherlayercount, typeindex[MAXORIGLAYERS];
 	static POLYGON *poly = NOPOLYGON;
+	Q_UNUSED( arcs );
 
 	/* allocate a polygon */
 	(void)needstaticpolygon(&poly, 4, net_tool->cluster);
@@ -364,7 +365,7 @@ void via_to_contact( NODEINST** parselist, INTBIG *parselistcount,
 
 		/* create the new contact */
 		contact = allocnodeinst(facet->cell->cluster);
-		nodeprotosizeoffset(thisismycontact, &lx, &ly, &hx, &hy);
+		nodeprotosizeoffset(thisismycontact, &lx, &ly, &hx, &hy, facet);
 		contact->highx = highx + hx;
 		contact->lowx = lowx - lx;
 		contact->highy = highy + hy;
@@ -551,7 +552,7 @@ void  build_node_arc_list( NODEINST** parselist,
 		if (nodeinst1 == NONODEINST)
 		{
 			nodeinst1 = allocnodeinst(facet->cell->cluster);
-			nodeprotosizeoffset(nodetech, &lx, &ly, &hx, &hy);
+			nodeprotosizeoffset(nodetech, &lx, &ly, &hx, &hy, facet);
 			nodeinst1->highx = highx1 + hx;
 			nodeinst1->lowx = lowx1 - lx;
 			nodeinst1->highy = highy1 + hy;
@@ -577,7 +578,7 @@ void  build_node_arc_list( NODEINST** parselist,
 		if (nodeinst2 == NONODEINST)
 		{
 			nodeinst2 = allocnodeinst(facet->cell->cluster);
-			nodeprotosizeoffset(nodetech, &lx, &ly, &hx, &hy);
+			nodeprotosizeoffset(nodetech, &lx, &ly, &hx, &hy, facet);
 			nodeinst2->highx = highx2 + hx;
 			nodeinst2->lowx = lowx2 - lx;
 			nodeinst2->highy = highy2 + hy;
@@ -610,7 +611,7 @@ void  build_node_arc_list( NODEINST** parselist,
 	}
 
 	/* free arc structure */
-	efree((char *)arclist);
+	efree((CHAR *)arclist);
 }
 
 /*********************************** NOT YET USED ***********************************/
