@@ -37,6 +37,7 @@
 #define IGNOREFOURPORT 1				/* comment out to handle 4-port transistors properly */
 
 static INTBIG    net_pseudonode;		/* net number for pseudonetworks */
+static BOOLEAN   net_mfactorwarned;		/* TRUE if a warning was issued about zero m-factors */
 static NODEINST *net_toplevelinst;		/* actual top-instance associated with this node */
 static PCOMP    *net_seriesend1, *net_seriesend2;	/* end component of series transistor chains */
 static INTBIG    net_seriescon1,  net_seriescon2;	/* end index of series transistor chains */
@@ -50,27 +51,28 @@ static PCOMP    **net_serieslist;
 static INTBIG     net_serieslistcount;
 static INTBIG     net_serieslisttotal = 0;
 
+#define STATIC
+
 /* prototypes for local routines */
-static BOOLEAN net_addtoserieslist(PCOMP *pc);
-static PCOMP  *net_allocpcomp(void);
-static PNET   *net_allocpnet(void);
-static PCOMP  *net_buildpseudo(NODEPROTO*, PCOMP*, INTBIG*, PNET**, BOOLEAN, BOOLEAN);
-static void    net_crawlforseries(PCOMP *pc);
-static INTBIG  net_findotherexporttopology(NODEPROTO *np, char *exportname);
-static INTBIG  net_findotherexportcharacteristic(NODEPROTO *parent, INTBIG bits);
-static PCOMP **net_gatherseries(PCOMP *pc, INTBIG *seriescount);
-static INTBIG  net_getfunction(NODEINST*);
-static float   net_getpartvalue(NODEINST *ni);
-static BOOLEAN net_getpnetandstate(NODEINST *ni, PORTPROTO *pp, NETWORK *forcenet,
+STATIC BOOLEAN net_addtoserieslist(PCOMP *pc);
+STATIC PCOMP  *net_allocpcomp(void);
+STATIC PNET   *net_allocpnet(void);
+STATIC PCOMP  *net_buildpseudo(NODEPROTO*, PCOMP*, INTBIG*, PNET**, PNET**, BOOLEAN, BOOLEAN, float);
+STATIC void    net_crawlforseries(PCOMP *pc);
+STATIC INTBIG  net_findotherexporttopology(NODEPROTO *np, CHAR *exportname);
+STATIC INTBIG  net_findotherexportcharacteristic(NODEPROTO *parent, INTBIG bits);
+STATIC PCOMP **net_gatherseries(PCOMP *pc, INTBIG *seriescount);
+STATIC INTBIG  net_getfunction(NODEINST*);
+STATIC float   net_getpartvalue(NODEINST *ni);
+STATIC BOOLEAN net_getpnetandstate(NODEINST *ni, PORTPROTO *pp, NETWORK *forcenet,
 				INTBIG index, PNET **netnumber, INTSML *state, PNET **pnetlist,
-				INTBIG nodewidth, INTBIG nindex, INTBIG destsignals);
-static INTBIG  net_mergeseries(PCOMP **pcomp, PNET *pnet, INTBIG *components);
-static PNET   *net_newpnet(NETWORK *net, PNET **pnetlist);
-static void    net_setallexporttopology(void);
-static void    net_setthisexporttopology(PORTPROTO *pp, INTBIG *index);
-static int     net_sortpcompbyhash(const void *e1, const void *e2);
-static void    net_addexporttopnet(PNET *pn, PORTPROTO *pp);
-static void    net_gatherglobals(NODEPROTO *facet, PNET **pnetlist);
+				PNET **globalpnetlist, INTBIG nodewidth, INTBIG nindex, INTBIG destsignals);
+STATIC INTBIG  net_mergeseries(PCOMP **pcomp, PNET *pnet, INTBIG *components);
+STATIC PNET   *net_newpnet(NETWORK *net, PNET **pnetlist, PNET **globalpnetlist);
+STATIC void    net_setthisexporttopology(PORTPROTO *pp, INTBIG *index);
+STATIC int     net_sortpcompbyhash(const void *e1, const void *e2);
+STATIC void    net_addexporttopnet(PNET *pn, PORTPROTO *pp);
+STATIC void    net_gatherglobals(NODEPROTO *facet, PNET **pnetlist, PNET **globalpnetlist);
 
 /*
  * Routine to free all memory associated with this module.
@@ -84,15 +86,20 @@ void net_freeflatmemory(void)
 	{
 		p = net_pcompfree;
 		net_pcompfree = net_pcompfree->nextpcomp;
-		efree((char *)p);
+		efree((CHAR *)p);
 	}
 	while (net_pnetfree != NOPNET)
 	{
 		pn = net_pnetfree;
 		net_pnetfree = net_pnetfree->nextpnet;
-		efree((char *)pn);
+		if (pn->nodetotal > 0)
+		{
+			efree((CHAR *)pn->nodelist);
+			efree((CHAR *)pn->nodewire);
+		}
+		efree((CHAR *)pn);
 	}
-	if (net_comparelistsize > 0) efree((char *)net_comparelist);
+	if (net_comparelistsize > 0) efree((CHAR *)net_comparelist);
 }
 
 /*********************** PSEUDO-NETWORK CONSTRUCTION ***********************/
@@ -103,6 +110,8 @@ void net_freeflatmemory(void)
  *   PCOMP *pcomp;
  *   PNET *pnet;
  *   INTBIG components, nets, powernets, groundnets;
+ *
+ *   net_initnetflattening();
  *   pcomp = net_makepseudo(facet, &components, &nets, &powernets, &groundnets,
  *	    &pnet, hierarchical, mergeparallel, mergeseries, checkfacetoverrides, figuresizes);
  *   .....
@@ -111,6 +120,8 @@ void net_freeflatmemory(void)
  *   net_freeallpnet(pnet);
  *   net_freeallpcomp(pcomp);
  *
+ * "net_initnetflattening" gathers network topology for primitives and cells.  It needs to be
+ * called only once for any set of libraries.
  * "net_makepseudo" builds a pseudonetwork structure that represents the
  * network in facet "facet".  If it returns NOPCOMP and sets "components" negative,
  * there is an error (if it returns NOPCOMP with "components" zero, there just are not
@@ -134,15 +145,23 @@ PCOMP *net_makepseudo(NODEPROTO *facet, INTBIG *components, INTBIG *nets, INTBIG
 	BOOLEAN mergeseries, BOOLEAN checkfacetoverrides, BOOLEAN figuresizes)
 {
 	PCOMP *pcomplist;
-	REGISTER BOOLEAN localmergeparallel, localmergeseries;
+	PNET *globalpnetlist;
+	REGISTER BOOLEAN localmergeparallel, localmergeseries, killnet;
 	REGISTER INTBIG i, mergecount;
 	REGISTER NETWORK *net, *subnet;
-	REGISTER PNET *pn;
+	REGISTER PNET *pn, *lastpnet, *nextpnet;
 	REGISTER VARIABLE *var;
 	REGISTER LIBRARY *lib;
 	REGISTER NODEPROTO *np;
 	REGISTER PORTPROTO *pp, *opp;
 
+#ifdef NEWNCC
+	/* cache NCC options */
+	var = getvalkey((INTBIG)net_tool, VTOOL, VINTEGER, net_ncc_optionskey);
+	if (var == NOVARIABLE) net_ncc_options = 0; else
+		net_ncc_options = var->addr;
+#endif
+
 	/* see if the current facet overrides the options */
 	localmergeparallel = mergeparallel;
 	localmergeseries = mergeseries;
@@ -167,13 +186,14 @@ PCOMP *net_makepseudo(NODEPROTO *facet, INTBIG *components, INTBIG *nets, INTBIG
 	/* first create net numbers inside of this facet */
 	net_pseudonode = 0;
 	*pnetlist = NOPNET;
+	globalpnetlist = NOPNET;
 	for(net = facet->firstnetwork; net != NONETWORK; net = net->nextnetwork)
 		net->temp1 = (INTBIG)NOPNET;
 	for(pp = facet->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
 	{
 		net = pp->network;
 		if (net->temp1 != (INTBIG)NOPNET) continue;
-		pn = net_newpnet(net, pnetlist);
+		pn = net_newpnet(net, pnetlist, &globalpnetlist);
 		if (pn == NOPNET) { *components = -1;   return(NOPCOMP); }
 		if ((pp->userbits&STATEBITS) == PWRPORT) pn->flags |= POWERNET; else
 			if ((pp->userbits&STATEBITS) == GNDPORT) pn->flags |= GROUNDNET;
@@ -196,7 +216,7 @@ PCOMP *net_makepseudo(NODEPROTO *facet, INTBIG *components, INTBIG *nets, INTBIG
 					net_addexporttopnet(pn, pp);
 					continue;
 				}
-				pn = net_newpnet(subnet, pnetlist);
+				pn = net_newpnet(subnet, pnetlist, &globalpnetlist);
 				pn->flags |= EXPORTEDNET;
 				subnet->temp1 = (INTBIG)pn;
 				pn->realportcount = 1;
@@ -205,19 +225,28 @@ PCOMP *net_makepseudo(NODEPROTO *facet, INTBIG *components, INTBIG *nets, INTBIG
 		}
 	}
 
-	/* establish topology of exports */
-	net_setallexporttopology();
-
 	/* create a list of pseudocomponents in this facet */
 	*components = 0;
 	begintraversehierarchy();
 	net_toplevelinst = NONODEINST;
-	pcomplist = net_buildpseudo(facet, NOPCOMP, components, pnetlist, hierarchical, figuresizes);
+	net_mfactorwarned = FALSE;
+	pcomplist = net_buildpseudo(facet, NOPCOMP, components, pnetlist, &globalpnetlist,
+		hierarchical, figuresizes, 1.0f);
 	endtraversehierarchy();
 	if (pcomplist == 0) { *components = -1;   return(NOPCOMP); }
 	if (*components == 0)
 		ttyputmsg(_("There are no components in facet %s"), describenodeproto(facet));
 
+	/* append all global networks to the main list */
+	while (globalpnetlist != NOPNET)
+	{
+		pn = globalpnetlist;
+		globalpnetlist = pn->nextpnet;
+
+		pn->nextpnet = *pnetlist;
+		*pnetlist = pn;
+	}
+
 	/* reduce network by merging parallel components */
 	if (localmergeparallel)
 	{
@@ -236,29 +265,51 @@ PCOMP *net_makepseudo(NODEPROTO *facet, INTBIG *components, INTBIG *nets, INTBIG
 				mergecount, describenodeproto(facet));
 	}
 
-	/* report the total number of nets */
-	*nets = net_pseudonode;
-
-	/* count the power and ground nets */
-	*powernets = *groundnets = 0;
-	for(pn = *pnetlist; pn != NOPNET; pn = pn->nextpnet)
-	{
-		if ((pn->flags&POWERNET) != 0) (*powernets)++;
-		if ((pn->flags&GROUNDNET) != 0) (*groundnets)++;
-		if ((pn->flags&(POWERNET|GROUNDNET)) == (POWERNET|GROUNDNET))
-		{
-			if (pn->network == NONETWORK) np = NONODEPROTO; else
-				np = pn->network->parent;
-			ttyputmsg(_("WARNING: facet %s, network '%s' shorts power and ground"),
-				describenodeproto(np), describenetwork(pn->network));
-		}
-	}
-
 	/* look to the bottom of the hierarchy and be sure all global signals are listed */
 	for(lib = el_curlib; lib != NOLIBRARY; lib = lib->nextlibrary)
 		for(np = lib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
 			np->temp2 = 0;
-	net_gatherglobals(facet, pnetlist);
+	net_gatherglobals(facet, pnetlist, &globalpnetlist);
+
+	/* count the power and ground nets */
+	net_fillinnetpointers(pcomplist, *pnetlist);
+	*powernets = *groundnets = *nets = 0;
+	lastpnet = NOPNET;
+	for(pn = *pnetlist; pn != NOPNET; pn = nextpnet)
+	{
+		nextpnet = pn->nextpnet;
+		net = pn->network;
+#ifdef NEWNCC  
+		killnet = FALSE;
+		if (pn->nodecount <= 0)
+		{
+			if (net == NONETWORK) killnet = TRUE;
+			if ((net_ncc_options & NCCINCLUDENOCOMPNETS) == 0 && net->buswidth <= 1)
+				killnet = TRUE;
+		}
+		if (killnet)
+#else
+		if ((net == NONETWORK || net->buswidth <= 1) && pn->nodecount <= 0)
+#endif
+		{
+			if (lastpnet == NOPNET) *pnetlist = nextpnet; else
+				lastpnet->nextpnet = nextpnet;
+			net_freepnet(pn);
+		} else
+		{
+			(*nets)++;
+			if ((pn->flags&POWERNET) != 0) (*powernets)++;
+			if ((pn->flags&GROUNDNET) != 0) (*groundnets)++;
+			if ((pn->flags&(POWERNET|GROUNDNET)) == (POWERNET|GROUNDNET))
+			{
+				if (pn->network == NONETWORK) np = NONODEPROTO; else
+					np = pn->network->parent;
+				ttyputmsg(_("WARNING: facet %s, network '%s' shorts power and ground"),
+					describenodeproto(np), describenetwork(pn->network));
+			}
+			lastpnet = pn;
+		}
+	}
 
 	return(pcomplist);
 }
@@ -267,7 +318,7 @@ PCOMP *net_makepseudo(NODEPROTO *facet, INTBIG *components, INTBIG *nets, INTBIG
  * Routine to recursively examine the hierarchy and make sure that all globals are mentioned
  * at the top level.
  */
-void net_gatherglobals(NODEPROTO *facet, PNET **pnetlist)
+void net_gatherglobals(NODEPROTO *facet, PNET **pnetlist, PNET **globalpnetlist)
 {
 	REGISTER INTBIG i, index;
 	REGISTER NETWORK *net;
@@ -285,9 +336,7 @@ void net_gatherglobals(NODEPROTO *facet, PNET **pnetlist)
 		if (net == NONETWORK) continue;
 		for(pn = *pnetlist; pn != NOPNET; pn = pn->nextpnet)
 		{
-#if 1
 			if (pn->network == NONETWORK) continue;
-#endif
 			index = pn->network->globalnet;
 			if (index < 0) continue;
 			pnparent = pn->network->parent;
@@ -296,7 +345,7 @@ void net_gatherglobals(NODEPROTO *facet, PNET **pnetlist)
 		if (pn != NOPNET) continue;
 
 		/* didn't find network "net" in the list */
-		pn = net_newpnet(net, pnetlist);
+		pn = net_newpnet(net, pnetlist, globalpnetlist);
 		net->temp1 = (INTBIG)pn;
 	}
 
@@ -312,7 +361,7 @@ void net_gatherglobals(NODEPROTO *facet, PNET **pnetlist)
 		/* switch from icon to schematic */
 		cnp = contentsview(subnp);
 		if (cnp != NONODEPROTO) subnp = cnp;
-		net_gatherglobals(subnp, pnetlist);
+		net_gatherglobals(subnp, pnetlist, globalpnetlist);
 	}
 }
 
@@ -324,7 +373,8 @@ void net_gatherglobals(NODEPROTO *facet, PNET **pnetlist)
  * "compare_hierarchically" is nonzero, net is flattened.  Returns zero on error.
  */
 PCOMP *net_buildpseudo(NODEPROTO *facet, PCOMP *initiallist, INTBIG *components,
-	PNET **pnetlist, BOOLEAN compare_hierarchically, BOOLEAN figuresizes)
+	PNET **pnetlist, PNET **globalpnetlist, BOOLEAN compare_hierarchically,
+	BOOLEAN figuresizes, float mfactor)
 {
 	REGISTER PCOMP *pcomp;
 	REGISTER PORTPROTO *pp, *opp, *realpp, *temprealpp;
@@ -333,6 +383,7 @@ PCOMP *net_buildpseudo(NODEPROTO *facet, PCOMP *initiallist, INTBIG *components,
 	REGISTER NETWORK *net, *subnet, *foundnet;
 	REGISTER NODEINST *ni;
 	NODEINST **nilist;
+	float submfactor, thismfactor;
 	REGISTER INTBIG fun, i, j, k, l, toplevel, flattenit, lambda,
 		nodewidth, nindex, sigcount, stopcheck;
 	BOOLEAN localcompare_hierarchically;
@@ -359,8 +410,8 @@ PCOMP *net_buildpseudo(NODEPROTO *facet, PCOMP *initiallist, INTBIG *components,
 					if ((opp->userbits&STATEBITS) != (pp->userbits&STATEBITS))
 					{
 						ttyputerr(_("Warning: bus export %s is %s but export %s is %s"),
-							pp->protoname, describeportbits(pp), opp->protoname,
-								describeportbits(opp));
+							pp->protoname, describeportbits(pp->userbits), opp->protoname,
+								describeportbits(opp->userbits));
 					}
 					break;
 				}
@@ -389,14 +440,14 @@ PCOMP *net_buildpseudo(NODEPROTO *facet, PCOMP *initiallist, INTBIG *components,
 		{
 			pn = (PNET *)net->temp1;
 			if (pn == NOPNET)
-				pn = net_newpnet(net, pnetlist);
+				pn = net_newpnet(net, pnetlist, globalpnetlist);
 			pn->flags |= POWERNET;
 		}
 		if ((pe->exportproto->userbits&STATEBITS) == GNDPORT)
 		{
 			pn = (PNET *)net->temp1;
 			if (pn == NOPNET)
-				pn = net_newpnet(net, pnetlist);
+				pn = net_newpnet(net, pnetlist, globalpnetlist);
 			pn->flags |= GROUNDNET;
 		}
 	}
@@ -405,7 +456,7 @@ PCOMP *net_buildpseudo(NODEPROTO *facet, PCOMP *initiallist, INTBIG *components,
 	for(net = facet->firstnetwork; net != NONETWORK; net = net->nextnetwork)
 	{
 		if (net->temp1 != (INTBIG)NOPNET) continue;
-		pn = net_newpnet(net, pnetlist);
+		pn = net_newpnet(net, pnetlist, globalpnetlist);
 		if (pn == NOPNET) return(0);
 		net->temp1 = (INTBIG)pn;
 		if (net->buswidth > 1)
@@ -414,7 +465,7 @@ PCOMP *net_buildpseudo(NODEPROTO *facet, PCOMP *initiallist, INTBIG *components,
 			{
 				subnet = net->networklist[i];
 				if (subnet->temp1 != (INTBIG)NOPNET) continue;
-				pn = net_newpnet(subnet, pnetlist);
+				pn = net_newpnet(subnet, pnetlist, globalpnetlist);
 				subnet->temp1 = (INTBIG)pn;
 			}
 		}
@@ -457,6 +508,26 @@ PCOMP *net_buildpseudo(NODEPROTO *facet, PCOMP *initiallist, INTBIG *components,
 		nodewidth = ni->arraysize;
 		if (nodewidth < 1) nodewidth = 1;
 
+		/* accumulate m factors */
+		submfactor = mfactor;
+		var = getvalkey((INTBIG)ni, VNODEINST, -1, el_attrkey_M);
+		if (var != NOVARIABLE)
+		{
+			CHAR *pt = describevariable(var, -1, -1);
+			if (isanumber(pt))
+			{
+				thismfactor = (float)atof(pt);
+				if (thismfactor == 0.0)
+				{
+					if (!net_mfactorwarned)
+						ttyputmsg(_("WARNING: Facet %s, node %s has a zero M-factor"),
+							describenodeproto(ni->parent), describenodeinst(ni));
+					net_mfactorwarned = TRUE;
+				}
+				submfactor *= thismfactor;
+			}
+		}
+
 		/* run through each instantiation of the node */
 		for(nindex = 0; nindex < nodewidth; nindex++)
 		{
@@ -508,7 +579,7 @@ PCOMP *net_buildpseudo(NODEPROTO *facet, PCOMP *initiallist, INTBIG *components,
 						}
 						if (pe != NOPORTEXPINST) foundnet = pe->exportproto->network; else
 						{
-							pn = net_newpnet(realpp->network, pnetlist);
+							pn = net_newpnet(realpp->network, pnetlist, globalpnetlist);
 							if (pn == NOPNET) return(0);
 							if ((realpp->userbits&STATEBITS) == PWRPORT)
 							{
@@ -562,7 +633,7 @@ PCOMP *net_buildpseudo(NODEPROTO *facet, PCOMP *initiallist, INTBIG *components,
 				/* recurse into the facet */
 				downhierarchy(ni, realnp, nindex);
 				initiallist = net_buildpseudo(realnp, initiallist, components, pnetlist,
-					compare_hierarchically, figuresizes);
+					globalpnetlist, compare_hierarchically, figuresizes, submfactor);
 				uphierarchy();
 				if (initiallist == 0) return(0);
 				continue;
@@ -578,7 +649,7 @@ PCOMP *net_buildpseudo(NODEPROTO *facet, PCOMP *initiallist, INTBIG *components,
 				/* special case: ignore resistors and capacitors if they are being ignored electrically */
 				if (fun == NPRESIST || fun == NPCAPAC || fun == NPECAPAC)
 				{
-					if (asktech(sch_tech, "ignoring-resistor-topology") != 0)
+					if (asktech(sch_tech, x_("ignoring-resistor-topology")) != 0)
 						continue;
 				}
 			}
@@ -590,7 +661,7 @@ PCOMP *net_buildpseudo(NODEPROTO *facet, PCOMP *initiallist, INTBIG *components,
 			initiallist = pcomp;
 			pcomp->function = (INTSML)fun;
 			pcomp->hashreason = 0;
-			gettraversalpath(ni->parent, &nilist, &indexlist, &pathcount, 0);
+			gettraversalpath(ni->parent, NOWINDOWPART, &nilist, &indexlist, &pathcount, 0);
 			pcomp->hierpathcount = pathcount;
 			if (pcomp->hierpathcount > 0)
 			{
@@ -653,11 +724,11 @@ PCOMP *net_buildpseudo(NODEPROTO *facet, PCOMP *initiallist, INTBIG *components,
 						transistorsize(ni, &length, &width);
 						lambda = lambdaofnode(ni);
 						pcomp->length = (float)muldiv(length, WHOLE, lambda);
-						pcomp->width = (float)muldiv(width, WHOLE, lambda);
+						pcomp->width = (float)muldiv(width, WHOLE, lambda) * submfactor;
 					} else
 					{
 						/* just set fake sizes */
-						pcomp->length = pcomp->width = 2.0f;
+						pcomp->length = pcomp->width = 2.0f * submfactor;
 					}
 					pcomp->flags |= COMPHASWIDLEN;
 #ifdef IGNOREFOURPORT
@@ -673,8 +744,8 @@ PCOMP *net_buildpseudo(NODEPROTO *facet, PCOMP *initiallist, INTBIG *components,
 						transistorsize(ni, &length, &width);
 						lambda = lambdaofnode(ni);
 						if (length < 0) pcomp->length = 0.0; else
-							pcomp->length = (float)muldiv(length, WHOLE, lambda);
-					} else pcomp->length = 4.0f;
+							pcomp->length = (float)muldiv(length, WHOLE, lambda) * submfactor;
+					} else pcomp->length = 4.0f * submfactor;
 					pcomp->width = 0.0;
 					pcomp->flags |= COMPHASAREA;
 					break;
@@ -683,7 +754,7 @@ PCOMP *net_buildpseudo(NODEPROTO *facet, PCOMP *initiallist, INTBIG *components,
 				case NPCAPAC:   case NPECAPAC:
 				case NPDIODE:   case NPDIODEZ:
 				case NPINDUCT:
-					pcomp->length = net_getpartvalue(ni);
+					pcomp->length = net_getpartvalue(ni) * submfactor;
 					pcomp->width = 0.0;
 					pcomp->flags |= COMPHASAREA;
 					break;
@@ -730,7 +801,8 @@ PCOMP *net_buildpseudo(NODEPROTO *facet, PCOMP *initiallist, INTBIG *components,
 						pp = pcomp->portlist[j];
 						pcomp->portindices[j] = (INTSML)pp->network->temp2;
 						if (net_getpnetandstate(ni, pp, NONETWORK, -1, &pcomp->netnumbers[j],
-							&pcomp->state[j], pnetlist, nodewidth, nindex, pp->network->buswidth)) return(0);
+							&pcomp->state[j], pnetlist, globalpnetlist, nodewidth, nindex,
+								pp->network->buswidth)) return(0);
 					}
 					break;
 
@@ -753,7 +825,8 @@ PCOMP *net_buildpseudo(NODEPROTO *facet, PCOMP *initiallist, INTBIG *components,
 						pp = pcomp->portlist[j];
 						pcomp->portindices[j] = (INTSML)pp->network->temp2;
 						if (net_getpnetandstate(ni, pp, NONETWORK, -1, &pcomp->netnumbers[j],
-							&pcomp->state[j], pnetlist, nodewidth, nindex, pp->network->buswidth)) return(0);
+							&pcomp->state[j], pnetlist, globalpnetlist, nodewidth, nindex,
+								pp->network->buswidth)) return(0);
 					}
 					break;
 
@@ -779,7 +852,7 @@ PCOMP *net_buildpseudo(NODEPROTO *facet, PCOMP *initiallist, INTBIG *components,
 								pcomp->portlist[j] = pp;
 								pcomp->portindices[j] = (INTSML)pp->network->temp2;
 								if (net_getpnetandstate(ni, pp, pi->conarcinst->network, -1,
-									&pcomp->netnumbers[j], &pcomp->state[j], pnetlist,
+									&pcomp->netnumbers[j], &pcomp->state[j], pnetlist, globalpnetlist,
 										nodewidth, nindex, sigcount)) return(0);
 								j++;
 							}
@@ -795,7 +868,8 @@ PCOMP *net_buildpseudo(NODEPROTO *facet, PCOMP *initiallist, INTBIG *components,
 							if (l >= j)
 							{
 								if (net_getpnetandstate(ni, pp, NONETWORK, -1, &pcomp->netnumbers[j],
-									&pcomp->state[j], pnetlist, nodewidth, nindex, sigcount)) return(0);
+									&pcomp->state[j], pnetlist, globalpnetlist, nodewidth, nindex,
+										sigcount)) return(0);
 								j++;
 							}
 						} else
@@ -809,7 +883,7 @@ PCOMP *net_buildpseudo(NODEPROTO *facet, PCOMP *initiallist, INTBIG *components,
 								if (l >= j)
 								{
 									if (net_getpnetandstate(ni, pp, NONETWORK, k,
-										&pcomp->netnumbers[j], &pcomp->state[j], pnetlist,
+										&pcomp->netnumbers[j], &pcomp->state[j], pnetlist, globalpnetlist,
 											nodewidth, nindex, sigcount)) return(0);
 									j++;
 								}
@@ -833,7 +907,7 @@ PCOMP *net_buildpseudo(NODEPROTO *facet, PCOMP *initiallist, INTBIG *components,
  * Returns true on error.
  */
 BOOLEAN net_getpnetandstate(NODEINST *ni, PORTPROTO *pp, NETWORK *forcenet,
-	INTBIG index, PNET **netnumber, INTSML *state, PNET **pnetlist,
+	INTBIG index, PNET **netnumber, INTSML *state, PNET **pnetlist, PNET **globalpnetlist,
 	INTBIG nodewidth, INTBIG nindex, INTBIG destsignals)
 {
 	REGISTER ARCINST *ai;
@@ -857,6 +931,7 @@ BOOLEAN net_getpnetandstate(NODEINST *ni, PORTPROTO *pp, NETWORK *forcenet,
 		/* pickup the network number of this connection */
 		ai = pi->conarcinst;
 		net = ai->network;
+		if (net == NONETWORK) continue;
 		if (index < 0)
 		{
 			if (nodewidth > 1 && net->buswidth == nodewidth)
@@ -880,6 +955,11 @@ BOOLEAN net_getpnetandstate(NODEINST *ni, PORTPROTO *pp, NETWORK *forcenet,
 		{
 			if (((*netnumber)->flags&EXPORTEDNET) != 0)
 				*state |= EXPORTEDPORT;
+			if (forcenet == NONETWORK)
+			{
+				if ((pp->userbits&STATEBITS) == GNDPORT) (*netnumber)->flags |= GROUNDNET; else
+					if ((pp->userbits&STATEBITS) == PWRPORT) (*netnumber)->flags |= POWERNET;
+			}
 			return(FALSE);
 		}
 	}
@@ -915,7 +995,7 @@ BOOLEAN net_getpnetandstate(NODEINST *ni, PORTPROTO *pp, NETWORK *forcenet,
 	if (forcenet == NONETWORK)
 		ttyputmsg(_("Warning: facet %s: no connection to node %s, port %s"),
 			describenodeproto(ni->parent), describenodeinst(ni), pp->protoname);
-	pn = net_newpnet(forcenet, pnetlist);
+	pn = net_newpnet(forcenet, pnetlist, globalpnetlist);
 	if (pn == NOPNET) return(TRUE);
 	pn->network = forcenet;
 	*netnumber = pn;
@@ -929,7 +1009,7 @@ void net_fillinnetpointers(PCOMP *pcomplist, PNET *pnetlist)
 {
 	REGISTER PCOMP *pc;
 	REGISTER PNET *pn;
-	REGISTER INTBIG i;
+	REGISTER INTBIG i, index;
 
 	for(pn = pnetlist; pn != NOPNET; pn = pn->nextpnet)
 		pn->nodecount = 0;
@@ -947,8 +1027,8 @@ void net_fillinnetpointers(PCOMP *pcomplist, PNET *pnetlist)
 		if (pn->nodecount <= pn->nodetotal) continue;
 		if (pn->nodetotal > 0)
 		{
-			efree((char *)pn->nodelist);
-			efree((char *)pn->nodewire);
+			efree((CHAR *)pn->nodelist);
+			efree((CHAR *)pn->nodewire);
 			pn->nodetotal = 0;
 		}
 		pn->nodelist = (PCOMP **)emalloc(pn->nodecount * (sizeof (PCOMP *)), net_tool->cluster);
@@ -966,9 +1046,10 @@ void net_fillinnetpointers(PCOMP *pcomplist, PNET *pnetlist)
 			pn = pc->netnumbers[i];
 			if (pn->nodelist == 0)
 				continue;
-			pn->nodelist[pn->nodecount] = pc;
-			pn->nodewire[pn->nodecount] = i;
-			pn->nodecount++;
+			index = pn->nodecount++;
+			if (index >= pn->nodetotal) continue;
+			pn->nodelist[index] = pc;
+			pn->nodewire[index] = i;
 		}
 	}
 }	
@@ -1063,12 +1144,13 @@ INTBIG net_mergeparallel(PCOMP **pcomp, PNET *pnet, INTBIG *components)
 
 			/* add "pc"s node pointer to "opc" */
 			newnum = pc->numactual + opc->numactual;
+			newsingle = NONODEINST;
 			if (newnum > 1)
 			{
 				newlist = (NODEINST **)emalloc(newnum * (sizeof (NODEINST *)),
 					net_tool->cluster);
 				if (newlist == 0) return(0);
-			}
+			} else newlist = 0;
 			k = 0;
 			for(j=0; j<pc->numactual; j++)
 			{
@@ -1084,7 +1166,7 @@ INTBIG net_mergeparallel(PCOMP **pcomp, PNET *pnet, INTBIG *components)
 				if (newnum == 1) newsingle = ni; else
 					newlist[k++] = ni;
 			}
-			if (opc->numactual > 1) efree((char *)opc->actuallist);
+			if (opc->numactual > 1) efree((CHAR *)opc->actuallist);
 			if (newnum == 1) opc->actuallist = (void *)newsingle; else
 				opc->actuallist = (void *)newlist;
 			opc->numactual = newnum;
@@ -1140,7 +1222,7 @@ INTBIG net_mergeparallel(PCOMP **pcomp, PNET *pnet, INTBIG *components)
 			pc->flags |= COMPDELETED;
 		}
 	}
-	efree((char *)complist);
+	efree((CHAR *)complist);
 
 	/* remove deleted components */
 	lastpc = NOPCOMP;
@@ -1186,7 +1268,7 @@ BOOLEAN net_addtoserieslist(PCOMP *pc)
 		if (newlist == 0) return(TRUE);
 		for(i=0; i<net_serieslistcount; i++)
 			newlist[i] = net_serieslist[i];
-		if (net_serieslisttotal > 0) efree((char *)net_serieslist);
+		if (net_serieslisttotal > 0) efree((CHAR *)net_serieslist);
 		net_serieslist = newlist;
 		net_serieslisttotal = newtotal;
 	}
@@ -1224,6 +1306,7 @@ void net_crawlforseries(PCOMP *pc)
 	for(i=1; i<3; i++)
 	{
 		badend = 0;
+		opc = NOPCOMP;
 
 		/* connection must be to exactly 1 other component */
 		pn = pc->netnumbers[i];
@@ -1442,6 +1525,7 @@ INTBIG net_mergeseries(PCOMP **pcomp, PNET *pnet, INTBIG *components)
 BOOLEAN net_comparewirelist(PCOMP *p1, PCOMP *p2, BOOLEAN useportnames)
 {
 	REGISTER INTBIG i, j;
+	Q_UNUSED( useportnames );
 
 	/* simple test: number of wire lists must be equal */
 	if (p1->wirecount != p2->wirecount) return(TRUE);
@@ -1462,7 +1546,7 @@ BOOLEAN net_comparewirelist(PCOMP *p1, PCOMP *p2, BOOLEAN useportnames)
 	/* make sure there is memory for flags corresponding to component 2 */
 	if (p2->wirecount > net_comparelistsize)
 	{
-		if (net_comparelistsize != 0) efree((char *)net_comparelist);
+		if (net_comparelistsize != 0) efree((CHAR *)net_comparelist);
 		net_comparelist = (BOOLEAN *)emalloc(((sizeof (BOOLEAN)) * p2->wirecount),
 			net_tool->cluster);
 		net_comparelistsize = p2->wirecount;
@@ -1491,7 +1575,7 @@ float net_getpartvalue(NODEINST *ni)
 {
 	REGISTER NODEPROTO *np;
 	REGISTER VARIABLE *var;
-	REGISTER char *pt;
+	REGISTER CHAR *pt;
 
 	np = ni->proto;
 	if (np->primindex == 0) return(0.0);
@@ -1501,7 +1585,7 @@ float net_getpartvalue(NODEINST *ni)
 	{
 		var = getvalkey((INTBIG)ni, VNODEINST, -1, sch_diodekey);
 		pt = describesimplevariable(var);
-		return((float)atof(pt));
+		return((float)eatof(pt));
 	}
 
 	/* capacitors have Farads on them */
@@ -1509,7 +1593,7 @@ float net_getpartvalue(NODEINST *ni)
 	{
 		var = getvalkey((INTBIG)ni, VNODEINST, -1, sch_capacitancekey);
 		if (var == NOVARIABLE) return(0.0);
-		return((float)atof(describesimplevariable(var)));
+		return((float)eatof(describesimplevariable(var)));
 	}
 
 	/* resistors have Ohms on them */
@@ -1517,7 +1601,7 @@ float net_getpartvalue(NODEINST *ni)
 	{
 		var = getvalkey((INTBIG)ni, VNODEINST, -1, sch_resistancekey);
 		if (var == NOVARIABLE) return(0.0);
-		return((float)atof(describesimplevariable(var)));
+		return((float)eatof(describesimplevariable(var)));
 	}
 
 	/* inductors have Henrys on them */
@@ -1525,7 +1609,7 @@ float net_getpartvalue(NODEINST *ni)
 	{
 		var = getvalkey((INTBIG)ni, VNODEINST, -1, sch_inductancekey);
 		if (var == NOVARIABLE) return(0.0);
-		return((float)atof(describesimplevariable(var)));
+		return((float)eatof(describesimplevariable(var)));
 	}
 	return(0.0);
 }
@@ -1538,28 +1622,50 @@ float net_getpartvalue(NODEINST *ni)
  * global "net_pseudonode" and adds the module to the list in "pnetlist".
  * Return the module (NOPNET on error).
  */
-PNET *net_newpnet(NETWORK *net, PNET **pnetlist)
+PNET *net_newpnet(NETWORK *net, PNET **localpnetlist, PNET **globalpnetlist)
 {
-	REGISTER PNET *pn;
+	REGISTER PNET *pn, **pnetlist;
 	REGISTER NETWORK *onet;
-	REGISTER char *globalname;
-	REGISTER INTBIG characteristics;
+	REGISTER CHAR *globalname;
+	REGISTER UINTBIG characteristics;
+	REGISTER BOOLEAN isglobal;
+
+	/* see if this is a global network */
+	if (net != NONETWORK && net->globalnet >= 0 &&
+		net->globalnet < net->parent->globalnetcount) isglobal = TRUE; else
+			isglobal = FALSE;
 
 	/* if the net is global, look for an equivalent */
-	if (net != NONETWORK && net->globalnet >= 0 &&
-		net->globalnet < net->parent->globalnetcount)
+	if (isglobal)
 	{
-		globalname = net->parent->globalnetnames[net->globalnet];
-		for(pn = *pnetlist; pn != NOPNET; pn = pn->nextpnet)
+		pnetlist = globalpnetlist;
+		if (net->globalnet <= 1)
 		{
-			if ((pn->flags&GLOBALNET) == 0) continue;
-			onet = pn->network;
-			if (onet == NONETWORK) continue;
-			if (onet->globalnet < 0) continue;
-			if (onet->globalnet >= onet->parent->globalnetcount) continue;
-			if (namesame(onet->parent->globalnetnames[onet->globalnet], globalname) == 0)
-				return(pn);
+			/* power and ground: search by index */
+			for(pn = *pnetlist; pn != NOPNET; pn = pn->nextpnet)
+			{
+				onet = pn->network;
+				if (onet == NONETWORK) continue;
+				if (net->globalnet == onet->globalnet) return(pn);
+			}
+		} else
+		{
+			/* not power-and-ground: search by name */
+			globalname = net->parent->globalnetnames[net->globalnet];
+			for(pn = *pnetlist; pn != NOPNET; pn = pn->nextpnet)
+			{
+				if ((pn->flags&GLOBALNET) == 0) continue;
+				onet = pn->network;
+				if (onet == NONETWORK) continue;
+				if (onet->globalnet < 0) continue;
+				if (onet->globalnet >= onet->parent->globalnetcount) continue;
+				if (namesame(onet->parent->globalnetnames[onet->globalnet], globalname) == 0)
+					return(pn);
+			}
 		}
+	} else
+	{
+		pnetlist = localpnetlist;
 	}
 
 	/* global net not found */
@@ -1569,8 +1675,7 @@ PNET *net_newpnet(NETWORK *net, PNET **pnetlist)
 	pn->nextpnet = *pnetlist;
 	*pnetlist = pn;
 	pn->network = net;
-	if (net != NONETWORK && net->globalnet >= 0 &&
-		net->globalnet < net->parent->globalnetcount)
+	if (isglobal)
 	{
 		pn->flags |= GLOBALNET;
 		characteristics = net->parent->globalnetchar[net->globalnet];
@@ -1604,7 +1709,7 @@ void net_addexporttopnet(PNET *pn, PORTPROTO *pp)
 		newportlist[i] = npp;
 	}
 	newportlist[pn->realportcount] = pp;
-	if (pn->realportcount > 1) efree((char *)pn->realportlist);
+	if (pn->realportcount > 1) efree((CHAR *)pn->realportlist);
 	pn->realportlist = newportlist;
 	pn->realportcount++;
 }
@@ -1636,23 +1741,24 @@ void net_freepcomp(PCOMP *pc)
 {
 	if (pc->wirecount != 0)
 	{
-		efree((char *)pc->portlist);
-		efree((char *)pc->state);
-		efree((char *)pc->netnumbers);
-		efree((char *)pc->portindices);
+		efree((CHAR *)pc->portlist);
+		efree((CHAR *)pc->state);
+		efree((CHAR *)pc->netnumbers);
+		efree((CHAR *)pc->portindices);
 	}
-	if (pc->numactual > 1) efree((char *)pc->actuallist);
-	if (pc->hashreason != 0) efree((char *)pc->hashreason);
+	if (pc->numactual > 1) efree((CHAR *)pc->actuallist);
+	if (pc->hashreason != 0) efree((CHAR *)pc->hashreason);
 	if (pc->hierpathcount != 0)
 	{
-		efree((char *)pc->hierpath);
-		efree((char *)pc->hierindex);
+		efree((CHAR *)pc->hierpath);
+		efree((CHAR *)pc->hierindex);
 	}
 
 	pc->nextpcomp = net_pcompfree;
 	net_pcompfree = pc;
 }
 
+
 /*
  * routine to allocate a new pnet module from the pool (if any) or memory
  */
@@ -1664,6 +1770,7 @@ PNET *net_allocpnet(void)
 	{
 		pn = (PNET *)emalloc(sizeof (PNET), net_tool->cluster);
 		if (pn == 0) return(NOPNET);
+		pn->nodetotal = 0;
 	} else
 	{
 		pn = net_pnetfree;
@@ -1671,7 +1778,6 @@ PNET *net_allocpnet(void)
 	}
 
 	pn->flags = 0;
-	pn->nodetotal = 0;
 	pn->nodecount = 0;
 	pn->realportcount = 0;
 	return(pn);
@@ -1682,13 +1788,8 @@ PNET *net_allocpnet(void)
  */
 void net_freepnet(PNET *pn)
 {
-	if (pn->nodetotal > 0)
-	{
-		efree((char *)pn->nodelist);
-		efree((char *)pn->nodewire);
-	}
 	if (pn->realportcount > 1)
-		efree((char *)pn->realportlist);
+		efree((CHAR *)pn->realportlist);
 
 	pn->nextpnet = net_pnetfree;
 	net_pnetfree = pn;
@@ -1730,7 +1831,7 @@ void net_freeallpcomp(PCOMP *pclist)
 
 typedef struct Itranmodel
 {
-	char *modelname;
+	CHAR *modelname;
 	INTBIG tmindex;
 	struct Itranmodel *nexttranmodel;
 } TRANMODEL;
@@ -1803,20 +1904,20 @@ INTBIG net_getfunction(NODEINST *ni)
 	return(fun);
 }
 
-void net_setallexporttopology(void)
+void net_initnetflattening(void)
 {
-	REGISTER LIBRARY *lib;
+	REGISTER LIBRARY *lib, *olib;
 	REGISTER NODEPROTO *np;
-	REGISTER INTBIG i;
+	REGISTER INTBIG i, primeindex;
 	REGISTER PORTPROTO *pp;
-	REGISTER CELL *c;
+	REGISTER CELL *c, *oc;
 	REGISTER TECHNOLOGY *tech;
 	REGISTER NETWORK *net;
 
 	/* clear prime number indices in the cells */
 	for(lib = el_curlib; lib != NOLIBRARY; lib = lib->nextlibrary)
 		for(c = lib->firstcell; c != NOCELL; c = c->nextcell)
-			c->temp2 = 0;
+			c->temp1 = c->temp2 = 0;
 
 	/* clear network topology information */
 	for(lib = el_curlib; lib != NOLIBRARY; lib = lib->nextlibrary)
@@ -1828,70 +1929,32 @@ void net_setallexporttopology(void)
 		}
 	}
 
-#if 0
-	/* assign network topology information from previous NCC runs */
-	infstr = 0;
+	/* match cell names across library boundaries */
+	primeindex = 1;
 	for(lib = el_curlib; lib != NOLIBRARY; lib = lib->nextlibrary)
 	{
-		/* assign topology information uniformly in each cell */
-		for(np = lib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
+		if ((lib->userbits&HIDDENLIBRARY) != 0) continue;
+		for(c = lib->firstcell; c != NOCELL; c = c->nextcell)
 		{
-			for(i=0; i<np->numvar; i++)
+			if (c->temp1 != 0) continue;
+
+			/* see if this cellname exists in another library */
+			for(olib = el_curlib; olib != NOLIBRARY; olib = olib->nextlibrary)
 			{
-				var = &np->firstvar[i];
-				pt = makename(var->key);
-				if (namesamen(pt, "NET_ncc_last_result", 19) != 0) continue;
-				net_parsenccresult(np, var, &onp, &matchdate);
-				if (onp == NONODEPROTO) continue;
-				if (np->revisiondate > matchdate) continue;
-
-				/* valid NCC match from this facet to "onp", see if it is reciprocated */
-				ovar = net_nccfindmatch(onp, np, &matchdate);
-				if (ovar == NOVARIABLE) continue;
-				if (onp->revisiondate > matchdate) continue;
-
-				/* report these reuses */
-				if (infstr == 0)
+				if (olib == lib) continue;
+				if ((olib->userbits&HIDDENLIBRARY) != 0) continue;
+				for(oc = olib->firstcell; oc != NOCELL; oc = oc->nextcell)
+					if (namesame(c->cellname, oc->cellname) == 0) break;
+				if (oc != NOCELL && oc->temp1 != 0)
 				{
-					infstr = initinfstr();
-					addstringtoinfstr(infstr, _("NOTE: Using previous NCC match information between"));
-				} else
-				{
-					addstringtoinfstr(infstr, ",");
-				}
-				formatinfstr(infstr, _(" %s and %s"), describenodeproto(np), describenodeproto(onp));
-
-				/* found match: assign network pointers */
-				len = getlength(var);
-				strings = (char **)var->addr;
-				for(j=0; j<len; j++)
-				{
-					pt = strings[j];
-					if (namesamen(pt, "EXPORT ", 7) != 0) continue;
-					pt += 7;
-					name = pt;
-					while (*pt != 0 && *pt != ':') pt++;
-					if (*pt == 0) continue;
-					*pt = 0;
-					oname = pt+1;
-
-					/* found the names: make the assignment */
-					net = getnetwork(name, np);
-					onet = getnetwork(oname, onp);
-					if (net != NONETWORK && onet != NONETWORK)
-					{
-						if (net->temp2 == 0 && onet->temp2 == 0)
-						{
-							net->temp2 = onet->temp2 = getprime(np->cell->temp2++);
-						}
-					}
-					*pt = ':';
+					c->temp1 = oc->temp1;
+					break;
 				}
 			}
+			if (c->temp1 != 0) continue;
+			c->temp1 = getprime(primeindex++);
 		}
 	}
-	if (infstr != 0) ttyputmsg("%s", returninfstr(infstr));
-#endif
 
 	/* assign remaining network topology based on export names */
 	for(lib = el_curlib; lib != NOLIBRARY; lib = lib->nextlibrary)
@@ -1974,8 +2037,9 @@ void net_setthisexporttopology(PORTPROTO *pp, INTBIG *index)
 	REGISTER NETWORK *net, *subnet;
 	REGISTER PORTPROTO *opp;
 	REGISTER NODEPROTO *np;
-	REGISTER INTBIG i, bits;
-	REGISTER char *name;
+	REGISTER INTBIG i;
+	REGISTER UINTBIG bits;
+	REGISTER CHAR *name;
 
 	/* assign the unique prime numbers to the export's network */
 	net = pp->network;
@@ -2012,7 +2076,7 @@ void net_setthisexporttopology(PORTPROTO *pp, INTBIG *index)
 			subnet = net->networklist[i];
 			if (subnet->temp2 == 0)
 			{
-				if (subnet->namecount > 0) name = subnet->netname; else
+				if (subnet->namecount > 0) name = networkname(subnet, 0); else
 					name = pp->protoname;
 				subnet->temp2 = net_findotherexporttopology(np, name);
 				if (subnet->temp2 == 0) subnet->temp2 = getprime((*index)++);
@@ -2026,11 +2090,12 @@ void net_setthisexporttopology(PORTPROTO *pp, INTBIG *index)
  * but with a different view) and find an export with the name "exportname".  Returns
  * the "temp2" field (unique ID) of that network.  Returns zero if no association can be found.
  */
-INTBIG net_findotherexporttopology(NODEPROTO *parent, char *exportname)
+INTBIG net_findotherexporttopology(NODEPROTO *parent, CHAR *exportname)
 {
 	REGISTER NODEPROTO *np;
 	REGISTER PORTPROTO *opp;
 	REGISTER NETWORK *net;
+	REGISTER LIBRARY *lib;
 
 	/* first look for an equivalent export in another facet */
 	for(np = parent->cell->lib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
@@ -2054,6 +2119,24 @@ INTBIG net_findotherexporttopology(NODEPROTO *parent, char *exportname)
 		if (net == NONETWORK) continue;
 		if (net->temp2 != 0) return(net->temp2);
 	}
+
+	/* now look for an equivalent in another library */
+	for(lib = el_curlib; lib != NOLIBRARY; lib = lib->nextlibrary)
+	{
+		if (lib == parent->cell->lib) continue;
+		if ((lib->userbits&HIDDENLIBRARY) != 0) continue;
+		for(np = lib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
+		{
+			if (np->cell->temp1 != parent->cell->temp1) continue;
+
+			/* facet from the same cell in another library: look for an equivalent export or network name */
+			opp = getportproto(np, exportname);
+			if (opp != NOPORTPROTO && opp->network->temp2 != 0) return(opp->network->temp2);
+			net = getnetwork(exportname, np);
+			if (net == NONETWORK) continue;
+			if (net->temp2 != 0) return(net->temp2);
+		}
+	}
 	return(0);
 }
 
