@@ -44,7 +44,7 @@ static BOOLEAN plac_nmos_init_columns(INTBIG, INTBIG, INTBIG, INTBIG, NODEPROTO*
 static BOOLEAN plac_nmos_init_rows(INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, NODEPROTO*);
 static BOOLEAN plac_finish_columns(INTBIG, INTBIG, INTBIG, INTBIG, NODEPROTO*, NODEPROTO*);
 
-NODEPROTO *plac_nmos_grid(LIBRARY *library, FILE *file, char facet_name[])
+NODEPROTO *plac_nmos_grid(LIBRARY *library, FILE *file, CHAR facet_name[])
 {
 	INTBIG height, width, height_in, width_in, read_rows;
 	NODEPROTO *pla_array_facet, *np, *nmos_one;
@@ -57,7 +57,7 @@ NODEPROTO *plac_nmos_grid(LIBRARY *library, FILE *file, char facet_name[])
 	X_offset = PLAC_X_SEP * pla_lam;
 	Y_offset = PLAC_Y_SEP * pla_lam;
 	Y_M_offset = PLAC_Y_MIR_SEP * pla_lam;
-	nmos_one = getnodeproto("nmos_one");
+	nmos_one = getnodeproto(x_("nmos_one"));
 	if (nmos_one == NONODEPROTO)
 	{
 		ttyputerr(_("Unable to find prototype called nmos_one"));
@@ -73,10 +73,10 @@ NODEPROTO *plac_nmos_grid(LIBRARY *library, FILE *file, char facet_name[])
 		return(NONODEPROTO);
 	}
 
-	(void)setval((INTBIG)pla_array_facet, VNODEPROTO, "PLA_data_cols", width_in, VINTEGER);
-	(void)setval((INTBIG)pla_array_facet, VNODEPROTO, "PLA_access_rows", height_in, VINTEGER);
-	(void)setval((INTBIG)pla_array_facet, VNODEPROTO, "PLA_cols", width, VINTEGER);
-	(void)setval((INTBIG)pla_array_facet, VNODEPROTO, "PLA_rows", height, VINTEGER);
+	(void)setval((INTBIG)pla_array_facet, VNODEPROTO, x_("PLA_data_cols"), width_in, VINTEGER);
+	(void)setval((INTBIG)pla_array_facet, VNODEPROTO, x_("PLA_access_rows"), height_in, VINTEGER);
+	(void)setval((INTBIG)pla_array_facet, VNODEPROTO, x_("PLA_cols"), width, VINTEGER);
+	(void)setval((INTBIG)pla_array_facet, VNODEPROTO, x_("PLA_rows"), height, VINTEGER);
 
 	/* initialize the columns */
 	if (plac_nmos_init_columns(width, X, Y, X_offset, pla_array_facet))
@@ -153,7 +153,7 @@ NODEPROTO *plac_nmos_grid(LIBRARY *library, FILE *file, char facet_name[])
 		return(NONODEPROTO);
 
 	/* put a well node over the region */
-	np = getnodeproto("mocmos:P-Well-Node");
+	np = getnodeproto(x_("mocmos:P-Well-Node"));
 
 	X1 = pla_array_facet->lowx;
 	X2 = pla_array_facet->highx;
@@ -178,7 +178,7 @@ BOOLEAN plac_gnd_strap(INTBIG i, INTBIG X, INTBIG Y, INTBIG row, NODEPROTO *pla_
 
 	/* put in Substrate contact first */
 	new_item->nodeinst = plac_make_Pin(pla_array_facet, X,
-		Y+11*pla_lam, 14*pla_lam, "Metal-1-Well-Con");
+		Y+11*pla_lam, 14*pla_lam, x_("Metal-1-Well-Con"));
 	if (new_item->nodeinst == NONODEINST) return(TRUE);
 
 	/* wire in the first ground strap */
@@ -186,7 +186,7 @@ BOOLEAN plac_gnd_strap(INTBIG i, INTBIG X, INTBIG Y, INTBIG row, NODEPROTO *pla_
 	last_col_pp = plac_col_list[i].lastitem->nodeinst->proto->firstportproto;
 
 	/* connect to last column object */
-	plac_wire("Metal-1", 4*pla_lam, plac_col_list[i].lastitem->nodeinst,
+	plac_wire(x_("Metal-1"), 4*pla_lam, plac_col_list[i].lastitem->nodeinst,
 		last_col_pp, new_item->nodeinst, ni_col_pp, pla_array_facet);
 
 	/* only put this in a column list */
@@ -196,7 +196,7 @@ BOOLEAN plac_gnd_strap(INTBIG i, INTBIG X, INTBIG Y, INTBIG row, NODEPROTO *pla_
 	/* put in metal diffusion contact */
 	new_item = plac_newUCITEM();
 	new_item->nodeinst = plac_make_Pin(pla_array_facet, X,
-		Y+pla_lam, 14*pla_lam, "Metal-1-D-Active-Con");
+		Y+pla_lam, 14*pla_lam, x_("Metal-1-D-Active-Con"));
 	if (new_item->nodeinst == NONODEINST) return(TRUE);
 
 	/* wire in the first ground strap */
@@ -204,14 +204,14 @@ BOOLEAN plac_gnd_strap(INTBIG i, INTBIG X, INTBIG Y, INTBIG row, NODEPROTO *pla_
 	last_col_pp = plac_col_list[i].lastitem->nodeinst->proto->firstportproto;
 
 	/* connect to last column object */
-	plac_wire("Metal-1", 4*pla_lam, plac_col_list[i].lastitem->nodeinst,
+	plac_wire(x_("Metal-1"), 4*pla_lam, plac_col_list[i].lastitem->nodeinst,
 		last_col_pp, new_item->nodeinst, ni_col_pp, pla_array_facet);
 
 	/* connect to last row object */
 	if (plac_row_list[row][1].lastitem->nodeinst->proto != nmos_one)
 		last_col_pp = plac_row_list[row][1].lastitem->nodeinst->proto->firstportproto; else
-			last_col_pp = getportproto(plac_row_list[row][1].lastitem->nodeinst->proto, "GND.d.s");
-	plac_wire("D-active", 14*pla_lam, plac_row_list[row][1].lastitem->nodeinst,
+			last_col_pp = getportproto(plac_row_list[row][1].lastitem->nodeinst->proto, x_("GND.d.s"));
+	plac_wire(x_("D-active"), 14*pla_lam, plac_row_list[row][1].lastitem->nodeinst,
 		last_col_pp, new_item->nodeinst, ni_col_pp, pla_array_facet);
 
 	/* insert into row and column lists */
@@ -241,13 +241,13 @@ BOOLEAN plac_nmos_make_one(INTBIG i, INTBIG X, INTBIG Y, INTBIG Mirror, INTBIG r
 	if (ni == NONODEINST) return(TRUE);
 
 	/* find the ports that need to be connected */
-	ni_col_pp = getportproto(ni->proto, "OUT.m-1.n");
+	ni_col_pp = getportproto(ni->proto, x_("OUT.m-1.n"));
 	if (plac_col_list[i].lastitem->nodeinst->proto != nmos_one) /* a Metal pin */
 		last_col_pp = plac_col_list[i].firstitem->nodeinst->proto->firstportproto; else
-			last_col_pp = getportproto(plac_col_list[i].lastitem->nodeinst->proto, "OUT.m-1.n");
+			last_col_pp = getportproto(plac_col_list[i].lastitem->nodeinst->proto, x_("OUT.m-1.n"));
 
 	/* connect to last column object */
-	plac_wire("Metal-1", 4*pla_lam, plac_col_list[i].lastitem->nodeinst, last_col_pp,
+	plac_wire(x_("Metal-1"), 4*pla_lam, plac_col_list[i].lastitem->nodeinst, last_col_pp,
 		ni, ni_col_pp, pla_array_facet);
 
 	/* connect to last ground object */
@@ -264,23 +264,23 @@ BOOLEAN plac_nmos_make_one(INTBIG i, INTBIG X, INTBIG Y, INTBIG Mirror, INTBIG r
 
 	if (plac_row_list[row][1].lastitem->nodeinst->proto != nmos_one)
 		last_col_pp = plac_row_list[row][1].lastitem->nodeinst->proto->firstportproto; else
-			last_col_pp =  getportproto(plac_row_list[row][1].lastitem->nodeinst->proto, "GND.d.s");
+			last_col_pp =  getportproto(plac_row_list[row][1].lastitem->nodeinst->proto, x_("GND.d.s"));
 	if (last_col_pp == NOPORTPROTO)
 	{
 		ttyputerr(M_("No NODEPROTO for GND.d.s"), row);
 		return(TRUE);
 	}
-	ni_col_pp = getportproto(ni->proto, "GND.d.s");
-	plac_wire("D-active", 14*pla_lam, plac_row_list[row][1].lastitem->nodeinst,
+	ni_col_pp = getportproto(ni->proto, x_("GND.d.s"));
+	plac_wire(x_("D-active"), 14*pla_lam, plac_row_list[row][1].lastitem->nodeinst,
 		last_col_pp, ni, ni_col_pp, pla_array_facet);
 
 	/* connect to last GATE object */
 	if (plac_row_list[row][row_pos].lastitem->nodeinst->proto != nmos_one)
 		last_col_pp = plac_row_list[row][row_pos].lastitem->nodeinst->proto->firstportproto; else
 			last_col_pp =  getportproto(plac_row_list[row][row_pos].lastitem->nodeinst->proto,
-				"GATE.p.e");
-	ni_col_pp = getportproto(ni->proto, "GATE.p.w");
-	plac_wire("Polysilicon", 0, plac_row_list[row][row_pos].lastitem->nodeinst, last_col_pp,
+				x_("GATE.p.e"));
+	ni_col_pp = getportproto(ni->proto, x_("GATE.p.w"));
+	plac_wire(x_("Polysilicon"), 0, plac_row_list[row][row_pos].lastitem->nodeinst, last_col_pp,
 		ni, ni_col_pp, pla_array_facet);
 
 	/* put in column list */
@@ -303,60 +303,60 @@ BOOLEAN plac_complete_row(INTBIG row, INTBIG X, INTBIG Y, NODEPROTO *nmos_one,
 {
 	UCITEM *new_item;
 	PORTPROTO *last_col_pp, *ni_col_pp;
-	char name[40];
+	CHAR name[40];
 
 	new_item = plac_newUCITEM();
 	new_item->nodeinst = plac_make_Pin(pla_array_facet, X, Y+6*pla_lam,
-		6*pla_lam, "Metal-1-Polysilicon-Con");
+		6*pla_lam, x_("Metal-1-Polysilicon-Con"));
 	if (new_item->nodeinst == NONODEINST) return(TRUE);
 
 	/* connect to last GATE object */
 	if (plac_row_list[row][0].lastitem->nodeinst->proto != nmos_one)
 		last_col_pp = plac_row_list[row][0].lastitem->nodeinst->proto->firstportproto; else
-			last_col_pp =  getportproto(plac_row_list[row][0].lastitem->nodeinst->proto, "GATE.p.e");
+			last_col_pp =  getportproto(plac_row_list[row][0].lastitem->nodeinst->proto, x_("GATE.p.e"));
 	ni_col_pp = new_item->nodeinst->proto->firstportproto;
-	plac_wire("Polysilicon", 0, plac_row_list[row][0].lastitem->nodeinst,
+	plac_wire(x_("Polysilicon"), 0, plac_row_list[row][0].lastitem->nodeinst,
 		last_col_pp, new_item->nodeinst, ni_col_pp, pla_array_facet);
 	plac_row_list[row][0].lastitem = new_item;
 
 	/* Now export port at beginning and end of this half of the row grouping */
-	(void)sprintf(name, "ACCESS%ld.m-1.w", row * 2);
+	(void)esnprintf(name, 40, x_("ACCESS%ld.m-1.w"), row * 2);
 	(void)newportproto(pla_array_facet, plac_row_list[row][0].firstitem->nodeinst,
 		plac_row_list[row][0].firstitem->nodeinst->proto->firstportproto, name);
-	(void)sprintf(name, "ACCESS%ld.m-1.e", row * 2);
+	(void)esnprintf(name, 40, x_("ACCESS%ld.m-1.e"), row * 2);
 	(void)newportproto(pla_array_facet, plac_row_list[row][0].lastitem->nodeinst,
 		plac_row_list[row][0].lastitem->nodeinst->proto->firstportproto, name);
-	(void)sprintf(name, "ACCESS%ld.p.w", row * 2);
+	(void)esnprintf(name, 40, x_("ACCESS%ld.p.w"), row * 2);
 	(void)newportproto(pla_array_facet, plac_row_list[row][0].firstitem->nodeinst,
 		plac_row_list[row][0].firstitem->nodeinst->proto->firstportproto, name);
-	(void)sprintf(name, "ACCESS%ld.p.e", row * 2);
+	(void)esnprintf(name, 40, x_("ACCESS%ld.p.e"), row * 2);
 	(void)newportproto(pla_array_facet, plac_row_list[row][0].lastitem->nodeinst,
 		plac_row_list[row][0].lastitem->nodeinst->proto->firstportproto, name);
 
 	new_item = plac_newUCITEM();
 	new_item->nodeinst = plac_make_Pin(pla_array_facet, X, Y-4*pla_lam,
-		6*pla_lam, "Metal-1-Polysilicon-Con");
+		6*pla_lam, x_("Metal-1-Polysilicon-Con"));
 	if (new_item->nodeinst == NONODEINST) return(TRUE);
 
 	/* connect to last GATE object */
 	if (plac_row_list[row][2].lastitem->nodeinst->proto != nmos_one)
 		last_col_pp = plac_row_list[row][2].lastitem->nodeinst->proto->firstportproto; else
-			last_col_pp =  getportproto(plac_row_list[row][2].lastitem->nodeinst->proto, "GATE.p.e");
+			last_col_pp =  getportproto(plac_row_list[row][2].lastitem->nodeinst->proto, x_("GATE.p.e"));
 	ni_col_pp = new_item->nodeinst->proto->firstportproto;
-	plac_wire("Polysilicon", 0, plac_row_list[row][2].lastitem->nodeinst,
+	plac_wire(x_("Polysilicon"), 0, plac_row_list[row][2].lastitem->nodeinst,
 		last_col_pp, new_item->nodeinst, ni_col_pp, pla_array_facet);
 	plac_row_list[row][2].lastitem = new_item;
 
-	(void)sprintf(name, "ACCESS%ld.m-1.w", row * 2 + 1);
+	(void)esnprintf(name, 40, x_("ACCESS%ld.m-1.w"), row * 2 + 1);
 	(void)newportproto(pla_array_facet, plac_row_list[row][2].firstitem->nodeinst,
 		plac_row_list[row][2].firstitem->nodeinst->proto->firstportproto, name);
-	(void)sprintf(name, "ACCESS%ld.m-1.e", row * 2 + 1);
+	(void)esnprintf(name, 40, x_("ACCESS%ld.m-1.e"), row * 2 + 1);
 	(void)newportproto(pla_array_facet, plac_row_list[row][2].lastitem->nodeinst,
 		plac_row_list[row][2].lastitem->nodeinst->proto->firstportproto, name);
-	(void)sprintf(name, "ACCESS%ld.p.w", row * 2 + 1);
+	(void)esnprintf(name, 40, x_("ACCESS%ld.p.w"), row * 2 + 1);
 	(void)newportproto(pla_array_facet, plac_row_list[row][2].firstitem->nodeinst,
 		plac_row_list[row][2].firstitem->nodeinst->proto->firstportproto, name);
-	(void)sprintf(name, "ACCESS%ld.p.e", row * 2 + 1);
+	(void)esnprintf(name, 40, x_("ACCESS%ld.p.e"), row * 2 + 1);
 	(void)newportproto(pla_array_facet, plac_row_list[row][2].lastitem->nodeinst,
 		plac_row_list[row][2].lastitem->nodeinst->proto->firstportproto, name);
 	return(FALSE);
@@ -365,7 +365,7 @@ BOOLEAN plac_complete_row(INTBIG row, INTBIG X, INTBIG Y, NODEPROTO *nmos_one,
 BOOLEAN plac_nmos_init_columns(INTBIG width, INTBIG X, INTBIG Y, INTBIG X_offset,
 	NODEPROTO *pla_array_facet)
 {
-	char name[40];
+	CHAR name[40];
 	INTBIG i, gnd_cnt;
 
 	gnd_cnt = 0;
@@ -377,17 +377,17 @@ BOOLEAN plac_nmos_init_columns(INTBIG width, INTBIG X, INTBIG Y, INTBIG X_offset
 		/* put in a Ground  pin every 5th position */
 		if ((i % 5) == 0)
 		{
-			(void)sprintf(name, "GND%ld.m-1.n", gnd_cnt);
+			(void)esnprintf(name, 40, x_("GND%ld.m-1.n"), gnd_cnt);
 			plac_col_list[i].firstitem->nodeinst = plac_make_Pin(pla_array_facet,
-				X_offset * i + X, Y, 14*pla_lam, "Metal-1-Well-Con");
+				X_offset * i + X, Y, 14*pla_lam, x_("Metal-1-Well-Con"));
 			if (plac_col_list[i].firstitem->nodeinst == NONODEINST) return(TRUE);
 			gnd_cnt++;
 		} else
 		{
 			/* must be a data pin, don't count ground pins */
-			(void)sprintf(name, "DATA%ld.m-1.n", (i - gnd_cnt));
+			(void)esnprintf(name, 40, x_("DATA%ld.m-1.n"), (i - gnd_cnt));
 			plac_col_list[i].firstitem->nodeinst = plac_make_Pin(pla_array_facet,
-				X_offset * i + X, Y, 4*pla_lam, "Metal-1-Pin");
+				X_offset * i + X, Y, 4*pla_lam, x_("Metal-1-Pin"));
 			if (plac_col_list[i].firstitem->nodeinst == NONODEINST) return(TRUE);
 		}
 		(void)newportproto(pla_array_facet, plac_col_list[i].firstitem->nodeinst,
@@ -414,7 +414,7 @@ BOOLEAN plac_nmos_init_rows(INTBIG height_in, INTBIG X, INTBIG Y, INTBIG Y_offse
 
 		/* put in Substrate contact first */
 		new_item->nodeinst = plac_make_Pin(pla_array_facet, X,
-			Y-Y_M_offset+10*pla_lam, 14*pla_lam, "Metal-1-Well-Con");
+			Y-Y_M_offset+10*pla_lam, 14*pla_lam, x_("Metal-1-Well-Con"));
 		if (new_item->nodeinst == NONODEINST) return(TRUE);
 
 		/* wire in the first ground strap */
@@ -422,7 +422,7 @@ BOOLEAN plac_nmos_init_rows(INTBIG height_in, INTBIG X, INTBIG Y, INTBIG Y_offse
 		last_col_pp = plac_col_list[0].lastitem->nodeinst->proto->firstportproto;
 
 		/* connect to last column object */
-		plac_wire("Metal-1", 4*pla_lam, plac_col_list[0].lastitem->nodeinst,
+		plac_wire(x_("Metal-1"), 4*pla_lam, plac_col_list[0].lastitem->nodeinst,
 			last_col_pp, new_item->nodeinst, ni_col_pp, pla_array_facet);
 
 		/* only put this in a column list */
@@ -438,14 +438,14 @@ BOOLEAN plac_nmos_init_rows(INTBIG height_in, INTBIG X, INTBIG Y, INTBIG Y_offse
 
 		plac_row_list[i][0].firstitem->nodeinst = plac_make_Pin(pla_array_facet,
 			X-7*pla_lam, Y-5*pla_lam,
-				6*pla_lam, "Metal-1-Polysilicon-Con");
+				6*pla_lam, x_("Metal-1-Polysilicon-Con"));
 		if (plac_row_list[i][0].firstitem->nodeinst == NONODEINST) return(TRUE);
 		plac_row_list[i][1].firstitem->nodeinst = plac_make_Pin(pla_array_facet,
-			X, Y-Y_M_offset, 14*pla_lam, "Metal-1-D-Active-Con");
+			X, Y-Y_M_offset, 14*pla_lam, x_("Metal-1-D-Active-Con"));
 		if (plac_row_list[i][1].firstitem->nodeinst == NONODEINST) return(TRUE);
 		plac_row_list[i][2].firstitem->nodeinst = plac_make_Pin(pla_array_facet,
 			X-7*pla_lam, Y-15*pla_lam,
-				6*pla_lam, "Metal-1-Polysilicon-Con");
+				6*pla_lam, x_("Metal-1-Polysilicon-Con"));
 		if (plac_row_list[i][2].firstitem->nodeinst == NONODEINST) return(TRUE);
 
 		/* wire in the first ground strap */
@@ -453,7 +453,7 @@ BOOLEAN plac_nmos_init_rows(INTBIG height_in, INTBIG X, INTBIG Y, INTBIG Y_offse
 		last_col_pp = plac_col_list[0].lastitem->nodeinst->proto->firstportproto;
 
 		/* connect to last column object */
-		plac_wire("Metal-1", 4*pla_lam, plac_col_list[0].lastitem->nodeinst,
+		plac_wire(x_("Metal-1"), 4*pla_lam, plac_col_list[0].lastitem->nodeinst,
 			last_col_pp, plac_row_list[i][1].lastitem->nodeinst, ni_col_pp, pla_array_facet);
 		plac_col_list[0].lastitem->bottomitem = plac_row_list[i][1].lastitem;
 		plac_col_list[0].lastitem = plac_col_list[0].lastitem->bottomitem;
@@ -466,7 +466,7 @@ BOOLEAN plac_nmos_init_rows(INTBIG height_in, INTBIG X, INTBIG Y, INTBIG Y_offse
 BOOLEAN plac_finish_columns(INTBIG width, INTBIG X, INTBIG Y, INTBIG X_offset,
 	NODEPROTO *nmos_one, NODEPROTO *pla_array_facet)
 {
-	char name[40];
+	CHAR name[40];
 	INTBIG i, gnd_cnt;
 	UCITEM *new_item;
 	PORTPROTO *last_col_pp, *ni_col_pp;
@@ -479,30 +479,30 @@ BOOLEAN plac_finish_columns(INTBIG width, INTBIG X, INTBIG Y, INTBIG X_offset,
 		/* put in a Ground  pin every 5th position */
 		if ((i % 5) == 0)
 		{
-			(void)sprintf(name, "GND%ld.m-1.s", gnd_cnt);
+			(void)esnprintf(name, 40, x_("GND%ld.m-1.s"), gnd_cnt);
 			new_item->nodeinst = plac_make_Pin(pla_array_facet,
-				X_offset*i+X, Y, 14*pla_lam, "Metal-1-Well-Con");
+				X_offset*i+X, Y, 14*pla_lam, x_("Metal-1-Well-Con"));
 			if (new_item->nodeinst == NONODEINST) return(TRUE);
 			last_col_pp = plac_col_list[i].lastitem->nodeinst->proto->firstportproto;
 			gnd_cnt++;
 		} else
 		{
 			/* must be a data pin, don't count ground pins */
-			(void)sprintf(name, "DATA%ld.m-1.s", (i - gnd_cnt));
+			(void)esnprintf(name, 40, x_("DATA%ld.m-1.s"), (i - gnd_cnt));
 			new_item->nodeinst = plac_make_Pin(pla_array_facet,
-				X_offset * i + X, Y, 4*pla_lam, "Metal-1-Pin");
+				X_offset * i + X, Y, 4*pla_lam, x_("Metal-1-Pin"));
 			if (new_item->nodeinst == NONODEINST) return(TRUE);
 			if (plac_col_list[i].lastitem->nodeinst->proto != nmos_one)
 				last_col_pp = plac_col_list[i].lastitem->nodeinst->proto->firstportproto; else
 					last_col_pp = getportproto(plac_col_list[i].lastitem->nodeinst->proto,
-						"OUT.m-1.n");
+						x_("OUT.m-1.n"));
 		}
 
 		/* wire in the first ground strap */
 		ni_col_pp = new_item->nodeinst->proto->firstportproto;
 
 		/* connect to last column object */
-		plac_wire("Metal-1", 4*pla_lam, plac_col_list[i].lastitem->nodeinst,
+		plac_wire(x_("Metal-1"), 4*pla_lam, plac_col_list[i].lastitem->nodeinst,
 			last_col_pp, new_item->nodeinst, ni_col_pp, pla_array_facet);
 
 		/* only put this in a column list */
