@@ -40,7 +40,7 @@ UCROW plac_col_list[PLAC_MAX_COL_SIZE];
 UCROW plac_row_list[PLAC_MAX_COL_SIZE][3];
 
 /* Plus Output options eg. column decode etc. */
-NODEPROTO *plac_or_plane(LIBRARY *library, NODEPROTO *or_np, char *facet_name,
+NODEPROTO *plac_or_plane(LIBRARY *library, NODEPROTO *or_np, CHAR *facet_name,
 	INTBIG OUTPUTS)
 {
 	NODEPROTO *or_plane_np, *buf_np;
@@ -49,7 +49,7 @@ NODEPROTO *plac_or_plane(LIBRARY *library, NODEPROTO *or_np, char *facet_name,
 	PORTPROTO *pwr_e_pp, *pwr_w_pp, *gnd_1_e_pp, *gnd_1_w_pp, *gnd_2_e_pp,
 		*gnd_2_w_pp, *p_pp, *n_pp, *out_pp;
 	VARIABLE *var;
-	char a_name[60], i_name[60], side;
+	CHAR a_name[60], i_name[60], side;
 	INTBIG columns, diff, limit, x, i, cnt, Y, X_offset;
 	INTBIG pwr_X, pwr_Y, amt_1, lowx, lowy, highx, highy;
 
@@ -59,7 +59,7 @@ NODEPROTO *plac_or_plane(LIBRARY *library, NODEPROTO *or_np, char *facet_name,
 
 	new_ni = NONODEINST;
 	last_buf_ni = NONODEINST;
-	var = getval((INTBIG)or_np, VNODEPROTO, VINTEGER, "PLA_data_cols");
+	var = getval((INTBIG)or_np, VNODEPROTO, VINTEGER, x_("PLA_data_cols"));
 	if (var != NOVARIABLE) columns = (INTBIG)((INTBIG *)var->addr); else
 	{
 		ttyputerr(M_("DATA_cols defaulting to 2"));
@@ -69,7 +69,7 @@ NODEPROTO *plac_or_plane(LIBRARY *library, NODEPROTO *or_np, char *facet_name,
 	if (OUTPUTS != TRUE) side = 'n'; else side = 's';
 	lowx = n_ni->geom->lowx;   highx = n_ni->geom->highx;
 	lowy = n_ni->geom->lowy;   highy = n_ni->geom->highy;
-	buf_np = getnodeproto("io-inv-4");
+	buf_np = getnodeproto(x_("io-inv-4"));
 	if (buf_np != NONODEPROTO)
 	{
 		diff = (INTBIG)(buf_np->highy - buf_np->lowy);
@@ -80,16 +80,16 @@ NODEPROTO *plac_or_plane(LIBRARY *library, NODEPROTO *or_np, char *facet_name,
 		if (OUTPUTS == TRUE) Y = lowy - diff; else Y = highy;
 		Y -= 5*pla_lam;
 		X_offset = lowx + 17*pla_lam;
-		(void)sprintf(a_name, "PWR.m-2.w");
-		(void)sprintf(i_name, "PWR.m-2.e");
+		(void)esnprintf(a_name, 60, x_("PWR.m-2.w"));
+		(void)esnprintf(i_name, 60, x_("PWR.m-2.e"));
 		pwr_w_pp = getportproto(buf_np, a_name);
 		pwr_e_pp = getportproto(buf_np, i_name);
-		(void)sprintf(a_name, "GND.m-2.sw");
-		(void)sprintf(i_name, "GND.m-2.se");
+		(void)esnprintf(a_name, 60, x_("GND.m-2.sw"));
+		(void)esnprintf(i_name, 60, x_("GND.m-2.se"));
 		gnd_1_w_pp = getportproto(buf_np, a_name);
 		gnd_1_e_pp = getportproto(buf_np, i_name);
-		(void)sprintf(a_name, "GND.m-2.nw");
-		(void)sprintf(i_name, "GND.m-2.ne");
+		(void)esnprintf(a_name, 60, x_("GND.m-2.nw"));
+		(void)esnprintf(i_name, 60, x_("GND.m-2.ne"));
 		gnd_2_w_pp = getportproto(buf_np, a_name);
 		gnd_2_e_pp = getportproto(buf_np, i_name);
 		for (i = 0; i < limit; i++)
@@ -109,24 +109,24 @@ NODEPROTO *plac_or_plane(LIBRARY *library, NODEPROTO *or_np, char *facet_name,
 			}
 			if (last_buf_ni == NONODEINST)
 			{
-				(void)newportproto(or_plane_np, new_ni, pwr_w_pp, "PWR.m-2.w");
-				(void)newportproto(or_plane_np, new_ni, gnd_1_w_pp, "GND.m-2.w");
+				(void)newportproto(or_plane_np, new_ni, pwr_w_pp, x_("PWR.m-2.w"));
+				(void)newportproto(or_plane_np, new_ni, gnd_1_w_pp, x_("GND.m-2.w"));
 
 				/* Put in GND bar pin (metal-2) */
 				portposition(new_ni, gnd_1_w_pp, &pwr_X, &pwr_Y);
 				gnd_ni_1 = plac_make_Pin(or_plane_np, lowx-13*pla_lam, pwr_Y,
-					6*pla_lam, "Metal-1-Metal-2-Con");
+					6*pla_lam, x_("Metal-1-Metal-2-Con"));
 				if (gnd_ni_1 == NONODEINST) return(NONODEPROTO);
-				plac_wire("Metal-2", 14*pla_lam, new_ni, gnd_1_w_pp, gnd_ni_1,
+				plac_wire(x_("Metal-2"), 14*pla_lam, new_ni, gnd_1_w_pp, gnd_ni_1,
 					gnd_ni_1->proto->firstportproto, or_plane_np);
 				portposition(new_ni, gnd_2_w_pp, &pwr_X, &pwr_Y);
 
 				gnd_ni_2 = plac_make_Pin(or_plane_np, lowx-13*pla_lam, pwr_Y,
-					6*pla_lam, "Metal-1-Metal-2-Con");
+					6*pla_lam, x_("Metal-1-Metal-2-Con"));
 				if (gnd_ni_2 == NONODEINST) return(NONODEPROTO);
-				plac_wire("Metal-2", 14*pla_lam, new_ni, gnd_2_w_pp, gnd_ni_2,
+				plac_wire(x_("Metal-2"), 14*pla_lam, new_ni, gnd_2_w_pp, gnd_ni_2,
 					gnd_ni_2->proto->firstportproto, or_plane_np);
-				plac_wire("Metal-2", 14*pla_lam, gnd_ni_1,
+				plac_wire(x_("Metal-2"), 14*pla_lam, gnd_ni_1,
 					gnd_ni_1->proto->firstportproto, gnd_ni_2,
 						gnd_ni_2->proto->firstportproto, or_plane_np);
 				last_buf_ni = new_ni;
@@ -134,29 +134,29 @@ NODEPROTO *plac_or_plane(LIBRARY *library, NODEPROTO *or_np, char *facet_name,
 			{
 				/* get wired */
 				if ((pwr_w_pp != NOPORTPROTO) && (pwr_e_pp != NOPORTPROTO))
-					plac_wire("Metal-2", 14*pla_lam, last_buf_ni,
+					plac_wire(x_("Metal-2"), 14*pla_lam, last_buf_ni,
 						pwr_e_pp, new_ni, pwr_w_pp, or_plane_np);
 				if ((gnd_1_w_pp != NOPORTPROTO) && (gnd_1_e_pp != NOPORTPROTO))
-					plac_wire("Metal-2", 14*pla_lam, last_buf_ni,
+					plac_wire(x_("Metal-2"), 14*pla_lam, last_buf_ni,
 						gnd_1_e_pp, new_ni, gnd_1_w_pp, or_plane_np);
 				if ((gnd_2_w_pp != NOPORTPROTO) && (gnd_2_e_pp != NOPORTPROTO))
-					plac_wire("Metal-2", 14*pla_lam, last_buf_ni,
+					plac_wire(x_("Metal-2"), 14*pla_lam, last_buf_ni,
 						gnd_2_e_pp, new_ni, gnd_2_w_pp, or_plane_np);
 				last_buf_ni = new_ni;
 			}
 			for (x = cnt; x < cnt+4; x++)
 			{
-				(void)sprintf(a_name, "DATA%ld.m-1.%c", x, side);
-				(void)sprintf(i_name, "in%ld.m-1.n", x % 4);
+				(void)esnprintf(a_name, 60, x_("DATA%ld.m-1.%c"), x, side);
+				(void)esnprintf(i_name, 60, x_("in%ld.m-1.n"), x % 4);
 				p_pp = getportproto(or_np, a_name);
 				n_pp = getportproto(buf_np, i_name);
-				(void)sprintf(a_name, "out%ld-bar.m-1.s", x % 4);
+				(void)esnprintf(a_name, 60, x_("out%ld-bar.m-1.s"), x % 4);
 				out_pp = getportproto(buf_np, a_name);
-				(void)sprintf(a_name, "out%ld.m-1.%c", cnt + (x % 4), side);
+				(void)esnprintf(a_name, 60, x_("out%ld.m-1.%c"), cnt + (x % 4), side);
 				if (out_pp != NOPORTPROTO)
 					(void)newportproto(or_plane_np, new_ni, out_pp, a_name);
 				if ((p_pp != NOPORTPROTO) && (n_pp != NOPORTPROTO))
-					plac_wire("Metal-1", 4*pla_lam, n_ni, p_pp,
+					plac_wire(x_("Metal-1"), 4*pla_lam, n_ni, p_pp,
 						new_ni, n_pp, or_plane_np);
 			}
 			cnt += 4;
@@ -165,21 +165,21 @@ NODEPROTO *plac_or_plane(LIBRARY *library, NODEPROTO *or_np, char *facet_name,
 		{
 			portposition(last_buf_ni, pwr_e_pp, &pwr_X, &pwr_Y);
 			pwr_ni_1 = plac_make_Pin(or_plane_np, highx+13*pla_lam, pwr_Y,
-				14*pla_lam, "Metal-2-Pin");
+				14*pla_lam, x_("Metal-2-Pin"));
 			if (pwr_ni_1 == NONODEINST) return(NONODEPROTO);
-			plac_wire("Metal-2", 14*pla_lam, last_buf_ni, pwr_e_pp, pwr_ni_1,
+			plac_wire(x_("Metal-2"), 14*pla_lam, last_buf_ni, pwr_e_pp, pwr_ni_1,
 				pwr_ni_1->proto->firstportproto, or_plane_np);
-			(void)newportproto(or_plane_np, last_buf_ni, pwr_e_pp, "PWR.m-2.e");
+			(void)newportproto(or_plane_np, last_buf_ni, pwr_e_pp, x_("PWR.m-2.e"));
 		}
 		if (gnd_1_w_pp != NOPORTPROTO)
-			(void)newportproto(or_plane_np, last_buf_ni, gnd_1_e_pp, "GND.m-2.e");
+			(void)newportproto(or_plane_np, last_buf_ni, gnd_1_e_pp, x_("GND.m-2.e"));
 	}
 
 	/* OK PUT in the PULLUPS */
 	new_ni = NONODEINST;
 	last_buf_ni = NONODEINST;
 	if (OUTPUTS != TRUE) side = 's'; else side = 'n';
-	buf_np = getnodeproto("pullups");
+	buf_np = getnodeproto(x_("pullups"));
 	if (buf_np != NONODEPROTO)
 	{
 		diff = buf_np->highy - buf_np->lowy;
@@ -188,12 +188,12 @@ NODEPROTO *plac_or_plane(LIBRARY *library, NODEPROTO *or_np, char *facet_name,
 		if (OUTPUTS != TRUE) Y = lowy - diff; else Y = highy;
 		Y += 16*pla_lam;
 		X_offset = lowx + 27*pla_lam;
-		(void)sprintf(a_name, "PWR.m-2.w");
-		(void)sprintf(i_name, "PWR.m-2.e");
+		(void)esnprintf(a_name, 60, x_("PWR.m-2.w"));
+		(void)esnprintf(i_name, 60, x_("PWR.m-2.e"));
 		pwr_w_pp = getportproto(buf_np, a_name);
 		pwr_e_pp = getportproto(buf_np, i_name);
-		(void)sprintf(a_name, "GND.m-1.sw");
-		(void)sprintf(i_name, "GND.m-1.se");
+		(void)esnprintf(a_name, 60, x_("GND.m-1.sw"));
+		(void)esnprintf(i_name, 60, x_("GND.m-1.se"));
 		gnd_1_w_pp = getportproto(buf_np, a_name);
 		gnd_1_e_pp = getportproto(buf_np, i_name);
 		for (i= 0; i < limit; i++)
@@ -213,56 +213,56 @@ NODEPROTO *plac_or_plane(LIBRARY *library, NODEPROTO *or_np, char *facet_name,
 			}
 			if (last_buf_ni == NONODEINST)
 			{
-				(void)newportproto(or_plane_np, new_ni, pwr_w_pp, "PWR0.m-2.w");
-				(void)newportproto(or_plane_np, new_ni, gnd_1_w_pp, "GND0.m-1.w");
+				(void)newportproto(or_plane_np, new_ni, pwr_w_pp, x_("PWR0.m-2.w"));
+				(void)newportproto(or_plane_np, new_ni, gnd_1_w_pp, x_("GND0.m-1.w"));
 				portposition(new_ni, gnd_1_w_pp, &pwr_X, &pwr_Y);
 				gnd_ni_1 = plac_make_Pin(or_plane_np, lowx-13*pla_lam, pwr_Y,
-					6*pla_lam, "Metal-1-Metal-2-Con");
+					6*pla_lam, x_("Metal-1-Metal-2-Con"));
 				if (gnd_ni_1 == NONODEINST) return(NONODEPROTO);
-				plac_wire("Metal-1", 4*pla_lam, new_ni, gnd_1_w_pp,
+				plac_wire(x_("Metal-1"), 4*pla_lam, new_ni, gnd_1_w_pp,
 					gnd_ni_1, gnd_ni_1->proto->firstportproto, or_plane_np);
-				plac_wire("Metal-2", 14*pla_lam, gnd_ni_1,
+				plac_wire(x_("Metal-2"), 14*pla_lam, gnd_ni_1,
 					gnd_ni_1->proto->firstportproto, gnd_ni_2,
 						gnd_ni_2->proto->firstportproto, or_plane_np);
 
-				(void)sprintf(a_name, "GND%ld.m-1.%c", i, side);
-				(void)sprintf(i_name, "GND%ld.m-1.%c", i+1, side);
+				(void)esnprintf(a_name, 60, x_("GND%ld.m-1.%c"), i, side);
+				(void)esnprintf(i_name, 60, x_("GND%ld.m-1.%c"), i+1, side);
 				gnd_2_w_pp = getportproto(or_np, a_name);
 				gnd_2_e_pp = getportproto(or_np, i_name);
 
 				if ((gnd_1_w_pp != NOPORTPROTO) && (gnd_2_w_pp != NOPORTPROTO))
-					plac_wire("Metal-1", 4*pla_lam, new_ni,
+					plac_wire(x_("Metal-1"), 4*pla_lam, new_ni,
 						gnd_1_w_pp, n_ni, gnd_2_w_pp, or_plane_np);
 				if ((gnd_2_w_pp != NOPORTPROTO) && (gnd_2_e_pp != NOPORTPROTO))
-					plac_wire("Metal-1", 4*pla_lam, new_ni,
+					plac_wire(x_("Metal-1"), 4*pla_lam, new_ni,
 						gnd_1_e_pp, n_ni, gnd_2_e_pp, or_plane_np);
 				last_buf_ni = new_ni;
 			} else
 			{
 				/* get wired */
 				if ((pwr_w_pp != NOPORTPROTO) && (pwr_e_pp != NOPORTPROTO))
-					plac_wire("Metal-2", 14*pla_lam, last_buf_ni,
+					plac_wire(x_("Metal-2"), 14*pla_lam, last_buf_ni,
 						pwr_e_pp, new_ni, pwr_w_pp, or_plane_np);
-				(void)sprintf(a_name, "GND%ld.m-1.%c", i, side);
-				(void)sprintf(i_name, "GND%ld.m-1.%c", i+1, side);
+				(void)esnprintf(a_name, 60, x_("GND%ld.m-1.%c"), i, side);
+				(void)esnprintf(i_name, 60, x_("GND%ld.m-1.%c"), i+1, side);
 				gnd_2_w_pp = getportproto(or_np, a_name);
 				gnd_2_e_pp = getportproto(or_np, i_name);
 				if ((gnd_1_w_pp != NOPORTPROTO) && (gnd_2_w_pp != NOPORTPROTO))
-					plac_wire("Metal-1", 4*pla_lam, new_ni,
+					plac_wire(x_("Metal-1"), 4*pla_lam, new_ni,
 						gnd_1_w_pp, n_ni, gnd_2_w_pp, or_plane_np);
 				if ((gnd_1_e_pp != NOPORTPROTO) && (gnd_2_e_pp != NOPORTPROTO))
-					plac_wire("Metal-1", 4*pla_lam, new_ni,
+					plac_wire(x_("Metal-1"), 4*pla_lam, new_ni,
 						gnd_1_e_pp, n_ni, gnd_2_e_pp, or_plane_np);
 				last_buf_ni = new_ni;
 			}
 			for (x = cnt; x < cnt+4; x++)
 			{
-				(void)sprintf(a_name, "DATA%ld.m-1.%c", x, side);
-				(void)sprintf(i_name, "PULLUP%ld.m-1.s", x % 4);
+				(void)esnprintf(a_name, 60, x_("DATA%ld.m-1.%c"), x, side);
+				(void)esnprintf(i_name, 60, x_("PULLUP%ld.m-1.s"), x % 4);
 				p_pp = getportproto(or_np, a_name);
 				n_pp = getportproto(buf_np, i_name);
 				if ((p_pp != NOPORTPROTO) && (n_pp != NOPORTPROTO))
-					plac_wire("Metal-1", 4*pla_lam, n_ni, p_pp,
+					plac_wire(x_("Metal-1"), 4*pla_lam, n_ni, p_pp,
 						new_ni, n_pp, or_plane_np);
 			}
 			cnt += 4;
@@ -271,25 +271,25 @@ NODEPROTO *plac_or_plane(LIBRARY *library, NODEPROTO *or_np, char *facet_name,
 		{
 			portposition(last_buf_ni, pwr_e_pp, &pwr_X, &pwr_Y);
 			pwr_ni_2 = plac_make_Pin(or_plane_np, highx+13*pla_lam,
-				pwr_Y, 14*pla_lam, "Metal-2-Pin");
+				pwr_Y, 14*pla_lam, x_("Metal-2-Pin"));
 			if (pwr_ni_2 == NONODEINST) return(NONODEPROTO);
-			plac_wire("Metal-2", 14*pla_lam, last_buf_ni, pwr_e_pp,
+			plac_wire(x_("Metal-2"), 14*pla_lam, last_buf_ni, pwr_e_pp,
 				pwr_ni_2, pwr_ni_2->proto->firstportproto, or_plane_np);
-			plac_wire("Metal-2", 14*pla_lam, pwr_ni_1,
+			plac_wire(x_("Metal-2"), 14*pla_lam, pwr_ni_1,
 				pwr_ni_1->proto->firstportproto, pwr_ni_2,
 					pwr_ni_2->proto->firstportproto, or_plane_np);
-			(void)newportproto(or_plane_np, last_buf_ni, pwr_e_pp, "PWR0.m-2.e");
+			(void)newportproto(or_plane_np, last_buf_ni, pwr_e_pp, x_("PWR0.m-2.e"));
 		}
 		if (gnd_1_e_pp != NOPORTPROTO)
-			(void)newportproto(or_plane_np, last_buf_ni, gnd_1_e_pp, "GND0.m-1.e");
+			(void)newportproto(or_plane_np, last_buf_ni, gnd_1_e_pp, x_("GND0.m-1.e"));
 		x = 0;
-		(void)sprintf(a_name, "ACCESS%ld.p.w", x);
+		(void)esnprintf(a_name, 60, x_("ACCESS%ld.p.w"), x);
 		p_pp = getportproto(or_np, a_name);
 		while (p_pp != NOPORTPROTO)
 		{
 			(void)newportproto(or_plane_np, n_ni, p_pp, a_name);
 			x++;
-			(void)sprintf(a_name, "ACCESS%ld.p.w", x);
+			(void)esnprintf(a_name, 60, x_("ACCESS%ld.p.w"), x);
 			p_pp = getportproto(or_np, a_name);
 		}
 	}
@@ -301,13 +301,13 @@ NODEPROTO *plac_or_plane(LIBRARY *library, NODEPROTO *or_np, char *facet_name,
 }
 
 NODEPROTO *plac_make_pla(LIBRARY *library, NODEPROTO *decode_np, NODEPROTO *or_plane_np,
-	char *name)
+	CHAR *name)
 {
 	NODEPROTO *pla_np;
 	NODEINST *decode_ni, *or_ni;
 	INTBIG x;
 	PORTPROTO *dec_pp, *or_pp;
-	char a_name[40];
+	CHAR a_name[40];
 	INTBIG dy, dec_X, dec_Y, or_X, or_Y;
 
 	pla_np = newnodeproto(name, library);
@@ -317,9 +317,9 @@ NODEPROTO *plac_make_pla(LIBRARY *library, NODEPROTO *decode_np, NODEPROTO *or_p
 	if (or_ni == NONODEINST) return(NONODEPROTO);
 
 	x = 0;
-	(void)sprintf(a_name, "ACCESS%ld.p.w", x);
+	(void)esnprintf(a_name, 40, x_("ACCESS%ld.p.w"), x);
 	or_pp = getportproto(or_plane_np, a_name);
-	(void)sprintf(a_name, "DATA%ld.m-1.n", x);
+	(void)esnprintf(a_name, 40, x_("DATA%ld.m-1.n"), x);
 	dec_pp = getportproto(decode_np, a_name);
 
 	portposition(or_ni, or_pp, &or_X, &or_Y);
@@ -329,11 +329,11 @@ NODEPROTO *plac_make_pla(LIBRARY *library, NODEPROTO *decode_np, NODEPROTO *or_p
 
 	while ((or_pp != NOPORTPROTO) && (dec_pp != NOPORTPROTO))
 	{
-		plac_wire("Metal-1", 4*pla_lam, or_ni, or_pp, decode_ni, dec_pp, pla_np);
+		plac_wire(x_("Metal-1"), 4*pla_lam, or_ni, or_pp, decode_ni, dec_pp, pla_np);
 		x++;
-		(void)sprintf(a_name, "ACCESS%ld.p.w", x);
+		(void)esnprintf(a_name, 40, x_("ACCESS%ld.p.w"), x);
 		or_pp = getportproto(or_plane_np, a_name);
-		(void)sprintf(a_name, "DATA%ld.m-1.n", x);
+		(void)esnprintf(a_name, 40, x_("DATA%ld.m-1.n"), x);
 		dec_pp = getportproto(decode_np, a_name);
 	}
 
