@@ -41,7 +41,7 @@
 /* prototypes for local routines */
 static INTBIG plac_init_bits(void);
 
-NODEINST *plac_make_Pin(NODEPROTO *facet, INTBIG X, INTBIG Y, INTBIG size, char *pin_type)
+NODEINST *plac_make_Pin(NODEPROTO *facet, INTBIG X, INTBIG Y, INTBIG size, CHAR *pin_type)
 {
 	NODEPROTO *node;
 	NODEINST  *ni;
@@ -50,18 +50,18 @@ NODEINST *plac_make_Pin(NODEPROTO *facet, INTBIG X, INTBIG Y, INTBIG size, char
 	node = getnodeproto(pin_type);
 	if (node == NONODEPROTO)
 	{
-		if (namesame(pin_type, "Metal-1-Well-Con") == 0)
-			node = getnodeproto("Metal-1-P-Well-Con");
-		if (namesame(pin_type, "Metal-1-Substrate-Con") == 0)
-			node = getnodeproto("Metal-1-N-Well-Con");
+		if (namesame(pin_type, x_("Metal-1-Well-Con")) == 0)
+			node = getnodeproto(x_("Metal-1-P-Well-Con"));
+		if (namesame(pin_type, x_("Metal-1-Substrate-Con")) == 0)
+			node = getnodeproto(x_("Metal-1-N-Well-Con"));
 
-		if (namesame(pin_type, "Metal-1-D-Active-Con") == 0)
-			node = getnodeproto("Metal-1-N-Active-Con");
-		if (namesame(pin_type, "Metal-1-S-Active-Con") == 0)
-			node = getnodeproto("Metal-1-P-Active-Con");
+		if (namesame(pin_type, x_("Metal-1-D-Active-Con")) == 0)
+			node = getnodeproto(x_("Metal-1-N-Active-Con"));
+		if (namesame(pin_type, x_("Metal-1-S-Active-Con")) == 0)
+			node = getnodeproto(x_("Metal-1-P-Active-Con"));
 
-		if (namesame(pin_type, "Metal-1-Polysilicon-Con") == 0)
-			node = getnodeproto("Metal-1-Polysilicon-1-Con");
+		if (namesame(pin_type, x_("Metal-1-Polysilicon-Con")) == 0)
+			node = getnodeproto(x_("Metal-1-Polysilicon-1-Con"));
 	}
 	if (node == NONODEPROTO)
 	{
@@ -90,7 +90,7 @@ UCITEM *plac_newUCITEM(void)
 	return(temp);
 }
 
-void plac_wire(char *type_arc, INTBIG width, NODEINST *fromnodeinst,
+void plac_wire(CHAR *type_arc, INTBIG width, NODEINST *fromnodeinst,
 	PORTPROTO *fromportproto, NODEINST *tonodeinst, PORTPROTO *toportproto,
 	NODEPROTO *facet)
 {
@@ -103,12 +103,12 @@ void plac_wire(char *type_arc, INTBIG width, NODEINST *fromnodeinst,
 	typ = getarcproto(type_arc);
 	if (typ == NOARCPROTO)
 	{
-		if (namesame(type_arc, "Polysilicon") == 0)
-			typ = getarcproto("Polysilicon-1");
-		if (namesame(type_arc, "D-active") == 0)
-			typ = getarcproto("N-Active");
-		if (namesame(type_arc, "S-active") == 0)
-			typ = getarcproto("P-Active");
+		if (namesame(type_arc, x_("Polysilicon")) == 0)
+			typ = getarcproto(x_("Polysilicon-1"));
+		if (namesame(type_arc, x_("D-active")) == 0)
+			typ = getarcproto(x_("N-Active"));
+		if (namesame(type_arc, x_("S-active")) == 0)
+			typ = getarcproto(x_("P-Active"));
 	}
 	if (typ == NOARCPROTO)
 	{
