@@ -89,9 +89,9 @@ NODEPROTO *pla_nmos_Connect(void)
 		0, 4*pla_lam, NOTRANS, NOROT, facet);
 	if (md_contact == NONODEINST) return(NONODEPROTO);
 
-	if ((newportproto(facet, md_contact, pla_md_proto->firstportproto, "DiffGnd") == NOPORTPROTO) ||
-		(newportproto(facet, mp_contact, pla_mp_proto->firstportproto, "AndEnd") == NOPORTPROTO) ||
-		(newportproto(facet, poly_pin, pla_pp_proto->firstportproto, "OrEnd") == NOPORTPROTO))
+	if ((newportproto(facet, md_contact, pla_md_proto->firstportproto, x_("DiffGnd")) == NOPORTPROTO) ||
+		(newportproto(facet, mp_contact, pla_mp_proto->firstportproto, x_("AndEnd")) == NOPORTPROTO) ||
+		(newportproto(facet, poly_pin, pla_pp_proto->firstportproto, x_("OrEnd")) == NOPORTPROTO))
 			return(NONODEPROTO);
 
 	/* ensure that the facet is the proper size */
@@ -106,7 +106,7 @@ NODEPROTO *pla_nmos_InPullup(void)
 	ARCINST *pa, *da;
 	PORTPROTO *dtran_dport, *dtran_pport, *bc_dport, *bc_pport;
 
-	pu = newnodeproto("nmos_InPullup",el_curlib);
+	pu = newnodeproto(x_("nmos_InPullup"),el_curlib);
 	if (pu == NONODEPROTO) return(NONODEPROTO);
 
 	dtran = newnodeinst(pla_dtran_proto, pla_lam, 7*pla_lam, 5*pla_lam, 11*pla_lam, NOTRANS, NOROT,
@@ -126,8 +126,8 @@ NODEPROTO *pla_nmos_InPullup(void)
 	if (bc_pport == NOPORTPROTO || bc_dport == NOPORTPROTO) return(NONODEPROTO);
 
 	/* export the bc_dport, bc_pport for external connections */
-	if (newportproto(pu, bc, bc_dport, "PullDNpt") == NOPORTPROTO ||
-		newportproto(pu, bc, bc_pport, "Outpt") == NOPORTPROTO) return(NONODEPROTO);
+	if (newportproto(pu, bc, bc_dport, x_("PullDNpt")) == NOPORTPROTO ||
+		newportproto(pu, bc, bc_pport, x_("Outpt")) == NOPORTPROTO) return(NONODEPROTO);
 
 	/* have to create pins to bend the arcs */
 	dpin = newnodeinst(pla_dp_proto, 3*pla_lam, 7*pla_lam, 2*pla_lam, 6*pla_lam, NOTRANS, NOROT, pu);
@@ -161,11 +161,11 @@ NODEPROTO *pla_nmos_InPullup(void)
 	 */
 	dtran_dport = pla_FindPort(dtran, 4*pla_lam, 10*pla_lam);
 	if (dtran_dport == NOPORTPROTO) return(NONODEPROTO);
-	if (newportproto(pu, dtran, dtran_dport, "Vddpt") == NOPORTPROTO) return(NONODEPROTO);
+	if (newportproto(pu, dtran, dtran_dport, x_("Vddpt")) == NOPORTPROTO) return(NONODEPROTO);
 
 	dtran_pport = pla_FindPort(dtran, 6*pla_lam, 8*pla_lam);
 	if (dtran_pport == NOPORTPROTO) return(NONODEPROTO);
-	if (newportproto(pu, dtran, dtran_pport, "Invpt") == NOPORTPROTO) return(NONODEPROTO);
+	if (newportproto(pu, dtran, dtran_pport, x_("Invpt")) == NOPORTPROTO) return(NONODEPROTO);
 
 	/* ensure that the facet is the proper size */
 	(*el_curconstraint->solve)(pu);
@@ -192,7 +192,7 @@ NODEPROTO *pla_nmos_Input(void)
 	 * in heights (see code below) comes from the savings resulting
 	 * from the fact that these two are interconnected.
 	 */
-	facet = newnodeproto("nmos_Input", el_curlib);
+	facet = newnodeproto(x_("nmos_Input"), el_curlib);
 	if (facet == NONODEPROTO) return(NONODEPROTO);
 
 	md_contact = newnodeinst(pla_md_proto, 2*pla_lam, 8*pla_lam,
@@ -200,7 +200,7 @@ NODEPROTO *pla_nmos_Input(void)
 	if (md_contact == NONODEINST) return(NONODEPROTO);
 
 	/* export this for vdd connection */
-	if (newportproto(facet, md_contact, pla_md_proto->firstportproto, "Vdd") ==
+	if (newportproto(facet, md_contact, pla_md_proto->firstportproto, x_("Vdd")) ==
 		NOPORTPROTO) return(NONODEPROTO);
 
 	/* Instance the pullups on either side (top and bottom) of this contact */
@@ -344,11 +344,11 @@ NODEPROTO *pla_nmos_Input(void)
 				facet) == NOARCINST) return(NONODEPROTO);
 
 	/* Export some of the pins and ports for external connections */
-	if (newportproto(facet, md_contact, pla_md_proto->firstportproto, "Gnd") == NOPORTPROTO ||
-		newportproto(facet, ppin1, pla_pp_proto->firstportproto, "InvInput") == NOPORTPROTO ||
-		newportproto(facet, ppin2, pla_pp_proto->firstportproto, "NonInvInput") == NOPORTPROTO ||
-		newportproto(facet, etran1, pla_FindPort(etran1, 10*pla_lam, pla_lam), "Input") == NOPORTPROTO  ||
-		newportproto(facet, md_contact1,pla_md_proto->firstportproto, "DiffGnd") == NOPORTPROTO)
+	if (newportproto(facet, md_contact, pla_md_proto->firstportproto, x_("Gnd")) == NOPORTPROTO ||
+		newportproto(facet, ppin1, pla_pp_proto->firstportproto, x_("InvInput")) == NOPORTPROTO ||
+		newportproto(facet, ppin2, pla_pp_proto->firstportproto, x_("NonInvInput")) == NOPORTPROTO ||
+		newportproto(facet, etran1, pla_FindPort(etran1, 10*pla_lam, pla_lam), x_("Input")) == NOPORTPROTO  ||
+		newportproto(facet, md_contact1,pla_md_proto->firstportproto, x_("DiffGnd")) == NOPORTPROTO)
 			return(NONODEPROTO);
 
 	/* ensure that the facet is the proper size */
@@ -366,7 +366,7 @@ NODEPROTO *pla_nmos_OutPullup(void)
 	sizeX = 10 * pla_lam;
 	sizeY =  9 * pla_lam;
 
-	pu = newnodeproto("nmos_OutPullup", el_curlib);
+	pu = newnodeproto(x_("nmos_OutPullup"), el_curlib);
 	if (pu == NONODEPROTO) return(NONODEPROTO);
 
 	/* Instance a depletion load pullup in pu */
@@ -382,7 +382,7 @@ NODEPROTO *pla_nmos_OutPullup(void)
 	if (dpin == NONODEINST) return(NONODEPROTO);
 
 	/* Export this pin for external connections */
-	if (newportproto(pu, dpin, pla_dp_proto->firstportproto, "VddPt") == NOPORTPROTO)
+	if (newportproto(pu, dpin, pla_dp_proto->firstportproto, x_("VddPt")) == NOPORTPROTO)
 		return(NONODEPROTO);
 
 	if (newarcinst(pla_da_proto, 2*pla_lam, FIXANG, dpin, pla_dp_proto->firstportproto,
@@ -397,7 +397,7 @@ NODEPROTO *pla_nmos_OutPullup(void)
 	if (dpin == NONODEINST) return(NONODEPROTO);
 
 	/* Export this pin for external connections */
-	if (newportproto(pu, dpin, pla_dp_proto->firstportproto, "EtranPt") == NOPORTPROTO)
+	if (newportproto(pu, dpin, pla_dp_proto->firstportproto, x_("EtranPt")) == NOPORTPROTO)
 		return(NONODEPROTO);
 
 	if (newarcinst(pla_da_proto, 2*pla_lam, FIXANG, dpin, pla_dp_proto->firstportproto,
@@ -425,8 +425,8 @@ NODEPROTO *pla_nmos_OutPullup(void)
 		bc, bc_pport,  6*pla_lam, 2*pla_lam, pu) == NOARCINST) return(NONODEPROTO);
 
 	/* Export bc_dport and bc_pport for external connections */
-	if (newportproto(pu, bc, bc_pport, "Output2") == NOPORTPROTO ||
-		newportproto(pu, bc, bc_dport, "DiffPt") == NOPORTPROTO) return(NONODEPROTO);
+	if (newportproto(pu, bc, bc_pport, x_("Output2")) == NOPORTPROTO ||
+		newportproto(pu, bc, bc_dport, x_("DiffPt")) == NOPORTPROTO) return(NONODEPROTO);
 
 	/* ensure that the facet is the proper size */
 	(*el_curconstraint->solve)(pu);
@@ -477,7 +477,7 @@ NODEPROTO *pla_nmos_Output(void)
 				return(NONODEPROTO);
 
 	/* Export ppin2 as Output1 Point */
-	if (newportproto(facet, ppin2, pla_pp_proto->firstportproto, "Output1") == NOPORTPROTO)
+	if (newportproto(facet, ppin2, pla_pp_proto->firstportproto, x_("Output1")) == NOPORTPROTO)
 		return(NONODEPROTO);
 
 	/*
@@ -490,7 +490,7 @@ NODEPROTO *pla_nmos_Output(void)
 	if (md_cont1 == NONODEINST) return(NONODEPROTO);
 
 	/* Export this contact for external Vdd connection */
-	if (newportproto(facet, md_cont1, pla_md_proto->firstportproto, "Vdd") == NOPORTPROTO)
+	if (newportproto(facet, md_cont1, pla_md_proto->firstportproto, x_("Vdd")) == NOPORTPROTO)
 		return(NONODEPROTO);
 
 	/* Extend the Diff wires from the pullups to md_cont1 */
@@ -581,7 +581,7 @@ NODEPROTO *pla_nmos_Output(void)
 	if (md_cont1 == NONODEINST) return(NONODEPROTO);
 
 	/*  Export this as the external Ground contact */
-	if (newportproto(facet, md_cont1, pla_md_proto->firstportproto, "Gnd") == NOPORTPROTO)
+	if (newportproto(facet, md_cont1, pla_md_proto->firstportproto, x_("Gnd")) == NOPORTPROTO)
 		return(NONODEPROTO);
 
 	/* Now connect etran1 to Ground contact */
@@ -623,8 +623,8 @@ NODEPROTO *pla_nmos_Output(void)
 	if (md_cont1 == NONODEINST || md_cont2 == NONODEINST) return(NONODEPROTO);
 
 	/* Export these for external connections */
-	if (newportproto(facet, md_cont1, pla_mp_proto->firstportproto, "Input1") == NOPORTPROTO ||
-		newportproto(facet, md_cont2, pla_mp_proto->firstportproto, "Input2") == NOPORTPROTO)
+	if (newportproto(facet, md_cont1, pla_mp_proto->firstportproto, x_("Input1")) == NOPORTPROTO ||
+		newportproto(facet, md_cont2, pla_mp_proto->firstportproto, x_("Input2")) == NOPORTPROTO)
 			return(NONODEPROTO);
 
 	/* Connect these to the etrans */
@@ -638,7 +638,7 @@ NODEPROTO *pla_nmos_Output(void)
 				6*pla_lam, WorkPtY+5*pla_lam, facet) == NOARCINST) return(NONODEPROTO);
 
 	/* Export the Output point of pu2 as Output2 */
-	if (newportproto(facet, pu2, pla_FindPort(pu2, 11*pla_lam, pla_lam), "Output2") == NOPORTPROTO)
+	if (newportproto(facet, pu2, pla_FindPort(pu2, 11*pla_lam, pla_lam), x_("Output2")) == NOPORTPROTO)
 		return(NONODEPROTO);
 
 	/* ensure that the facet is the proper size */
@@ -671,10 +671,10 @@ NODEPROTO *pla_nmos_Program(void)
 		8*pla_lam, 4*pla_lam, md_contact, pla_md_proto->firstportproto,
 			10*pla_lam, 4*pla_lam, facet) == NOARCINST) return(NONODEPROTO);
 
-	if (newportproto(facet, dpin, pla_dp_proto->firstportproto, "DiffPt") == NOPORTPROTO ||
-		newportproto(facet, etran, pla_FindPort(etran,6*pla_lam,7*pla_lam), "Up") == NOPORTPROTO ||
-		newportproto(facet, etran, pla_FindPort(etran,6*pla_lam,pla_lam), "Down") == NOPORTPROTO ||
-		newportproto(facet, md_contact, pla_md_proto->firstportproto, "MdPt") == NOPORTPROTO)
+	if (newportproto(facet, dpin, pla_dp_proto->firstportproto, x_("DiffPt")) == NOPORTPROTO ||
+		newportproto(facet, etran, pla_FindPort(etran,6*pla_lam,7*pla_lam), x_("Up")) == NOPORTPROTO ||
+		newportproto(facet, etran, pla_FindPort(etran,6*pla_lam,pla_lam), x_("Down")) == NOPORTPROTO ||
+		newportproto(facet, md_contact, pla_md_proto->firstportproto, x_("MdPt")) == NOPORTPROTO)
 			return(NONODEPROTO);
 
 	/* ensure that the facet is the proper size */
@@ -759,9 +759,9 @@ NODEPROTO *pla_nmos_Pullup(void)
 	 * give names to vdd line and diffusion side of the butting/buried
 	 * contact so that they are accessible to outside world
 	 */
-	vpname = newportproto(pu, vdd_line, pla_md_proto->firstportproto, "Vdd");
-	dpname = pla_buttingcontact ? newportproto(pu, bc, bc_dport, "Pullup") :
-		newportproto(pu, md, pla_md_proto->firstportproto, "Pullup");
+	vpname = newportproto(pu, vdd_line, pla_md_proto->firstportproto, x_("Vdd"));
+	dpname = pla_buttingcontact ? newportproto(pu, bc, bc_dport, x_("Pullup")) :
+		newportproto(pu, md, pla_md_proto->firstportproto, x_("Pullup"));
 	if (vpname == NOPORTPROTO || dpname == NOPORTPROTO)
 		return(NONODEPROTO);
 
