@@ -70,28 +70,28 @@
  * Keywords recognized by the program.  NOTE: if this order is changed, same
  * changes should be made in the last set of #define statements in 'planmos.h'
  */
-static char *pla_KeyWords[] =
+static CHAR *pla_KeyWords[] =
 {
-	"off",
-	"on",
-	"1", "0", "x", "-",
-	"set",
-	"=",
-	"verbose",
-	"flexible",
-	"fixedangle",
-	"buttingcontact",
-	"samesideoutput",
-	"inputs",
-	"outputs",
-	"pterms",
-	"vddwidth",
-	"groundwidth",
-	"file",
-	"name",
-	"begin",
-	"end",
-	""
+	x_("off"),
+	x_("on"),
+	x_("1"), x_("0"), x_("x"), x_("-"),
+	x_("set"),
+	x_("="),
+	x_("verbose"),
+	x_("flexible"),
+	x_("fixedangle"),
+	x_("buttingcontact"),
+	x_("samesideoutput"),
+	x_("inputs"),
+	x_("outputs"),
+	x_("pterms"),
+	x_("vddwidth"),
+	x_("groundwidth"),
+	x_("file"),
+	x_("name"),
+	x_("begin"),
+	x_("end"),
+	x_("")
 };
 
 NODEPROTO *pla_pu_proto;		/* Pullup Prototype */
@@ -121,8 +121,8 @@ INTBIG  pla_userbits;
 INTBIG  pla_inputs, pla_outputs, pla_pterms;
 INTBIG  pla_VddWidth;			/* VDD width in use */
 INTBIG  pla_GndWidth;			/* Vdd and Gnd Widths in use */
-char    pla_infile[100];		/* Name of the input file */
-char    pla_name[32];			/* Name of the PLA facet */
+CHAR    pla_infile[100];		/* Name of the input file */
+CHAR    pla_name[32];			/* Name of the PLA facet */
 
 /*   Miscellaneous global variables  */
 INTBIG    pla_halfVdd, pla_halfGnd;   /* To save repeated division by 2 */
@@ -145,13 +145,13 @@ static void    pla_Recover(void);
 static void    pla_SetFlag(void);
 static void    pla_SetName(void);
 static BOOLEAN pla_SkipChars(void);
-static char   *pla_onoffmessage(INTBIG onoff);
+static CHAR   *pla_onoffmessage(INTBIG onoff);
 
 /* Set the given option to ON or OFF */
 void pla_Flag(INTBIG option)
 {
 	INTBIG onoroff;
-	char keyword[16];
+	CHAR keyword[16];
 
 	onoroff = pla_GetKeyWord(keyword);
 	if (onoroff != ERRORRET)
@@ -201,9 +201,9 @@ void pla_Flag(INTBIG option)
  * pla_KeyWords[] in pla.c.  Return ERRORRET on end-of-file else return OK.
  * The keyoword fround is returned via the input parameter.
  */
-INTBIG pla_GetKeyWord(char *keyword)
+INTBIG pla_GetKeyWord(CHAR *keyword)
 {
-	char *savekeywordaddr;
+	CHAR *savekeywordaddr;
 	INTBIG k, c;
 
 	savekeywordaddr = keyword;
@@ -212,10 +212,10 @@ INTBIG pla_GetKeyWord(char *keyword)
 	while((c = xgetc(pla_fin)) != EOF)
 	{
 		if ((c >= 'A' && c <= 'Z') || (c >= 'a' && c <= 'z') ||
-			(c >= '0' && c <= '9') || (c == '=')) *keyword++ = (char)c; else
+			(c >= '0' && c <= '9') || (c == '=')) *keyword++ = (CHAR)c; else
 		{
 			*keyword = 0;
-			xungetc((char)c, pla_fin);
+			xungetc((CHAR)c, pla_fin);
 			break;
 		}
 	}
@@ -230,12 +230,12 @@ INTBIG pla_GetKeyWord(char *keyword)
 /* Get a number from the input stream */
 INTBIG pla_GetVal(void)
 {
-	char keyword[16];
+	CHAR keyword[16];
 	INTBIG n;
 
 	if (pla_GetKeyWord(keyword) != ERRORRET)
 	{
-		if ((n = atoi(keyword)) == 0)
+		if ((n = eatoi(keyword)) == 0)
 		{
 			ttyputerr(M_("Inappropriate numbers in input"));
 			return(ERRORRET);
@@ -247,7 +247,7 @@ INTBIG pla_GetVal(void)
 
 BOOLEAN pla_ProcessFlags(void)
 {
-	char keyword[16];
+	CHAR keyword[16];
 	INTBIG position;
 
 	while((position = pla_GetKeyWord(keyword)) != ERRORRET)
@@ -278,11 +278,11 @@ BOOLEAN pla_ProcessFlags(void)
 
 BOOLEAN pla_ReadOffEqualSign(void)
 {
-	char keyword[16];
+	CHAR keyword[16];
 
 	if (pla_GetKeyWord(keyword) != ERRORRET)
 	{
-		if (namesame(keyword, "=") == 0) return(FALSE);
+		if (namesame(keyword, x_("=")) == 0) return(FALSE);
 		ttyputerr(M_("equal sign expected. Read '%s' instead."), keyword);
 		pla_Recover();
 	}
@@ -291,19 +291,19 @@ BOOLEAN pla_ReadOffEqualSign(void)
 
 void pla_Recover(void)
 {
-	char keyword[16];
+	CHAR keyword[16];
 
 	ttyputmsg(M_("Skipping text until next 'set' or 'begin' directive ..."));
 
 	while(pla_GetKeyWord(keyword) != ERRORRET)
 	{
-		if (namesame(keyword, "set") == 0)
+		if (namesame(keyword, x_("set")) == 0)
 		{
 			xungetc('t', pla_fin); xungetc('e', pla_fin);
 			xungetc('s', pla_fin);
 			return;
 		}
-		if (namesame(keyword, "begin") == 0)
+		if (namesame(keyword, x_("begin")) == 0)
 		{
 			xungetc('n', pla_fin); xungetc('i', pla_fin);
 			xungetc('g', pla_fin);
@@ -316,7 +316,7 @@ void pla_Recover(void)
 /* Sets one flag and returns */
 void pla_SetFlag(void)
 {
-	char keyword[16];
+	CHAR keyword[16];
 	INTBIG position;
 
 	position = pla_GetKeyWord(keyword);
@@ -386,9 +386,9 @@ void pla_SetFlag(void)
 
 void pla_SetName(void)
 {
-	char keyword[32];
+	CHAR keyword[32];
 
-	if (pla_GetKeyWord(keyword) != ERRORRET) (void)strcpy(pla_name, keyword);
+	if (pla_GetKeyWord(keyword) != ERRORRET) (void)estrcpy(pla_name, keyword);
 	if (pla_verbose)
 		ttyputmsg(M_("Name of the PLA set to '%s'"), pla_name);
 }
@@ -406,7 +406,7 @@ BOOLEAN pla_SkipChars(void)
 		if ((c >= 'A' && c <= 'Z') || (c >= 'a' && c <= 'z') ||
 			(c >= '0' && c <= '9') || (c == '='))
 		{
-			xungetc((char)c, pla_fin);
+			xungetc((CHAR)c, pla_fin);
 			return(FALSE);
 		}
 		if (c == '{' || c == ';')  /* Skip over Comments */
@@ -443,17 +443,17 @@ void pla_displayoptions(void)
 	ttyputmsg(M_("  Name of the PLA = %s"), pla_name);
 }
 
-char *pla_onoffmessage(INTBIG onoff)
+CHAR *pla_onoffmessage(INTBIG onoff)
 {
 	if (onoff != 0) return(M_("ON"));
 	return(M_("OFF"));
 }
 
-void pla_setoption(char *option, char *value)
+void pla_setoption(CHAR *option, CHAR *value)
 {
 	INTBIG k, val, len;
 
-	len = strlen(option);
+	len = estrlen(option);
 	if (namesame(option, NULLSTR) == 0)
 	{
 		ttyputerr(M_("Set must be followed by an option name"));
@@ -469,13 +469,13 @@ void pla_setoption(char *option, char *value)
 		if (namesamen(option, pla_KeyWords[k], len) == 0) break;
 	if (k >= MAXKEYWORDS)
 	{
-		ttyputbadusage("telltool pla nmos");
+		ttyputbadusage(x_("telltool pla nmos"));
 		return;
 	}
 	if (k >= VERBOSE && k <= SAMESIDEOUTPUT)
 	{
-		if (namesamen(value, "on", len) == 0) val = 1; else
-			if (namesamen(value, "off", len) == 0) val = 0; else
+		if (namesamen(value, x_("on"), len) == 0) val = 1; else
+			if (namesamen(value, x_("off"), len) == 0) val = 0; else
 		{
 			ttyputerr(M_("Value must be ON or OFF"));
 			return;
@@ -513,7 +513,7 @@ void pla_setoption(char *option, char *value)
 
 	if (k >= INPUTS && k <= GNDWIDTH)
 	{
-		val = atoi(value);       /* Note:  this is incorrect because value */
+		val = eatoi(value);       /* Note:  this is incorrect because value */
 		switch(k)		/*	may contain nondigit characters */
 		{
 			case INPUTS:
@@ -549,12 +549,12 @@ void pla_setoption(char *option, char *value)
 	}
 	if (k == FILENAME)
 	{
-		(void)strncpy(pla_infile, value, 100);
+		(void)estrncpy(pla_infile, value, 100);
 		ttyputverbose(M_("File set to %s"), pla_infile);
 	}
 	if (k == NAME)
 	{
-		(void)strncpy(pla_name, value, 32);
+		(void)estrncpy(pla_name, value, 32);
 		ttyputverbose(M_("Name set to %s"), pla_name);
 	}
 }
