@@ -65,11 +65,11 @@ BOOLEAN pla_Make(void)
 		  progX, progY,           /* Dimensions of Programming Transistor */
 		  connectX, connectY;     /* Dimensions of Connect facet */
 	INTBIG pos;
-	char keyword[32], *filename;
+	CHAR keyword[32], *filename;
 	TECHNOLOGY *tech;
 
 	if (pla_fin != NULL) xclose(pla_fin);
-	pla_fin = xopen(pla_infile, pla_filetypeplatab, "", &filename);
+	pla_fin = xopen(pla_infile, pla_filetypeplatab, x_(""), &filename);
 	if (pla_fin == NULL)
 	{
 		ttyputerr(_("File '%s' not found, use 'telltool pla nmos file FILE'"), pla_infile);
@@ -97,18 +97,18 @@ BOOLEAN pla_Make(void)
 	pla_halfGnd = pla_GndWidth / 2;
 
 	/* Search for the prototypes for PLA generation */
-	pla_md_proto = getnodeproto("nmos:metal-diffusion-con");
-	pla_mp_proto = getnodeproto("nmos:metal-polysilicon-con");
-	pla_dp_proto = getnodeproto("nmos:diffusion-pin");
-	pla_bp_proto = getnodeproto("nmos:metal-pin");
-	pla_pp_proto = getnodeproto("nmos:polysilicon-pin");
-	pla_etran_proto = getnodeproto("nmos:transistor");
-	pla_dtran_proto = getnodeproto("nmos:implant-transistor");
-	if (pla_buttingcontact) pla_bc_proto = getnodeproto("nmos:butting-con");
-		else pla_bc_proto = getnodeproto("nmos:buried-con-cross-t");
-	pla_ma_proto = getarcproto("nmos:metal");
-	pla_da_proto = getarcproto("nmos:diffusion");
-	pla_pa_proto = getarcproto("nmos:polysilicon");
+	pla_md_proto = getnodeproto(x_("nmos:metal-diffusion-con"));
+	pla_mp_proto = getnodeproto(x_("nmos:metal-polysilicon-con"));
+	pla_dp_proto = getnodeproto(x_("nmos:diffusion-pin"));
+	pla_bp_proto = getnodeproto(x_("nmos:metal-pin"));
+	pla_pp_proto = getnodeproto(x_("nmos:polysilicon-pin"));
+	pla_etran_proto = getnodeproto(x_("nmos:transistor"));
+	pla_dtran_proto = getnodeproto(x_("nmos:implant-transistor"));
+	if (pla_buttingcontact) pla_bc_proto = getnodeproto(x_("nmos:butting-con"));
+		else pla_bc_proto = getnodeproto(x_("nmos:buried-con-cross-t"));
+	pla_ma_proto = getarcproto(x_("nmos:metal"));
+	pla_da_proto = getarcproto(x_("nmos:diffusion"));
+	pla_pa_proto = getarcproto(x_("nmos:polysilicon"));
 	if (pla_md_proto    == NONODEPROTO || pla_dp_proto  == NONODEPROTO ||
 		pla_mp_proto    == NONODEPROTO || pla_pp_proto  == NONODEPROTO ||
 		pla_da_proto    == NOARCPROTO  || pla_pa_proto  == NOARCPROTO  ||
@@ -204,7 +204,7 @@ BOOLEAN pla_Make(void)
 			return(TRUE);
 		}
 		if (namesame(pla_name, DEFNAME) == 0)
-			(void)sprintf(pla_name, "PLA-%ld-%ld-%ld", pla_inputs, pla_pterms, pla_outputs);
+			(void)esnprintf(pla_name, 32, x_("PLA-%ld-%ld-%ld"), pla_inputs, pla_pterms, pla_outputs);
 
 		pla_facet = newnodeproto(pla_name, el_curlib);
 		if (pla_facet == NONODEPROTO)
@@ -267,7 +267,7 @@ FACETIST *pla_PlaceInputs(INTBIG puX, INTBIG inX, INTBIG inY, NODEPROTO *pla)
 	VDDGND *cicv, *picv, *cicg, *picg;
 	INTBIG i;
 	INTBIG llXpos, llYpos, VddYpos, GndYpos;
-	char portname[16];
+	CHAR portname[16];
 
 	llXpos = puX;
 	llYpos = 0 - (pla_VddWidth - 4*pla_lam);
@@ -314,7 +314,7 @@ FACETIST *pla_PlaceInputs(INTBIG puX, INTBIG inX, INTBIG inY, NODEPROTO *pla)
 		ptr->rcoltrans = ptr->lcoltrans = NOPROGTRANS;
 
 		/* Export the input point giving it a name */
-		(void)sprintf(portname, "Input%ld", i);
+		(void)esnprintf(portname, 16, x_("Input%ld"), i);
 		if (newportproto(pla, ptr->facetinst, pla_FindPort(ptr->facetinst,llXpos+10*pla_lam,
 			llYpos+pla_lam), portname) == NOPORTPROTO) return(NOFACETIST);
 
@@ -336,7 +336,7 @@ FACETIST *pla_PlaceOutputs(INTBIG orLeft, INTBIG outX, INTBIG outY, NODEPROTO *p
 	VDDGND *cocv, *pocv, *cocg, *pocg;
 	INTBIG o;
 	INTBIG llXpos, llYpos, VddYpos, GndYpos;
-	char portname[16];
+	CHAR portname[16];
 
 	llXpos = orLeft - pla_lam;
 	llYpos = -(pla_VddWidth + 4 * pla_lam);
@@ -386,11 +386,11 @@ FACETIST *pla_PlaceOutputs(INTBIG orLeft, INTBIG outX, INTBIG outY, NODEPROTO *p
 		ptr->rcoltrans = ptr->lcoltrans = NOPROGTRANS;
 
 		/* Export the output ports */
-		(void)sprintf(portname, "Output%ld", 2*o-1);
+		(void)esnprintf(portname, 16, x_("Output%ld"), 2*o-1);
 		if (newportproto(pla, ptr->facetinst,
 			pla_FindPort(ptr->facetinst,llXpos+pla_lam,llYpos+pla_lam), portname) == NOPORTPROTO)
 				return(NOFACETIST);
-		(void)sprintf(portname, "Output%ld", 2*o);
+		(void)esnprintf(portname, 16, x_("Output%ld"), 2*o);
 		if (newportproto(pla, ptr->facetinst,
 			pla_FindPort(ptr->facetinst,llXpos+11*pla_lam, llYpos+pla_lam), portname) == NOPORTPROTO)
 				return(NOFACETIST);
@@ -682,7 +682,7 @@ BOOLEAN pla_ProgramPLA(INTBIG inX, INTBIG inY, INTBIG puX, INTBIG puY, INTBIG ou
 		orLeft,				/* Left edge of OR plane */
 		orRight,			/* Right edge of OR plane */
 		CurRow, CurCol;		/* Current Row and Column positions */
-	char keyword[16];		/* Input holder */
+	CHAR keyword[16];		/* Input holder */
 	NODEINST *connect;		/* Metal-Poly Contact */
 	FACETIST *PullupAND,	/* List of Pullups on AND plane */
 		*PullupOR,			/* List of Pullups on OR plane */
