@@ -47,10 +47,10 @@ static void    pla_CHfromPuAND(INTBIG, FACETIST*, NODEPROTO*);
 static void    pla_CVfromInput(INTBIG, INTBIG, FACETIST*, NODEPROTO*);
 static void    pla_CVfromOutput(FACETIST*, FACETIST*, NODEPROTO*);
 static BOOLEAN pla_ConnectFirstFacet(INTBIG, FACETIST*, NODEPROTO*);
-static void    pla_ConnectOnMetal(INTBIG, VDDGND*, char*, NODEPROTO*);
-static void    pla_ConnectThruFacets(INTBIG, VDDGND*, char*, NODEPROTO*);
+static void    pla_ConnectOnMetal(INTBIG, VDDGND*, CHAR*, NODEPROTO*);
+static void    pla_ConnectThruFacets(INTBIG, VDDGND*, CHAR*, NODEPROTO*);
 static void    pla_DrawArcs(INTBIG, PROGTRANS*, FACETIST*, INTBIG, NODEPROTO*);
-static void    pla_InstTurnPin(INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, VDDGND*, VDDGND*, char*, NODEPROTO*);
+static void    pla_InstTurnPin(INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, VDDGND*, VDDGND*, CHAR*, NODEPROTO*);
 
 /* pla_AssignPort:  Find the proper port and note down its coordinates. */
 PORT *pla_AssignPort(NODEINST *inst, INTBIG x, INTBIG y)
@@ -368,7 +368,7 @@ BOOLEAN pla_ConnectFirstFacet(INTBIG from, FACETIST *facet, NODEPROTO *pla)
 }
 
 /* Draw a metal arc between two programming transistors. */
-void pla_ConnectOnMetal(INTBIG which, VDDGND *ptr, char *mesg, NODEPROTO *pla)
+void pla_ConnectOnMetal(INTBIG which, VDDGND *ptr, CHAR *mesg, NODEPROTO *pla)
 {
 	VDDGND *prevptr;
 	PORT *fport, *tport;
@@ -382,7 +382,7 @@ void pla_ConnectOnMetal(INTBIG which, VDDGND *ptr, char *mesg, NODEPROTO *pla)
 	width = ((which == GND) ? pla_GndWidth : pla_VddWidth);
 	if (newarcinst(pla_ma_proto, width, pla_userbits, prevptr->inst, fport->port, fport->x,
 		fport->y, ptr->inst, tport->port, tport->x, tport->y, pla) == NOARCINST)
-			ttyputerr("%s", mesg);
+			ttyputerr(x_("%s"), mesg);
 }
 
 /* Connect the programming transistors on both the planes */
@@ -395,7 +395,7 @@ void pla_ConnectPlanes(INTBIG inY, INTBIG andY, INTBIG orRight, FACETIST *Inputs
 }
 
 /* Connect the Vdd/Gnd points in a string of facets */
-void pla_ConnectThruFacets(INTBIG which, VDDGND *ptr, char *mesg, NODEPROTO *pla)
+void pla_ConnectThruFacets(INTBIG which, VDDGND *ptr, CHAR *mesg, NODEPROTO *pla)
 {
 	while(ptr->nextinst != NOVDDGND)
 	{
@@ -563,10 +563,10 @@ void pla_DrawArcs(INTBIG from, PROGTRANS *endtrans, FACETIST *startfacet,
 
 /* Instance a turning pin while laying out the Vdd/Gnd busses */
 void pla_InstTurnPin(INTBIG lx, INTBIG hx, INTBIG ly, INTBIG hy, INTBIG px, INTBIG py,
-	VDDGND *tp, VDDGND *next, char *mesg, NODEPROTO *pla)
+	VDDGND *tp, VDDGND *next, CHAR *mesg, NODEPROTO *pla)
 {
 	tp->inst = newnodeinst(pla_bp_proto, lx, hx, ly, hy, NOTRANS, NOROT, pla);
-	if (tp->inst == NONODEINST) ttyputerr("%s", mesg);
+	if (tp->inst == NONODEINST) ttyputerr(x_("%s"), mesg);
 
 	tp->port = pla_AssignPort(tp->inst, px, py);
 	tp->port->port = pla_bp_proto->firstportproto;
@@ -655,7 +655,7 @@ void pla_RunVddGnd(INTBIG puX, INTBIG andX, NODEPROTO *pla)
 	pla_ConnectThruFacets(VDD, pla_otv, M_("RunVddGnd: cannot connect on Vdd at Or Top"), pla);
 
 	/* Export this as the external VDD connection point */
-	if (newportproto(pla, pla_otv->inst, pla_otv->port->port, "VDD") == NOPORTPROTO)
+	if (newportproto(pla, pla_otv->inst, pla_otv->port->port, x_("VDD")) == NOPORTPROTO)
 		ttyputerr(M_("RunVddGnd: cannot export VDD point"));
 
 	/* Now instance a ground pin above the Pullups on the AND plane
@@ -797,7 +797,7 @@ void pla_RunVddGnd(INTBIG puX, INTBIG andX, NODEPROTO *pla)
 	pla_ConnectThruFacets(GND, &turnpin, M_("RunVddGnd: cannot connect through Or Right Gnds"), pla);
 
 	/* Export this as the external GND connection point */
-	if (newportproto(pla, pla_org->inst, pla_org->port->port, "GND") == NOPORTPROTO)
+	if (newportproto(pla, pla_org->inst, pla_org->port->port, x_("GND")) == NOPORTPROTO)
 		ttyputerr(M_("RunVddGnd: cannot export GND point"));
 }
 
