@@ -42,92 +42,92 @@
 
 /* the ROUTER tool table */
 static COMCOMP routerfacetp = {NOKEYWORD, topoffacets, nextfacets, NOPARAMS,
-	INPUTOPT, " \t", M_("Facet to stitch"), 0};
+	INPUTOPT, x_(" \t"), M_("Facet to stitch"), 0};
 static COMCOMP routerarcp = {NOKEYWORD, topofarcs, nextarcs, NOPARAMS,
-	INPUTOPT, " \t", M_("Arc prototype to use in stitching (* to reset)"), 0};
+	INPUTOPT, x_(" \t"), M_("Arc prototype to use in stitching (* to reset)"), 0};
 static KEYWORD routerautoopt[] =
 {
-	{"stitch-now",             1,{&routerfacetp,NOKEY,NOKEY,NOKEY,NOKEY}},
-	{"highlighted-stitch-now", 0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
+	{x_("stitch-now"),             1,{&routerfacetp,NOKEY,NOKEY,NOKEY,NOKEY}},
+	{x_("highlighted-stitch-now"), 0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
 	TERMKEY
 };
 static COMCOMP routerautop = {routerautoopt, NOTOPLIST, NONEXTLIST, NOPARAMS,
-	INPUTOPT, " \t", M_("Auto-stitching action"), 0};
+	INPUTOPT, x_(" \t"), M_("Auto-stitching action"), 0};
 static KEYWORD routermimicopt[] =
 {
-	{"do-now",                 0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
-	{"enable",                 0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
-	{"stitch-and-unstitch",    0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
-	{"stitch-only",            0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
-	{"port-general",           0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
-	{"port-specific",          0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
-	{"any-arc-count",          0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
-	{"same-arc-count",         0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
+	{x_("do-now"),                 0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
+	{x_("enable"),                 0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
+	{x_("stitch-and-unstitch"),    0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
+	{x_("stitch-only"),            0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
+	{x_("port-general"),           0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
+	{x_("port-specific"),          0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
+	{x_("any-arc-count"),          0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
+	{x_("same-arc-count"),         0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
 	TERMKEY
 };
 static COMCOMP routermimicp = {routermimicopt, NOTOPLIST, NONEXTLIST, NOPARAMS,
-	INPUTOPT, " \t", M_("Mimic-stitching action"), 0};
+	INPUTOPT, x_(" \t"), M_("Mimic-stitching action"), 0};
 static COMCOMP routerriverp = {NOKEYWORD, topoffacets, nextfacets, NOPARAMS,
-	INPUTOPT, " \t", M_("Facet to river-route"), 0};
+	INPUTOPT, x_(" \t"), M_("Facet to river-route"), 0};
 static COMCOMP routermazesetboundaryp = {NOKEYWORD,NOTOPLIST,NONEXTLIST,NOPARAMS,
-	0, " \t", M_("routing boundary"), 0};
+	0, x_(" \t"), M_("routing boundary"), 0};
 static COMCOMP routermazesetgridxp = {NOKEYWORD,NOTOPLIST,NONEXTLIST,NOPARAMS,
-	0, " \t", M_("routing grid x"), 0};
+	0, x_(" \t"), M_("routing grid x"), 0};
 static COMCOMP routermazesetgridyp = {NOKEYWORD,NOTOPLIST,NONEXTLIST,NOPARAMS,
-	0, " \t", M_("routing grid y"), 0};
+	0, x_(" \t"), M_("routing grid y"), 0};
 static COMCOMP routermazesetoffsetxp = {NOKEYWORD,NOTOPLIST,NONEXTLIST,NOPARAMS,
-	0, " \t", M_("routing offset x"), 0};
+	0, x_(" \t"), M_("routing offset x"), 0};
 static COMCOMP routermazesetoffsetyp = {NOKEYWORD,NOTOPLIST,NONEXTLIST,NOPARAMS,
-	0, " \t", M_("routing offset y"), 0};
+	0, x_(" \t"), M_("routing offset y"), 0};
 static KEYWORD routermazesetopt[] =
 {
-	{"boundary",			 1,{&routermazesetboundaryp,NOKEY,NOKEY,NOKEY,NOKEY}},
-	{"grid",				 2,{&routermazesetgridxp,&routermazesetgridyp,NOKEY,NOKEY,NOKEY}},
-	{"offset",			     2,{&routermazesetoffsetxp,&routermazesetoffsetyp,NOKEY,NOKEY,NOKEY}},
+	{x_("boundary"),			 1,{&routermazesetboundaryp,NOKEY,NOKEY,NOKEY,NOKEY}},
+	{x_("grid"),				 2,{&routermazesetgridxp,&routermazesetgridyp,NOKEY,NOKEY,NOKEY}},
+	{x_("offset"),			     2,{&routermazesetoffsetxp,&routermazesetoffsetyp,NOKEY,NOKEY,NOKEY}},
 	TERMKEY
 };
 static COMCOMP routermazesetp = {routermazesetopt, NOTOPLIST, NONEXTLIST, NOPARAMS,
-	0, " \t", M_("set operation"), 0 };
+	0, x_(" \t"), M_("set operation"), 0 };
 static KEYWORD routermazerouteopt[] =
 {
-	{"cell",	 0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
-	{"selected", 0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
+	{x_("cell"),	 0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
+	{x_("selected"), 0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
 	TERMKEY
 };
 static COMCOMP routermazeroutep = {routermazerouteopt, NOTOPLIST, NONEXTLIST, NOPARAMS,
-	0, " \t", M_("routing operation"), 0 };
+	0, x_(" \t"), M_("routing operation"), 0 };
 static KEYWORD routermazeopt[] =
 {
-	{"set",	    1, {&routermazesetp,NOKEY,NOKEY,NOKEY,NOKEY}},
-	{"route",   1, {&routermazeroutep,NOKEY,NOKEY,NOKEY,NOKEY}},
+	{x_("set"),	    1, {&routermazesetp,NOKEY,NOKEY,NOKEY,NOKEY}},
+	{x_("route"),   1, {&routermazeroutep,NOKEY,NOKEY,NOKEY,NOKEY}},
 	TERMKEY
 };
 static COMCOMP routermazep = {routermazeopt, NOTOPLIST, NONEXTLIST, NOPARAMS,
-	0, " \t", M_("Maze routing operation"), 0 };
+	0, x_(" \t"), M_("Maze routing operation"), 0 };
 static KEYWORD routernopt[] =
 {
-	{"select",             0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
+	{x_("select"),             0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
 	TERMKEY
 };
 static COMCOMP routernp = {routernopt, NOTOPLIST, NONEXTLIST, NOPARAMS,
-	INPUTOPT, " \t", M_("Negating action"), 0};
+	INPUTOPT, x_(" \t"), M_("Negating action"), 0};
 static KEYWORD routeropt[] =
 {
-	{"auto-stitch",    1,{&routerautop,NOKEY,NOKEY,NOKEY,NOKEY}},
-	{"mimic-stitch",   1,{&routermimicp,NOKEY,NOKEY,NOKEY,NOKEY}},
-	{"river-route",    1,{&routerriverp,NOKEY,NOKEY,NOKEY,NOKEY}},
-	{"maze-route",     1,{&routermazep,NOKEY,NOKEY,NOKEY,NOKEY}},
-	{"use-arc",        1,{&routerarcp,NOKEY,NOKEY,NOKEY,NOKEY}},
-	{"select",         0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
-	{"no-stitch",      0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
-	{"unroute",        0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
-	{"copy-topology",  0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
-	{"paste-topology", 0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
-	{"not",            1,{&routernp,NOKEY,NOKEY,NOKEY,NOKEY}},
+	{x_("auto-stitch"),    1,{&routerautop,NOKEY,NOKEY,NOKEY,NOKEY}},
+	{x_("mimic-stitch"),   1,{&routermimicp,NOKEY,NOKEY,NOKEY,NOKEY}},
+	{x_("river-route"),    1,{&routerriverp,NOKEY,NOKEY,NOKEY,NOKEY}},
+	{x_("maze-route"),     1,{&routermazep,NOKEY,NOKEY,NOKEY,NOKEY}},
+	{x_("use-arc"),        1,{&routerarcp,NOKEY,NOKEY,NOKEY,NOKEY}},
+	{x_("select"),         0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
+	{x_("no-stitch"),      0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
+	{x_("unroute"),        0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
+	{x_("copy-topology"),  0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
+	{x_("paste-topology"), 0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
+	{x_("not"),            1,{&routernp,NOKEY,NOKEY,NOKEY,NOKEY}},
 	TERMKEY
 };
 COMCOMP ro_routerp = {routeropt, NOTOPLIST, NONEXTLIST, NOPARAMS,
-	0, " \t", M_("Routing action"), 0};
+	0, x_(" \t"), M_("Routing action"), 0};
 
        RCHECK      *ro_firstrcheck;
 static RCHECK      *ro_rcheckfree;
@@ -210,8 +210,11 @@ void ro_queuercheck(NODEINST *ni)
 	ro_firstrcheck = r;
 }
 
-void ro_init(INTBIG *argc, char *argv[], TOOL *thistool)
+void ro_init(INTBIG *argc, CHAR1 *argv[], TOOL *thistool)
 {
+	Q_UNUSED( argc );
+	Q_UNUSED( argv );
+
 	if (thistool == 0)
 	{
 		/* pass 3: nothing to do */
@@ -226,9 +229,9 @@ void ro_init(INTBIG *argc, char *argv[], TOOL *thistool)
 		ro_tool = thistool;
 
 		/* set default mode for router: facet stitching */
-		ro_statekey = makekey("ROUT_state");
-		ro_optionskey = makekey("ROUT_options");
-		ro_preferedkey = makekey("ROUT_prefered_arc");
+		ro_statekey = makekey(x_("ROUT_state"));
+		ro_optionskey = makekey(x_("ROUT_options"));
+		ro_preferedkey = makekey(x_("ROUT_prefered_arc"));
 		nextchangequiet();
 		ro_state = NOSTITCH;
 		(void)setvalkey((INTBIG)ro_tool, VTOOL, ro_statekey, ro_state, VINTEGER|VDONTSAVE);
@@ -249,7 +252,7 @@ void ro_init(INTBIG *argc, char *argv[], TOOL *thistool)
 		if (ro_autostitchplist == 0) return;
 
 		/* delcare dialogs */
-		DiaDeclareHook("routeopt", &routerarcp, ro_optionsdlog);
+		DiaDeclareHook(x_("routeopt"), &routerarcp, ro_optionsdlog);
 	}
 }
 
@@ -269,31 +272,32 @@ void ro_done(void)
 	{
 		r = ro_rcheckfree;
 		ro_rcheckfree = ro_rcheckfree->nextcheck;
-		efree((char *)r);
+		efree((CHAR *)r);
 	}
 
 	if (ro_findnetlisttotal > 0)
 	{
-		efree((char *)ro_findnetlistni);
-		efree((char *)ro_findnetlistpp);
-		efree((char *)ro_findnetlistx);
-		efree((char *)ro_findnetlisty);
+		efree((CHAR *)ro_findnetlistni);
+		efree((CHAR *)ro_findnetlistpp);
+		efree((CHAR *)ro_findnetlistx);
+		efree((CHAR *)ro_findnetlisty);
 	}
 
 	freepolylist(ro_autostitchplist);
+	ro_freeautomemory();
 	ro_freemimicmemory();
 	ro_freerivermemory();
 	ro_freemazememory();
 #endif
 }
 
-void ro_set(INTBIG count, char *par[])
+void ro_set(INTBIG count, CHAR *par[])
 {
 	REGISTER INTBIG l, savestate;
 	REGISTER NODEPROTO *np;
 	REGISTER ARCPROTO *ap;
 	REGISTER NODEINST *ni;
-	REGISTER char *pp;
+	REGISTER CHAR *pp;
 	REGISTER GEOM **list;
 	REGISTER VARIABLE *var;
 
@@ -315,26 +319,26 @@ void ro_set(INTBIG count, char *par[])
 		return;
 	}
 
-	l = strlen(pp = par[0]);
+	l = estrlen(pp = par[0]);
 
-	if (namesamen(pp, "no-stitch", l) == 0)
+	if (namesamen(pp, x_("no-stitch"), l) == 0)
 	{
 		(void)setvalkey((INTBIG)ro_tool, VTOOL, ro_statekey,
 			(ro_state & ~STITCHMODE) | NOSTITCH, VINTEGER|VDONTSAVE);
 		return;
 	}
 
-	if (namesamen(pp, "auto-stitch", l) == 0)
+	if (namesamen(pp, x_("auto-stitch"), l) == 0)
 	{
 		if (count <= 1) return;
-		l = strlen(pp = par[1]);
-		if (namesamen(pp, "enable", l) == 0)
+		l = estrlen(pp = par[1]);
+		if (namesamen(pp, x_("enable"), l) == 0)
 		{
 			(void)setvalkey((INTBIG)ro_tool, VTOOL, ro_statekey,
 				(ro_state & ~STITCHMODE) | AUTOSTITCH, VINTEGER|VDONTSAVE);
 			return;
 		}
-		if (namesamen(pp, "stitch-now", l) == 0)
+		if (namesamen(pp, x_("stitch-now"), l) == 0)
 		{
 			if (count >= 3)
 			{
@@ -383,9 +387,9 @@ void ro_set(INTBIG count, char *par[])
 			ttyputverbose(M_("Facet %s stitched"), describenodeproto(np));
 			return;
 		}
-		if (namesamen(pp, "highlighted-stitch-now", l) == 0)
+		if (namesamen(pp, x_("highlighted-stitch-now"), l) == 0)
 		{
-			list = (GEOM **)asktool(us_tool, "get-all-nodes");
+			list = (GEOM **)asktool(us_tool, x_("get-all-nodes"));
 			if (list[0] == NOGEOM)
 			{
 				ttyputerr(_("Select an area to be stitched"));
@@ -406,76 +410,76 @@ void ro_set(INTBIG count, char *par[])
 			ttyputverbose(M_("Stitching complete"));
 			return;
 		}
-		ttyputbadusage("telltool routing auto-stitch");
+		ttyputbadusage(x_("telltool routing auto-stitch"));
 		return;
 	}
 
-	if (namesamen(pp, "mimic-stitch", l) == 0 && l > 1)
+	if (namesamen(pp, x_("mimic-stitch"), l) == 0 && l > 1)
 	{
 		if (count < 2)
 		{
-			ttyputusage("telltool routing mimic-stitch OPTION");
+			ttyputusage(x_("telltool routing mimic-stitch OPTION"));
 			return;
 		}
-		l = strlen(pp = par[1]);
-		if (namesamen(pp, "do-now", l) == 0)
+		l = estrlen(pp = par[1]);
+		if (namesamen(pp, x_("do-now"), l) == 0)
 		{
 			ro_mimicstitch(TRUE);
 			return;
 		}
-		if (namesamen(pp, "enable", l) == 0)
+		if (namesamen(pp, x_("enable"), l) == 0)
 		{
 			(void)setvalkey((INTBIG)ro_tool, VTOOL, ro_statekey,
 				(ro_state & ~STITCHMODE) | MIMICSTITCH, VINTEGER|VDONTSAVE);
 			return;
 		}
-		if (namesamen(pp, "stitch-and-unstitch", l) == 0 && l >= 8)
+		if (namesamen(pp, x_("stitch-and-unstitch"), l) == 0 && l >= 8)
 		{
 			(void)setvalkey((INTBIG)ro_tool, VTOOL, ro_optionskey,
 				ro_getoptions() | MIMICUNROUTES, VINTEGER);
 			ttyputverbose(M_("Mimic stitcher will route and unroute"));
 			return;
 		}
-		if (namesamen(pp, "stitch-only", l) == 0 && l >= 8)
+		if (namesamen(pp, x_("stitch-only"), l) == 0 && l >= 8)
 		{
 			(void)setvalkey((INTBIG)ro_tool, VTOOL, ro_optionskey,
 				ro_getoptions() & ~MIMICUNROUTES, VINTEGER);
 			ttyputverbose(M_("Mimic stitcher will only route, not unroute"));
 			return;
 		}
-		if (namesamen(pp, "port-general", l) == 0 && l >= 8)
+		if (namesamen(pp, x_("port-general"), l) == 0 && l >= 8)
 		{
 			(void)setvalkey((INTBIG)ro_tool, VTOOL, ro_optionskey,
 				ro_getoptions() | MIMICIGNOREPORTS, VINTEGER);
 			ttyputverbose(M_("Mimic stitcher will route to any port"));
 			return;
 		}
-		if (namesamen(pp, "port-specific", l) == 0 && l >= 8)
+		if (namesamen(pp, x_("port-specific"), l) == 0 && l >= 8)
 		{
 			(void)setvalkey((INTBIG)ro_tool, VTOOL, ro_optionskey,
 				ro_getoptions() & ~MIMICIGNOREPORTS, VINTEGER);
 			ttyputverbose(M_("Mimic stitcher will rout only to similar ports"));
 			return;
 		}
-		if (namesamen(pp, "any-arc-count", l) == 0 && l >= 8)
+		if (namesamen(pp, x_("any-arc-count"), l) == 0 && l >= 8)
 		{
 			(void)setvalkey((INTBIG)ro_tool, VTOOL, ro_optionskey,
 				ro_getoptions() & ~MIMICONSIDERARCCOUNT, VINTEGER);
 			ttyputverbose(M_("Mimic stitcher will route without regard to arc count"));
 			return;
 		}
-		if (namesamen(pp, "same-arc-count", l) == 0 && l >= 8)
+		if (namesamen(pp, x_("same-arc-count"), l) == 0 && l >= 8)
 		{
 			(void)setvalkey((INTBIG)ro_tool, VTOOL, ro_optionskey,
 				ro_getoptions() | MIMICONSIDERARCCOUNT, VINTEGER);
 			ttyputverbose(M_("Mimic stitcher will rout only where arc counts are the same"));
 			return;
 		}
-		ttyputbadusage("telltool routing mimic-stitching");
+		ttyputbadusage(x_("telltool routing mimic-stitching"));
 		return;
 	}
 
-	if (namesamen(pp, "river-route", l) == 0)
+	if (namesamen(pp, x_("river-route"), l) == 0)
 	{
 		if (count >= 2)
 		{
@@ -505,27 +509,27 @@ void ro_set(INTBIG count, char *par[])
 		return;
 	}
 
-	if (namesamen(pp, "maze-route", l) == 0 && l > 1)
+	if (namesamen(pp, x_("maze-route"), l) == 0 && l > 1)
 	{
-		l = strlen(pp = par[1]);
-		if (namesamen(pp, "route", l) == 0)
+		l = estrlen(pp = par[1]);
+		if (namesamen(pp, x_("route"), l) == 0)
 		{
 			if (count <= 2) return;
-			l = strlen(pp = par[2]);
-			if (namesamen(pp, "cell", l) == 0)
+			l = estrlen(pp = par[2]);
+			if (namesamen(pp, x_("cell"), l) == 0)
 			{
 				ro_mazeroutecell();
 				return;
 			}
-			if (namesamen(pp, "selected", l) == 0)
+			if (namesamen(pp, x_("selected"), l) == 0)
 			{
 				ro_mazerouteselected();
 				return;
 			}
-			ttyputbadusage("telltool routing maze-route");
+			ttyputbadusage(x_("telltool routing maze-route"));
 			return;
 		}
-		if (namesamen(pp, "set", l) == 0)
+		if (namesamen(pp, x_("set"), l) == 0)
 		{
 			if (count <= 2)
 			{
@@ -535,34 +539,34 @@ void ro_set(INTBIG count, char *par[])
 				return;
 			}
 
-			l = strlen(pp = par[2]);
-			if (namesamen(pp, "grid", l) == 0)
+			l = estrlen(pp = par[2]);
+			if (namesamen(pp, x_("grid"), l) == 0)
 			{
 				ro_mazegridx = atola(par[3], 0);
 				ro_mazegridy = atola(par[4], 0);
 				ttyputmsg(M_("Routing grid: %sx%s"), latoa(ro_mazegridx, 0), latoa(ro_mazegridy, 0));
 				return;
 			}
-			if (namesamen(pp, "offset", l) == 0)
+			if (namesamen(pp, x_("offset"), l) == 0)
 			{
 				ro_mazeoffsetx = atola(par[3], 0);
 				ro_mazeoffsety = atola(par[4], 0);
 				ttyputmsg(M_("Routing offset: (%s,%s)"), latoa(ro_mazeoffsetx, 0), latoa(ro_mazeoffsety, 0));
 				return;
 			}
-			if (namesamen(pp, "boundary", l) == 0)
+			if (namesamen(pp, x_("boundary"), l) == 0)
 			{
 				ro_mazeboundary = atola(par[3], 0);
 				ttyputmsg(M_("Routing boundary: %s"), latoa(ro_mazeboundary, 0));
 				return;
 			}
 
-			ttyputbadusage("telltool routing maze-route set");
+			ttyputbadusage(x_("telltool routing maze-route set"));
 			return;
 		}
 	}
 
-	if (namesamen(pp, "copy-topology", l) == 0)
+	if (namesamen(pp, x_("copy-topology"), l) == 0)
 	{
 		np = getcurfacet();
 		if (np == NONODEPROTO)
@@ -573,7 +577,7 @@ void ro_set(INTBIG count, char *par[])
 		ro_copiedtopofacet = np;
 		return;
 	}
-	if (namesamen(pp, "paste-topology", l) == 0 && l >= 3)
+	if (namesamen(pp, x_("paste-topology"), l) == 0 && l >= 3)
 	{
 		np = getcurfacet();
 		if (np == NONODEPROTO)
@@ -585,14 +589,14 @@ void ro_set(INTBIG count, char *par[])
 		return;
 	}
 
-	if (namesamen(pp, "use-arc", l) == 0)
+	if (namesamen(pp, x_("use-arc"), l) == 0)
 	{
 		if (count < 2)
 		{
-			ttyputusage("telltool routing use-arc ARCPROTO");
+			ttyputusage(x_("telltool routing use-arc ARCPROTO"));
 			return;
 		}
-		if (strcmp(par[1], "*") == 0)
+		if (estrcmp(par[1], x_("*")) == 0)
 		{
 			if (getvalkey((INTBIG)ro_tool, VTOOL, VARCPROTO, ro_preferedkey) != NOVARIABLE)
 				(void)delvalkey((INTBIG)ro_tool, VTOOL, ro_preferedkey);
@@ -610,32 +614,32 @@ void ro_set(INTBIG count, char *par[])
 		return;
 	}
 
-	if (namesamen(pp, "unroute", l) == 0)
+	if (namesamen(pp, x_("unroute"), l) == 0)
 	{
 		ro_unroutecurrent();
 		return;
 	}
 
-	if (namesamen(pp, "not", l) == 0)
+	if (namesamen(pp, x_("not"), l) == 0)
 	{
 		if (count <= 1)
 		{
-			ttyputusage("telltool routing not OPTION");
+			ttyputusage(x_("telltool routing not OPTION"));
 			return;
 		}
-		l = strlen(pp = par[1]);
-		if (namesamen(pp, "select", l) == 0)
+		l = estrlen(pp = par[1]);
+		if (namesamen(pp, x_("select"), l) == 0)
 		{
 			(void)setvalkey((INTBIG)ro_tool, VTOOL, ro_statekey,
 				ro_state & ~SELECT, VINTEGER|VDONTSAVE);
 			ttyputverbose(M_("Wire placement not subject to approval"));
 			return;
 		}
-		ttyputbadusage("telltool routing not");
+		ttyputbadusage(x_("telltool routing not"));
 		return;
 	}
 
-	if (namesamen(pp, "select", l) == 0)
+	if (namesamen(pp, x_("select"), l) == 0)
 	{
 		(void)setvalkey((INTBIG)ro_tool, VTOOL, ro_statekey,
 			ro_state | SELECT, VINTEGER|VDONTSAVE);
@@ -643,7 +647,7 @@ void ro_set(INTBIG count, char *par[])
 		return;
 	}
 
-	ttyputbadusage("telltool routing");
+	ttyputbadusage(x_("telltool routing"));
 }
 
 void ro_slice(void)
@@ -671,6 +675,8 @@ void ro_slice(void)
 
 void ro_startbatch(TOOL *source, BOOLEAN undoredo)
 {
+	Q_UNUSED( undoredo );
+
 	/* code cannot be called by multiple procesors: uses globals */
 	NOT_REENTRANT;
 
@@ -707,6 +713,13 @@ void ro_endbatch(void)
 void ro_modifynodeinst(NODEINST *ni, INTBIG oldlx, INTBIG oldly, INTBIG oldhx,
 	INTBIG oldhy, INTBIG oldrot, INTBIG oldtran)
 {
+	Q_UNUSED( oldlx );
+	Q_UNUSED( oldly );
+	Q_UNUSED( oldhx );
+	Q_UNUSED( oldhy );
+	Q_UNUSED( oldrot );
+	Q_UNUSED( oldtran );
+
 	if ((ro_state&STITCHMODE) == AUTOSTITCH)
 	{
 		if (ro_source != ro_tool) ro_queuercheck(ni);
@@ -716,10 +729,20 @@ void ro_modifynodeinst(NODEINST *ni, INTBIG oldlx, INTBIG oldly, INTBIG oldhx,
 void ro_modifyarcinst(ARCINST *ai, INTBIG oldxA, INTBIG oldyA, INTBIG oldxB,
 	INTBIG oldyB, INTBIG oldwid, INTBIG oldlen)
 {
+	Q_UNUSED( ai );
+	Q_UNUSED( oldxA );
+	Q_UNUSED( oldyA );
+	Q_UNUSED( oldxB );
+	Q_UNUSED( oldyB );
+	Q_UNUSED( oldwid );
+	Q_UNUSED( oldlen );
 }
 
 void ro_modifyportproto(PORTPROTO *pp, NODEINST *oldsubni, PORTPROTO *oldsubpp)
 {
+	Q_UNUSED( pp );
+	Q_UNUSED( oldsubni );
+	Q_UNUSED( oldsubpp );
 }
 
 void ro_newobject(INTBIG addr, INTBIG type)
@@ -889,6 +912,7 @@ BOOLEAN ro_unroutenet(NETWORK *net)
 	for(first=0; ; first++)
 	{
 		found = 1;
+		bestdist = besti = bestj = 0;
 		for(i=0; i<count; i++)
 		{
 			for(j=i+1; j<count; j++)
@@ -919,7 +943,7 @@ BOOLEAN ro_unroutenet(NETWORK *net)
 			return(TRUE);
 		}
 		endobjectchange((INTBIG)ai, VARCINST);
-		(void)asktool(us_tool, "show-object", (INTBIG)ai->geom);
+		(void)asktool(us_tool, x_("show-object"), (INTBIG)ai->geom);
 	}
 	return(FALSE);
 }
@@ -997,10 +1021,10 @@ INTBIG ro_findnetends(NETWORK *net, NODEINST ***nilist, PORTPROTO ***pplist,
 					}
 					if (ro_findnetlisttotal > 0)
 					{
-						efree((char *)ro_findnetlistni);
-						efree((char *)ro_findnetlistpp);
-						efree((char *)ro_findnetlistx);
-						efree((char *)ro_findnetlisty);
+						efree((CHAR *)ro_findnetlistni);
+						efree((CHAR *)ro_findnetlistpp);
+						efree((CHAR *)ro_findnetlistx);
+						efree((CHAR *)ro_findnetlisty);
 					}
 					ro_findnetlistni = newlistni;
 					ro_findnetlistpp = newlistpp;
@@ -1051,7 +1075,7 @@ void ro_pastetopology(NODEPROTO *tonp)
 	REGISTER PORTARCINST *fpi, *ofpi;
 	REGISTER NETWORK *net;
 	REGISTER INTBIG fromcount, tocount, i, j, fun, ofun;
-	REGISTER char *matchname;
+	REGISTER CHAR *matchname;
 	REGISTER VARIABLE *var, *ovar;
 
 	if (ro_copiedtopofacet == NONODEPROTO)
@@ -1090,6 +1114,7 @@ void ro_pastetopology(NODEPROTO *tonp)
 		if (ni->temp1 != 0) continue;
 
 		/* ignore connecting nodes */
+		fun = NPUNKNOWN;
 		if (ni->proto->primindex != 0)
 		{
 			fun = nodefunction(ni);
@@ -1173,7 +1198,7 @@ void ro_pastetopology(NODEPROTO *tonp)
 				if (tolist[j] == NONODEINST) continue;
 				ovar = getvalkey((INTBIG)tolist[j], VNODEINST, VSTRING, el_node_name_key);
 				if (ovar == NOVARIABLE) continue;
-				if (namesame((char *)var->addr, (char *)ovar->addr) == 0) break;
+				if (namesame((CHAR *)var->addr, (CHAR *)ovar->addr) == 0) break;
 			}
 			if (j < tocount)
 			{
@@ -1207,8 +1232,8 @@ void ro_pastetopology(NODEPROTO *tonp)
 			tolist[i]->temp1 = (INTBIG)fromlist[i];
 
 		/* free the arrays */
-		efree((char *)fromlist);
-		efree((char *)tolist);
+		efree((CHAR *)fromlist);
+		efree((CHAR *)tolist);
 	}
 
 	/* association made, now copy the topology */
@@ -1225,6 +1250,7 @@ void ro_pastetopology(NODEPROTO *tonp)
 			ofni = (NODEINST *)otni->temp1;
 
 			/* see if they share a connection in the original */
+			ofpi = NOPORTARCINST;
 			for(fpi = fni->firstportarcinst; fpi != NOPORTARCINST; fpi = fpi->nextportarcinst)
 			{
 				ai = fpi->conarcinst;
@@ -1262,6 +1288,7 @@ void ro_pastetopology(NODEPROTO *tonp)
 		/* find that export in the source facet */
 		tpp = tni->proto->firstportproto;
 		matchname = tni->firstportexpinst->exportproto->protoname;
+		net = NONETWORK;
 		for(fpp = ro_copiedtopofacet->firstportproto; fpp != NOPORTPROTO; fpp = fpp->nextportproto)
 		{
 			net = fpp->network;
@@ -1271,7 +1298,7 @@ void ro_pastetopology(NODEPROTO *tonp)
 				{
 					net = fpp->network->networklist[i];
 					if (net->namecount <= 0) continue;
-					if (namesame(net->netname, matchname) == 0) break;
+					if (namesame(networkname(net, 0), matchname) == 0) break;
 				}
 				if (i < fpp->network->buswidth) break;
 			} else
@@ -1282,6 +1309,7 @@ void ro_pastetopology(NODEPROTO *tonp)
 		if (fpp == NOPORTPROTO) continue;
 
 		/* check to see if this is connected elsewhere in the "to" facet */
+		ofpi = NOPORTARCINST;
 		for(otni = tonp->firstnodeinst; otni != NONODEINST; otni = otni->nextnodeinst)
 		{
 			if (otni->temp1 == 0) continue;
@@ -1368,20 +1396,21 @@ int ro_sortinstspatially(const void *e1, const void *e2)
 /* Routing Options */
 static DIALOGITEM ro_optionsdialogitems[] =
 {
- /*  1 */ {0, {240,240,264,304}, BUTTON, N_("OK")},
- /*  2 */ {0, {240,12,264,76}, BUTTON, N_("Cancel")},
- /*  3 */ {0, {32,88,48,272}, POPUP, ""},
+ /*  1 */ {0, {264,264,288,328}, BUTTON, N_("OK")},
+ /*  2 */ {0, {264,12,288,76}, BUTTON, N_("Cancel")},
+ /*  3 */ {0, {32,88,48,272}, POPUP, x_("")},
  /*  4 */ {0, {32,8,48,88}, MESSAGE, N_("Currently:")},
  /*  5 */ {0, {8,8,24,220}, MESSAGE, N_("Arc to use in stitching routers:")},
  /*  6 */ {0, {68,8,84,268}, CHECK, N_("Mimic stitching can unstitch")},
- /*  7 */ {0, {116,24,132,304}, CHECK, N_("Ports must match")},
- /*  8 */ {0, {212,8,228,268}, CHECK, N_("Mimic stitching runs interactively")},
+ /*  7 */ {0, {116,24,132,348}, CHECK, N_("Ports must match")},
+ /*  8 */ {0, {236,8,252,268}, CHECK, N_("Mimic stitching runs interactively")},
  /*  9 */ {0, {92,8,108,268}, MESSAGE, N_("Mimic stitching restrictions:")},
- /* 10 */ {0, {188,24,204,304}, CHECK, N_("Node types must match")},
- /* 11 */ {0, {164,24,180,304}, CHECK, N_("Nodes sizes must match")},
- /* 12 */ {0, {140,24,156,304}, CHECK, N_("Number of existing arcs must match")}
+ /* 10 */ {0, {188,24,204,348}, CHECK, N_("Node types must match")},
+ /* 11 */ {0, {164,24,180,348}, CHECK, N_("Nodes sizes must match")},
+ /* 12 */ {0, {140,24,156,348}, CHECK, N_("Number of existing arcs must match")},
+ /* 13 */ {0, {212,24,228,348}, CHECK, N_("Cannot have other arcs in the same direction")}
 };
-static DIALOG ro_optionsdialog = {{50,75,323,388}, N_("Routing Options"), 0, 12, ro_optionsdialogitems, 0, 0};
+static DIALOG ro_optionsdialog = {{50,75,347,433}, N_("Routing Options"), 0, 13, ro_optionsdialogitems, 0, 0};
 
 /* special items for the "Routing Options" dialog: */
 #define DROO_ARCLIST         3		/* Arc list (popup) */
@@ -1391,13 +1420,14 @@ static DIALOG ro_optionsdialog = {{50,75,323,388}, N_("Routing Options"), 0, 12,
 #define DROO_MNODEPSECIFIC  10		/* Mimic node-specific (check) */
 #define DROO_MNODESIZESPEC  11		/* Mimic node-size-specific (check) */
 #define DROO_MARCCOUNTSPEC  12		/* Mimic arc-count-specific (check) */
+#define DROO_MOTHARCDIRSPEC 13		/* Mimic other-arc-in-this-direction-specific (check) */
 
 void ro_optionsdlog(void)
 {
 	INTBIG itemHit, numarcnames, initialindex, i, options, oldoptions;
 	REGISTER VARIABLE *var;
 	REGISTER ARCPROTO *ap, **arcs, *oldap;
-	char **arcnames, *paramstart[3];
+	CHAR **arcnames, *paramstart[3];
 	REGISTER void *dia;
 
 	/* gather list of arcs */
@@ -1408,10 +1438,10 @@ void ro_optionsdlog(void)
 	for(ap = el_curtech->firstarcproto; ap != NOARCPROTO; ap = ap->nextarcproto)
 		numarcnames++;
 	arcs = (ARCPROTO **)emalloc((numarcnames+1) * (sizeof (ARCPROTO *)), el_tempcluster);
-	arcnames = (char **)emalloc((numarcnames+1) * (sizeof (char *)), el_tempcluster);
+	arcnames = (CHAR **)emalloc((numarcnames+1) * (sizeof (CHAR *)), el_tempcluster);
 	if (arcs == 0 || arcnames == 0) return;
 	arcs[0] = NOARCPROTO;
-	arcnames[0] = "DEFAULT ARC";
+	arcnames[0] = x_("DEFAULT ARC");
 	numarcnames = 1;
 	initialindex = 0;
 	for(ap = el_curtech->firstarcproto; ap != NOARCPROTO; ap = ap->nextarcproto)
@@ -1427,14 +1457,14 @@ void ro_optionsdlog(void)
 	if (dia == 0) return;
 	DiaSetPopup(dia, DROO_ARCLIST, numarcnames, arcnames);
 	DiaSetPopupEntry(dia, DROO_ARCLIST, initialindex);
-	efree((char *)arcnames);
+	efree((CHAR *)arcnames);
 	ap = arcs[initialindex];
 	oldoptions = options = ro_getoptions();
 	if ((options&MIMICUNROUTES) != 0) DiaSetControl(dia, DROO_MUNSTITCH, 1);
 	if ((options&MIMICIGNOREPORTS) == 0) DiaSetControl(dia, DROO_MPORTSPECIFIC, 1);
 	if ((options&MIMICONSIDERARCCOUNT) != 0) DiaSetControl(dia, DROO_MARCCOUNTSPEC, 1);
 	if ((options&MIMICIGNORENODETYPE) == 0) DiaSetControl(dia, DROO_MNODEPSECIFIC, 1);
-	if ((options&MIMICIGNORENODESIZE) == 0) DiaSetControl(dia, DROO_MNODESIZESPEC, 1);
+	if ((options&MIMICOTHARCTHISDIR) == 0) DiaSetControl(dia, DROO_MOTHARCDIRSPEC, 1);
 	if ((options&MIMICINTERACTIVE) != 0) DiaSetControl(dia, DROO_MINTERACTIVE, 1);
 
 	/* loop until done */
@@ -1444,7 +1474,8 @@ void ro_optionsdlog(void)
 		if (itemHit == OK || itemHit == CANCEL) break;
 		if (itemHit == DROO_MUNSTITCH || itemHit == DROO_MPORTSPECIFIC ||
 			itemHit == DROO_MINTERACTIVE || itemHit == DROO_MNODEPSECIFIC ||
-			itemHit == DROO_MNODESIZESPEC || itemHit == DROO_MARCCOUNTSPEC)
+			itemHit == DROO_MNODESIZESPEC || itemHit == DROO_MARCCOUNTSPEC ||
+			itemHit == DROO_MOTHARCDIRSPEC)
 		{
 			DiaSetControl(dia, itemHit, 1 - DiaGetControl(dia, itemHit));
 			continue;
@@ -1467,22 +1498,24 @@ void ro_optionsdlog(void)
 			options &= ~MIMICONSIDERARCCOUNT;
 		if (DiaGetControl(dia, DROO_MNODEPSECIFIC) == 0) options |= MIMICIGNORENODETYPE; else
 			options &= ~MIMICIGNORENODETYPE;
+		if (DiaGetControl(dia, DROO_MOTHARCDIRSPEC) == 0) options |= MIMICOTHARCTHISDIR; else
+			options &= ~MIMICOTHARCTHISDIR;
 		if (DiaGetControl(dia, DROO_MNODESIZESPEC) == 0) options |= MIMICIGNORENODESIZE; else
 			options &= ~MIMICIGNORENODESIZE;
 		if (DiaGetControl(dia, DROO_MINTERACTIVE) != 0) options |= MIMICINTERACTIVE; else
 			options &= ~MIMICINTERACTIVE;
 		if (options != oldoptions)
 			(void)setvalkey((INTBIG)ro_tool, VTOOL, ro_optionskey, options, VINTEGER);
-		paramstart[0] = "use-arc";
+		paramstart[0] = x_("use-arc");
 		if (ap != oldap)
 		{
-			if (ap == NOARCPROTO) paramstart[1] = "*"; else
+			if (ap == NOARCPROTO) paramstart[1] = x_("*"); else
 				paramstart[1] = ap->protoname;
 			telltool(ro_tool, 2, paramstart);
 		}
 	}
 	DiaDoneDialog(dia);
-	efree((char *)arcs);
+	efree((CHAR *)arcs);
 }
 
 #endif  /* ROUTTOOL - at top */
