@@ -43,6 +43,10 @@
 
 static ARCPROTO *ro_preferedarc;	/* the prefered arc */
 
+/* working memory for "ro_checkstitching()" */
+static INTBIG     ro_nodesinareatotal = 0;
+static NODEINST **ro_nodesinarea;
+
 /* prototypes for local routines */
 static INTBIG  ro_checkstitching(NODEINST*);
 static INTBIG  ro_testpoly(NODEINST*, PORTPROTO*, ARCPROTO*, POLYGON*, NODEINST*);
@@ -51,6 +55,11 @@ static BOOLEAN ro_canconnect(ARCPROTO*, PORTPROTO*);
 static void    ro_findsmallestlayer(ARCPROTO*);
 static INTBIG  ro_didaccept(ARCINST*, ARCINST*, ARCINST*, NODEINST*, NODEINST*);
 
+void ro_freeautomemory(void)
+{
+	if (ro_nodesinareatotal > 0) efree((CHAR *)ro_nodesinarea);
+}
+
 void ro_autostitch(void)
 {
 	REGISTER RCHECK *r, *nextr;
@@ -168,12 +177,12 @@ void ro_autostitch(void)
 	{
 		for(ni = np->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
 			if (ni->temp2 != -1 && ni->temp2 != 0)
-				efree((char *)ni->temp2);
+				efree((CHAR *)ni->temp2);
 	}
 
 	/* if selection was done, restore the highlighting */
 	if ((ro_state&SELDONE) != 0)
-		(void)asktool(us_tool, "up-stack");
+		(void)asktool(us_tool, x_("up-stack"));
 
 	/* report results */
 	if (count != 0)
@@ -187,11 +196,11 @@ void ro_autostitch(void)
 INTBIG ro_checkstitching(NODEINST *ni)
 {
 	REGISTER INTBIG search, lx, hx, ly, hy, bestdist, dist, ox, oy, stitched, count,
-		tot, i, j, bbp, useportpoly;
+		tot, i, j, k, bbp, useportpoly, nodesinareacount, newtotal;
 	INTBIG x, y;
 	XARRAY trans, localtran, temp;
 	REGISTER GEOM *geom;
-	REGISTER NODEINST *oni, *rni;
+	REGISTER NODEINST *oni, *rni, **newlist;
 	REGISTER PORTPROTO *pp, *rpp, *bestpp;
 	REGISTER PORTARCINST *pi;
 	REGISTER ARCPROTO *ap;
@@ -201,22 +210,38 @@ INTBIG ro_checkstitching(NODEINST *ni)
 	/* get polygon */
 	(void)needstaticpolygon(&poly, 4, ro_tool->cluster);
 
-	/* look for any other nodes that touch or overlap this one */
+	/* gather a list of other nodes that touch or overlap this one */
 	lx = ni->geom->lowx;   hx = ni->geom->highx;
 	ly = ni->geom->lowy;   hy = ni->geom->highy;
 	search = initsearch(lx-1, hx+1, ly-1, hy+1, ni->parent);
-	count = 0;
+	nodesinareacount = 0;
 	for(;;)
 	{
-		if (stopping(STOPREASONROUTING)) { termsearch(search);   return(count); }
-
-		/* find another node in this area */
 		if ((geom = nextobject(search)) == NOGEOM) break;
 		if (!geom->entryisnode) continue;
-		oni = geom->entryaddr.ni;
+		if (nodesinareacount >= ro_nodesinareatotal)
+		{
+			newtotal = ro_nodesinareatotal * 2;
+			if (nodesinareacount >= newtotal) newtotal = nodesinareacount + 50;
+			newlist = (NODEINST **)emalloc(newtotal * (sizeof (NODEINST *)), ro_tool->cluster);
+			if (newlist == 0) return(0);
+			for(k=0; k<nodesinareacount; k++) newlist[k] = ro_nodesinarea[k];
+			if (ro_nodesinareatotal > 0) efree((CHAR *)ro_nodesinarea);
+			ro_nodesinareatotal = newtotal;
+			ro_nodesinarea = newlist;
+		}
+		ro_nodesinarea[nodesinareacount++] = geom->entryaddr.ni;
+	}
+		
+	count = 0;
+	for(k=0; k<nodesinareacount; k++)
+	{
+		/* find another node in this area */
+		oni = ro_nodesinarea[k];
+		if (stopping(STOPREASONROUTING)) { termsearch(search);   return(count); }
 
 		/* don't check newly created nodes */
-		if (oni->temp2 == 0) continue;
+/*		if (oni->temp2 == 0) continue; */
 
 		/* if both nodes are being checked, examine them only once */
 		if (oni->temp1 != 0 && oni->temp1 <= ni->temp1) continue;
@@ -364,6 +389,7 @@ INTBIG ro_checkstitching(NODEINST *ni)
 				{
 					/* search all ports for the closest */
 					bestpp = NOPORTPROTO;
+					bestdist = 0;
 					for(rpp = ni->proto->firstportproto; rpp != NOPORTPROTO; rpp = rpp->nextportproto)
 					{
 						/* compute best distance to the other node */
@@ -392,6 +418,7 @@ INTBIG ro_checkstitching(NODEINST *ni)
 
 					/* search all ports for the closest connected to this layer */
 					bestpp = NOPORTPROTO;
+					bestdist = 0;
 					for(rpp = ni->proto->firstportproto; rpp != NOPORTPROTO; rpp = rpp->nextportproto)
 						if (rpp->network == polyptr->portproto->network)
 					{
@@ -579,6 +606,7 @@ INTBIG ro_testpoly(NODEINST *ni, PORTPROTO *pp, ARCPROTO *ap, POLYGON *poly, NOD
 		{
 			/* not a geometric primitive: look for ports that touch */
 			bestpp = NOPORTPROTO;
+			bestdist = 0;
 			for(rpp = oni->proto->firstportproto; rpp != NOPORTPROTO; rpp = rpp->nextportproto)
 			{
 				/* compute best distance to the other node */
@@ -623,6 +651,7 @@ INTBIG ro_testpoly(NODEINST *ni, PORTPROTO *pp, ARCPROTO *ap, POLYGON *poly, NOD
 
 				/* search all ports for the closest connected to this layer */
 				bestpp = NOPORTPROTO;
+				bestdist = 0;
 				for(rpp = oni->proto->firstportproto; rpp != NOPORTPROTO; rpp = rpp->nextportproto)
 					if (rpp->network == opoly->portproto->network)
 				{
@@ -731,13 +760,13 @@ INTBIG ro_didaccept(ARCINST *ai, ARCINST *alt1, ARCINST *alt2, NODEINST *con1, N
 		/* save highlighting on the first selection */
 		if ((ro_state&SELDONE) == 0)
 		{
-			(void)asktool(us_tool, "down-stack");
+			(void)asktool(us_tool, x_("down-stack"));
 			(void)setvalkey((INTBIG)ro_tool, VTOOL, ro_statekey, ro_state | SELDONE,
 				VINTEGER|VDONTSAVE);
 		}
 
 		/* erase all highlighting */
-		(void)asktool(us_tool, "clear");
+		(void)asktool(us_tool, x_("clear"));
 
 		/* force the stitch to be drawn */
 		endobjectchange((INTBIG)ai, VARCINST);
@@ -747,17 +776,17 @@ INTBIG ro_didaccept(ARCINST *ai, ARCINST *alt1, ARCINST *alt2, NODEINST *con1, N
 		if (con2 != NONODEINST) endobjectchange((INTBIG)con2, VNODEINST);
 
 		/* highlight the stitch */
-		(void)asktool(us_tool, "show-object", (INTBIG)ai->geom);
-		if (alt1 != NOARCINST) (void)asktool(us_tool, "show-object", (INTBIG)alt1->geom);
-		if (alt2 != NOARCINST) (void)asktool(us_tool, "show-object", (INTBIG)alt2->geom);
-		if (con1 != NONODEINST) (void)asktool(us_tool, "show-object", (INTBIG)con1->geom);
-		if (con2 != NONODEINST) (void)asktool(us_tool, "show-object", (INTBIG)con2->geom);
-		(void)asktool(us_tool, "flush-changes");
+		(void)asktool(us_tool, x_("show-object"), (INTBIG)ai->geom);
+		if (alt1 != NOARCINST) (void)asktool(us_tool, x_("show-object"), (INTBIG)alt1->geom);
+		if (alt2 != NOARCINST) (void)asktool(us_tool, x_("show-object"), (INTBIG)alt2->geom);
+		if (con1 != NONODEINST) (void)asktool(us_tool, x_("show-object"), (INTBIG)con1->geom);
+		if (con2 != NONODEINST) (void)asktool(us_tool, x_("show-object"), (INTBIG)con2->geom);
+		(void)asktool(us_tool, x_("flush-changes"));
 
 		/* prepare confirm menu */
 		pm = (POPUPMENU *)emalloc(sizeof(POPUPMENU), ro_tool->cluster);
 		if (pm == 0) return(0);
-		pm->name = "x";
+		pm->name = x_("x");
 		pm->header = _("Confirm stitch");
 		pm->total = 3;
 		pm->list = (POPUPMENUITEM *)emalloc(pm->total * sizeof(POPUPMENUITEM), ro_tool->cluster);
@@ -783,7 +812,7 @@ INTBIG ro_didaccept(ARCINST *ai, ARCINST *alt1, ARCINST *alt2, NODEINST *con1, N
 			y = applyyscale(w, y-w->screenly) + w->usely + MENUDISPY;
 		} else x = y = -1;
 		miret = us_popupmenu(&pm, &butstate, TRUE, x, y, 4);
-		(void)asktool(us_tool, "clear");
+		(void)asktool(us_tool, x_("clear"));
 		if (miret != NOPOPUPMENUITEM)
 		{
 			switch (miret - pm->list)
@@ -828,8 +857,8 @@ INTBIG ro_didaccept(ARCINST *ai, ARCINST *alt1, ARCINST *alt2, NODEINST *con1, N
 					break;
 			}
 		}
-		efree((char *)pm->list);
-		efree((char *)pm);
+		efree((CHAR *)pm->list);
+		efree((CHAR *)pm);
 	}
 	return(retval);
 }
@@ -875,6 +904,7 @@ void ro_findsmallestlayer(ARCPROTO *ap)
 
 	/* find the smallest layer */
 	bestfound = 0;
+	bestarea = 0;
 	j = arcpolys(ai, NOWINDOWPART);
 	for(i=0; i<j; i++)
 	{
