@@ -45,7 +45,7 @@
 #define MAXBUSPORT     256		/* maximum width of bus wire */
 
 /* bit width of long word */
-#define SRMAXLAYERS (sizeof (UINTBIG) * 8)
+#define SRMAXLAYERS (INTBIG)(sizeof (UINTBIG) * 8)
 
 /******************* SRREGION *******************/
 /* Defines a routing region to the router */
@@ -66,7 +66,7 @@ typedef struct
  * SR_GSET is off, then the grid point can be used by the router for
  * routing (and temporary structure).
  */
-typedef unsigned char SRGPT;
+typedef UCHAR1 SRGPT;
 
 /* common bit masks */
 #define SR_GCLEAR	0xFF				/* clear all bits */
@@ -89,7 +89,7 @@ typedef enum
 
 typedef struct _srlayer
 {
-	char            *hused, *vused;
+	UCHAR1          *hused, *vused;
 	INTBIG           index;				/* the layer index (sort order) */
 	UINTBIG          mask;				/* the layer mask */
 	INTBIG           transx, transy;	/* translation value for grid */
@@ -250,7 +250,7 @@ static void        ro_mazedraw_arcinst(ARCINST *ai, XARRAY trans, NETWORK *net,
 static void        ro_mazedraw_facet(NODEINST *ni, XARRAY prevtrans, NETWORK *net, SRREGION *region);
 static void        ro_mazedraw_nodeinst(NODEINST *ni, XARRAY prevtrans, NETWORK *net, SRREGION *region);
 static void        ro_mazedraw_showpoly(POLYGON *obj, SRREGION *region, INTBIG layer);
-static void        ro_mazedump_layer(char *message, SRREGION *region, UINTBIG layers);
+static void        ro_mazedump_layer(CHAR *message, SRREGION *region, UINTBIG layers);
 static INTBIG      ro_mazeexamine_pt(SRPORT *port, SRLAYER *layer, INTBIG x, INTBIG y, INTBIG code);
 static INTBIG      ro_mazeexpand_wavefront(SRPORT *port, INTBIG code);
 static BOOLEAN     ro_mazeextract_paths(NODEPROTO *parent, SRNET *net);
@@ -291,37 +291,37 @@ void ro_freemazememory(void)
 		{
 			layer = ro_theregion->layers[i];
 			if (layer == NOSRLAYER) continue;
-			if (layer->grids != 0) efree((char *)layer->grids);
-			if (layer->vused != 0) efree((char *)layer->vused);
-			if (layer->hused != 0) efree((char *)layer->hused);
-			if (layer->array != 0) efree((char *)layer->array);
-			efree((char *)layer);
+			if (layer->grids != 0) efree((CHAR *)layer->grids);
+			if (layer->vused != 0) efree((CHAR *)layer->vused);
+			if (layer->hused != 0) efree((CHAR *)layer->hused);
+			if (layer->array != 0) efree((CHAR *)layer->array);
+			efree((CHAR *)layer);
 		}
-		efree((char *)ro_theregion);
+		efree((CHAR *)ro_theregion);
 	}
 	while (ro_mazenet_free_list != NOSRNET)
 	{
 		net = ro_mazenet_free_list;
 		ro_mazenet_free_list = ro_mazenet_free_list->next;
-		efree((char *)net);
+		efree((CHAR *)net);
 	}
 	while (ro_mazewavept_free_list != NOSRWAVEPT)
 	{
 		wavept = ro_mazewavept_free_list;
 		ro_mazewavept_free_list = ro_mazewavept_free_list->next;
-		efree((char *)wavept);
+		efree((CHAR *)wavept);
 	}
 	while (ro_mazeport_free_list != NOSRPORT)
 	{
 		port = ro_mazeport_free_list;
 		ro_mazeport_free_list = ro_mazeport_free_list->next;
-		efree((char *)port);
+		efree((CHAR *)port);
 	}
 	while (ro_mazepath_free_list != NOSRPATH)
 	{
 		path = ro_mazepath_free_list;
 		ro_mazepath_free_list = ro_mazepath_free_list->next;
-		efree((char *)path);
+		efree((CHAR *)path);
 	}
 }
 
@@ -419,7 +419,7 @@ BOOLEAN ro_mazeroutenet(NETWORK *net)
 	INTBIG *xplist, *yplist, count;
 	NODEINST *ni, *nextni;
 	ARCINST *ai, *nextai;
-	char *dummy;
+	CHAR *dummy;
 	PORTPROTO *pp;
 	SRREGION *region;
 	SRNET *srnet;
@@ -533,7 +533,7 @@ BOOLEAN ro_mazeroutenet(NETWORK *net)
 	/* do maze routing */
 	if (ro_mazedebug)
 	{
-		ro_mazedebuggingout = xcreate("routing", el_filetypetext, 0, &dummy);
+		ro_mazedebuggingout = xcreate(x_("routing"), el_filetypetext, 0, &dummy);
 		if (ro_mazedebuggingout == NULL) return(TRUE);
 		ro_mazedump_layer(_("before"), region, (UINTBIG)3);
 	}
@@ -1063,6 +1063,8 @@ INTBIG ro_mazefindport_geom(NODEPROTO *facet, INTBIG x, INTBIG y, ARCPROTO *ap,
 
 	cnt = 0;
 	closestni = NONODEINST;
+	bestdist = 0;
+	closestpp = NOPORTPROTO;
 	sea = initsearch(x, x, y, y, facet);
 	for(;;)
 	{
@@ -1343,6 +1345,10 @@ SRREGION *ro_mazeget_region(INTBIG wlx, INTBIG wly, INTBIG whx, INTBIG why,
 {
 	INTBIG index;
 	SRLAYER *vlayer, *hlayer;
+	Q_UNUSED( gridx );
+	Q_UNUSED( gridy );
+	Q_UNUSED( offsetx );
+	Q_UNUSED( offsety );
 
 	if (wlx > whx || wly > why) return NOSRREGION;
 
@@ -1458,17 +1464,17 @@ SRLAYER *ro_mazeadd_layer(SRREGION *region, INTBIG index, SRDIRECTION direction,
 	{
 		if (layer->grids != 0)
 		{
-			efree((char *)layer->grids);
+			efree((CHAR *)layer->grids);
 			layer->grids = 0;
 		}
 		layer->grids = (SRGPT **)emalloc(sizeof (SRGPT *) * layer->wid, ro_tool->cluster);
 		if (layer->grids == NULL) return NOSRLAYER;
 		if (layer->vused != 0)
 		{
-			efree((char *)layer->vused);
+			efree((CHAR *)layer->vused);
 			layer->vused = 0;
 		}
-		layer->vused = (char *)emalloc(sizeof (char) * layer->wid, ro_tool->cluster);
+		layer->vused = (UCHAR1 *)emalloc(sizeof (UCHAR1) * layer->wid, ro_tool->cluster);
 		if (layer->vused == NULL) return NOSRLAYER;
 		layer->allocwid = layer->wid;
 	}
@@ -1476,10 +1482,10 @@ SRLAYER *ro_mazeadd_layer(SRREGION *region, INTBIG index, SRDIRECTION direction,
 	{
 		if (layer->hused != 0)
 		{
-			efree((char *)layer->hused);
+			efree((CHAR *)layer->hused);
 			layer->hused = 0;
 		}
-		layer->hused = (char *)emalloc(sizeof (char) * layer->hei, ro_tool->cluster);
+		layer->hused = (UCHAR1 *)emalloc(sizeof (UCHAR1) * layer->hei, ro_tool->cluster);
 		if (layer->hused == NULL) return NOSRLAYER;
 		layer->allochei = layer->hei;
 	}
@@ -1487,7 +1493,7 @@ SRLAYER *ro_mazeadd_layer(SRREGION *region, INTBIG index, SRDIRECTION direction,
 	{
 		if (layer->array != 0)
 		{
-			efree((char *)layer->array);
+			efree((CHAR *)layer->array);
 			layer->array = 0;
 		}
 		layer->array = (SRGPT *)emalloc(sizeof (SRGPT *) * layer->wid * layer->hei, ro_tool->cluster);
@@ -1559,6 +1565,7 @@ void ro_mazeset_line(SRREGION *region, SRLAYER *layer, SRGPT type, INTBIG wx1, I
 	INTBIG wx2, INTBIG wy2, SRMODE mode)
 {
 	INTBIG x[2], y[2], lx, hx, ly, hy, diff, dx, dy, e, xi, yi;
+	Q_UNUSED( region );
 
 	/* convert to grid coordinates */
 	x[0] = GRIDX(wx1, layer);   x[1] = GRIDX(wx2, layer);
@@ -1640,6 +1647,7 @@ void ro_mazeset_line(SRREGION *region, SRLAYER *layer, SRGPT type, INTBIG wx1, I
 void ro_mazeset_box(SRREGION *region, SRLAYER *layer, SRGPT type, INTBIG wx1, INTBIG wy1, INTBIG wx2, INTBIG wy2, SRMODE mode)
 {
 	INTBIG lx, ly, hx, hy, x, y;
+	Q_UNUSED( region );
 
 	lx = GRIDX(wx1, layer);   ly = GRIDY(wy1, layer);
 	hx = GRIDX(wx2, layer);   hy = GRIDY(wy2, layer);
@@ -1836,7 +1844,7 @@ void ro_mazecreate_wavefront(SRPORT *port)
 			 * added detection of immediate blockage ... smr
 			 */
 			if (ro_mazedebug)
-				xprintf(ro_mazedebuggingout, "Port %ld<=X<=%ld %ld<=Y<=%ld\n", lx, hx, ly, hy);
+				xprintf(ro_mazedebuggingout, x_("Port %ld<=X<=%ld %ld<=Y<=%ld\n"), lx, hx, ly, hy);
 			onedge = FALSE;
 			for (x = lx; x <= hx; x++)
 			{
@@ -2346,8 +2354,8 @@ INTBIG ro_mazefind_paths(SRWAVEPT *wavept, SRPATH *path)
 					path->wx[0], path->wy[0], path->wx[1], path->wy[1], SR_MOR);
 				if (ro_mazedebug)
 				{
-					char line[256];
-					sprintf(line, "path (%ld,%ld) to (%ld,%ld)", sx, sy, ex, ey);
+					CHAR line[256];
+					esnprintf(line, 256, x_("path (%ld,%ld) to (%ld,%ld)"), sx, sy, ex, ey);
 					ro_mazedump_layer(line, path->port->net->region, (UINTBIG)3);
 				}
 				path = NOSRPATH;
@@ -2365,6 +2373,7 @@ INTBIG ro_mazeinit_path(SRPORT *port, SRLAYER *layer, SRWAVEPT *wavept, INTBIG x
 	SRPORT *target, *sport;
 	SRWAVEPT *twavept;
 	SRPATH *path;
+	Q_UNUSED( code );
 
 	/* search for others */
 	for (target = port->net->ports; target != NOSRPORT; target = target->next)
@@ -2791,11 +2800,11 @@ BOOLEAN ro_mazeroute_net(SRNET *net)
 			status = ro_mazeexpand_wavefront(port, code);
 			if (ro_mazedebug)
 			{
-				char *mstatus;
-				if (status == SRERROR) mstatus = "error"; else
-				if (status == SRROUTED) mstatus = "routed"; else
-				if (status == SRBLOCKED) mstatus = "blocked"; else
-					mstatus = "unknown";
+				CHAR *mstatus;
+				if (status == SRERROR) mstatus = x_("error"); else
+				if (status == SRROUTED) mstatus = x_("routed"); else
+				if (status == SRBLOCKED) mstatus = x_("blocked"); else
+					mstatus = x_("unknown");
 				ro_mazedump_layer(mstatus, net->region, (UINTBIG)3);
 			}
 			if (status == SRERROR) return(TRUE);
@@ -2861,13 +2870,13 @@ TECHNOLOGY *ro_findtech(NODEINST *ni, PORTPROTO *pp)
 	return(ro_findtech(pp->subnodeinst, pp->subportproto));
 }
 
-void ro_mazedump_layer(char *message, SRREGION *region, UINTBIG layers)
+void ro_mazedump_layer(CHAR *message, SRREGION *region, UINTBIG layers)
 {
 	SRLAYER *layer;
 	INTBIG x, y, hei, wid;
 	INTBIG index;
 	UINTBIG mask;
-	char gpt;
+	CHAR gpt;
 
 	/* scan for the first layer */
 	for (index = 0, mask = 1; index < SRMAXLAYERS; index++, mask = mask<<1)
@@ -2879,15 +2888,15 @@ void ro_mazedump_layer(char *message, SRREGION *region, UINTBIG layers)
 	}
 	hei = layer->hei;
 	wid = layer->wid;
-	xprintf(ro_mazedebuggingout, "====================== %s ======================\n", message);
-	xprintf(ro_mazedebuggingout, "   ");
-	for (x = 0; x < wid; x++) xprintf(ro_mazedebuggingout, "%ld", x / 10);
-	xprintf(ro_mazedebuggingout, "\n   ");
-	for (x = 0; x < wid; x++) xprintf(ro_mazedebuggingout, "%ld", x % 10);
-	xprintf(ro_mazedebuggingout, "\n");
+	xprintf(ro_mazedebuggingout, x_("====================== %s ======================\n"), message);
+	xprintf(ro_mazedebuggingout, x_("   "));
+	for (x = 0; x < wid; x++) xprintf(ro_mazedebuggingout, x_("%ld"), x / 10);
+	xprintf(ro_mazedebuggingout, x_("\n   "));
+	for (x = 0; x < wid; x++) xprintf(ro_mazedebuggingout, x_("%ld"), x % 10);
+	xprintf(ro_mazedebuggingout, x_("\n"));
 	for (y = hei-1; y >= 0; y--)
 	{
-		xprintf(ro_mazedebuggingout, "%3d", y);
+		xprintf(ro_mazedebuggingout, x_("%3d"), y);
 		for (x = 0; x < wid; x++)
 		{
 			gpt = ' ';
@@ -2907,11 +2916,11 @@ void ro_mazedump_layer(char *message, SRREGION *region, UINTBIG layers)
 							gpt = 'A' + (layer->grids[x][y] & SR_GMASK) - SR_GSTART;
 				}
 			}
-			xprintf(ro_mazedebuggingout, "%c", gpt);
+			xprintf(ro_mazedebuggingout, x_("%c"), gpt);
 		}
-		xprintf(ro_mazedebuggingout, "\n");
+		xprintf(ro_mazedebuggingout, x_("\n"));
 	}
-	xprintf(ro_mazedebuggingout, "\n");
+	xprintf(ro_mazedebuggingout, x_("\n"));
 }
 
 #endif  /* ROUTTOOL - at top */
