@@ -38,10 +38,11 @@
 #include "edialogs.h"
 
 #define NOPOSSIBLEARC ((POSSIBLEARC *)-1)
-#define LIKELYDIFFPORT     1
-#define LIKELYDIFFARCCOUNT 2
-#define LIKELYDIFFNODETYPE 4
-#define LIKELYDIFFNODESIZE 8
+#define LIKELYDIFFPORT      1
+#define LIKELYDIFFARCCOUNT  2
+#define LIKELYDIFFNODETYPE  4
+#define LIKELYDIFFNODESIZE  8
+#define LIKELYARCSSAMEDIR  16
 
 typedef struct Ipossiblearc
 {
@@ -62,10 +63,10 @@ static void         ro_mimicdelete(ARCPROTO *typ, NODEINST **nodes, PORTPROTO **
 static INTBIG       ro_mimiccreatedarc(ARCINST *arc);
 static INTBIG       ro_mimiccreatedany(NODEINST *ni1, PORTPROTO *pp1, INTBIG x1, INTBIG y1,
 						NODEINST *ni2, PORTPROTO *pp2, INTBIG x2, INTBIG y2,
-						INTBIG width, INTBIG userbits, ARCPROTO *proto, INTBIG prefx, INTBIG prefy);
+						INTBIG width, ARCPROTO *proto, INTBIG prefx, INTBIG prefy);
 static INTBIG       ro_mimicthis(NODEINST *ni1, PORTPROTO *pp1, INTBIG x1, INTBIG y1,
 						NODEINST *ni2, PORTPROTO *pp2, INTBIG x2, INTBIG y2,
-						INTBIG width, INTBIG userbits, ARCPROTO *proto, INTBIG prefx, INTBIG prefy);
+						INTBIG width, ARCPROTO *proto, INTBIG prefx, INTBIG prefy);
 static POSSIBLEARC *ro_allocpossiblearc(void);
 static void         ro_freepossiblearc(POSSIBLEARC *pa);
 
@@ -81,11 +82,11 @@ void ro_freemimicmemory(void)
 	{
 		pa = ro_mimicpossiblearcfree;
 		ro_mimicpossiblearcfree = pa->nextpossiblearc;
-		efree((char *)pa);
+		efree((CHAR *)pa);
 	}
 	for(i=0; i<ro_totalmimicports; i++)
 		freepolygon(ro_mimicportpolys[i]);
-	if (ro_totalmimicports > 0) efree((char *)ro_mimicportpolys);
+	if (ro_totalmimicports > 0) efree((CHAR *)ro_mimicportpolys);
 }
 
 /*
@@ -102,7 +103,7 @@ void ro_mimicstitch(BOOLEAN forced)
 	INTBIG endx[2], endy[2], x0, y0, x1, y1;
 	ARCPROTO *proto;
 	REGISTER NODEPROTO *parent;
-	REGISTER INTBIG options, i, width, userbits, foundends, e, prefx, prefy;
+	REGISTER INTBIG options, i, width, foundends, e, prefx, prefy;
 	float elapsed;
 
 	options = ro_getoptions();
@@ -117,6 +118,8 @@ void ro_mimicstitch(BOOLEAN forced)
 		}
 		ap = ro_lastactivity.deletedarcs[0]->proto;
 		ro_mimicdelete(ap, endnode, endport);
+		ro_lastactivity.numdeletedarcs = 0;
+		return;
 	}
 
 	/* if a single arc was just created, mimic that */
@@ -134,6 +137,8 @@ void ro_mimicstitch(BOOLEAN forced)
 			ttybeep(SOUNDBEEP, TRUE);
 		if ((options&MIMICINTERACTIVE) == 0 && elapsed >= 2.0)
 			ttyputmsg(_("Mimicing took %s"), explainduration(elapsed));
+		ro_lastactivity.numcreatedarcs = 0;
+		return;
 	}
 
 	/* if multiple arcs were just created, find the true end and mimic that */
@@ -165,7 +170,6 @@ void ro_mimicstitch(BOOLEAN forced)
 					endy[foundends] = ro_lastactivity.createdarcs[i]->end[e].ypos;
 					if (ro_lastactivity.createdarcs[i]->width > width)
 						width = ro_lastactivity.createdarcs[i]->width;
-					userbits = ro_lastactivity.createdarcs[i]->userbits;
 					proto = ro_lastactivity.createdarcs[i]->proto;
 				}
 				foundends++;
@@ -198,7 +202,7 @@ void ro_mimicstitch(BOOLEAN forced)
 			}
 			if (ro_mimiccreatedany(endnode[0], endport[0], endx[0], endy[0],
 				endnode[1], endport[1], endx[1], endy[1],
-				width, userbits, proto, prefx, prefy) == 0)
+				width, proto, prefx, prefy) == 0)
 			{
 				/* nothing was wired */
 				if (forced) ttyputmsg(_("No wires mimiced"));
@@ -209,6 +213,8 @@ void ro_mimicstitch(BOOLEAN forced)
 			if ((options&MIMICINTERACTIVE) == 0 && elapsed >= 2.0)
 				ttyputmsg(_("Mimicing took %s"), explainduration(elapsed));
 		}
+		ro_lastactivity.numcreatedarcs = 0;
+		return;
 	}
 }
 
@@ -227,8 +233,7 @@ void ro_mimicdelete(ARCPROTO *typ, NODEINST **nodes, PORTPROTO **ports)
 	portposition(nodes[0], ports[0], &x0, &y0);
 	portposition(nodes[1], ports[1], &x1, &y1);
 	dist = computedistance(x0, y0, x1, y1);
-	if (dist != 0)
-		angle = figureangle(x0, y0, x1, y1);
+	angle = (dist != 0 ? figureangle(x0, y0, x1, y1) : 0);
 
 	/* look for a similar situation to delete */
 	deleted = 0;
@@ -277,9 +282,9 @@ void ro_mimicdelete(ARCPROTO *typ, NODEINST **nodes, PORTPROTO **ports)
  */
 INTBIG ro_mimiccreatedany(NODEINST *ni1, PORTPROTO *pp1, INTBIG x1, INTBIG y1,
 	NODEINST *ni2, PORTPROTO *pp2, INTBIG x2, INTBIG y2,
-	INTBIG width, INTBIG userbits, ARCPROTO *proto, INTBIG prefx, INTBIG prefy)
+	INTBIG width, ARCPROTO *proto, INTBIG prefx, INTBIG prefy)
 {
-	return(ro_mimicthis(ni1, pp1, x1, y1, ni2, pp2, x2, y2, width, userbits, proto, prefx, prefy));
+	return(ro_mimicthis(ni1, pp1, x1, y1, ni2, pp2, x2, y2, width, proto, prefx, prefy));
 }
 
 /*
@@ -293,7 +298,7 @@ INTBIG ro_mimiccreatedarc(ARCINST *ai)
 	x2 = ai->end[1].xpos;   y2 = ai->end[1].ypos;
 	return(ro_mimicthis(ai->end[0].nodeinst, ai->end[0].portarcinst->proto, x1, y1,
 		ai->end[1].nodeinst, ai->end[1].portarcinst->proto, x2, y2,
-		ai->width, ai->userbits, ai->proto, 0, 0));
+		ai->width, ai->proto, 0, 0));
 }
 
 /* Prompt: Yes/No with "stop asking" */
@@ -301,7 +306,7 @@ static DIALOGITEM ro_yesnostopdialogitems[] =
 {
  /*  1 */ {0, {64,156,88,228}, BUTTON, N_("Yes")},
  /*  2 */ {0, {64,68,88,140}, BUTTON, N_("No")},
- /*  3 */ {0, {6,15,54,279}, MESSAGE, ""},
+ /*  3 */ {0, {6,15,54,279}, MESSAGE, x_("")},
  /*  4 */ {0, {96,156,120,276}, BUTTON, N_("Yes, then stop")},
  /*  5 */ {0, {96,20,120,140}, BUTTON, N_("No, and stop")}
 };
@@ -315,7 +320,7 @@ static DIALOG ro_yesnostopdialog = {{50,75,179,363}, N_("Warning"), 0, 5, ro_yes
 
 INTBIG ro_mimicthis(NODEINST *oni1, PORTPROTO *opp1, INTBIG ox1, INTBIG oy1,
 	NODEINST *oni2, PORTPROTO *opp2, INTBIG ox2, INTBIG oy2,
-	INTBIG owidth, INTBIG ouserbits, ARCPROTO *oproto, INTBIG prefx, INTBIG prefy)
+	INTBIG owidth, ARCPROTO *oproto, INTBIG prefx, INTBIG prefy)
 {
 	REGISTER NODEPROTO *facet, *proto0, *proto1;
 	REGISTER NODEINST *ni, *oni, *node0, *node1;
@@ -328,34 +333,54 @@ INTBIG ro_mimicthis(NODEINST *oni1, PORTPROTO *opp1, INTBIG ox1, INTBIG oy1,
 	REGISTER INTBIG dist, angle, options, count, i, wantx1, wanty1, end, end0offx, end0offy,
 		situation, total, node0wid, node0hei, node1wid, node1hei, wid, hei, con1, con2,
 		portpos, oportpos, stopcheck, ifignoreports, ifignorenodetype, ifignorenodesize,
-		ifignorearccount, itemHit;
+		ifignorearccount, ifignoreothersamedir, itemHit=0;
 	INTBIG x0, y0, x1, y1, x0c, y0c, desiredangle, existingangle, thisend, lx, hx, ly, hy,
 		endx[2], endy[2];
 	static POLYGON *poly = NOPOLYGON;
 	REGISTER POLYGON *thispoly, **newportpolys;
 	REGISTER POSSIBLEARC *firstpossiblearc, *pa;
-	char question[200];
-#define NUMSITUATIONS 16
-	static INTBIG situations[] = {
+	CHAR question[200];
+#define NUMSITUATIONS 32
+	static INTBIG situations[NUMSITUATIONS] = {
 		0,
-		LIKELYDIFFNODESIZE,
-		                   LIKELYDIFFARCCOUNT,
-		                                      LIKELYDIFFPORT,
-		                                                     LIKELYDIFFNODETYPE,
-		LIKELYDIFFNODESIZE|LIKELYDIFFARCCOUNT,
-		LIKELYDIFFNODESIZE|                   LIKELYDIFFPORT,
-		LIKELYDIFFNODESIZE|                                  LIKELYDIFFNODETYPE,
-		                   LIKELYDIFFARCCOUNT|LIKELYDIFFPORT,
-		                   LIKELYDIFFARCCOUNT|               LIKELYDIFFNODETYPE,
-		                                      LIKELYDIFFPORT|LIKELYDIFFNODETYPE,
+		LIKELYARCSSAMEDIR,
+		                  LIKELYDIFFNODESIZE,
+		                                     LIKELYDIFFARCCOUNT,
+		                                                        LIKELYDIFFPORT,
+		                                                                       LIKELYDIFFNODETYPE,
 
-		LIKELYDIFFNODESIZE|LIKELYDIFFARCCOUNT|LIKELYDIFFPORT,
-		LIKELYDIFFNODESIZE|LIKELYDIFFARCCOUNT|               LIKELYDIFFNODETYPE,
-		LIKELYDIFFNODESIZE|                   LIKELYDIFFPORT|LIKELYDIFFNODETYPE,
-		                   LIKELYDIFFARCCOUNT|LIKELYDIFFPORT|LIKELYDIFFNODETYPE,
-		LIKELYDIFFNODESIZE|LIKELYDIFFARCCOUNT|LIKELYDIFFPORT|LIKELYDIFFNODETYPE
+		LIKELYARCSSAMEDIR|LIKELYDIFFNODESIZE,
+		LIKELYARCSSAMEDIR|                   LIKELYDIFFARCCOUNT,
+		LIKELYARCSSAMEDIR|                                      LIKELYDIFFPORT,
+		LIKELYARCSSAMEDIR|                                                     LIKELYDIFFNODETYPE,
+		                  LIKELYDIFFNODESIZE|LIKELYDIFFARCCOUNT,
+		                  LIKELYDIFFNODESIZE|                   LIKELYDIFFPORT,
+		                  LIKELYDIFFNODESIZE|                                  LIKELYDIFFNODETYPE,
+		                                     LIKELYDIFFARCCOUNT|LIKELYDIFFPORT,
+		                                     LIKELYDIFFARCCOUNT|               LIKELYDIFFNODETYPE,
+		                                                        LIKELYDIFFPORT|LIKELYDIFFNODETYPE,
+
+		LIKELYARCSSAMEDIR|LIKELYDIFFNODESIZE|LIKELYDIFFARCCOUNT,
+		LIKELYARCSSAMEDIR|LIKELYDIFFNODESIZE|                   LIKELYDIFFPORT,
+		LIKELYARCSSAMEDIR|LIKELYDIFFNODESIZE|                                  LIKELYDIFFNODETYPE,
+		LIKELYARCSSAMEDIR|                   LIKELYDIFFARCCOUNT|LIKELYDIFFPORT,
+		LIKELYARCSSAMEDIR|                   LIKELYDIFFARCCOUNT|               LIKELYDIFFNODETYPE,
+		LIKELYARCSSAMEDIR|                                      LIKELYDIFFPORT|LIKELYDIFFNODETYPE,
+		                  LIKELYDIFFNODESIZE|LIKELYDIFFARCCOUNT|LIKELYDIFFPORT,
+		                  LIKELYDIFFNODESIZE|LIKELYDIFFARCCOUNT|               LIKELYDIFFNODETYPE,
+		                  LIKELYDIFFNODESIZE|                   LIKELYDIFFPORT|LIKELYDIFFNODETYPE,
+		                                     LIKELYDIFFARCCOUNT|LIKELYDIFFPORT|LIKELYDIFFNODETYPE,
+
+		LIKELYARCSSAMEDIR|LIKELYDIFFNODESIZE|LIKELYDIFFARCCOUNT|LIKELYDIFFPORT,
+		LIKELYARCSSAMEDIR|LIKELYDIFFNODESIZE|LIKELYDIFFARCCOUNT|               LIKELYDIFFNODETYPE,
+		LIKELYARCSSAMEDIR|LIKELYDIFFNODESIZE|                   LIKELYDIFFPORT|LIKELYDIFFNODETYPE,
+		LIKELYARCSSAMEDIR|                   LIKELYDIFFARCCOUNT|LIKELYDIFFPORT|LIKELYDIFFNODETYPE,
+		                  LIKELYDIFFNODESIZE|LIKELYDIFFARCCOUNT|LIKELYDIFFPORT|LIKELYDIFFNODETYPE,
+
+		LIKELYARCSSAMEDIR|LIKELYDIFFNODESIZE|LIKELYDIFFARCCOUNT|LIKELYDIFFPORT|LIKELYDIFFNODETYPE
 	};
 	REGISTER void *infstr, *dia;
+	Q_UNUSED( owidth );
 
 	ttyputmsg(_("Mimicing last arc..."));
 
@@ -400,7 +425,7 @@ INTBIG ro_mimicthis(NODEINST *oni1, PORTPROTO *opp1, INTBIG ox1, INTBIG oy1,
 			newportpolys[i] = ro_mimicportpolys[i];
 		for(i=ro_totalmimicports; i<total; i++)
 			newportpolys[i] = allocpolygon(4, ro_tool->cluster);
-		if (ro_totalmimicports > 0) efree((char *)ro_mimicportpolys);
+		if (ro_totalmimicports > 0) efree((CHAR *)ro_mimicportpolys);
 		ro_mimicportpolys = newportpolys;
 		ro_totalmimicports = total;
 	}
@@ -429,8 +454,7 @@ INTBIG ro_mimicthis(NODEINST *oni1, PORTPROTO *opp1, INTBIG ox1, INTBIG oy1,
 		x0 = endx[end];     y0 = endy[end];
 		x1 = endx[1-end];   y1 = endy[1-end];
 		dist = computedistance(x0, y0, x1, y1);
-		if (dist != 0)
-			angle = figureangle(x0, y0, x1, y1);
+		angle = (dist != 0 ? figureangle(x0, y0, x1, y1) : 0);
 		portposition(node0, port0, &x0c, &y0c);
 		end0offx = x0 - x0c;   end0offy = y0 - y0c;
 		nodesizeoffset(node0, &lx, &ly, &hx, &hy);
@@ -511,7 +535,10 @@ INTBIG ro_mimicthis(NODEINST *oni1, PORTPROTO *opp1, INTBIG ox1, INTBIG oy1,
 						/* see if they are the same distance apart */
 						if (!isinside(wantx1, wanty1, thispoly)) continue;
 
-						/* see if they are already wired */
+						/* figure out the wiring situation here */
+						situation = 0;
+
+						/* see if there are already wires going in this direction */
 						if (x0 == wantx1 && y0 == wanty1) desiredangle = -1; else
 							desiredangle = figureangle(x0, y0, wantx1, wanty1);
 						for(pi = ni->firstportarcinst; pi != NOPORTARCINST; pi = pi->nextportarcinst)
@@ -532,7 +559,7 @@ INTBIG ro_mimicthis(NODEINST *oni1, PORTPROTO *opp1, INTBIG ox1, INTBIG oy1,
 								if (existingangle == desiredangle) break;
 							}
 						}
-						if (pi != NOPORTARCINST) continue;
+						if (pi != NOPORTARCINST) situation |= LIKELYARCSSAMEDIR;
 
 						if (x0 == wantx1 && y0 == wanty1) desiredangle = -1; else
 							desiredangle = figureangle(wantx1, wanty1, x0, y0);
@@ -554,10 +581,8 @@ INTBIG ro_mimicthis(NODEINST *oni1, PORTPROTO *opp1, INTBIG ox1, INTBIG oy1,
 								if (existingangle == desiredangle) break;
 							}
 						}
-						if (pi != NOPORTARCINST) continue;
+						if (pi != NOPORTARCINST) situation |= LIKELYARCSSAMEDIR;
 
-						/* figure out the wiring situation here */
-						situation = 0;
 						if (pp != port0 || opp != port1)
 							situation |= LIKELYDIFFPORT;
 						con2 = 0;
@@ -614,7 +639,7 @@ INTBIG ro_mimicthis(NODEINST *oni1, PORTPROTO *opp1, INTBIG ox1, INTBIG oy1,
 	toolturnoff(net_tool, FALSE);
 
 	/* now create the mimiced arcs */
-	ifignoreports = ifignorearccount = ifignorenodetype = ifignorenodesize = 0;
+	ifignoreports = ifignorearccount = ifignorenodetype = ifignorenodesize = ifignoreothersamedir = 0;
 	for(i=0; i<NUMSITUATIONS; i++)
 	{
 		/* see if this situation is possible */
@@ -647,25 +672,31 @@ INTBIG ro_mimicthis(NODEINST *oni1, PORTPROTO *opp1, INTBIG ox1, INTBIG oy1,
 				ifignorenodesize += total;
 				continue;
 			}
+			if ((options&MIMICOTHARCTHISDIR) == 0 && (situations[i]&LIKELYARCSSAMEDIR) != 0)
+			{
+				ifignoreothersamedir += total;
+				continue;
+			}
 		} else
 		{
 			/* show the wires to be created */
-			(void)asktool(us_tool, "down-stack");
-			(void)asktool(us_tool, "clear");
+			(void)asktool(us_tool, x_("down-stack"));
+			(void)asktool(us_tool, x_("clear"));
 			for(pa = firstpossiblearc; pa != NOPOSSIBLEARC; pa = pa->nextpossiblearc)
 			{
 				if (pa->situation != situations[i]) continue;
 				if (pa->x1 == pa->x2 && pa->y1 == pa->y2)
 				{
 					dist = el_curlib->lambda[el_curtech->techindex];
-					(void)asktool(us_tool, "show-area", pa->x1-dist, pa->x1+dist, pa->y1-dist, pa->y1+dist,
+					(void)asktool(us_tool, x_("show-area"), pa->x1-dist, pa->x1+dist, pa->y1-dist, pa->y1+dist,
 						(INTBIG)facet);
 				} else
 				{
-					(void)asktool(us_tool, "show-line", pa->x1, pa->y1, pa->x2, pa->y2, (INTBIG)facet);
+					(void)asktool(us_tool, x_("show-line"), pa->x1, pa->y1, pa->x2, pa->y2, (INTBIG)facet);
 				}
 			}
-			sprintf(question, _("Create %ld %s shown here?"), total, makeplural(_("wire"), total));
+			esnprintf(question, 200, _("Create %ld %s shown here?"),
+				total, makeplural(_("wire"), total));
 			dia = DiaInitDialog(&ro_yesnostopdialog);
 			if (dia == 0)
 			{
@@ -680,7 +711,7 @@ INTBIG ro_mimicthis(NODEINST *oni1, PORTPROTO *opp1, INTBIG ox1, INTBIG oy1,
 					itemHit == DYNS_NO || itemHit == DYNS_NOSTOP) break;
 			}
 			DiaDoneDialog(dia);
-			(void)asktool(us_tool, "up-stack");
+			(void)asktool(us_tool, x_("up-stack"));
 			if (itemHit == DYNS_NO) continue;
 			if (itemHit == DYNS_NOSTOP) break;
 		}
@@ -701,7 +732,7 @@ INTBIG ro_mimicthis(NODEINST *oni1, PORTPROTO *opp1, INTBIG ox1, INTBIG oy1,
 			}
 			count++;
 		}
-		(void)asktool(us_tool, "flush-changes");
+		(void)asktool(us_tool, x_("flush-changes"));
 
 		/* stop now if requested */
 		if ((options&MIMICINTERACTIVE) != 0 && itemHit == DYNS_YESSTOP) break;
@@ -732,7 +763,9 @@ INTBIG ro_mimicthis(NODEINST *oni1, PORTPROTO *opp1, INTBIG ox1, INTBIG oy1,
 			formatinfstr(infstr, _(", would add %ld wires if 'node types must match' were off"), ifignorenodetype);
 		if (ifignorenodesize != 0)
 			formatinfstr(infstr, _(", would add %ld wires if 'nodes sizes must match' were off"), ifignorenodesize);
-		ttyputmsg("%s", returninfstr(infstr));
+		if (ifignoreothersamedir != 0)
+			formatinfstr(infstr, _(", would add %ld wires if 'cannot have other arcs in the same direction' were off"), ifignoreothersamedir);
+		ttyputmsg(x_("%s"), returninfstr(infstr));
 	}
 	return(count);
 }
