@@ -183,21 +183,29 @@ static ROUTEINFO ro_rrinfo;
 static BOOLEAN   ro_initialized = FALSE;
 
 static TRANSFORM ro_rrnorot     = { 1,  0,	/* X increasing, y2>y1                */
-									0,  1};
+									0,  1,
+                                    0,  0};
 static TRANSFORM ro_rrrot90     = { 0,  1,	/* Y decreasing, x2>x1                */
-								   -1,  0};
+								   -1,  0,
+                                    0,  0};
 static TRANSFORM ro_rrrot180    = {-1,  0,	/* X decreasing, y2<y1                */
-									0, -1};
+									0, -1,
+                                    0,  0};
 static TRANSFORM ro_rrrot270    = { 0, -1,	/* Y increasing, x2<x1                */
-									1,  0};	/* or rot -90                         */
+									1,  0,	/* or rot -90                         */
+									0,  0};
 static TRANSFORM ro_rrmirrorx   = {-1,  0,	/* X decreasing, y2>y1                */
-									0,  1};	/* mirror X coordinate, around Y axis */
+								    0,  1,	/* mirror X coordinate, around Y axis */
+								    0,  0};
 static TRANSFORM ro_rrrot90mirx = { 0,  1,	/* Y increasing, x2>x1                */
-									1,  0};	/* rot90 and mirror X                 */
+									1,  0,	/* rot90 and mirror X                 */
+									0,  0};
 static TRANSFORM ro_rrmirrory   = { 1,  0,	/* X increasing, y2<y1                */
-									0, -1};	/* mirror Y coordinate, around X axis */
+									0, -1,	/* mirror Y coordinate, around X axis */
+									0,  0};
 static TRANSFORM ro_rrmirxr90   = { 0, -1,	/* Y decreasing, x2<x1                */
-								   -1,  0};	/* mirror X, rot90                    */
+								   -1,  0,	/* mirror X, rot90                    */
+									0,  0};
 											/*    original		inverse   */
 static TRANSFORM ro_rrinverse   = { 1,  0,	/*   [ cos0  sin0] [ cos0  -sin0] */
 									0,  1,	/*   [-sin0  cos0] [ sin0   cos0] */
@@ -208,13 +216,13 @@ static INTBIG ro_rrbx, ro_rrby, ro_rrex, ro_rrey;
 /* the parsing structure for interactive routing options */
 static KEYWORD ro_riveropt[] =
 {
-	{"route",      0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
-	{"move-facet", 0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
-	{"abort",      0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
+	{x_("route"),      0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
+	{x_("move-facet"), 0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
+	{x_("abort"),      0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
 	TERMKEY
 };
 static COMCOMP ro_riverp = {ro_riveropt, NOTOPLIST, NONEXTLIST, NOPARAMS,
-	0, " \t", M_("River-routing action"), 0};
+	0, x_(" \t"), M_("River-routing action"), 0};
 
 /******** prototypes for local routines ********/
 
@@ -305,7 +313,7 @@ void ro_freerpath(RPATH *rp)
 	for(rvp = rp->pathdesc, rvpnext = (rvp ?rvp->next:NULLRPOINT);
 		rvp; rvp = rvpnext, rvpnext = (rvpnext?rvpnext->next:NULLRPOINT))
 			ro_freerivpoint(rvp);
-	efree((char *)rp);
+	efree((CHAR *)rp);
 }
 
 RPOINT *ro_newrivpoint(RPATH *rp, INTBIG first, INTBIG sec, RPOINT *next)
@@ -337,7 +345,7 @@ RPOINT *ro_newrvpoint(INTBIG x, INTBIG y, INTBIG side)
 
 void ro_freerivpoint(RPOINT *rvp)
 {
-	efree((char *)rvp);
+	efree((CHAR *)rvp);
 }
 
 RCOORD *ro_newcoord(INTBIG c)
@@ -373,7 +381,7 @@ RDESC *ro_newroutedesc(INTBIG fx, INTBIG fy, INTBIG fside, INTBIG sx, INTBIG sy,
 void ro_freeroutedesc(RDESC *rd)
 {
 	ro_freerivpoint(rd->from);   ro_freerivpoint(rd->to);
-	efree((char *)rd);
+	efree((CHAR *)rd);
 }
 
 RDESC **ro_newrdarray(INTBIG size)
@@ -389,7 +397,7 @@ RDESC **ro_newrdarray(INTBIG size)
 
 void ro_freerdarray(RDESC **r)
 {
-	efree((char *)r);
+	efree((CHAR *)r);
 }
 
 void ro_initialize(void)
@@ -422,13 +430,13 @@ void ro_freerivermemory(void)
 	{
 		c = ro_rrinfo.xaxis;
 		ro_rrinfo.xaxis = ro_rrinfo.xaxis->next;
-		efree((char *)c);
+		efree((CHAR *)c);
 	}
 	while (ro_rrinfo.yaxis != 0)
 	{
 		c = ro_rrinfo.yaxis;
 		ro_rrinfo.yaxis = ro_rrinfo.yaxis->next;
-		efree((char *)c);
+		efree((CHAR *)c);
 	}
 }
 
@@ -1175,7 +1183,7 @@ void ro_pseudomake(RDESC *rd, NODEPROTO *facet)
 			if (prev->x == rp->x && rp->x == rp->next->x) continue;
 			if (prev->y == rp->y && rp->y == rp->next->y) continue;
 		}
-		(void)asktool(us_tool, "show-line", prev->x, prev->y, rp->x, rp->y, facet);
+		(void)asktool(us_tool, x_("show-line"), prev->x, prev->y, rp->x, rp->y, facet);
 		prev = rp;
 	}
 	ro_checkthefacet(rd->unroutedwire2->end[rd->unroutedend2].nodeinst);
@@ -1195,7 +1203,7 @@ void ro_makepseudogeometry(NODEPROTO *facet)
 		latoa(ro_rrinfo.urx, lambda), latoa(ro_rrinfo.lly, lambda), latoa(ro_rrinfo.ury, lambda));
 
 	/* remove highlighting */
-	(void)asktool(us_tool, "clear");
+	(void)asktool(us_tool, x_("clear"));
 
 	for(q = ro_rrinfo.rightp; q != NULLRDESC; q = q->next) ro_pseudomake(q, facet);
 	for(q = ro_rrinfo.leftp; q != NULLRDESC; q = q->next) ro_pseudomake(q, facet);
@@ -1401,7 +1409,7 @@ void ro_makethegeometry(NODEPROTO *np)
 {
 	RDESC *q;
 
-	(void)asktool(us_tool, "clear");
+	(void)asktool(us_tool, x_("clear"));
 	ro_clear_flags(np);
 	for(q = ro_rrinfo.rightp; q != NULLRDESC; q = q->next)
 	{
@@ -1657,7 +1665,7 @@ RDESC *ro_findhighlightedwires(NODEPROTO *np, INTBIG *tot)
 	BOOLEAN wireadded;
 
 	/* get list of all highlighted arcs */
-	list = (GEOM **)asktool(us_tool, "get-all-arcs");
+	list = (GEOM **)asktool(us_tool, x_("get-all-arcs"));
 	if (list[0] == NOGEOM)
 	{
 		total = 0;   tot = &total;
@@ -1665,7 +1673,7 @@ RDESC *ro_findhighlightedwires(NODEPROTO *np, INTBIG *tot)
 	}
 
 	/* get boundary of highlight */
-	(void)asktool(us_tool, "get-highlighted-area", (INTBIG)&ro_rrinfo.llx,
+	(void)asktool(us_tool, x_("get-highlighted-area"), (INTBIG)&ro_rrinfo.llx,
 		(INTBIG)&ro_rrinfo.urx, (INTBIG)&ro_rrinfo.lly, (INTBIG)&ro_rrinfo.ury);
 
 	/* reset flags on all arcs in this facet */
@@ -1753,7 +1761,7 @@ BOOLEAN ro_findwires(NODEPROTO *np)
 
 	/* first look for the current arcproto */
 	wantap = NOARCPROTO;
-	var = getval((INTBIG)us_tool, VTOOL, VARCPROTO, "USER_current_arc");
+	var = getval((INTBIG)us_tool, VTOOL, VARCPROTO, x_("USER_current_arc"));
 	if (var != NOVARIABLE)
 	{
 		ap = (ARCPROTO *)var->addr;
@@ -1830,7 +1838,7 @@ BOOLEAN ro_move_instance(void)
 
 BOOLEAN ro_query_user(void)
 {
-	char *par[MAXPARS];
+	CHAR *par[MAXPARS];
 	INTBIG count;
 
 	/* wait for user response */
