@@ -39,8 +39,8 @@
 #include <setjmp.h>
 #include <math.h>
 
-extern char *sc_errmsg;
-extern char *sc_standard_errmsg[];
+extern CHAR *sc_errmsg;
+extern CHAR *sc_standard_errmsg[];
 extern COMCOMP    sc_silcomp;
 
 /*********** Global Variables ******************************************/
@@ -49,18 +49,18 @@ SCCELL			*sc_cells, *sc_curcell;
 jmp_buf			sc_please_stop;
 
 /* prototypes for local routines */
-static int  Sc_Mytoupper(char);
-static int  Sc_parse(int, char*[]);
-static int  Sc_compile(int, char*[]);
-static int  Sc_show(int, char*[]);
+static int  Sc_Mytoupper(CHAR);
+static int  Sc_parse(int, CHAR*[]);
+static int  Sc_compile(int, CHAR*[]);
+static int  Sc_show(int, CHAR*[]);
 static void Sc_nitreelist(SCNITREE*, int);
-static int  Sc_select(int, char*[]);
-static int  Sc_xset(int, char*[]);
-static int  Sc_library(int, char*[]);
-static int  Sc_order(int, char*[]);
-static int  Sc_pull(int, char*[]);
+static int  Sc_select(int, CHAR*[]);
+static int  Sc_xset(int, CHAR*[]);
+static int  Sc_library(int, CHAR*[]);
+static int  Sc_order(int, CHAR*[]);
+static int  Sc_pull(int, CHAR*[]);
 static int  Sc_pull_inst(SCNITREE*, SCCELL*, int);
-static int  Sc_help(int, char*[]);
+static int  Sc_help(int, CHAR*[]);
 
 /***********************************************************************
 Module:  Sc_initialize
@@ -91,7 +91,7 @@ Calling Sequence:  Sc_main();
 void Sc_main(void)
 {
 	int	   count, l, err;
-	char   *pars[PARS];
+	CHAR   *pars[PARS];
 
 	ttyputmsg(M_("QUISC - Queen's University Interactive Silicon Compiler"));
 	ttyputmsg(M_("Version %s, %s"), VERSION, DATE);
@@ -107,11 +107,11 @@ void Sc_main(void)
 		count = ttygetfullparam(M_("Enter command> "), &sc_silcomp, PARS, pars);
 		if (count < 0) break;
 		if (count == 0) continue;
-		l = strlen(pars[0]);
+		l = estrlen(pars[0]);
 		l = maxi(l, 3);
-		if ((namesamen(pars[0], "quit", l) == 0) && l >= 0) break;
+		if ((namesamen(pars[0], x_("quit"), l) == 0) && l >= 0) break;
 		if ((err = Sc_parse(count, pars)))
-			ttyputmsg("SCERR %d - %s", err, sc_errmsg);
+			ttyputmsg(x_("SCERR %d - %s"), err, sc_errmsg);
 	}
 }
 
@@ -130,7 +130,7 @@ pars		*char[]		Array of pointer to parameters.
 ------------------------------------------------------------------------
 */
 
-void Sc_one_command(int count, char *pars[])
+void Sc_one_command(int count, CHAR *pars[])
 {
 	int		err;
 
@@ -142,7 +142,7 @@ void Sc_one_command(int count, char *pars[])
 	}
 
 	if ((err = Sc_parse(count, pars)))
-		ttyputmsg("SCERR %d - %s", err, sc_errmsg);
+		ttyputmsg(x_("SCERR %d - %s"), err, sc_errmsg);
 }
 
 /***********************************************************************
@@ -159,7 +159,7 @@ c			char		Character to be converted.
 ------------------------------------------------------------------------
 */
 
-int Sc_Mytoupper(char c)
+int Sc_Mytoupper(CHAR c)
 {
 	if (islower(c)) c = toupper(c);
 	return(c);
@@ -175,11 +175,11 @@ Description:
 */
 int Sc_seterrmsg(int errnum, ...)
 {
-	static char sc_swork[MAXLINE];
+	static CHAR sc_swork[MAXLINE];
 	va_list ap;
 
 	var_start(ap, errnum);
-	evsnprintf(sc_swork, MAXLINE, _(sc_standard_errmsg[errnum]), ap);
+	evsnprintf(sc_swork, MAXLINE, TRANSLATE(sc_standard_errmsg[errnum]), ap);
 	va_end(ap);
 	sc_errmsg = sc_swork;
 	return(errnum);
@@ -193,75 +193,75 @@ Description:
 ------------------------------------------------------------------------
 */
 
-int Sc_parse(int count, char *pars[])
+int Sc_parse(int count, CHAR *pars[])
 {
 	int		l;
-	char	*sptr;
+	CHAR	*sptr;
 
 	if (Sc_stop()) longjmp(sc_please_stop, 1);
 
 	if (count == 0) return(0);
-	l = strlen(sptr = pars[0]);
+	l = estrlen(sptr = pars[0]);
 	l = maxi(l, 3);
 
-	if (namesamen(sptr, "compile", l) == 0)
+	if (namesamen(sptr, x_("compile"), l) == 0)
 		return(Sc_compile(count-1, &pars[1]));
 
-	if (namesamen(sptr, "connect", l) == 0)
+	if (namesamen(sptr, x_("connect"), l) == 0)
 		return(Sc_connect(count-1, &pars[1]));
 
-	if (namesamen(sptr, "create", l) == 0)
+	if (namesamen(sptr, x_("create"), l) == 0)
 		return(Sc_create(count-1, &pars[1]));
 
-	if (namesamen(sptr, "delete", l) == 0)
+	if (namesamen(sptr, x_("delete"), l) == 0)
 		return(Sc_delete());
 
-	if (namesamen(sptr, "export", l) == 0)
+	if (namesamen(sptr, x_("export"), l) == 0)
 		return(Sc_export(count-1, &pars[1]));
 
-	if (namesamen(sptr, "extract", l) == 0)
+	if (namesamen(sptr, x_("extract"), l) == 0)
 		return(Sc_extract(count-1, &pars[1]));
 
-	if (namesamen(sptr, "help", l) == 0)
+	if (namesamen(sptr, x_("help"), l) == 0)
 		return(Sc_help(count-1, &pars[1]));
 
-	if (namesamen(sptr, "library", l) == 0)
+	if (namesamen(sptr, x_("library"), l) == 0)
 		return(Sc_library(count-1, &pars[1]));
 
-	if (namesamen(sptr, "make", l) == 0)
+	if (namesamen(sptr, x_("make"), l) == 0)
 		return(Sc_maker(count - 1, &pars[1]));
 
-	if (namesamen(sptr, "order", l) == 0)
+	if (namesamen(sptr, x_("order"), l) == 0)
 		return(Sc_order(count-1, &pars[1]));
 
-	if (namesamen(sptr, "place", l) == 0)
+	if (namesamen(sptr, x_("place"), l) == 0)
 		return(Sc_place(count-1, &pars[1]));
 
-	if (namesamen(sptr, "pull", l) == 0)
+	if (namesamen(sptr, x_("pull"), l) == 0)
 		return(Sc_pull(count - 1, &pars[1]));
 
-	if (namesamen(sptr, "route", l) == 0)
+	if (namesamen(sptr, x_("route"), l) == 0)
 		return(Sc_route(count - 1, &pars[1]));
 
-	if (namesamen(sptr, "schematic", l) == 0)
+	if (namesamen(sptr, x_("schematic"), l) == 0)
 	{
 		Sc_schematic();
 		return(SC_NOERROR);
 	}
 
-	if (namesamen(sptr, "select", l) == 0)
+	if (namesamen(sptr, x_("select"), l) == 0)
 		return(Sc_select(count-1, &pars[1]));
 
-	if (namesamen(sptr, "set", l) == 0)
+	if (namesamen(sptr, x_("set"), l) == 0)
 		return(Sc_xset(count-1, &pars[1]));
 
-	if (namesamen(sptr, "show", l) == 0)
+	if (namesamen(sptr, x_("show"), l) == 0)
 		return(Sc_show(count-1, &pars[1]));
 
-	if (namesamen(sptr, "simulation", l) == 0)
+	if (namesamen(sptr, x_("simulation"), l) == 0)
 		return(Sc_simulation(count-1, &pars[1]));
 
-	if (namesamen(sptr, "verify", l) == 0)
+	if (namesamen(sptr, x_("verify"), l) == 0)
 		return(Sc_verify());
 
 	return(Sc_seterrmsg(SC_UNKNOWN, sptr));
@@ -276,12 +276,14 @@ Description:
 ------------------------------------------------------------------------
 */
 
-int Sc_compile(int count, char *pars[])
+int Sc_compile(int count, CHAR *pars[])
 {
 	int		lnum, icount, err, i;
-	char	inbuf[MAXLINE], *par[PARS], *sptr, *intended;
+	CHAR	inbuf[MAXLINE], *par[PARS], *sptr, *intended;
 	extern TOOL *vhdl_tool;
 	REGISTER NODEPROTO *np;
+	Q_UNUSED( count );
+	Q_UNUSED( pars );
 
 	/* demand a QUISC netlist */
 	np = getcurfacet();
@@ -291,10 +293,10 @@ int Sc_compile(int count, char *pars[])
 		return(SC_NOERROR);
 	}
 
-	(void)asktool(vhdl_tool, "want-netlist-input", (INTBIG)np, sim_filetypequisc);
+	(void)asktool(vhdl_tool, x_("want-netlist-input"), (INTBIG)np, sim_filetypequisc);
 
 	/* begin input of the netlist */
-	i = asktool(vhdl_tool, "begin-netlist-input", (INTBIG)np, sim_filetypequisc, (INTBIG)&intended);
+	i = asktool(vhdl_tool, x_("begin-netlist-input"), (INTBIG)np, sim_filetypequisc, (INTBIG)&intended);
 	if (i != 0)
 	{
 		ttyputerr(_("Cannot find netlist in %s"), intended);
@@ -306,15 +308,15 @@ int Sc_compile(int count, char *pars[])
 	(void)Sc_cpu_time(TIME_RESET);
 	for(;;)
 	{
-		lnum = asktool(vhdl_tool, "get-line", (INTBIG)inbuf);
+		lnum = asktool(vhdl_tool, x_("get-line"), (INTBIG)inbuf);
 		if (lnum == 0) break;
 
 		/* check for a comment line or empty line */
-		if (*inbuf == '!' || strlen(inbuf) == 0) continue;
+		if (*inbuf == '!' || estrlen(inbuf) == 0) continue;
 		icount = 0;
 
 		/* strip off last newline */
-		sptr = &inbuf[strlen(inbuf) - 1];
+		sptr = &inbuf[estrlen(inbuf) - 1];
 		if (*sptr == '\n') *sptr = 0;
 		sptr = inbuf;
 		while (*sptr)
@@ -357,7 +359,7 @@ int Sc_compile(int count, char *pars[])
 			break;
 		}
 	}
-	(void)asktool(vhdl_tool, "end-input");
+	(void)asktool(vhdl_tool, x_("end-input"));
 	ttyputmsg(_("Done (time = %s)"), Sc_cpu_time(TIME_ABS));
 	return(SC_NOERROR);
 }
@@ -375,11 +377,11 @@ Description:
 		6.  routing
 ------------------------------------------------------------------------
 */
-int Sc_show(int count, char *pars[])
+int Sc_show(int count, CHAR *pars[])
 {
 	int         l, bits, all_flag;
-	char        *sptr, *ptype, pdir[40];
-	char	*leafcell, *leafport;
+	CHAR        *sptr, *ptype, pdir[40];
+	CHAR	*leafcell, *leafport;
 	SCPORT	*port;
 	SCCELL	*cells;
 	SCROWLIST	*row;
@@ -389,22 +391,22 @@ int Sc_show(int count, char *pars[])
 	if (count == 0)
 		return(Sc_seterrmsg(SC_NSHOW));
 
-	l = strlen(sptr = pars[0]);
+	l = estrlen(sptr = pars[0]);
 	l = maxi(l, 2);
-	if (namesamen(sptr, "cells", l) == 0)
+	if (namesamen(sptr, x_("cells"), l) == 0)
 	{
 		ttyputmsg(M_("***** List of cells *****"));
 		for (cells = sc_cells; cells; cells = cells->next)
 		{
 			if (cells == sc_curcell)
-				ttyputmsg(" -->%s", cells->name); else
-					ttyputmsg("    %s", cells->name);
+				ttyputmsg(x_(" -->%s"), cells->name); else
+					ttyputmsg(x_("    %s"), cells->name);
 		}
 		ttyputmsg(M_("***** End of cell list *****"));
 		return(0);
 	}
 
-	if (namesamen(sptr, "ports", l) == 0) 
+	if (namesamen(sptr, x_("ports"), l) == 0) 
 	{
 		if (--count == 0)
 		{
@@ -458,16 +460,16 @@ int Sc_show(int count, char *pars[])
 				*pdir = 0;
 				bits = port->bits;
 				if (bits & SCPORTDIRUP)
-					(void)strcat(pdir, M_(" up"));
+					(void)estrcat(pdir, M_(" up"));
 				if (bits & SCPORTDIRDOWN)
-					(void)strcat(pdir, M_(" down"));
+					(void)estrcat(pdir, M_(" down"));
 				if (bits & SCPORTDIRRIGHT)
-					(void)strcat(pdir, M_(" right"));
+					(void)estrcat(pdir, M_(" right"));
 				if (bits & SCPORTDIRLEFT)
-					(void)strcat(pdir, M_(" left"));
+					(void)estrcat(pdir, M_(" left"));
 				if (!(bits & SCPORTDIRMASK))
-					(void)strcat(pdir, M_(" none"));
-				ttyputmsg("  %-20s    %-20s    %-20s", port->name,
+					(void)estrcat(pdir, M_(" none"));
+				ttyputmsg(x_("  %-20s    %-20s    %-20s"), port->name,
 					ptype, pdir);
 			}
 		} else
@@ -499,16 +501,16 @@ int Sc_show(int count, char *pars[])
 				*pdir = 0;
 				bits = Sc_leaf_port_bits(leafport);
 				if (bits & SCPORTDIRUP)
-					(void)strcat(pdir, M_(" up"));
+					(void)estrcat(pdir, M_(" up"));
 				if (bits & SCPORTDIRDOWN)
-					(void)strcat(pdir, M_(" down"));
+					(void)estrcat(pdir, M_(" down"));
 				if (bits & SCPORTDIRRIGHT)
-					(void)strcat(pdir, M_(" right"));
+					(void)estrcat(pdir, M_(" right"));
 				if (bits & SCPORTDIRLEFT)
-					(void)strcat(pdir, M_(" left"));
+					(void)estrcat(pdir, M_(" left"));
 				if (!(bits & SCPORTDIRMASK))
-					(void)strcat(pdir, M_(" none"));
-				ttyputmsg("  %-20s    %-20s    %-20s",
+					(void)estrcat(pdir, M_(" none"));
+				ttyputmsg(x_("  %-20s    %-20s    %-20s"),
 					Sc_leaf_port_name(leafport), ptype, pdir);
 			}
 		}
@@ -516,26 +518,26 @@ int Sc_show(int count, char *pars[])
 		return(0);
 	}
 
-	if (namesamen(sptr, "leaf-cell-numbers", l) == 0)
+	if (namesamen(sptr, x_("leaf-cell-numbers"), l) == 0)
 	{
 		if ((leafcell = Sc_find_leaf_facet(pars[1])) == NULL)
 		{
 			return(Sc_seterrmsg(SC_CELLNOFIND, pars[1]));
 		}
 		Sc_leaf_facet_get_nums(leafcell, &cnums);
-		ttyputmsg("****************************************");
+		ttyputmsg(x_("****************************************"));
 		ttyputmsg(M_("**      LEAF CELL MAGIC NUMBERS       **"));
-		ttyputmsg("****************************************");
-		ttyputmsg(" ");
+		ttyputmsg(x_("****************************************"));
+		ttyputmsg(x_(" "));
 		ttyputmsg(M_("Top active distance      =  %d"), cnums.top_active);
 		ttyputmsg(M_("Bottom active distance   =  %d"), cnums.bottom_active);
 		ttyputmsg(M_("Left active distance     =  %d"), cnums.left_active);
 		ttyputmsg(M_("Right active distance    =  %d"), cnums.right_active);
-		ttyputmsg("----------------------------------------");
+		ttyputmsg(x_("----------------------------------------"));
 		return(SC_NOERROR);
 	}
 
-	if (namesamen(sptr, "instances", l) == 0)
+	if (namesamen(sptr, x_("instances"), l) == 0)
 	{
 		if (--count == 0)
 		{
@@ -568,7 +570,7 @@ int Sc_show(int count, char *pars[])
 		return(0);
 	}
 
-	if (namesamen(sptr, "nodes", l) == 0)
+	if (namesamen(sptr, x_("nodes"), l) == 0)
 	{
 		if (sc_curcell == NULL)
 			return(Sc_seterrmsg(SC_NOCELL));
@@ -577,7 +579,7 @@ int Sc_show(int count, char *pars[])
 		return(SC_NOERROR);
 	}
 
-	if (namesamen(sptr, "placement", l) == 0)
+	if (namesamen(sptr, x_("placement"), l) == 0)
 	{
 		if (--count == 0)
 		{
@@ -603,12 +605,12 @@ int Sc_show(int count, char *pars[])
 		{
 			ttyputmsg(M_("For Row #%d, size %d:"), row->row_num, row->row_size);
 			for (place = row->start; place; place = place->next)
-				ttyputmsg("    %8d    %-s", place->xpos, place->cell->name);
+				ttyputmsg(x_("    %8d    %-s"), place->xpos, place->cell->name);
 		}
 		return(SC_NOERROR);
 	}
 
-	if (namesamen(sptr, "routing", l) == 0)
+	if (namesamen(sptr, x_("routing"), l) == 0)
 	{
 		if (--count == 0)
 		{
@@ -629,12 +631,12 @@ int Sc_show(int count, char *pars[])
 		}
 		if (cells->route == NULL)
 			return(Sc_seterrmsg(SC_CELL_NO_ROUTE, cells->name));
-		ttyputmsg("****************************************");
+		ttyputmsg(x_("****************************************"));
 		ttyputmsg(M_("**     CHANNEL ROUTING INFORMATION    **"));
-		ttyputmsg("****************************************");
-		ttyputmsg(" ");
+		ttyputmsg(x_("****************************************"));
+		ttyputmsg(x_(" "));
 		Sc_route_print_channel(cells->route->channels);
-		ttyputmsg("----------------------------------------");
+		ttyputmsg(x_("----------------------------------------"));
 		return(SC_NOERROR);
 	}
 
@@ -652,7 +654,7 @@ Description:
 
 void Sc_nitreelist(SCNITREE *ntp, int all_flag)
 {
-	char	*type;
+	CHAR	*type;
 
 	if (ntp == NULL) return;
 	if (ntp->lptr)
@@ -672,7 +674,7 @@ void Sc_nitreelist(SCNITREE *ntp, int all_flag)
 			break;
 	}
 	if (all_flag || ntp->type != SCSPECIALCELL)
-		ttyputmsg("    %-20s    type = %s", ntp->name, type);
+		ttyputmsg(x_("    %-20s    type = %s"), ntp->name, type);
 	if (ntp->rptr)
 		Sc_nitreelist(ntp->rptr, all_flag);
 }
@@ -685,7 +687,7 @@ Description:
 ------------------------------------------------------------------------
 */
 
-int Sc_select(int count, char *pars[])
+int Sc_select(int count, CHAR *pars[])
 {
 	SCCELL	*cell;
 
@@ -716,13 +718,13 @@ Description:
 ------------------------------------------------------------------------
 */
 
-int Sc_xset(int count, char *pars[])
+int Sc_xset(int count, CHAR *pars[])
 {
 	SCCELL	*cell;
 	SCCELLNUMS	cnums;
 	SCPORT	*port;
-	char	*leafcell, *leafport;
-	char	*dir;
+	CHAR	*leafcell, *leafport;
+	CHAR	*dir;
 	int		*bits, numpar, err, l;
 	SCNITREE	**instptr;
 	SCNIPORT	*iport;
@@ -730,8 +732,8 @@ int Sc_xset(int count, char *pars[])
 	if (!count)
 		return(Sc_seterrmsg(SC_SETNCMD));
 
-	l = maxi(strlen(pars[0]), 1);
-	if (namesamen("leaf-cell-numbers", pars[0], l) == 0)
+	l = maxi(estrlen(pars[0]), 1);
+	if (namesamen(x_("leaf-cell-numbers"), pars[0], l) == 0)
 	{
 		if ((leafcell = Sc_find_leaf_facet(pars[1])) == NULL)
 			return(Sc_seterrmsg(SC_NPNOTFIND, pars[1]));
@@ -739,32 +741,32 @@ int Sc_xset(int count, char *pars[])
 		numpar = 2;
 		while (numpar < count)
 		{
-			if (namesame("top-active", pars[numpar]) == 0)
+			if (namesame(x_("top-active"), pars[numpar]) == 0)
 			{
 				numpar++;
 				if (numpar < count)
-					cnums.top_active = atoi(pars[numpar++]);
+					cnums.top_active = eatoi(pars[numpar++]);
 				continue;
 			}
-			if (namesame("bottom-active", pars[numpar]) == 0)
+			if (namesame(x_("bottom-active"), pars[numpar]) == 0)
 			{
 				numpar++;
 				if (numpar < count)
-					cnums.bottom_active = atoi(pars[numpar++]);
+					cnums.bottom_active = eatoi(pars[numpar++]);
 				continue;
 			}
-			if (namesame("left-active", pars[numpar]) == 0)
+			if (namesame(x_("left-active"), pars[numpar]) == 0)
 			{
 				numpar++;
 				if (numpar < count)
-					cnums.left_active = atoi(pars[numpar++]);
+					cnums.left_active = eatoi(pars[numpar++]);
 				continue;
 			}
-			if (namesame("right-active", pars[numpar]) == 0)
+			if (namesame(x_("right-active"), pars[numpar]) == 0)
 			{
 				numpar++;
 				if (numpar < count)
-					cnums.right_active = atoi(pars[numpar++]);
+					cnums.right_active = eatoi(pars[numpar++]);
 				continue;
 			}
 			return(Sc_seterrmsg(SC_SET_CNUMS_XOPT, pars[numpar]));
@@ -774,7 +776,7 @@ int Sc_xset(int count, char *pars[])
 		return(SC_NOERROR);
 	}
 
-	if (namesamen("node-name", pars[0], l) == 0)
+	if (namesamen(x_("node-name"), pars[0], l) == 0)
 	{
 		/* check for sufficient parameters */
 		if (count < 4)
@@ -814,7 +816,7 @@ int Sc_xset(int count, char *pars[])
 		}
 	}
 
-	if (namesamen("port-direction", pars[0], l) == 0)
+	if (namesamen(x_("port-direction"), pars[0], l) == 0)
 	{
 		for (cell = sc_cells; cell; cell = cell->next)
 		{
@@ -878,23 +880,23 @@ Description:
 ------------------------------------------------------------------------
 */
 
-int Sc_library(int count, char *pars[])
+int Sc_library(int count, CHAR *pars[])
 {
 	int        l, err;
-	char       *sptr;
+	CHAR       *sptr;
 
-	l = strlen((sptr = pars[0]));
+	l = estrlen((sptr = pars[0]));
 	if (count == 0 || l == 0) return(Sc_seterrmsg(SC_NLIBRARY));
-	if (namesamen(sptr, "use", l) == 0)
+	if (namesamen(sptr, x_("use"), l) == 0)
 	{
-		l = strlen(sptr = pars[1]);
+		l = estrlen(sptr = pars[1]);
 		if (--count == 0 || l == 0) return(Sc_seterrmsg(SC_NLIBRARYUSE));
 		err = Sc_library_use(sptr);
 		return(err);
 	}
-	if (namesamen(sptr, "read", l) == 0)
+	if (namesamen(sptr, x_("read"), l) == 0)
 	{
-		l = strlen(sptr = pars[1]);
+		l = estrlen(sptr = pars[1]);
 		if (--count == 0 || l == 0) return(Sc_seterrmsg(SC_NLIBRARYREAD));
 		err = Sc_library_read(sptr);
 		return(err);
@@ -911,11 +913,11 @@ Description:
 ------------------------------------------------------------------------
 */
 
-int Sc_order(int count, char *pars[])
+int Sc_order(int count, CHAR *pars[])
 {
-	char	order[MAXLINE], *sptr, *filename;
+	CHAR	order[MAXLINE], *sptr, *filename;
 	int		i, j, k, err_flag;
-	char	*leafcell, *port, *whichpp[100];
+	CHAR	*leafcell, *port, *whichpp[100];
 	FILE	*fp;
 
 	if (!count)
@@ -929,7 +931,7 @@ int Sc_order(int count, char *pars[])
 	fp = (FILE *)NULL;
 	if (count > 1)
 	{
-		if ((fp = xopen(pars[1], sc_filetypesctab, "", &filename)) == NULL)
+		if ((fp = xopen(pars[1], sc_filetypesctab, x_(""), &filename)) == NULL)
 			return(Sc_seterrmsg(SC_ORDER_XOPEN_FILE, pars[1]));
 	}
 
@@ -939,8 +941,8 @@ int Sc_order(int count, char *pars[])
 		if (fp == NULL)
 		{
 			sptr = ttygetline(M_("Port>  "));
-			if (sptr == 0 || strlen(sptr) == 0) break;
-			(void)strcpy(order, sptr);
+			if (sptr == 0 || estrlen(sptr) == 0) break;
+			(void)estrcpy(order, sptr);
 		} else
 		{
 			order[0] = 0;
@@ -1019,7 +1021,7 @@ int Sc_order(int count, char *pars[])
 	/* order ports */
 	for (j = 0; j < (i - 1); j++)
 		Sc_leaf_port_set_next(whichpp[j], whichpp[j + 1]);
-	Sc_leaf_port_set_next(whichpp[i - 1], (char *)0);
+	Sc_leaf_port_set_next(whichpp[i - 1], (CHAR *)0);
 	Sc_leaf_port_set_first(leafcell, whichpp[0]);
 
 	if (fp) xclose(fp);
@@ -1047,7 +1049,7 @@ err			int			Returned error code, 0 = no error.
 ------------------------------------------------------------------------
 */
 
-int Sc_pull(int count, char *pars[])
+int Sc_pull(int count, CHAR *pars[])
 {
 	int		info_flag, err;
 	SCNITREE	*inst;
@@ -1057,7 +1059,7 @@ int Sc_pull(int count, char *pars[])
 	/* check if any parameters passed */
 	if (count)
 	{
-		if (namesame(pars[0], "information") == 0)
+		if (namesame(pars[0], x_("information")) == 0)
 			info_flag = TRUE;
 	}
 
@@ -1101,7 +1103,7 @@ int Sc_pull_inst(SCNITREE *inst, SCCELL *cell, int info_flag)
 	SCCELL	*subcell;
 	SCNITREE	*subinst, *ninst;
 	int		err, oldnum, newnum;
-	char	newname[MAXLINE], *pars[PARS], *sptr;
+	CHAR	newname[MAXLINE], *pars[PARS], *sptr;
 	SCEXTNODE	*enode, *bnode;
 	SCNIPORT	*iport;
 	SCEXTPORT	*eport, *nport;
@@ -1119,8 +1121,8 @@ int Sc_pull_inst(SCNITREE *inst, SCCELL *cell, int info_flag)
 	{
 		if (subinst->type != SCSPECIALCELL)
 		{
-			pars[0] = "instance";
-			(void)sprintf(newname, "%s.%s", inst->name, subinst->name);
+			pars[0] = x_("instance");
+			(void)esnprintf(newname, MAXLINE, x_("%s.%s"), inst->name, subinst->name);
 			pars[1] = newname;
 			if (subinst->type == SCLEAFCELL)
 			{
@@ -1180,7 +1182,7 @@ int Sc_pull_inst(SCNITREE *inst, SCCELL *cell, int info_flag)
 				nport = (SCEXTPORT *)emalloc(sizeof(SCEXTPORT), sc_tool->cluster);
 				if (nport == NULL)
 					return(Sc_seterrmsg(SC_NOMEMORY));
-				(void)sprintf(newname, "%s.%s", inst->name, eport->node->name);
+				(void)esnprintf(newname, MAXLINE, x_("%s.%s"), inst->name, eport->node->name);
 				nport->node = *(Sc_findni(&cell->niroot, newname));
 
 				/* add reference to extracted node to instance port list */
@@ -1207,7 +1209,7 @@ int Sc_pull_inst(SCNITREE *inst, SCCELL *cell, int info_flag)
 		nport = (SCEXTPORT *)emalloc(sizeof(SCEXTPORT), sc_tool->cluster);
 		if (nport  == NULL)
 			return(Sc_seterrmsg(SC_NOMEMORY));
-		(void)sprintf(newname, "%s.%s", inst->name, eport->node->name);
+		(void)esnprintf(newname, MAXLINE, x_("%s.%s"), inst->name, eport->node->name);
 		nport->node = *(Sc_findni(&cell->niroot, newname));
 
 		/* add reference to extracted node to instance port list */
@@ -1264,7 +1266,7 @@ int Sc_pull_inst(SCNITREE *inst, SCCELL *cell, int info_flag)
 		nport = (SCEXTPORT *)emalloc(sizeof(SCEXTPORT), sc_tool->cluster);
 		if (nport == NULL)
 			return(Sc_seterrmsg(SC_NOMEMORY));
-		(void)sprintf(newname, "%s.%s", inst->name, eport->node->name);
+		(void)esnprintf(newname, MAXLINE, x_("%s.%s"), inst->name, eport->node->name);
 		nport->node = *(Sc_findni(&cell->niroot, newname));
 
 		/* add reference to extracted node to instance port list */
@@ -1354,7 +1356,7 @@ int Sc_pull_inst(SCNITREE *inst, SCCELL *cell, int info_flag)
 				}
 				if (*sptr == 0)
 				{
-					newnum = atoi(enode->name + 1);
+					newnum = eatoi(enode->name + 1);
 					if (newnum > oldnum)
 						oldnum = newnum;
 				}
@@ -1367,7 +1369,7 @@ int Sc_pull_inst(SCNITREE *inst, SCCELL *cell, int info_flag)
 	{
 		if (enode->name == NULL)
 		{
-			(void)sprintf(newname, "n%d", ++oldnum);
+			(void)esnprintf(newname, MAXLINE, x_("n%d"), ++oldnum);
 			(void)allocstring(&(enode->name), newname, sc_tool->cluster);
 		}
 	}
@@ -1377,7 +1379,7 @@ int Sc_pull_inst(SCNITREE *inst, SCCELL *cell, int info_flag)
 	{
 		if (subinst->type == SCCOMPLEXCELL)
 		{
-			(void)sprintf(newname, "%s.%s", inst->name, subinst->name);
+			(void)esnprintf(newname, MAXLINE, x_("%s.%s"), inst->name, subinst->name);
 			ninst = *(Sc_findni(&cell->niroot, newname));
 			if ((err = Sc_pull_inst(ninst, cell, info_flag)))
 				return(err);
@@ -1408,9 +1410,9 @@ seconds		*char		Pointer to string giving time in seconds.
 ------------------------------------------------------------------------
 */
 
-char  *Sc_cpu_time(int action)
+CHAR  *Sc_cpu_time(int action)
 {
-	static char		sbuf[200];
+	static CHAR		sbuf[200];
 	static float	sofar;
 	float thisone;
 
@@ -1419,17 +1421,17 @@ char  *Sc_cpu_time(int action)
 		case TIME_ABS:
 			thisone = endtimer();
 			sofar += thisone;
-			(void)strcpy(sbuf, explainduration(sofar));
+			(void)estrcpy(sbuf, explainduration(sofar));
 			return(sbuf);
 		case TIME_REL:
 			thisone = endtimer();
 			sofar += thisone;
-			(void)strcpy(sbuf, explainduration(thisone));
+			(void)estrcpy(sbuf, explainduration(thisone));
 			return(sbuf);
 		case TIME_RESET:
 			starttimer();
 			sofar = 0.0;
-			return("0.00");
+			return(x_("0.00"));
 	}
 	return(_("NO_TIME"));
 }
@@ -1450,9 +1452,12 @@ err			int			Returned error count, 0 = no error.
 ------------------------------------------------------------------------
 */
 
-int Sc_help(int count, char *pars[])
+int Sc_help(int count, CHAR *pars[])
 {
-	(void)us_helpdlog("QUISC");
+	Q_UNUSED( count );
+	Q_UNUSED( pars );
+
+	(void)us_helpdlog(x_("QUISC"));
 	return(SC_NOERROR);
 }
 
