@@ -50,26 +50,26 @@ Description:
 ------------------------------------------------------------------------
 */
 
-int Sc_create(int count, char *pars[])
+int Sc_create(int count, CHAR *pars[])
 {
 	SCNITREE	 **ntp;
 	SCCELL	 *newcell, *cell;
 	SCPORT	 *port;
 	SCNIPORT	 *niport, *oldniport;
-	char         *sptr, *noden, *nodep, *proto, *bc, *bp;
+	CHAR         *sptr, *noden, *nodep, *proto, *bc, *bp;
 	int          l, type, size;
 
 	if (count == 0)
 		return(Sc_seterrmsg(SC_NCREATE));
 
-	l = strlen(sptr = pars[0]);
+	l = estrlen(sptr = pars[0]);
 	l = maxi(l, 1);
-	if (namesamen(sptr, "cell", l) == 0)
+	if (namesamen(sptr, x_("cell"), l) == 0)
 	{
 		if (--count == 0)
 			return(Sc_seterrmsg(SC_NCREATECELL));
 
-		l = strlen(sptr = pars[1]);
+		l = estrlen(sptr = pars[1]);
 
 		/* check if cell already exists in cell list */
 		for (cell = sc_cells; cell; cell = cell->next)
@@ -111,16 +111,16 @@ int Sc_create(int count, char *pars[])
 		sc_curcell = newcell;
 
 		/* create dummy ground and power nodes */
-		ntp = Sc_findni(&(sc_curcell->niroot), "ground");
-		if (*ntp) return(Sc_seterrmsg(SC_NIEXISTS, "ground"));
-		if ((*ntp = Sc_new_instance("ground", SCSPECIALCELL)) == 0)
+		ntp = Sc_findni(&(sc_curcell->niroot), x_("ground"));
+		if (*ntp) return(Sc_seterrmsg(SC_NIEXISTS, x_("ground")));
+		if ((*ntp = Sc_new_instance(x_("ground"), SCSPECIALCELL)) == 0)
 			return(Sc_seterrmsg(SC_NOMEMORY));
 		if (Sc_new_instance_port(*ntp) == NULL)
 			return(Sc_seterrmsg(SC_NOMEMORY));
 		(*ntp)->number = sc_curcell->max_node_num++;
-		ntp = Sc_findni(&(sc_curcell->niroot), "power");
-		if (*ntp) return(Sc_seterrmsg(SC_NIEXISTS, "power"));
-		if ((*ntp = Sc_new_instance("power", SCSPECIALCELL)) == 0)
+		ntp = Sc_findni(&(sc_curcell->niroot), x_("power"));
+		if (*ntp) return(Sc_seterrmsg(SC_NIEXISTS, x_("power")));
+		if ((*ntp = Sc_new_instance(x_("power"), SCSPECIALCELL)) == 0)
 			return(Sc_seterrmsg(SC_NOMEMORY));
 		if (Sc_new_instance_port(*ntp) == NULL)
 			return(Sc_seterrmsg(SC_NOMEMORY));
@@ -128,13 +128,13 @@ int Sc_create(int count, char *pars[])
 		return(0);
 	}
 
-	if (namesamen(sptr, "instance", l) == 0)
+	if (namesamen(sptr, x_("instance"), l) == 0)
 	{
 		if (--count == 0)
 			return(Sc_seterrmsg(SC_CRNODENONAME));
-		l = strlen(sptr = pars[1]);
+		l = estrlen(sptr = pars[1]);
 		noden = sptr;
-		l = strlen(sptr = pars[2]);
+		l = estrlen(sptr = pars[2]);
 		if (--count == 0 || l == 0)
 			return(Sc_seterrmsg(SC_CRNODENOPROTO));
 		nodep = sptr;
@@ -156,7 +156,7 @@ int Sc_create(int count, char *pars[])
 		} else
 		{
 			type = SCCOMPLEXCELL;
-			proto = (char *)cell;
+			proto = (CHAR *)cell;
 			size = 0;
 		}
 
@@ -188,7 +188,7 @@ int Sc_create(int count, char *pars[])
 						niport = (SCNIPORT *)emalloc(sizeof(SCNIPORT), sc_tool->cluster);
 						if (niport == 0)
 							return(Sc_seterrmsg(SC_NOMEMORY));
-						niport->port = (char *)port;
+						niport->port = (CHAR *)port;
 						niport->ext_node = NULL;
 						niport->bits = 0;
 						niport->xpos = 0;
@@ -199,7 +199,7 @@ int Sc_create(int count, char *pars[])
 						niport = (SCNIPORT *)emalloc(sizeof(SCNIPORT), sc_tool->cluster);
 						if (niport == 0)
 							return(Sc_seterrmsg(SC_NOMEMORY));
-						niport->port = (char *)port;
+						niport->port = (CHAR *)port;
 						niport->ext_node = NULL;
 						niport->bits = 0;
 						niport->xpos = 0;
@@ -210,7 +210,7 @@ int Sc_create(int count, char *pars[])
 						niport = (SCNIPORT *)emalloc(sizeof(SCNIPORT), sc_tool->cluster);
 						if (niport == 0)
 							return(Sc_seterrmsg(SC_NOMEMORY));
-						niport->port = (char *)port;
+						niport->port = (CHAR *)port;
 						niport->ext_node = NULL;
 						niport->bits = 0;
 						niport->xpos = 0;
@@ -288,7 +288,7 @@ node should be placed.  If the pointer does not have a value of
 NULL, then the object already exits.
 ------------------------------------------------------------------------
 */
-SCNITREE **Sc_findni(SCNITREE **nptr, char *name)
+SCNITREE **Sc_findni(SCNITREE **nptr, CHAR *name)
 {
 	int    i;
 
@@ -455,7 +455,7 @@ ninst		*SCNITREE	Returned new instance, NULL if error.
 ------------------------------------------------------------------------
 */
 
-SCNITREE  *Sc_new_instance(char *name, int type)
+SCNITREE  *Sc_new_instance(CHAR *name, int type)
 {
 	SCNITREE	*ninst;
 
