@@ -45,7 +45,7 @@ extern SCCELL	*sc_cells, *sc_curcell;
 
 /* prototypes for local routines */
 static int Sc_free_cell(SCCELL*);
-static int Sc_free_string(char*);
+static int Sc_free_string(CHAR*);
 static int Sc_free_port(SCPORT*);
 static int Sc_free_instance(SCNITREE*);
 static int Sc_free_instance_port(SCNIPORT*);
@@ -167,7 +167,7 @@ int Sc_free_cell(SCCELL *cell)
 	if ((err = Sc_free_route(cell->route)))
 		return(err);
 
-	efree((char *)cell);
+	efree((CHAR *)cell);
 
 	return(SC_NOERROR);
 }
@@ -187,7 +187,7 @@ err			int			Returned error code, 0 = no error.
 ------------------------------------------------------------------------
 */
 
-int Sc_free_string(char *string)
+int Sc_free_string(CHAR *string)
 {
 	if (string) efree(string);
 	return(SC_NOERROR);
@@ -216,7 +216,7 @@ int Sc_free_port(SCPORT *port)
 	{
 		if ((err = Sc_free_string(port->name)))
 			return(err);
-		efree((char *)port);
+		efree((CHAR *)port);
 	}
 	return(SC_NOERROR);
 }
@@ -249,7 +249,7 @@ int Sc_free_instance(SCNITREE *inst)
 		for (con = inst->connect; con; con = nextcon)
 		{
 			nextcon = con->next;
-			efree((char *)con);
+			efree((CHAR *)con);
 		}
 		for (nport = inst->ports; nport; nport = nextnport)
 		{
@@ -261,7 +261,7 @@ int Sc_free_instance(SCNITREE *inst)
 			return(err);
 		if ((err = Sc_free_instance_port(inst->ground)))
 			return(err);
-		efree((char *)inst);
+		efree((CHAR *)inst);
 	}
 
 	return(SC_NOERROR);
@@ -284,7 +284,7 @@ err			int			Returned error code, 0 = no error.
 
 int Sc_free_instance_port(SCNIPORT *port)
 {
-	if (port) efree((char *)port);
+	if (port) efree((CHAR *)port);
 	return(SC_NOERROR);
 }
 
@@ -315,9 +315,9 @@ int Sc_free_extracted_node(SCEXTNODE *enode)
 		for (eport = enode->firstport; eport; eport = nexteport)
 		{
 			nexteport = eport->next;
-			efree((char *)eport);
+			efree((CHAR *)eport);
 		}
-		efree((char *)enode);
+		efree((CHAR *)enode);
 	}
 
 	return(SC_NOERROR);
@@ -351,7 +351,7 @@ int Sc_free_placement(SCPLACE *placement)
 			if ((err = Sc_free_row(row)))
 				return(err);
 		}
-		efree((char *)placement);
+		efree((CHAR *)placement);
 	}
 
 	return(SC_NOERROR);
@@ -385,7 +385,7 @@ int Sc_free_row(SCROWLIST *row)
 			if ((err = Sc_free_place(place)))
 				return(err);
 		}
-		efree((char *)row);
+		efree((CHAR *)row);
 	}
 
 	return(SC_NOERROR);
@@ -408,7 +408,7 @@ err			int			Returned error code, 0 = no error.
 
 int Sc_free_place(SCNBPLACE *place)
 {
-	if (place) efree((char *)place);
+	if (place) efree((CHAR *)place);
 
 	return(SC_NOERROR);
 }
@@ -446,7 +446,7 @@ int Sc_free_route(SCROUTE *route)
 		for (xport = route->exports; xport; xport = nextxport)
 		{
 			nextxport = xport->next;
-			efree((char *)xport);
+			efree((CHAR *)xport);
 		}
 		for (row = route->rows; row; row = nextrow)
 		{
@@ -454,7 +454,7 @@ int Sc_free_route(SCROUTE *route)
 			if ((err = Sc_free_route_row(row)))
 				return(err);
 		}
-		efree((char *)route);
+		efree((CHAR *)route);
 	}
 
 	return(SC_NOERROR);
@@ -495,7 +495,7 @@ int Sc_free_route_channel(SCROUTECHANNEL *chan)
 			if ((err = Sc_free_channel_track(track)))
 				return(err);
 		}
-		efree((char *)chan);
+		efree((CHAR *)chan);
 	}
 
 	return(SC_NOERROR);
@@ -525,9 +525,9 @@ int Sc_free_channel_node(SCROUTECHNODE *node)
 		for (chport = node->firstport; chport; chport = nextchport)
 		{
 			nextchport = chport->next;
-			efree((char *)chport);
+			efree((CHAR *)chport);
 		}
-		efree((char *)node);
+		efree((CHAR *)node);
 	}
 
 	return(SC_NOERROR);
@@ -557,9 +557,9 @@ int Sc_free_channel_track(SCROUTETRACK *track)
 		for (mem = track->nodes; mem; mem = nextmem)
 		{
 			nextmem = mem->next;
-			efree((char *)mem);
+			efree((CHAR *)mem);
 		}
-		efree((char *)track);
+		efree((CHAR *)track);
 	}
 
 	return(SC_NOERROR);
@@ -592,7 +592,7 @@ int Sc_free_route_row(SCROUTEROW *row)
 			nextnode = node->next;
 			if ((err = Sc_free_route_node(node))) return(err);
 		}
-		efree((char *)row);
+		efree((CHAR *)row);
 	}
 
 	return(SC_NOERROR);
@@ -622,9 +622,9 @@ int Sc_free_route_node(SCROUTENODE *node)
 		for (port = node->firstport; port; port = nextport)
 		{
 			nextport = port->next;
-			efree((char *)port);
+			efree((CHAR *)port);
 		}
-		efree((char *)node);
+		efree((CHAR *)node);
 	}
 
 	return(SC_NOERROR);
