@@ -59,7 +59,7 @@ static ARCPROTO	 *sc_layer1arc = NOARCPROTO;
 static ARCPROTO	 *sc_layer2arc = NOARCPROTO;
 static LIBRARY   *sc_celllibrary = NOLIBRARY;
 
-extern char      *sc_errmsg;
+extern CHAR      *sc_errmsg;
 extern int        sc_sim_format;
 extern COMCOMP    sc_makep;
 
@@ -77,23 +77,25 @@ Description:
 ------------------------------------------------------------------------
 */
 
-void sc_init(INTBIG *argc, char *argv[], TOOL *thistool)
+void sc_init(INTBIG *argc, CHAR1 *argv[], TOOL *thistool)
 {
+	Q_UNUSED( argc );
+	Q_UNUSED( argv );
 	/* only initialize during pass 1 */
 	if (thistool == NOTOOL || thistool == 0) return;
 	sc_tool = thistool;
 	Sc_initialize();
-	if ((sc_simkey = makekey("SC_sim")) == -1)
-		ttyputmsg("ERROR making SIM key in SC Tool");
-	if ((sc_bitskey = makekey("SC_bits")) == -1)
-		ttyputmsg("ERROR making BITS key in SC Tool");
-	if ((sc_numskey = makekey("SC_nums")) == -1)
-		ttyputmsg("ERROR making NUMS key in SC Tool");
-	if ((sc_silkey = makekey("SC_silos")) == -1)
-		ttyputmsg("ERROR making SILOS key in SC Tool.");
-	DiaDeclareHook("silcomp", &sc_makep, sc_optionsdlog);
-	sc_filetypescsim = setupfiletype("", "*.*", MACFSTAG('TEXT'), FALSE, "scsim", _("QUISC simulation"));
-	sc_filetypesctab = setupfiletype("", "*.*", MACFSTAG('TEXT'), FALSE, "sctab", _("QUISC table"));
+	if ((sc_simkey = makekey(x_("SC_sim"))) == -1)
+		ttyputmsg(x_("ERROR making SIM key in SC Tool"));
+	if ((sc_bitskey = makekey(x_("SC_bits"))) == -1)
+		ttyputmsg(x_("ERROR making BITS key in SC Tool"));
+	if ((sc_numskey = makekey(x_("SC_nums"))) == -1)
+		ttyputmsg(x_("ERROR making NUMS key in SC Tool"));
+	if ((sc_silkey = makekey(x_("SC_silos"))) == -1)
+		ttyputmsg(x_("ERROR making SILOS key in SC Tool."));
+	DiaDeclareHook(x_("silcomp"), &sc_makep, sc_optionsdlog);
+	sc_filetypescsim = setupfiletype(x_(""), x_("*.*"), MACFSTAG('TEXT'), FALSE, x_("scsim"), _("QUISC simulation"));
+	sc_filetypesctab = setupfiletype(x_(""), x_("*.*"), MACFSTAG('TEXT'), FALSE, x_("sctab"), _("QUISC table"));
 }
 
 /***********************************************************************
@@ -120,7 +122,7 @@ Description:
 ------------------------------------------------------------------------
 */
 
-void sc_set(INTBIG count, char *pars[])
+void sc_set(INTBIG count, CHAR *pars[])
 {
 	Sc_one_command(count, pars);
 }
@@ -133,9 +135,11 @@ Description:
 ------------------------------------------------------------------------
 */
 
-INTBIG sc_request(char *command, va_list ap)
+INTBIG sc_request(CHAR *command, va_list ap)
 {
-	if (namesame(command, "cell-lib") == 0)
+	Q_UNUSED( ap );
+
+	if (namesame(command, x_("cell-lib")) == 0)
 		return((INTBIG)sc_celllibrary);
 	return(0);
 }
@@ -176,71 +180,71 @@ INTBIG ScGetParameter(INTBIG paramnum)
 	switch (paramnum)
 	{
 		case SC_PARAM_MAKE_HORIZ_ARC:
-			var = getval((INTBIG)sc_tool, VTOOL, -1, "SC_horiz_arc");
+			var = getval((INTBIG)sc_tool, VTOOL, -1, x_("SC_horiz_arc"));
 			if (var == NOVARIABLE) return((INTBIG)DEFAULT_ARC_HORIZONTAL);
 			break;
 		case SC_PARAM_MAKE_VERT_ARC:
-			var = getval((INTBIG)sc_tool, VTOOL, -1, "SC_vert_arc");
+			var = getval((INTBIG)sc_tool, VTOOL, -1, x_("SC_vert_arc"));
 			if (var == NOVARIABLE) return((INTBIG)DEFAULT_ARC_VERTICAL);
 			break;
 		case SC_PARAM_MAKE_L1_WIDTH:
-			var = getval((INTBIG)sc_tool, VTOOL, -1, "SC_l1_width");
+			var = getval((INTBIG)sc_tool, VTOOL, -1, x_("SC_l1_width"));
 			if (var == NOVARIABLE) return(DEFAULT_L1_TRACK_WIDTH);
 			break;
 		case SC_PARAM_MAKE_L2_WIDTH:
-			var = getval((INTBIG)sc_tool, VTOOL, -1, "SC_l2_width");
+			var = getval((INTBIG)sc_tool, VTOOL, -1, x_("SC_l2_width"));
 			if (var == NOVARIABLE) return(DEFAULT_L2_TRACK_WIDTH);
 			break;
 		case SC_PARAM_MAKE_PWR_WIDTH:
-			var = getval((INTBIG)sc_tool, VTOOL, -1, "SC_pwr_width");
+			var = getval((INTBIG)sc_tool, VTOOL, -1, x_("SC_pwr_width"));
 			if (var == NOVARIABLE) return(DEFAULT_POWER_TRACK_WIDTH);
 			break;
 		case SC_PARAM_MAKE_MAIN_PWR_WIDTH:
-			var = getval((INTBIG)sc_tool, VTOOL, -1, "SC_main_pwr_width");
+			var = getval((INTBIG)sc_tool, VTOOL, -1, x_("SC_main_pwr_width"));
 			if (var == NOVARIABLE) return(DEFAULT_MAIN_POWER_WIDTH);
 			break;
 		case SC_PARAM_MAKE_MAIN_PWR_RAIL:
-			var = getval((INTBIG)sc_tool, VTOOL, -1, "SC_main_pwr_rail");
+			var = getval((INTBIG)sc_tool, VTOOL, -1, x_("SC_main_pwr_rail"));
 			if (var == NOVARIABLE) return(DEFAULT_MAIN_POWER_RAIL);
 			break;
 		case SC_PARAM_MAKE_PWELL_SIZE:
-			var = getval((INTBIG)sc_tool, VTOOL, -1, "SC_pwell_size");
+			var = getval((INTBIG)sc_tool, VTOOL, -1, x_("SC_pwell_size"));
 			if (var == NOVARIABLE) return(DEFAULT_PWELL_SIZE);
 			break;
 		case SC_PARAM_MAKE_PWELL_OFFSET:
-			var = getval((INTBIG)sc_tool, VTOOL, -1, "SC_pwell_offset");
+			var = getval((INTBIG)sc_tool, VTOOL, -1, x_("SC_pwell_offset"));
 			if (var == NOVARIABLE) return(DEFAULT_PWELL_OFFSET);
 			break;
 		case SC_PARAM_MAKE_NWELL_SIZE:
-			var = getval((INTBIG)sc_tool, VTOOL, -1, "SC_nwell_size");
+			var = getval((INTBIG)sc_tool, VTOOL, -1, x_("SC_nwell_size"));
 			if (var == NOVARIABLE) return(DEFAULT_NWELL_SIZE);
 			break;
 		case SC_PARAM_MAKE_NWELL_OFFSET:
-			var = getval((INTBIG)sc_tool, VTOOL, -1, "SC_nwell_offset");
+			var = getval((INTBIG)sc_tool, VTOOL, -1, x_("SC_nwell_offset"));
 			if (var == NOVARIABLE) return(DEFAULT_NWELL_OFFSET);
 			break;
 		case SC_PARAM_MAKE_VIA_SIZE:
-			var = getval((INTBIG)sc_tool, VTOOL, -1, "SC_via_size");
+			var = getval((INTBIG)sc_tool, VTOOL, -1, x_("SC_via_size"));
 			if (var == NOVARIABLE) return(DEFAULT_VIA_SIZE);
 			break;
 		case SC_PARAM_MAKE_MIN_SPACING:
-			var = getval((INTBIG)sc_tool, VTOOL, -1, "SC_min_spacing");
+			var = getval((INTBIG)sc_tool, VTOOL, -1, x_("SC_min_spacing"));
 			if (var == NOVARIABLE) return(DEFAULT_MIN_SPACING);
 			break;
 		case SC_PARAM_ROUTE_FEEDTHRU_SIZE:
-			var = getval((INTBIG)sc_tool, VTOOL, -1, "SC_feedthru_size");
+			var = getval((INTBIG)sc_tool, VTOOL, -1, x_("SC_feedthru_size"));
 			if (var == NOVARIABLE) return(DEFAULT_FEED_THROUGH_SIZE);
 			break;
 		case SC_PARAM_ROUTE_PORT_X_MIN_DIST:
-			var = getval((INTBIG)sc_tool, VTOOL, -1, "SC_port_x_min_dist");
+			var = getval((INTBIG)sc_tool, VTOOL, -1, x_("SC_port_x_min_dist"));
 			if (var == NOVARIABLE) return(DEFAULT_PORT_X_MIN_DISTANCE);
 			break;
 		case SC_PARAM_ROUTE_ACTIVE_DIST:
-			var = getval((INTBIG)sc_tool, VTOOL, -1, "SC_active_dist");
+			var = getval((INTBIG)sc_tool, VTOOL, -1, x_("SC_active_dist"));
 			if (var == NOVARIABLE) return(DEFAULT_ACTIVE_DISTANCE);
 			break;
 		case SC_PARAM_PLACE_NUM_ROWS:
-			var = getval((INTBIG)sc_tool, VTOOL, -1, "SC_num_rows");
+			var = getval((INTBIG)sc_tool, VTOOL, -1, x_("SC_num_rows"));
 			if (var == NOVARIABLE) return(DEFAULT_NUM_OF_ROWS);
 			break;
 	}
@@ -252,55 +256,55 @@ void ScSetParameter(INTBIG paramnum, INTBIG addr)
 	switch (paramnum)
 	{
 		case SC_PARAM_MAKE_HORIZ_ARC:
-			setval((INTBIG)sc_tool, VTOOL, "SC_horiz_arc", addr, VARCPROTO);
+			setval((INTBIG)sc_tool, VTOOL, x_("SC_horiz_arc"), addr, VARCPROTO);
 			break;
 		case SC_PARAM_MAKE_VERT_ARC:
-			setval((INTBIG)sc_tool, VTOOL, "SC_vert_arc", addr, VARCPROTO);
+			setval((INTBIG)sc_tool, VTOOL, x_("SC_vert_arc"), addr, VARCPROTO);
 			break;
 		case SC_PARAM_MAKE_L1_WIDTH:
-			setval((INTBIG)sc_tool, VTOOL, "SC_l1_width", addr, VINTEGER);
+			setval((INTBIG)sc_tool, VTOOL, x_("SC_l1_width"), addr, VINTEGER);
 			break;
 		case SC_PARAM_MAKE_L2_WIDTH:
-			setval((INTBIG)sc_tool, VTOOL, "SC_l2_width", addr, VINTEGER);
+			setval((INTBIG)sc_tool, VTOOL, x_("SC_l2_width"), addr, VINTEGER);
 			break;
 		case SC_PARAM_MAKE_PWR_WIDTH:
-			setval((INTBIG)sc_tool, VTOOL, "SC_pwr_width", addr, VINTEGER);
+			setval((INTBIG)sc_tool, VTOOL, x_("SC_pwr_width"), addr, VINTEGER);
 			break;
 		case SC_PARAM_MAKE_MAIN_PWR_WIDTH:
-			setval((INTBIG)sc_tool, VTOOL, "SC_main_pwr_width", addr, VINTEGER);
+			setval((INTBIG)sc_tool, VTOOL, x_("SC_main_pwr_width"), addr, VINTEGER);
 			break;
 		case SC_PARAM_MAKE_MAIN_PWR_RAIL:
-			setval((INTBIG)sc_tool, VTOOL, "SC_main_pwr_rail", addr, VINTEGER);
+			setval((INTBIG)sc_tool, VTOOL, x_("SC_main_pwr_rail"), addr, VINTEGER);
 			break;
 		case SC_PARAM_MAKE_PWELL_SIZE:
-			setval((INTBIG)sc_tool, VTOOL, "SC_pwell_size", addr, VINTEGER);
+			setval((INTBIG)sc_tool, VTOOL, x_("SC_pwell_size"), addr, VINTEGER);
 			break;
 		case SC_PARAM_MAKE_PWELL_OFFSET:
-			setval((INTBIG)sc_tool, VTOOL, "SC_pwell_offset", addr, VINTEGER);
+			setval((INTBIG)sc_tool, VTOOL, x_("SC_pwell_offset"), addr, VINTEGER);
 			break;
 		case SC_PARAM_MAKE_NWELL_SIZE:
-			setval((INTBIG)sc_tool, VTOOL, "SC_nwell_size", addr, VINTEGER);
+			setval((INTBIG)sc_tool, VTOOL, x_("SC_nwell_size"), addr, VINTEGER);
 			break;
 		case SC_PARAM_MAKE_NWELL_OFFSET:
-			setval((INTBIG)sc_tool, VTOOL, "SC_nwell_offset", addr, VINTEGER);
+			setval((INTBIG)sc_tool, VTOOL, x_("SC_nwell_offset"), addr, VINTEGER);
 			break;
 		case SC_PARAM_MAKE_VIA_SIZE:
-			setval((INTBIG)sc_tool, VTOOL, "SC_via_size", addr, VINTEGER);
+			setval((INTBIG)sc_tool, VTOOL, x_("SC_via_size"), addr, VINTEGER);
 			break;
 		case SC_PARAM_MAKE_MIN_SPACING:
-			setval((INTBIG)sc_tool, VTOOL, "SC_min_spacing", addr, VINTEGER);
+			setval((INTBIG)sc_tool, VTOOL, x_("SC_min_spacing"), addr, VINTEGER);
 			break;
 		case SC_PARAM_ROUTE_FEEDTHRU_SIZE:
-			setval((INTBIG)sc_tool, VTOOL, "SC_feedthru_size", addr, VINTEGER);
+			setval((INTBIG)sc_tool, VTOOL, x_("SC_feedthru_size"), addr, VINTEGER);
 			break;
 		case SC_PARAM_ROUTE_PORT_X_MIN_DIST:
-			setval((INTBIG)sc_tool, VTOOL, "SC_port_x_min_dist", addr, VINTEGER);
+			setval((INTBIG)sc_tool, VTOOL, x_("SC_port_x_min_dist"), addr, VINTEGER);
 			break;
 		case SC_PARAM_ROUTE_ACTIVE_DIST:
-			setval((INTBIG)sc_tool, VTOOL, "SC_active_dist", addr, VINTEGER);
+			setval((INTBIG)sc_tool, VTOOL, x_("SC_active_dist"), addr, VINTEGER);
 			break;
 		case SC_PARAM_PLACE_NUM_ROWS:
-			setval((INTBIG)sc_tool, VTOOL, "SC_num_rows", addr, VINTEGER);
+			setval((INTBIG)sc_tool, VTOOL, x_("SC_num_rows"), addr, VINTEGER);
 			break;
 	}
 }
@@ -329,7 +333,7 @@ leaffacet	*char		Generic pointer to found facet,
 ------------------------------------------------------------------------
 */
 
-char  *Sc_find_leaf_facet(char *name)
+CHAR  *Sc_find_leaf_facet(CHAR *name)
 {
 	NODEPROTO *np, *laynp;
 	REGISTER void *infstr;
@@ -340,18 +344,18 @@ char  *Sc_find_leaf_facet(char *name)
 		infstr = initinfstr();
 		if (sc_celllibrary != NOLIBRARY)
 		{
-			formatinfstr(infstr, "%s:%s", sc_celllibrary->libname, name);
+			formatinfstr(infstr, x_("%s:%s"), sc_celllibrary->libname, name);
 		} else
 		{
-			formatinfstr(infstr, "%s", name);
+			formatinfstr(infstr, x_("%s"), name);
 		}
 		np = getnodeproto(returninfstr(infstr));
-		if (np == NONODEPROTO) return((char *)NULL);
+		if (np == NONODEPROTO) return((CHAR *)NULL);
 	}
 	laynp = layoutview(np);
 	if (laynp != NONODEPROTO) np = laynp;
-	if (np->primindex == 0) return((char *)np);
-	return((char *)NULL);
+	if (np->primindex == 0) return((CHAR *)np);
+	return((CHAR *)NULL);
 }
 
 /***********************************************************************
@@ -369,7 +373,7 @@ leaffacetname	*char		String of leaf facet name.
 ------------------------------------------------------------------------
 */
 
-char  *Sc_leaf_facet_name(char *leaffacet)
+CHAR  *Sc_leaf_facet_name(CHAR *leaffacet)
 {
 	NODEPROTO *np;
 
@@ -394,11 +398,11 @@ leaffacet	*char		Pointer to the first leaf facet, NULL if
 ------------------------------------------------------------------------
 */
 
-char  *Sc_first_leaf_facet(void)
+CHAR  *Sc_first_leaf_facet(void)
 {
-	if (el_curlib == NOLIBRARY) return((char *)NULL);
-	if (el_curlib->firstnodeproto == NONODEPROTO) return((char *)NULL);
-	return((char *)el_curlib->firstnodeproto);
+	if (el_curlib == NOLIBRARY) return((CHAR *)NULL);
+	if (el_curlib->firstnodeproto == NONODEPROTO) return((CHAR *)NULL);
+	return((CHAR *)el_curlib->firstnodeproto);
 }
 
 /***********************************************************************
@@ -417,11 +421,11 @@ nextleaffacet	*char		Returned pointer to next leaf facet.
 ------------------------------------------------------------------------
 */
 
-char  *Sc_next_leaf_facet(char *leaffacet)
+CHAR  *Sc_next_leaf_facet(CHAR *leaffacet)
 {
 	if (((NODEPROTO *)leaffacet)->nextnodeproto == NONODEPROTO)
-		return((char *)NULL);
-	return((char *)(((NODEPROTO *)leaffacet)->nextnodeproto));
+		return((CHAR *)NULL);
+	return((CHAR *)(((NODEPROTO *)leaffacet)->nextnodeproto));
 }
 
 /***********************************************************************
@@ -440,7 +444,7 @@ bits		int			Value of the SC bit field.
 ------------------------------------------------------------------------
 */
 
-int Sc_leaf_facet_bits(char *leaffacet)
+int Sc_leaf_facet_bits(CHAR *leaffacet)
 {
 	VARIABLE	*var;
 
@@ -471,7 +475,7 @@ bits_addr	*int		Address of the SC bits field.
 ------------------------------------------------------------------------
 */
 
-int  *Sc_leaf_facet_bits_address(char *leaffacet)
+int  *Sc_leaf_facet_bits_address(CHAR *leaffacet)
 {
 	VARIABLE	*var;
 	static int retval;
@@ -508,7 +512,7 @@ xsize		int			Returned size in x direction.
 ------------------------------------------------------------------------
 */
 
-int Sc_leaf_facet_xsize(char *leaffacet)
+int Sc_leaf_facet_xsize(CHAR *leaffacet)
 {
 	return(((NODEPROTO *)leaffacet)->highx - ((NODEPROTO *)leaffacet)->lowx);
 }
@@ -528,7 +532,7 @@ xsize		int			Returned size in y direction.
 ------------------------------------------------------------------------
 */
 
-int Sc_leaf_facet_ysize(char *leaffacet)
+int Sc_leaf_facet_ysize(CHAR *leaffacet)
 {
 	return(((NODEPROTO *)leaffacet)->highy - ((NODEPROTO *)leaffacet)->lowy);
 }
@@ -551,10 +555,10 @@ simlist		**char		Array of pointers to simulation info,
 ------------------------------------------------------------------------
 */
 
-char  **Sc_leaf_facet_sim_info(char *leaffacet)
+CHAR  **Sc_leaf_facet_sim_info(CHAR *leaffacet)
 {
 	VARIABLE	*simvar;
-	char	**simlist, **simlist2;
+	CHAR	**simlist, **simlist2;
 	int		i, numsim, use_key;
 
 	if (sc_sim_format == SC_ALS_FORMAT)
@@ -562,16 +566,16 @@ char  **Sc_leaf_facet_sim_info(char *leaffacet)
 	else if (sc_sim_format == SC_SILOS_FORMAT)
 		use_key = sc_silkey;
 	if ((simvar = getvalkey((INTBIG)leaffacet, VNODEPROTO, VSTRING | VISARRAY,
-		use_key)) == NOVARIABLE) return((char **)NULL);
-	simlist2 = (char **)simvar->addr;
+		use_key)) == NOVARIABLE) return((CHAR **)NULL);
+	simlist2 = (CHAR **)simvar->addr;
 
 	/* count the number of simulation lines */
 	numsim = 0;
 	for (i = 0; simlist2[i] != NOSTRING; i++) numsim++;
 
 	/* create array of pointers */
-	if ((simlist = (char **)emalloc(sizeof(char *)*(numsim+1),sc_tool->cluster))
-		== 0) return((char **)NULL);
+	if ((simlist = (CHAR **)emalloc(sizeof(CHAR *)*(numsim+1),sc_tool->cluster))
+		== 0) return((CHAR **)NULL);
 	for (i = 0; i < numsim; i++) simlist[i] = simlist2[i];
 	simlist[numsim] = NULL;
 	return(simlist);
@@ -593,9 +597,9 @@ err			int			Returned error code, 0 = no error.
 ------------------------------------------------------------------------
 */
 
-int Sc_leaf_facet_set_sim(SCSIM *simline, char *leaffacet)
+int Sc_leaf_facet_set_sim(SCSIM *simline, CHAR *leaffacet)
 {
-	char	**simlist;
+	CHAR	**simlist;
 	SCSIM	*nextsim;
 	int		i, numsim, use_key;
 
@@ -608,7 +612,7 @@ int Sc_leaf_facet_set_sim(SCSIM *simline, char *leaffacet)
 	for (nextsim = simline; nextsim; nextsim = nextsim->next) numsim++;
 
 	/* create array of pointers */
-	if ((simlist = (char **)emalloc(sizeof(char *)*(numsim+1),sc_tool->cluster)) == 0)
+	if ((simlist = (CHAR **)emalloc(sizeof(CHAR *)*(numsim+1),sc_tool->cluster)) == 0)
 		return(Sc_seterrmsg(SC_NOMEMORY));
 	for (i = 0; i < numsim; i++)
 	{
@@ -638,7 +642,7 @@ nums		*SCCELLNUMS	Address of structure to fill.
 ------------------------------------------------------------------------
 */
 
-void Sc_leaf_facet_get_nums(char *leaffacet, SCCELLNUMS *nums)
+void Sc_leaf_facet_get_nums(CHAR *leaffacet, SCCELLNUMS *nums)
 {
 	VARIABLE	*var;
 	int		i, j, *iarray, *jarray;
@@ -675,7 +679,7 @@ err			int			Returned error code, 0 = no error.
 ------------------------------------------------------------------------
 */
 
-int Sc_leaf_facet_set_nums(char *leaffacet, SCCELLNUMS *nums)
+int Sc_leaf_facet_set_nums(CHAR *leaffacet, SCCELLNUMS *nums)
 {
 	VARIABLE	*var;
 	int		i, j, *iarray;
@@ -721,7 +725,7 @@ leafport	*char		Generic pointer to first port,
 ------------------------------------------------------------------------
 */
 
-char  *Sc_find_leaf_port(char *leaffacet, char *portname)
+CHAR  *Sc_find_leaf_port(CHAR *leaffacet, CHAR *portname)
 {
 	PORTPROTO	*pp;
 
@@ -729,9 +733,9 @@ char  *Sc_find_leaf_port(char *leaffacet, char *portname)
 		pp = pp->nextportproto)
 	{
 		if (namesame(pp->protoname, portname) == 0)
-			return((char *)pp);
+			return((CHAR *)pp);
 	}
-	return((char *)NULL);
+	return((CHAR *)NULL);
 }
 
 /***********************************************************************
@@ -749,7 +753,7 @@ portname	*char		String of port name.
 ------------------------------------------------------------------------
 */
 
-char  *Sc_leaf_port_name(char *leafport)
+CHAR  *Sc_leaf_port_name(CHAR *leafport)
 {
 	return(((PORTPROTO *)leafport)->protoname);
 }
@@ -771,13 +775,13 @@ leafport	*char		Generic pointer to first port,
 ------------------------------------------------------------------------
 */
 
-char  *Sc_first_leaf_port(char *leaffacet)
+CHAR  *Sc_first_leaf_port(CHAR *leaffacet)
 {
 	PORTPROTO	*pp;
 
 	pp = ((NODEPROTO *)leaffacet)->firstportproto;
-	if (pp == NOPORTPROTO) return((char *)NULL);
-	return((char *)pp);
+	if (pp == NOPORTPROTO) return((CHAR *)NULL);
+	return((CHAR *)pp);
 }
 
 /***********************************************************************
@@ -797,13 +801,13 @@ nextport	*char		Generic pointer to next port,
 ------------------------------------------------------------------------
 */
 
-char  *Sc_next_leaf_port(char *curport)
+CHAR  *Sc_next_leaf_port(CHAR *curport)
 {
 	PORTPROTO	*pp;
 
 	pp = ((PORTPROTO *)curport)->nextportproto;
-	if (pp == NOPORTPROTO) return((char *)NULL);
-	return((char *)pp);
+	if (pp == NOPORTPROTO) return((CHAR *)NULL);
+	return((CHAR *)pp);
 }
 
 /***********************************************************************
@@ -821,7 +825,7 @@ bits		int			Value of the bits field.
 ------------------------------------------------------------------------
 */
 
-int Sc_leaf_port_bits(char *leafport)
+int Sc_leaf_port_bits(CHAR *leafport)
 {
 	VARIABLE	*var;
 
@@ -851,7 +855,7 @@ bits_a		*int		Address of the bits field.
 ------------------------------------------------------------------------
 */
 
-int  *Sc_leaf_port_bits_address(char *leafport)
+int  *Sc_leaf_port_bits_address(CHAR *leafport)
 {
 	VARIABLE	*var;
 	static int retval;
@@ -888,7 +892,7 @@ type		int			Returned type.
 ------------------------------------------------------------------------
 */
 
-int Sc_leaf_port_type(char *leafport)
+int Sc_leaf_port_type(CHAR *leafport)
 {
 	if (portispower((PORTPROTO *)leafport)) return(SCPWRPORT);
 	if (portisground((PORTPROTO *)leafport)) return(SCGNDPORT);
@@ -960,7 +964,7 @@ direct		int			Returned direction for attaching.
 ------------------------------------------------------------------------
 */
 
-int Sc_leaf_port_direction(char *port)
+int Sc_leaf_port_direction(CHAR *port)
 {
 	int		direct, bits;
 
@@ -993,7 +997,7 @@ xpos		int			Returned position from left side of facet.
 ------------------------------------------------------------------------
 */
 
-int Sc_leaf_port_xpos(char *port)
+int Sc_leaf_port_xpos(CHAR *port)
 {
 	INTBIG		x, y;
 
@@ -1022,7 +1026,7 @@ ypos		int			Returned position from bottom of facet.
 ------------------------------------------------------------------------
 */
 
-int Sc_leaf_port_ypos(char *port)
+int Sc_leaf_port_ypos(CHAR *port)
 {
 	INTBIG		x, y;
 
@@ -1051,7 +1055,7 @@ leafport	*char		Pointer to leaf port.
 ------------------------------------------------------------------------
 */
 
-void Sc_leaf_port_set_first(char *leaffacet, char *leafport)
+void Sc_leaf_port_set_first(CHAR *leaffacet, CHAR *leafport)
 {
 	((NODEPROTO *)leaffacet)->firstportproto = (PORTPROTO *)leafport;
 }
@@ -1072,7 +1076,7 @@ leafport2	*char		Pointer to second leaf port.
 ------------------------------------------------------------------------
 */
 
-void Sc_leaf_port_set_next(char *leafport1, char *leafport2)
+void Sc_leaf_port_set_next(CHAR *leafport1, CHAR *leafport2)
 {
 	if (leafport2 != 0)
 	{
@@ -1098,7 +1102,7 @@ err			int			Returned error code, 0 = no error.
 ------------------------------------------------------------------------
 */
 
-int Sc_library_read(char *libname)
+int Sc_library_read(CHAR *libname)
 {
 	LIBRARY    *lib;
 
@@ -1118,12 +1122,12 @@ int Sc_library_read(char *libname)
 		if (reallocstring(&lib->libfile, libname, lib->cluster))
 			return(Sc_seterrmsg(SC_NOMEMORY));
 	}
-	if (asktool(io_tool, "read", (INTBIG)lib, "binary") != 0)
+	if (asktool(io_tool, x_("read"), (INTBIG)lib, x_("binary")) != 0)
 	{
 		eraselibrary(lib);
 		return(Sc_seterrmsg(SC_LIBNOREAD, libname));
 	}
-	selectlibrary(lib);
+	selectlibrary(lib, TRUE);
 	return(0);
 }
 
@@ -1142,7 +1146,7 @@ err			int			Returned error code, 0 = no error.
 ------------------------------------------------------------------------
 */
 
-int Sc_library_use(char *libname)
+int Sc_library_use(CHAR *libname)
 {
 	LIBRARY    *lib;
 
@@ -1269,28 +1273,28 @@ bfacet		*char		Pointer to created leaf facet.
 ------------------------------------------------------------------------
 */
 
-char  *Sc_create_leaf_facet(char *name)
+CHAR  *Sc_create_leaf_facet(CHAR *name)
 {
 	NODEPROTO	*bfacet;
-	char	*view, layoutname[256];
+	CHAR	*view, layoutname[256];
 
 	/*
 	 * use layoutname because we don't know how
 	 * long "name" is
 	 */
-	(void) strcpy (layoutname, name);
+	(void) estrcpy (layoutname, name);
 
-	if ((view = strchr (layoutname, '{')) == NULL)
-		(void) strcat (layoutname, "{lay}"); else
-			if (strncmp (view, "{lay}", 5) != 0)
+	if ((view = estrchr (layoutname, '{')) == NULL)
+		(void) estrcat (layoutname, x_("{lay}")); else
+			if (estrncmp (view, x_("{lay}"), 5) != 0)
 	{
 		view = '\0';
-		(void) strcat (layoutname, "{lay}");
+		(void) estrcat (layoutname, x_("{lay}"));
 	}
 
 	bfacet = us_newnodeproto(layoutname, el_curlib);
-	if (bfacet == NONODEPROTO) return((char *)NULL);
-	return((char *)bfacet);
+	if (bfacet == NONODEPROTO) return((CHAR *)NULL);
+	return((CHAR *)bfacet);
 }
 
 /***********************************************************************
@@ -1316,15 +1320,15 @@ binst		*char		Pointer to created leaf instance.
 ------------------------------------------------------------------------
 */
 
-char  *Sc_create_leaf_instance(char *name, char *type, int minx, int maxx, int miny,
-	int maxy, int transpose, int rotation, char *parent)
+CHAR  *Sc_create_leaf_instance(CHAR *name, CHAR *type, int minx, int maxx, int miny,
+	int maxy, int transpose, int rotation, CHAR *parent)
 {
 	NODEINST	*binst;
 	REGISTER VARIABLE *var;
 
 	binst = newnodeinst((NODEPROTO *)type, minx, maxx, miny, maxy, transpose,
 		rotation, (NODEPROTO *)parent);
-	if (binst == NONODEINST) return((char *)NULL);
+	if (binst == NONODEINST) return((CHAR *)NULL);
 
 	var = setvalkey((INTBIG)binst, VNODEINST, el_node_name_key, (INTBIG)name, VSTRING|VDISPLAY);
 	if (var == NOVARIABLE)
@@ -1334,7 +1338,7 @@ char  *Sc_create_leaf_instance(char *name, char *type, int minx, int maxx, int m
 	{
 		defaulttextsize(3, var->textdescript);
 	}
-	return((char *)binst);
+	return((CHAR *)binst);
 }
 
 /***********************************************************************
@@ -1357,7 +1361,7 @@ binst		*char		Returned pointer to created instance.
 ------------------------------------------------------------------------
 */
 
-char  *Sc_create_layer1_node(int xpos, int ypos, int xsize, int ysize, char *bfacet)
+CHAR  *Sc_create_layer1_node(int xpos, int ypos, int xsize, int ysize, CHAR *bfacet)
 {
 	NODEINST	*binst;
 	int		lowx, highx, lowy, highy;
@@ -1368,8 +1372,8 @@ char  *Sc_create_layer1_node(int xpos, int ypos, int xsize, int ysize, char *bfa
 	highy = lowy + ysize;
 	binst = newnodeinst(sc_layer1proto, lowx, highx, lowy, highy, 0, 0,
 		(NODEPROTO *)bfacet);
-	if (binst == NONODEINST) return((char *)NULL);
-	return((char *)binst);
+	if (binst == NONODEINST) return((CHAR *)NULL);
+	return((CHAR *)binst);
 }
 
 /***********************************************************************
@@ -1392,7 +1396,7 @@ binst		*char		Returned pointer to created instance.
 ------------------------------------------------------------------------
 */
 
-char  *Sc_create_layer2_node(int xpos, int ypos, int xsize, int ysize, char *bfacet)
+CHAR  *Sc_create_layer2_node(int xpos, int ypos, int xsize, int ysize, CHAR *bfacet)
 {
 	NODEINST	*binst;
 	int		lowx, highx, lowy, highy;
@@ -1403,8 +1407,8 @@ char  *Sc_create_layer2_node(int xpos, int ypos, int xsize, int ysize, char *bfa
 	highy = lowy + ysize;
 	binst = newnodeinst(sc_layer2proto, lowx, highx, lowy, highy, 0, 0,
 		(NODEPROTO *)bfacet);
-	if (binst == NONODEINST) return((char *)NULL);
-	return((char *)binst);
+	if (binst == NONODEINST) return((CHAR *)NULL);
+	return((CHAR *)binst);
 }
 
 /***********************************************************************
@@ -1424,7 +1428,7 @@ binst		*char		Returned pointer to created instance.
 ------------------------------------------------------------------------
 */
 
-char  *Sc_create_via(int xpos, int ypos, char *bfacet)
+CHAR  *Sc_create_via(int xpos, int ypos, CHAR *bfacet)
 {
 	NODEINST	*binst;
 	int		lowx, highx, lowy, highy;
@@ -1437,8 +1441,8 @@ char  *Sc_create_via(int xpos, int ypos, char *bfacet)
 	highy = lowy + pys;
 	binst = newnodeinst(sc_viaproto, lowx, highx, lowy, highy, 0, 0,
 		(NODEPROTO *)bfacet);
-	if (binst == NONODEINST) return((char *)NULL);
-	return((char *)binst);
+	if (binst == NONODEINST) return((CHAR *)NULL);
+	return((CHAR *)binst);
 }
 
 /***********************************************************************
@@ -1460,12 +1464,12 @@ binst		*char		Returned pointer to created instance.
 ------------------------------------------------------------------------
 */
 
-char  *Sc_create_pwell(int xpos, int ypos, int xsize, int ysize, char *bfacet)
+CHAR  *Sc_create_pwell(int xpos, int ypos, int xsize, int ysize, CHAR *bfacet)
 {
 	NODEINST	*binst;
 	int		lowx, highx, lowy, highy;
 
-	if (sc_pwellproto == NONODEPROTO) return((char *)NULL);
+	if (sc_pwellproto == NONODEPROTO) return((CHAR *)NULL);
 
 	lowx = xpos - (xsize >> 1);
 	highx = lowx + xsize;
@@ -1473,8 +1477,8 @@ char  *Sc_create_pwell(int xpos, int ypos, int xsize, int ysize, char *bfacet)
 	highy = lowy + ysize;
 	binst = newnodeinst(sc_pwellproto, lowx, highx, lowy, highy, 0, 0,
 		(NODEPROTO *)bfacet);
-	if (binst == NONODEINST) return((char *)NULL);
-	return((char *)binst);
+	if (binst == NONODEINST) return((CHAR *)NULL);
+	return((CHAR *)binst);
 }
 
 /***********************************************************************
@@ -1497,12 +1501,12 @@ binst		*char		Returned pointer to created instance.
 ------------------------------------------------------------------------
 */
 
-char  *Sc_create_nwell(int xpos, int ypos, int xsize, int ysize, char *bfacet)
+CHAR  *Sc_create_nwell(int xpos, int ypos, int xsize, int ysize, CHAR *bfacet)
 {
 	NODEINST	*binst;
 	int		lowx, highx, lowy, highy;
 
-	if (sc_nwellproto == NONODEPROTO) return((char *)NULL);
+	if (sc_nwellproto == NONODEPROTO) return((CHAR *)NULL);
 
 	lowx = xpos - (xsize >> 1);
 	highx = lowx + xsize;
@@ -1510,8 +1514,8 @@ char  *Sc_create_nwell(int xpos, int ypos, int xsize, int ysize, char *bfacet)
 	highy = lowy + ysize;
 	binst = newnodeinst(sc_nwellproto, lowx, highx, lowy, highy, 0, 0,
 		(NODEPROTO *)bfacet);
-	if (binst == NONODEINST) return((char *)NULL);
-	return((char *)binst);
+	if (binst == NONODEINST) return((CHAR *)NULL);
+	return((CHAR *)binst);
 }
 
 /***********************************************************************
@@ -1537,8 +1541,8 @@ inst		*char		Returned pointer to created track.
 ------------------------------------------------------------------------
 */
 
-char  *Sc_create_track_layer1(char *instA, char *portA, char *instB, char *portB,
-	int width, char *bfacet)
+CHAR  *Sc_create_track_layer1(CHAR *instA, CHAR *portA, CHAR *instB, CHAR *portB,
+	int width, CHAR *bfacet)
 {
 	PORTPROTO *pa, *pb;
 	NODEINST *na, *nb;
@@ -1575,8 +1579,8 @@ char  *Sc_create_track_layer1(char *instA, char *portA, char *instB, char *portB
 
 	inst = newarcinst(sc_layer1arc, width, FIXANG, na, pa, xA, yA,
 		nb, pb, xB, yB, (NODEPROTO *)bfacet);
-	if (inst == NOARCINST) return((char *)NULL);
-	return((char *)inst);
+	if (inst == NOARCINST) return((CHAR *)NULL);
+	return((CHAR *)inst);
 }
 
 /***********************************************************************
@@ -1602,8 +1606,8 @@ inst		*char		Returned pointer to created track.
 ------------------------------------------------------------------------
 */
 
-char  *Sc_create_track_layer2(char *instA, char *portA, char *instB, char *portB,
-	int width, char *bfacet)
+CHAR  *Sc_create_track_layer2(CHAR *instA, CHAR *portA, CHAR *instB, CHAR *portB,
+	int width, CHAR *bfacet)
 {
 	PORTPROTO *pa, *pb;
 	NODEINST *na, *nb;
@@ -1640,8 +1644,8 @@ char  *Sc_create_track_layer2(char *instA, char *portA, char *instB, char *portB
 
 	inst = newarcinst(sc_layer2arc, width, FIXANG, na, pa, xA, yA,
 		nb, pb, xB, yB, (NODEPROTO *)bfacet);
-	if (inst == NOARCINST) return((char *)NULL);
-	return((char *)inst);
+	if (inst == NOARCINST) return((CHAR *)NULL);
+	return((CHAR *)inst);
 }
 
 void Sc_create_connection(NODEINST **ni, PORTPROTO **pp, INTBIG x, INTBIG y,
@@ -1714,19 +1718,19 @@ xport		*char		Returned pointer to created port.
 ------------------------------------------------------------------------
 */
 
-char  *Sc_create_export_port(char *inst, char *port, char *name, int type, char *bfacet)
+CHAR  *Sc_create_export_port(CHAR *inst, CHAR *port, CHAR *name, int type, CHAR *bfacet)
 {
 	PORTPROTO	*xport;
 
 	/* check if primative */
 	if ((PORTPROTO *)port == NULL)
-		port = (char *)(((NODEINST *)inst)->proto->firstportproto);
+		port = (CHAR *)(((NODEINST *)inst)->proto->firstportproto);
 
 	xport = newportproto((NODEPROTO *)bfacet, (NODEINST *)inst,
 		(PORTPROTO *)port, name);
-	if (xport == NOPORTPROTO) return((char *)NULL);
+	if (xport == NOPORTPROTO) return((CHAR *)NULL);
 	Sc_set_leaf_port_type(xport, type);
-	return((char *)xport);
+	return((CHAR *)xport);
 }
 
 /*
@@ -1744,61 +1748,61 @@ static DIALOGITEM sc_optionsdialogitems[] =
 {
  /*  1 */ {0, {500,268,524,326}, BUTTON, N_("OK")},
  /*  2 */ {0, {500,36,524,94}, BUTTON, N_("Cancel")},
- /*  3 */ {0, {60,208,76,388}, POPUP, ""},
- /*  4 */ {0, {8,208,24,388}, POPUP, ""},
+ /*  3 */ {0, {8,204,24,384}, POPUP, x_("")},
+ /*  4 */ {0, {32,204,48,276}, EDITTEXT, x_("")},
  /*  5 */ {0, {8,8,24,180}, MESSAGE, N_("Horizontal routing arc:")},
  /*  6 */ {0, {60,8,76,180}, MESSAGE, N_("Vertical routing arc:")},
  /*  7 */ {0, {32,8,48,174}, MESSAGE, N_("Horizontal wire width:")},
- /*  8 */ {0, {32,208,48,282}, EDITTEXT, "2.5"},
+ /*  8 */ {0, {60,204,76,384}, POPUP, x_("")},
  /*  9 */ {0, {84,8,100,174}, MESSAGE, N_("Vertical wire width:")},
- /* 10 */ {0, {84,208,100,282}, EDITTEXT, "2.5"},
+ /* 10 */ {0, {84,204,100,276}, EDITTEXT, x_("")},
  /* 11 */ {0, {120,8,136,174}, MESSAGE, N_("Power wire width:")},
- /* 12 */ {0, {120,208,136,282}, EDITTEXT, "2.5"},
+ /* 12 */ {0, {120,204,136,276}, EDITTEXT, x_("")},
  /* 13 */ {0, {144,8,160,174}, MESSAGE, N_("Main power wire width:")},
- /* 14 */ {0, {144,208,160,282}, EDITTEXT, "2.5"},
+ /* 14 */ {0, {144,204,160,276}, EDITTEXT, x_("")},
  /* 15 */ {0, {204,8,220,199}, MESSAGE, N_("P-Well height (0 for none):")},
- /* 16 */ {0, {204,204,220,278}, EDITTEXT, "2.5"},
+ /* 16 */ {0, {168,204,184,352}, POPUP, x_("")},
  /* 17 */ {0, {228,8,244,199}, MESSAGE, N_("P-Well offset from bottom:")},
- /* 18 */ {0, {228,204,244,278}, EDITTEXT, "2.5"},
+ /* 18 */ {0, {204,204,220,276}, EDITTEXT, x_("")},
  /* 19 */ {0, {320,8,336,199}, MESSAGE, N_("Via size:")},
- /* 20 */ {0, {320,204,336,278}, EDITTEXT, "2.5"},
+ /* 20 */ {0, {232,204,248,276}, EDITTEXT, x_("")},
  /* 21 */ {0, {344,8,360,199}, MESSAGE, N_("Minimum metal spacing:")},
- /* 22 */ {0, {344,204,360,278}, EDITTEXT, "2.5"},
+ /* 22 */ {0, {256,204,272,276}, EDITTEXT, x_("")},
  /* 23 */ {0, {384,8,400,199}, MESSAGE, N_("Routing: feed-through size:")},
- /* 24 */ {0, {384,204,400,278}, EDITTEXT, "2.5"},
+ /* 24 */ {0, {280,204,296,276}, EDITTEXT, x_("")},
  /* 25 */ {0, {408,8,424,199}, MESSAGE, N_("Routing: min. port distance:")},
- /* 26 */ {0, {408,204,424,278}, EDITTEXT, "2.5"},
+ /* 26 */ {0, {320,204,336,276}, EDITTEXT, x_("")},
  /* 27 */ {0, {432,8,448,199}, MESSAGE, N_("Routing: min. active dist.:")},
- /* 28 */ {0, {432,204,448,278}, EDITTEXT, "2.5"},
+ /* 28 */ {0, {344,204,360,276}, EDITTEXT, x_("")},
  /* 29 */ {0, {472,8,488,199}, MESSAGE, N_("Number of rows of cells:")},
- /* 30 */ {0, {472,204,488,278}, EDITTEXT, "5"},
- /* 31 */ {0, {168,208,184,356}, POPUP, ""},
+ /* 30 */ {0, {384,204,400,276}, EDITTEXT, x_("")},
+ /* 31 */ {0, {408,204,424,276}, EDITTEXT, x_("")},
  /* 32 */ {0, {168,8,184,180}, MESSAGE, N_("Main power arc:")},
  /* 33 */ {0, {256,8,272,199}, MESSAGE, N_("N-Well height (0 for none):")},
- /* 34 */ {0, {256,204,272,278}, EDITTEXT, "2.5"},
+ /* 34 */ {0, {432,204,448,276}, EDITTEXT, x_("")},
  /* 35 */ {0, {280,8,296,199}, MESSAGE, N_("N-Well offset from top:")},
- /* 36 */ {0, {280,204,296,278}, EDITTEXT, "2.5"}
+ /* 36 */ {0, {472,204,488,276}, EDITTEXT, x_("")}
 };
-static DIALOG sc_optionsdialog = {{50,75,583,472}, N_("Silicon Compiler Options"), 0, 36, sc_optionsdialogitems, 0, 0};
+static DIALOG sc_optionsdialog = {{50,75,583,473}, N_("Silicon Compiler Options"), 0, 36, sc_optionsdialogitems, 0, 0};
 
 /* special items for the "Silicon Compiler Options" dialog: */
-#define DSCO_VERTARCS      3		/* Vertical arc list (popup) */
-#define DSCO_HORIZARCS     4		/* Horizontal arc list (popup) */
-#define DSCO_HORIZWIDTH    8		/* Horizontal arc width (edit text) */
+#define DSCO_HORIZARCS     3		/* Horizontal arc list (popup) */
+#define DSCO_HORIZWIDTH    4		/* Horizontal arc width (edit text) */
+#define DSCO_VERTARCS      8		/* Vertical arc list (popup) */
 #define DSCO_VERTWIDTH    10		/* Vertical arc width (edit text) */
 #define DSCO_POWERWIDTH   12		/* Power arc width (edit text) */
 #define DSCO_MPOWERWIDTH  14		/* Main power arc width (edit text) */
-#define DSCO_PWELLHEIGHT  16		/* P-Well height (edit text) */
-#define DSCO_PWELLOFFSET  18		/* P-Well offset (edit text) */
-#define DSCO_VIASIZE      20		/* Via size (edit text) */
-#define DSCO_MINSPACING   22		/* Minimum spacing (edit text) */
-#define DSCO_FEEDTHRU     24		/* Routing feed-through size (edit text) */
-#define DSCO_PORTDIST     26		/* Routing minimum port dist (edit text) */
-#define DSCO_ACTIVEDIST   28		/* Routing minimum active dist (edit text) */
-#define DSCO_NUMROWS      30		/* Number of rows of cells (edit text) */
-#define DSCO_MPOWERARC    31		/* Main power arc (popup) */
-#define DSCO_NWELLHEIGHT  34		/* N-Well height (edit text) */
-#define DSCO_NWELLOFFSET  36		/* N-Well offset (edit text) */
+#define DSCO_MPOWERARC    16		/* Main power arc (popup) */
+#define DSCO_PWELLHEIGHT  18		/* P-Well height (edit text) */
+#define DSCO_PWELLOFFSET  20		/* P-Well offset (edit text) */
+#define DSCO_NWELLHEIGHT  22		/* N-Well height (edit text) */
+#define DSCO_NWELLOFFSET  24		/* N-Well offset (edit text) */
+#define DSCO_VIASIZE      26		/* Via size (edit text) */
+#define DSCO_MINSPACING   28		/* Minimum spacing (edit text) */
+#define DSCO_FEEDTHRU     30		/* Routing feed-through size (edit text) */
+#define DSCO_PORTDIST     31		/* Routing minimum port dist (edit text) */
+#define DSCO_ACTIVEDIST   34		/* Routing minimum active dist (edit text) */
+#define DSCO_NUMROWS      36		/* Number of rows of cells (edit text) */
 
 void sc_optionsdlog(void)
 {
@@ -1807,9 +1811,9 @@ void sc_optionsdlog(void)
 		viasize, minspacing, feedthrusize, portxmindist, activedist, numrows,
 		mainpwrrail;
 	REGISTER ARCPROTO *ap, *aphoriz, *apvert;
-	char **arcnames, numstring[20], *transnames[2];
+	CHAR **arcnames, numstring[20], *transnames[2];
 	REGISTER void *dia;
-	static char *powerarcnames[2] = {N_("Horizontal Arc"), N_("Vertical Arc")};
+	static CHAR *powerarcnames[2] = {N_("Horizontal Arc"), N_("Vertical Arc")};
 
 	/* get parameters */
 	aphoriz      = (ARCPROTO *)ScGetParameter(SC_PARAM_MAKE_HORIZ_ARC);
@@ -1835,7 +1839,7 @@ void sc_optionsdlog(void)
 	for(ap = el_curtech->firstarcproto; ap != NOARCPROTO; ap = ap->nextarcproto)
 		numarcnames++;
 	numarcnames++;
-	arcnames = (char **)emalloc(numarcnames * (sizeof (char *)), el_tempcluster);
+	arcnames = (CHAR **)emalloc(numarcnames * (sizeof (CHAR *)), el_tempcluster);
 	if (arcnames == 0) return;
 	numarcnames = 0;
 	arcnames[numarcnames++] = _("NOT SELECTED");
@@ -1851,7 +1855,7 @@ void sc_optionsdlog(void)
 	/* display the silicon compiler options dialog box */
 	dia = DiaInitDialog(&sc_optionsdialog);
 	if (dia == 0) return;
-	for(i=0; i<2; i++) transnames[i] = _(powerarcnames[i]);
+	for(i=0; i<2; i++) transnames[i] = TRANSLATE(powerarcnames[i]);
 	DiaSetPopup(dia, DSCO_MPOWERARC, 2, transnames);
 	DiaSetPopup(dia, DSCO_VERTARCS, numarcnames, arcnames);
 	DiaSetPopup(dia, DSCO_HORIZARCS, numarcnames, arcnames);
@@ -1868,7 +1872,7 @@ void sc_optionsdlog(void)
 	DiaSetText(dia, DSCO_FEEDTHRU, latoa(feedthrusize, 0));
 	DiaSetText(dia, DSCO_PORTDIST, latoa(portxmindist, 0));
 	DiaSetText(dia, DSCO_ACTIVEDIST, latoa(activedist, 0));
-	sprintf(numstring, "%ld", numrows);
+	esnprintf(numstring, 20, x_("%ld"), numrows);
 	DiaSetText(dia, DSCO_NUMROWS, numstring);
 	DiaSetPopupEntry(dia, DSCO_MPOWERARC, mainpwrrail);
 	DiaSetText(dia, DSCO_NWELLHEIGHT, latoa(nwellsize, 0));
@@ -1914,7 +1918,7 @@ void sc_optionsdlog(void)
 		if (i != portxmindist) ScSetParameter(SC_PARAM_ROUTE_PORT_X_MIN_DIST, i);
 		i = atola(DiaGetText(dia, DSCO_ACTIVEDIST), 0);
 		if (i != activedist) ScSetParameter(SC_PARAM_ROUTE_ACTIVE_DIST, i);
-		i = atoi(DiaGetText(dia, DSCO_NUMROWS));
+		i = eatoi(DiaGetText(dia, DSCO_NUMROWS));
 		if (i != numrows) ScSetParameter(SC_PARAM_PLACE_NUM_ROWS, i);
 		i = DiaGetPopupEntry(dia, DSCO_MPOWERARC);
 		if (i != mainpwrrail) ScSetParameter(SC_PARAM_MAKE_MAIN_PWR_RAIL, i);
@@ -1923,7 +1927,7 @@ void sc_optionsdlog(void)
 		i = atola(DiaGetText(dia, DSCO_NWELLOFFSET), 0);
 		if (i != nwelloffset) ScSetParameter(SC_PARAM_MAKE_NWELL_OFFSET, i);
 	}
-	efree((char *)arcnames);
+	efree((CHAR *)arcnames);
 	DiaDoneDialog(dia);
 }
 
