@@ -40,17 +40,17 @@
 
 /******************** Maker Version Blerb ********************/
 
-static char *sc_makerblerb[] =
+static CHAR *sc_makerblerb[] =
 {
 	M_("*********** QUISC MAKER MODULE - VERSION 1.03"),
-	" ",
+	x_(" "),
 	M_("    o  Determination of final position"),
 	M_("    o  Include squeezing rows in vertical direction"),
 	M_("    o  Squeeze tracks together if nonadjacent via"),
 	M_("    o  Creating ties to power and ground"),
 	M_("    o  Routing Power and Ground buses"),
 	M_("    o  Creation in VLSI Layout Tool's database"),
-	"----------------------------------------------------------",
+	x_("----------------------------------------------------------"),
 	0
 } ;
 
@@ -72,7 +72,7 @@ static int sc_makerverbose = DEFAULT_VERBOSE;
 extern SCCELL		*sc_curcell;
 
 /* prototypes for local routines */
-static int  Sc_maker_set_control(int, char*[]);
+static int  Sc_maker_set_control(int, CHAR*[]);
 static void Sc_maker_show_control(void);
 static int  Sc_maker_create_info(SCCELL*);
 static int  Sc_maker_set_up(SCCELL*, SCMAKERDATA**);
@@ -95,7 +95,7 @@ err			int			Returned error code, 0 = no error.
 ------------------------------------------------------------------------
 */
 
-int Sc_maker(int count, char *pars[])
+int Sc_maker(int count, CHAR *pars[])
 {
 	int i, err, l;
 	SCMAKERDATA *make_data;
@@ -103,16 +103,16 @@ int Sc_maker(int count, char *pars[])
 	/* parameter check */
 	if (count)
 	{
-		l = strlen(pars[0]);
+		l = estrlen(pars[0]);
 		l = maxi(l, 2);
-		if (namesamen(pars[0], "set-control", l) == 0)
+		if (namesamen(pars[0], x_("set-control"), l) == 0)
 			return(Sc_maker_set_control(count - 1, &pars[1]));
-		if (namesamen(pars[0], "show-control", l) == 0)
+		if (namesamen(pars[0], x_("show-control"), l) == 0)
 		{
 			Sc_maker_show_control();
 			return(SC_NOERROR);
 		}
-		if (namesamen(pars[0], "information", l) == 0)
+		if (namesamen(pars[0], x_("information"), l) == 0)
 		{
 			/* EMPTY */ 
 		} else
@@ -122,7 +122,7 @@ int Sc_maker(int count, char *pars[])
 	}
 
 	for (i = 0; sc_makerblerb[i]; i++)
-		ttyputverbose(_(sc_makerblerb[i]));
+		ttyputverbose(TRANSLATE(sc_makerblerb[i]));
 
 	/* check if working in a cell */
 	if (sc_curcell == NULL)
@@ -181,7 +181,7 @@ err			int			Returned error code, 0 = no error.
 ------------------------------------------------------------------------
 */
 
-int Sc_maker_set_control(int count, char *pars[])
+int Sc_maker_set_control(int count, CHAR *pars[])
 {
 	int numcmd, l, n;
 	REGISTER ARCPROTO *ap;
@@ -190,61 +190,61 @@ int Sc_maker_set_control(int count, char *pars[])
 	{
 		for (numcmd = 0; numcmd < count; numcmd++)
 		{
-			l = strlen(pars[numcmd]);
+			l = estrlen(pars[numcmd]);
 			n = maxi(l, 2);
-			if (namesamen(pars[numcmd], "verbose", n) == 0)
+			if (namesamen(pars[numcmd], x_("verbose"), n) == 0)
 			{
 				sc_makerverbose = TRUE;
 				continue;
 			}
-			if (namesamen(pars[numcmd], "l2-track-width", n) == 0)
+			if (namesamen(pars[numcmd], x_("l2-track-width"), n) == 0)
 			{
 				if (++numcmd < count)
-					ScSetParameter(SC_PARAM_MAKE_L2_WIDTH, atoi(pars[numcmd]));
+					ScSetParameter(SC_PARAM_MAKE_L2_WIDTH, eatoi(pars[numcmd]));
 				continue;
 			}
-			if (namesamen(pars[numcmd], "l1-track-width", n) == 0)
+			if (namesamen(pars[numcmd], x_("l1-track-width"), n) == 0)
 			{
 				if (++numcmd < count)
-					ScSetParameter(SC_PARAM_MAKE_L1_WIDTH, atoi(pars[numcmd]));
+					ScSetParameter(SC_PARAM_MAKE_L1_WIDTH, eatoi(pars[numcmd]));
 				continue;
 			}
-			if (namesamen(pars[numcmd], "power-track-width", n) == 0)
+			if (namesamen(pars[numcmd], x_("power-track-width"), n) == 0)
 			{
 				if (++numcmd < count)
-					ScSetParameter(SC_PARAM_MAKE_PWR_WIDTH, atoi(pars[numcmd]));
+					ScSetParameter(SC_PARAM_MAKE_PWR_WIDTH, eatoi(pars[numcmd]));
 				continue;
 			}
-			if (namesamen(pars[numcmd], "main-power-width", n) == 0)
+			if (namesamen(pars[numcmd], x_("main-power-width"), n) == 0)
 			{
 				if (++numcmd < count)
-					ScSetParameter(SC_PARAM_MAKE_MAIN_PWR_WIDTH, atoi(pars[numcmd]));
+					ScSetParameter(SC_PARAM_MAKE_MAIN_PWR_WIDTH, eatoi(pars[numcmd]));
 				continue;
 			}
-			if (namesamen(pars[numcmd], "main-power-rail", n) == 0)
+			if (namesamen(pars[numcmd], x_("main-power-rail"), n) == 0)
 			{
 				if (++numcmd < count)
 				{
-					if (namesame(pars[numcmd], "horizontal") == 0)
+					if (namesame(pars[numcmd], x_("horizontal")) == 0)
 						ScSetParameter(SC_PARAM_MAKE_MAIN_PWR_RAIL, 0);
-					if (namesame(pars[numcmd], "vertical") == 0)
+					if (namesame(pars[numcmd], x_("vertical")) == 0)
 						ScSetParameter(SC_PARAM_MAKE_MAIN_PWR_RAIL, 1);
 				}
 				continue;
 			}
-			if (namesamen(pars[numcmd], "via-size", n) == 0)
+			if (namesamen(pars[numcmd], x_("via-size"), n) == 0)
 			{
 				if (++numcmd < count)
-					ScSetParameter(SC_PARAM_MAKE_VIA_SIZE, atoi(pars[numcmd]));
+					ScSetParameter(SC_PARAM_MAKE_VIA_SIZE, eatoi(pars[numcmd]));
 				continue;
 			}
-			if (namesamen(pars[numcmd], "min-spacing", n) == 0)
+			if (namesamen(pars[numcmd], x_("min-spacing"), n) == 0)
 			{
 				if (++numcmd < count)
-					ScSetParameter(SC_PARAM_MAKE_MIN_SPACING, atoi(pars[numcmd]));
+					ScSetParameter(SC_PARAM_MAKE_MIN_SPACING, eatoi(pars[numcmd]));
 				continue;
 			}
-			if (namesamen(pars[numcmd], "default", n) == 0)
+			if (namesamen(pars[numcmd], x_("default"), n) == 0)
 			{
 				sc_makerverbose = DEFAULT_VERBOSE;
 				ScSetParameter(SC_PARAM_MAKE_MIN_SPACING, DEFAULT_MIN_SPACING);
@@ -263,12 +263,12 @@ int Sc_maker_set_control(int count, char *pars[])
 				continue;
 			}
 			n = maxi(l, 5);
-			if (namesamen(pars[numcmd], "no-verbose", n) == 0)
+			if (namesamen(pars[numcmd], x_("no-verbose"), n) == 0)
 			{
 				sc_makerverbose = FALSE;
 				continue;
 			}
-			if (namesamen(pars[numcmd], "arc-vertical", n) == 0)
+			if (namesamen(pars[numcmd], x_("arc-vertical"), n) == 0)
 			{
 				if (++numcmd < count)
 				{
@@ -277,7 +277,7 @@ int Sc_maker_set_control(int count, char *pars[])
 				}
 				continue;
 			}
-			if (namesamen(pars[numcmd], "arc-horizontal", n) == 0)
+			if (namesamen(pars[numcmd], x_("arc-horizontal"), n) == 0)
 			{
 				if (++numcmd < count)
 				{
@@ -287,28 +287,28 @@ int Sc_maker_set_control(int count, char *pars[])
 				continue;
 			}
 			n = maxi(l, 8);
-			if (namesamen(pars[numcmd], "p-well-size", n) == 0)
+			if (namesamen(pars[numcmd], x_("p-well-size"), n) == 0)
 			{
 				if (++numcmd < count)
-					ScSetParameter(SC_PARAM_MAKE_PWELL_SIZE, atoi(pars[numcmd]));
+					ScSetParameter(SC_PARAM_MAKE_PWELL_SIZE, eatoi(pars[numcmd]));
 				continue;
 			}
-			if (namesamen(pars[numcmd], "p-well-offset", n) == 0)
+			if (namesamen(pars[numcmd], x_("p-well-offset"), n) == 0)
 			{
 				if (++numcmd < count)
-					ScSetParameter(SC_PARAM_MAKE_PWELL_OFFSET, atoi(pars[numcmd]));
+					ScSetParameter(SC_PARAM_MAKE_PWELL_OFFSET, eatoi(pars[numcmd]));
 				continue;
 			}
-			if (namesamen(pars[numcmd], "n-well-size", n) == 0)
+			if (namesamen(pars[numcmd], x_("n-well-size"), n) == 0)
 			{
 				if (++numcmd < count)
-					ScSetParameter(SC_PARAM_MAKE_NWELL_SIZE, atoi(pars[numcmd]));
+					ScSetParameter(SC_PARAM_MAKE_NWELL_SIZE, eatoi(pars[numcmd]));
 				continue;
 			}
-			if (namesamen(pars[numcmd], "n-well-offset", n) == 0)
+			if (namesamen(pars[numcmd], x_("n-well-offset"), n) == 0)
 			{
 				if (++numcmd < count)
-					ScSetParameter(SC_PARAM_MAKE_NWELL_OFFSET, atoi(pars[numcmd]));
+					ScSetParameter(SC_PARAM_MAKE_NWELL_OFFSET, eatoi(pars[numcmd]));
 				continue;
 			}
 			return(Sc_seterrmsg(SC_MAKE_SET_XCMD, pars[numcmd]));
@@ -332,8 +332,8 @@ Calling Sequence:  Sc_maker_show_control();
 
 void Sc_maker_show_control(void)
 {
-	char *str1;
-	static char *hv[3] = {N_("Horizontal"), N_("Vertical")};
+	CHAR *str1;
+	static CHAR *hv[3] = {N_("Horizontal"), N_("Vertical")};
 
 	ttyputmsg(M_("************ MAKER CONTROL STRUCTURE"));
 	if (sc_makerverbose) str1 = M_("TRUE"); else
@@ -491,7 +491,7 @@ int Sc_maker_create_info(SCCELL *cell)
 	ttyputmsg(M_("    Total Track Length =  %d  (microns)"),
 		info->track_length / 2000);
 
-	efree((char *)info);
+	efree((CHAR *)info);
 	return(SC_NOERROR);
 }
 
@@ -875,7 +875,7 @@ int Sc_maker_set_up(SCCELL *cell, SCMAKERDATA **make_data)
 			}
 			minst->instance = NULL;
 			minst->flags = 0;
-			place->cell->tp = (char *)minst;
+			place->cell->tp = (CHAR *)minst;
 			minst->next = NULL;
 			if (last_minst)
 			{
@@ -994,7 +994,7 @@ data		*SCMAKERDATA	Pointer to layout data.
 
 int Sc_maker_create_layout(SCMAKERDATA *data)
 {
-	char			*bcell, *binst, *inst1, *inst2, *port1, *port2;
+	CHAR			*bcell, *binst, *inst1, *inst2, *port1, *port2;
 	SCMAKERROW		*row;
 	SCMAKERINST		*inst, *lastpower, *lastground;
 	SCMAKERINST		*firstinst, *previnst;
@@ -1098,7 +1098,7 @@ int Sc_maker_create_layout(SCMAKERDATA *data)
 						inst = (SCMAKERINST *)via->chport->port->place->cell->tp;
 						if (Sc_create_track_layer1(inst->instance,
 							via->chport->port->port->port,
-							via->instance, (char *)NULL,
+							via->instance, (CHAR *)NULL,
 							ScGetParameter(SC_PARAM_MAKE_L1_WIDTH),
 							bcell) == NULL)
 						{
@@ -1151,7 +1151,7 @@ int Sc_maker_create_layout(SCMAKERDATA *data)
 						inst = (SCMAKERINST *)node->tp;
 						if (Sc_create_track_layer2(inst->instance,
 							via->chport->port->port->port,
-							via->instance, (char *)NULL,
+							via->instance, (CHAR *)NULL,
 							ScGetParameter(SC_PARAM_MAKE_L2_WIDTH), bcell) == NULL)
 						{
 							return(Sc_seterrmsg(SC_MAKER_NOCREATE_LAYER2));
@@ -1161,7 +1161,7 @@ int Sc_maker_create_layout(SCMAKERDATA *data)
 					{
 						inst = (SCMAKERINST *)node->tp;
 						if (Sc_create_track_layer2(inst->instance,
-							(char *)NULL, via->instance, (char *)NULL,
+							(CHAR *)NULL, via->instance, (CHAR *)NULL,
 							ScGetParameter(SC_PARAM_MAKE_L2_WIDTH), bcell) == NULL)
 						{
 							return(Sc_seterrmsg(SC_MAKER_NOCREATE_LAYER2));
@@ -1188,8 +1188,8 @@ int Sc_maker_create_layout(SCMAKERDATA *data)
 							if (abs(via->next->xpos - via->xpos) < track_to_track)
 							{
 								if (Sc_create_track_layer2(via->instance,
-									(char *)NULL, via->next->instance,
-									(char *)NULL, ScGetParameter(SC_PARAM_MAKE_L2_WIDTH),
+									(CHAR *)NULL, via->next->instance,
+									(CHAR *)NULL, ScGetParameter(SC_PARAM_MAKE_L2_WIDTH),
 									bcell) == NULL)
 								{
 									return(Sc_seterrmsg
@@ -1204,8 +1204,8 @@ int Sc_maker_create_layout(SCMAKERDATA *data)
 								track_to_track)
 							{
 								if (Sc_create_track_layer2(via->instance,
-									(char *)NULL, via->next->instance,
-									(char *)NULL, ScGetParameter(SC_PARAM_MAKE_L2_WIDTH),
+									(CHAR *)NULL, via->next->instance,
+									(CHAR *)NULL, ScGetParameter(SC_PARAM_MAKE_L2_WIDTH),
 									bcell) == NULL)
 								{
 									return(Sc_seterrmsg
@@ -1216,7 +1216,7 @@ int Sc_maker_create_layout(SCMAKERDATA *data)
 							{
 								if (via2->flags & SCVIASPECIAL) continue;
 								if (Sc_create_track_layer1(via->instance,
-									(char *)NULL, via2->instance, (char *)NULL,
+									(CHAR *)NULL, via2->instance, (CHAR *)NULL,
 									ScGetParameter(SC_PARAM_MAKE_L1_WIDTH), bcell)
 									== NULL)
 								{
@@ -1260,7 +1260,7 @@ int Sc_maker_create_layout(SCMAKERDATA *data)
 				port1 = rport->port->port;
 				inst = (SCMAKERINST *)place->cell->tp;
 				inst2 = inst->instance;
-				if (Sc_create_track_layer1(inst1, port1, inst2, (char *)NULL,
+				if (Sc_create_track_layer1(inst1, port1, inst2, (CHAR *)NULL,
 					ScGetParameter(SC_PARAM_MAKE_L1_WIDTH), bcell) == NULL)
 				{
 					return(Sc_seterrmsg(SC_MAKER_NOCREATE_LAYER2));
@@ -1280,7 +1280,7 @@ int Sc_maker_create_layout(SCMAKERDATA *data)
 				{
 					if (via->flags & SCVIAEXPORT)
 					{
-						if (Sc_create_export_port(via->instance, (char *)NULL,
+						if (Sc_create_export_port(via->instance, (CHAR *)NULL,
 							via->xport->xport->name, via->xport->xport->bits
 							& SCPORTTYPE, bcell) == NULL)
 						{
@@ -1323,16 +1323,16 @@ int Sc_maker_create_layout(SCMAKERDATA *data)
 			/* join to previous */
 			if (mainpwrrail == 0)
 			{
-				if (Sc_create_track_layer1(binst, (char *)NULL,
-					(char *)lastpower, (char *)NULL,
+				if (Sc_create_track_layer1(binst, (CHAR *)NULL,
+					(CHAR *)lastpower, (CHAR *)NULL,
 					ScGetParameter(SC_PARAM_MAKE_MAIN_PWR_WIDTH), bcell) == NULL)
 				{
 					return(Sc_seterrmsg(SC_MAKER_NOCREATE_LAYER1));
 				}
 			} else
 			{
-				if (Sc_create_track_layer2(binst, (char *)NULL,
-					(char *)lastpower, (char *)NULL,
+				if (Sc_create_track_layer2(binst, (CHAR *)NULL,
+					(CHAR *)lastpower, (CHAR *)NULL,
 					ScGetParameter(SC_PARAM_MAKE_MAIN_PWR_WIDTH), bcell) == NULL)
 				{
 					return(Sc_seterrmsg(SC_MAKER_NOCREATE_LAYER1));
@@ -1346,7 +1346,7 @@ int Sc_maker_create_layout(SCMAKERDATA *data)
 			if (pport->last == NULL)
 			{
 				/* connect to main power node */
-				if (Sc_create_track_layer1((char *)lastpower, (char *)NULL,
+				if (Sc_create_track_layer1((CHAR *)lastpower, (CHAR *)NULL,
 					pport->inst->instance, pport->port->port,
 					ScGetParameter(SC_PARAM_MAKE_PWR_WIDTH), bcell) == NULL)
 				{
@@ -1396,16 +1396,16 @@ int Sc_maker_create_layout(SCMAKERDATA *data)
 			/* join to previous */
 			if (mainpwrrail == 0)
 			{
-				if (Sc_create_track_layer1(binst, (char *)NULL,
-					(char *)lastground, (char *)NULL,
+				if (Sc_create_track_layer1(binst, (CHAR *)NULL,
+					(CHAR *)lastground, (CHAR *)NULL,
 					ScGetParameter(SC_PARAM_MAKE_MAIN_PWR_WIDTH), bcell) == NULL)
 				{
 					return(Sc_seterrmsg(SC_MAKER_NOCREATE_LAYER1));
 				}
 			} else
 			{
-				if (Sc_create_track_layer2(binst, (char *)NULL,
-					(char *)lastground, (char *)NULL,
+				if (Sc_create_track_layer2(binst, (CHAR *)NULL,
+					(CHAR *)lastground, (CHAR *)NULL,
 					ScGetParameter(SC_PARAM_MAKE_MAIN_PWR_WIDTH), bcell) == NULL)
 				{
 					return(Sc_seterrmsg(SC_MAKER_NOCREATE_LAYER1));
@@ -1413,10 +1413,10 @@ int Sc_maker_create_layout(SCMAKERDATA *data)
 			}
 		} else
 		{
-			if (Sc_create_export_port(binst, (char *)NULL, "gnd", SCGNDPORT,
+			if (Sc_create_export_port(binst, (CHAR *)NULL, x_("gnd"), SCGNDPORT,
 				bcell) == NULL)
 			{
-				return(Sc_seterrmsg(SC_MAKER_NOCREATE_XPORT, "gnd"));
+				return(Sc_seterrmsg(SC_MAKER_NOCREATE_XPORT, x_("gnd")));
 			}
 		}
 		lastground = (SCMAKERINST *)binst;
@@ -1426,7 +1426,7 @@ int Sc_maker_create_layout(SCMAKERDATA *data)
 			if (pport->next == NULL)
 			{
 				/* connect to main ground node */
-				if (Sc_create_track_layer1((char *)lastground, (char *)NULL,
+				if (Sc_create_track_layer1((CHAR *)lastground, (CHAR *)NULL,
 					pport->inst->instance, pport->port->port,
 					ScGetParameter(SC_PARAM_MAKE_PWR_WIDTH), bcell) == NULL)
 				{
@@ -1449,10 +1449,10 @@ int Sc_maker_create_layout(SCMAKERDATA *data)
 	if (lastpower)
 	{
 		/* export as cell vdd */
-		if (Sc_create_export_port((char *)lastpower, (char *)NULL, "vdd",
+		if (Sc_create_export_port((CHAR *)lastpower, (CHAR *)NULL, x_("vdd"),
 			SCPWRPORT, bcell) == NULL)
 		{
-			return(Sc_seterrmsg(SC_MAKER_NOCREATE_XPORT, "vdd"));
+			return(Sc_seterrmsg(SC_MAKER_NOCREATE_XPORT, x_("vdd")));
 		}
 	}
 
@@ -1541,9 +1541,9 @@ void Sc_free_maker_data(SCMAKERDATA *data)
 			for (inst = row->members; inst; inst = nextinst)
 			{
 				nextinst = inst->next;
-				efree((char *)inst);
+				efree((CHAR *)inst);
 			}
-			efree((char *)row);
+			efree((CHAR *)row);
 		}
 		for (chan = data->channels; chan; chan = nextchan)
 		{
@@ -1557,13 +1557,13 @@ void Sc_free_maker_data(SCMAKERDATA *data)
 					for (via = node->vias; via; via = nextvia)
 					{
 						nextvia = via->next;
-						efree((char *)via);
+						efree((CHAR *)via);
 					}
-					efree((char *)node);
+					efree((CHAR *)node);
 				}
-				efree((char *)track);
+				efree((CHAR *)track);
 			}
-			efree((char *)chan);
+			efree((CHAR *)chan);
 		}
 		for (power = data->power; power; power = nextpower)
 		{
@@ -1571,9 +1571,9 @@ void Sc_free_maker_data(SCMAKERDATA *data)
 			for (pport = power->ports; pport; pport = nextpport)
 			{
 				nextpport = pport->next;
-				efree((char *)pport);
+				efree((CHAR *)pport);
 			}
-			efree((char *)power);
+			efree((CHAR *)power);
 		}
 		for (power = data->ground; power; power = nextpower)
 		{
@@ -1581,11 +1581,11 @@ void Sc_free_maker_data(SCMAKERDATA *data)
 			for (pport = power->ports; pport; pport = nextpport)
 			{
 				nextpport = pport->next;
-				efree((char *)pport);
+				efree((CHAR *)pport);
 			}
-			efree((char *)power);
+			efree((CHAR *)power);
 		}
-		efree((char *)data);
+		efree((CHAR *)data);
 	}
 }
 
