@@ -39,7 +39,7 @@
 
 /***** blerbs for showing what placement algorithms is used *****/
 
-static char *sc_placeblerb[] =
+static CHAR *sc_placeblerb[] =
 {
 	M_("************ QUISC PLACEMENT MODULE - VERSION 1.00"),
 	M_("Cluster Tree Creation:"),
@@ -86,7 +86,7 @@ extern jmp_buf sc_please_stop;
 extern SCCELL *sc_curcell;
 
 /* prototypes for local routines */
-static int  Sc_place_set_control(int, char*[]);
+static int  Sc_place_set_control(int, CHAR*[]);
 static void Sc_place_show_control(void);
 static int  Sc_place_create_clusters(SCCLUSTER**, SCCELL*);
 static void Sc_place_total_cell_size(SCNITREE*, int*, int*, int*);
@@ -139,7 +139,7 @@ err			int			Returned error code, 0 = no error.
 ------------------------------------------------------------------------
 */
 
-int Sc_place(int count, char *pars[])
+int Sc_place(int count, CHAR *pars[])
 {
 	int			err, l, numcl, i;
 	SCPLACE		*place;
@@ -149,11 +149,11 @@ int Sc_place(int count, char *pars[])
 	/* parameter check */
 	if (count)
 	{
-		l = strlen(pars[0]);
+		l = estrlen(pars[0]);
 		l = maxi(l, 2);
-		if (namesamen(pars[0], "set-control", l) == 0)
+		if (namesamen(pars[0], x_("set-control"), l) == 0)
 			return(Sc_place_set_control(count - 1, &pars[1]));
-		if (namesamen(pars[0], "show-control", l) == 0)
+		if (namesamen(pars[0], x_("show-control"), l) == 0)
 		{
 			Sc_place_show_control();
 			return(SC_NOERROR);
@@ -183,7 +183,7 @@ int Sc_place(int count, char *pars[])
 
 	/* DO PLACEMENT */
 	for (i = 0; sc_placeblerb[i]; i++)
-		ttyputverbose(_(sc_placeblerb[i]));
+		ttyputverbose(TRANSLATE(sc_placeblerb[i]));
 	if (sc_placecontrol.stats_flag)
 		Sc_place_show_control();
 	ttyputmsg(_("Starting PLACEMENT..."));
@@ -215,7 +215,7 @@ int Sc_place(int count, char *pars[])
 	if ((err = Sc_place_create_cluster_tree(&sc_gcluster_tree, cllist, numcl,
 		sc_curcell)))
 			return(err);
-	efree((char *)cllist);
+	efree((CHAR *)cllist);
 	ttyputverbose(M_("    Time to create Cluster Tree  =  %s."),
 		Sc_cpu_time(TIME_REL));
 	if (sc_placecontrol.stats_flag)
@@ -300,7 +300,7 @@ err			int			Returned error code, 0 = no error.
 ------------------------------------------------------------------------
 */
 
-int Sc_place_set_control(int count, char *pars[])
+int Sc_place_set_control(int count, CHAR *pars[])
 {
 	int		numcmd, l, n;
 
@@ -308,34 +308,34 @@ int Sc_place_set_control(int count, char *pars[])
 	{
 		for (numcmd = 0; numcmd < count; numcmd++)
 		{
-			l = strlen(pars[numcmd]);
+			l = estrlen(pars[numcmd]);
 			n = maxi(l, 2);
-			if (namesamen(pars[numcmd], "sort", n) == 0)
+			if (namesamen(pars[numcmd], x_("sort"), n) == 0)
 			{
 				sc_placecontrol.sort_flag = TRUE;
 				continue;
 			}
-			if (namesamen(pars[numcmd], "rows", n) == 0)
+			if (namesamen(pars[numcmd], x_("rows"), n) == 0)
 			{
 				numcmd++;
 				if (numcmd < count)
-					ScSetParameter(SC_PARAM_PLACE_NUM_ROWS, atoi(pars[numcmd]));
+					ScSetParameter(SC_PARAM_PLACE_NUM_ROWS, eatoi(pars[numcmd]));
 				continue;
 			}
 
-			if (namesamen(pars[numcmd], "net-balance", n) == 0)
+			if (namesamen(pars[numcmd], x_("net-balance"), n) == 0)
 			{
 				sc_placecontrol.net_balance_flag = TRUE;
 				continue;
 			}
-			if (namesamen(pars[numcmd], "limit-net-balance", n) == 0)
+			if (namesamen(pars[numcmd], x_("limit-net-balance"), n) == 0)
 			{
 				numcmd++;
 				if (numcmd < count)
-					sc_placecontrol.net_balance_limit = atoi(pars[numcmd]);
+					sc_placecontrol.net_balance_limit = eatoi(pars[numcmd]);
 				continue;
 			}
-			if (namesamen(pars[numcmd], "default", n) == 0)
+			if (namesamen(pars[numcmd], x_("default"), n) == 0)
 			{
 				sc_placecontrol.stats_flag = DEFAULT_STATS_FLAG;
 				sc_placecontrol.sort_flag = DEFAULT_SORT_FLAG;
@@ -346,30 +346,30 @@ int Sc_place_set_control(int count, char *pars[])
 				continue;
 			}
 			n = maxi(l, 4);
-			if (namesamen(pars[numcmd], "verbose", n) == 0)
+			if (namesamen(pars[numcmd], x_("verbose"), n) == 0)
 			{
 				sc_placecontrol.stats_flag = TRUE;
 				continue;
 			}
-			if (namesamen(pars[numcmd], "vertical-cost", n) == 0)
+			if (namesamen(pars[numcmd], x_("vertical-cost"), n) == 0)
 			{
 				numcmd++;
 				if (numcmd < count)
-					sc_placecontrol.vertical_cost = atoi(pars[numcmd]);
+					sc_placecontrol.vertical_cost = eatoi(pars[numcmd]);
 				continue;
 			}
 			n = maxi(l, 5);
-			if (namesamen(pars[numcmd], "no-verbose", n) == 0)
+			if (namesamen(pars[numcmd], x_("no-verbose"), n) == 0)
 			{
 				sc_placecontrol.stats_flag = FALSE;
 				continue;
 			}
-			if (namesamen(pars[numcmd], "no-sort", n) == 0)
+			if (namesamen(pars[numcmd], x_("no-sort"), n) == 0)
 			{
 				sc_placecontrol.sort_flag = FALSE;
 				continue;
 			}
-			if (namesamen(pars[numcmd], "no-net-balance", n) == 0)
+			if (namesamen(pars[numcmd], x_("no-net-balance"), n) == 0)
 			{
 				sc_placecontrol.net_balance_flag = FALSE;
 				continue;
@@ -397,7 +397,7 @@ Calling Sequence:  Sc_place_show_control();
 
 void Sc_place_show_control(void)
 {
-	char	*str1;
+	CHAR	*str1;
 
 	ttyputverbose(M_("************ PLACEMENT CONTROL STRUCTURE"));
 	if (sc_placecontrol.stats_flag)
@@ -977,14 +977,14 @@ int Sc_place_ctree_pair(SCCLUSTERTREE *nodes, SCCLCONNECT *nconnects,
 		if (connect == bconnect)
 		{
 			nconnect = connect->next;
-			efree((char *)connect);
+			efree((CHAR *)connect);
 			connect = nconnect;
 		} else
 		{
 			bconnect->last->next = bconnect->next;
 			if (bconnect->next)
 				bconnect->next->last = bconnect->last;
-			efree((char *)bconnect);
+			efree((CHAR *)bconnect);
 		}
 	}
 
@@ -1150,7 +1150,7 @@ level		int				Current level of tree (0 = root).
 
 void Sc_place_print_cluster_tree(SCCLUSTERTREE *node, int level)
 {
-	static char		spacer[80], trailer[80];
+	static CHAR		spacer[80], trailer[80];
 	int			i;
 
 	if (Sc_stop())
@@ -1181,7 +1181,7 @@ void Sc_place_print_cluster_tree(SCCLUSTERTREE *node, int level)
 		ttyputmsg(_("%sCell %s"), spacer, node->cluster->node->name);
 	} else
 	{
-		ttyputmsg("%s%-2d**%s", spacer, level, trailer);
+		ttyputmsg(x_("%s%-2d**%s"), spacer, level, trailer);
 	}
 
 	Sc_place_print_cluster_tree(node->rptr, level + 1);
@@ -1225,7 +1225,7 @@ int Sc_place_sort_cluster_tree(SCCLUSTERTREE *ctree, SCCELL *cell)
 		newtrunk->maxx = 0;
 		newtrunk->next = trunks;
 		trunks = newtrunk;
-		enode->ptr = (char *)newtrunk;		/* back reference pointer */
+		enode->ptr = (CHAR *)newtrunk;		/* back reference pointer */
 	}
 
 	sc_currentcost = Sc_place_cost_cluster_tree(sc_gcluster_tree, trunks, cell);
@@ -1252,7 +1252,7 @@ int Sc_place_sort_cluster_tree(SCCLUSTERTREE *ctree, SCCELL *cell)
 	for (newtrunk = trunks; newtrunk; newtrunk = nexttrunk)
 	{
 		nexttrunk = newtrunk->next;
-		efree((char *)newtrunk);
+		efree((CHAR *)newtrunk);
 	}
 
 	return(SC_NOERROR);
@@ -1615,7 +1615,7 @@ int Sc_place_add_cluster_to_row(SCCLUSTER *cluster, SCROWLIST *row, SCPLACE *pla
 		return(Sc_seterrmsg(SC_NOMEMORY));
 	newplace->cell = cluster->node;
 	newplace->xpos = 0;
-	cluster->node->tp = (char *)newplace;
+	cluster->node->tp = (CHAR *)newplace;
 	newplace->next = NULL;
 	newplace->last = place->endlist;
 	if (place->endlist == NULL)
@@ -1684,8 +1684,8 @@ void Sc_free_cluster_tree(SCCLUSTERTREE *node)
 		return;
 	Sc_free_cluster_tree(node->lptr);
 	Sc_free_cluster_tree(node->rptr);
-	if (node->cluster) efree((char *)node->cluster);
-	efree((char *)node);
+	if (node->cluster) efree((CHAR *)node->cluster);
+	efree((CHAR *)node);
 }
 
 /***********************************************************************
@@ -1710,6 +1710,7 @@ int Sc_place_net_balance(SCROWLIST *row, SCCELL *cell)
 	SCCHANNEL	*channel, *endchan, *newchan, *nextnewchan;
 	SCNBTRUNK	*trunks, *ntrunk, *oldtrunk, *sametrunk, *nextntrunk;
 	int		i, err;
+	Q_UNUSED( row );
 
 	/* create channel list */
 	channel = endchan = NULL;
@@ -1735,7 +1736,7 @@ int Sc_place_net_balance(SCROWLIST *row, SCCELL *cell)
 			ntrunk->same = NULL;
 			if (sametrunk == NULL)
 			{
-				nlist->ptr = (char *)ntrunk;
+				nlist->ptr = (CHAR *)ntrunk;
 			} else
 			{
 				sametrunk->same = ntrunk;
@@ -1790,9 +1791,9 @@ int Sc_place_net_balance(SCROWLIST *row, SCCELL *cell)
 		for (ntrunk = newchan->trunks; ntrunk; ntrunk = nextntrunk)
 		{
 			nextntrunk = ntrunk->next;
-			efree((char *)ntrunk);
+			efree((CHAR *)ntrunk);
 		}
-		efree((char *)newchan);
+		efree((CHAR *)newchan);
 	}
 
 	return(SC_NOERROR);
@@ -2388,7 +2389,7 @@ void Sc_place_show_placement(SCROWLIST *rows)
 		ttyputmsg(M_("For Row #%d, size %d:"), row->row_num, row->row_size);
 		for (inst = row->start; inst != row->end;)
 		{
-			ttyputmsg("    %8d    %-s", inst->xpos, inst->cell->name);
+			ttyputmsg(x_("    %8d    %-s"), inst->xpos, inst->cell->name);
 			if (row->row_num % 2)
 			{
 				inst = inst->last;
@@ -2397,7 +2398,7 @@ void Sc_place_show_placement(SCROWLIST *rows)
 				inst = inst->next;
 			}
 		}
-		ttyputmsg("    %8d    %-s", inst->xpos, inst->cell->name);
+		ttyputmsg(x_("    %8d    %-s"), inst->xpos, inst->cell->name);
 	}
 }
 
