@@ -40,17 +40,17 @@ extern SCCELL	*sc_cells, *sc_curcell;
 int sc_sim_format = SC_SILOS_FORMAT;
 
 /* prototypes for local routines */
-static int   Sc_simformat(int, char*[]);
-static int   Sc_simset(int, char*[]);
-static int   Sc_simshow(int, char*[]);
-static int   Sc_simwrite(int, char*[]);
+static int   Sc_simformat(int, CHAR*[]);
+static int   Sc_simset(int, CHAR*[]);
+static int   Sc_simshow(int, CHAR*[]);
+static int   Sc_simwrite(int, CHAR*[]);
 static void  Sc_simwrite_clear_flags(void);
-static int   Sc_simwrite_model(SCCELL*, char*, FILE*);
+static int   Sc_simwrite_model(SCCELL*, CHAR*, FILE*);
 static int   Sc_simwrite_subelements(SCNITREE*, FILE*);
 static int   Sc_simwrite_cell_instances(SCCELL*, FILE*);
-static char *Sc_sim_isaport(SCCELL*, char*);
-static int   Sc_simwrite_gate(char*, FILE*);
-static void  Sc_fprintf_80(FILE *fp, char *fstring, ...);
+static CHAR *Sc_sim_isaport(SCCELL*, CHAR*);
+static int   Sc_simwrite_gate(CHAR*, FILE*);
+static void  Sc_fprintf_80(FILE *fp, CHAR *fstring, ...);
 
 /***********************************************************************
 Module:  Sc_simulation
@@ -64,21 +64,21 @@ Description:
 ------------------------------------------------------------------------
 */
 
-int Sc_simulation(int count, char *pars[])
+int Sc_simulation(int count, CHAR *pars[])
 {
 	int		l;
 
 	if (!count)
 		return(Sc_seterrmsg(SC_SIMNPARS));
-	l = strlen(pars[0]);
+	l = estrlen(pars[0]);
 
-	if (namesamen(pars[0], "set", l) == 0)
+	if (namesamen(pars[0], x_("set"), l) == 0)
 		return(Sc_simset(count-1, &pars[1]));
-	if (namesamen(pars[0], "show", l) == 0)
+	if (namesamen(pars[0], x_("show"), l) == 0)
 		return(Sc_simshow(count-1, &pars[1]));
-	if (namesamen(pars[0], "write", l) == 0)
+	if (namesamen(pars[0], x_("write"), l) == 0)
 		return(Sc_simwrite(count-1, &pars[1]));
-	if (namesamen(pars[0], "format", l) == 0)
+	if (namesamen(pars[0], x_("format"), l) == 0)
 		return(Sc_simformat(count-1, &pars[1]));
 	return(Sc_seterrmsg(SC_SIMXCMD, pars[0]));
 }
@@ -90,16 +90,16 @@ Description: Set the simulator format to be used
 ------------------------------------------------------------------
 */
 
-int Sc_simformat(int count, char *pars[])
+int Sc_simformat(int count, CHAR *pars[])
 {
 	if (!count)
 		return(Sc_seterrmsg(SC_SIMNPARS));
-	if (namesamen(pars[0], "als", 3) == 0)
+	if (namesamen(pars[0], x_("als"), 3) == 0)
 	{
 		sc_sim_format = SC_ALS_FORMAT;
 		return(SC_NOERROR);
 	}
-	if (namesamen(pars[0], "silos", 5) == 0)
+	if (namesamen(pars[0], x_("silos"), 5) == 0)
 	{
 		sc_sim_format = SC_SILOS_FORMAT;
 		return(SC_NOERROR);
@@ -115,11 +115,11 @@ Description:
 ------------------------------------------------------------------------
 */
 
-int Sc_simset(int count, char *pars[])
+int Sc_simset(int count, CHAR *pars[])
 {
 	SCCELL	*cell;
-	char	**simlist, buffer[MAXLINE];
-	char	*leafcell, *filename;
+	CHAR	**simlist, buffer[MAXLINE];
+	CHAR	*leafcell, *filename;
 	SCSIM	*simline, *oldline, *startline;
 	int		type, i;
 	FILE	*fp;
@@ -151,7 +151,7 @@ int Sc_simset(int count, char *pars[])
 			if ((fp = xcreate(SCSIMFILE, sc_filetypescsim, _("Simulation File"), 0)) == NULL)
 				return(Sc_seterrmsg(SC_SIMSETFERROR));
 			for (simline = (SCSIM *)cell->siminfo; simline; simline = simline->next)
-				xprintf(fp, "%s\n", simline->model);
+				xprintf(fp, x_("%s\n"), simline->model);
 			xclose(fp);
 		}
 	} else
@@ -162,13 +162,13 @@ int Sc_simset(int count, char *pars[])
 			if ((fp = xcreate(SCSIMFILE, sc_filetypescsim, _("Simulation File"), 0)) == NULL)
 				return(Sc_seterrmsg(SC_SIMSETFERROR));
 			for (i = 0; simlist[i]; i++)
-				xprintf(fp, "%s\n", simlist[i]);
+				xprintf(fp, x_("%s\n"), simlist[i]);
 			xclose(fp);
 		}
 	}
 
 	/* get lines */
-	if ((fp = xopen(SCSIMFILE, sc_filetypescsim, "", &filename)) == NULL)
+	if ((fp = xopen(SCSIMFILE, sc_filetypescsim, x_(""), &filename)) == NULL)
 		return(Sc_seterrmsg(SC_SIMSETFERROR));
 	oldline = NULL;
 	startline = NULL;
@@ -182,7 +182,7 @@ int Sc_simset(int count, char *pars[])
 		 *    Therefore, check for '\n' before stripping it off.
 		 * LWS 12/11/89
 		 */
-		i = strlen(buffer);
+		i = estrlen(buffer);
 		if (buffer[i-1] == '\n') buffer[i-1] = '\0';
 		/* buffer[strlen(buffer) - 1] = NULL; */	/* strip off newline */
 		simline = (SCSIM *)emalloc(sizeof(SCSIM), sc_tool->cluster);
@@ -210,10 +210,10 @@ int Sc_simset(int count, char *pars[])
 			for (simline = (SCSIM *)cell->siminfo; simline; )
 			{
 				if (simline->model)
-					efree((char *)simline->model);
+					efree((CHAR *)simline->model);
 				oldline = simline;
 				simline = simline->next;
-				efree((char *)oldline);
+				efree((CHAR *)oldline);
 			}
 			cell->siminfo = NULL;
 		}
@@ -233,11 +233,11 @@ Description:
 ------------------------------------------------------------------------
 */
 
-int Sc_simshow(int count, char *pars[])
+int Sc_simshow(int count, CHAR *pars[])
 {
 	SCCELL		*cell;
 	SCSIM		*simline;
-	char		**simlist, *leafcell, simhdr[10];
+	CHAR		**simlist, *leafcell, simhdr[10];
 	int			i;
 
 	if (!count)
@@ -245,10 +245,10 @@ int Sc_simshow(int count, char *pars[])
 
 	if (sc_sim_format == SC_ALS_FORMAT)
 	{
-		strcpy(simhdr, "ALS");
+		estrcpy(simhdr, x_("ALS"));
 	} else if (sc_sim_format == SC_SILOS_FORMAT)
 	{
-		strcpy(simhdr, "SILOS");
+		estrcpy(simhdr, x_("SILOS"));
 	}
 	for (cell = sc_cells; cell; cell = cell->next)
 	{
@@ -269,7 +269,7 @@ int Sc_simshow(int count, char *pars[])
 					ttyputmsg(simlist[i]);
 				} else
 				{
-					ttyputmsg(" ");
+					ttyputmsg(x_(" "));
 				}
 			}
 		}
@@ -283,7 +283,7 @@ int Sc_simshow(int count, char *pars[])
 				ttyputmsg(simline->model);
 			} else
 			{
-				ttyputmsg(" ");
+				ttyputmsg(x_(" "));
 			}
 		}
 	}
@@ -298,9 +298,9 @@ Description:
 ------------------------------------------------------------------------
 */
 
-int Sc_simwrite(int count, char *pars[])
+int Sc_simwrite(int count, CHAR *pars[])
 {
-	char	*strtime, outfile[60];
+	CHAR	*strtime, outfile[60];
 	FILE	*fp;
 	SCCELL	*cell;
 	time_t	tsec;
@@ -322,16 +322,16 @@ int Sc_simwrite(int count, char *pars[])
 	/* open output file */
 	if (count > 1)
 	{
-		(void)strcpy(outfile, pars[1]);
+		(void)estrcpy(outfile, pars[1]);
 	} else
 	{
-		(void)strcpy(outfile, cell->name);
+		(void)estrcpy(outfile, cell->name);
 		if (sc_sim_format == SC_ALS_FORMAT)
 		{
-			(void)strcat(outfile, ".net");
+			(void)estrcat(outfile, x_(".net"));
 		} else if (sc_sim_format == SC_SILOS_FORMAT)
 		{
-			(void)strcat(outfile, ".sil");
+			(void)estrcat(outfile, x_(".sil"));
 		}
 	}
 
@@ -343,26 +343,26 @@ int Sc_simwrite(int count, char *pars[])
 
 	if (sc_sim_format == SC_ALS_FORMAT)
 	{
-		Sc_fprintf_80(fp, "#*************************************************\n");
-		Sc_fprintf_80(fp, "#  ALS Design System netlist file\n");
-		Sc_fprintf_80(fp, "#  File Created by Electric (vhdl-compiler) on:\n");
-		Sc_fprintf_80(fp, "#  %s\n", strtime);
-		Sc_fprintf_80(fp, "#  For main cell:    %s\n", pars[0]);
-		Sc_fprintf_80(fp, "#-------------------------------------------------\n\n");
-		err = Sc_simwrite_model(cell, "main", fp);
-		Sc_fprintf_80(fp, "\n#********* End of netlist file *******************\n");
+		Sc_fprintf_80(fp, x_("#*************************************************\n"));
+		Sc_fprintf_80(fp, x_("#  ALS Design System netlist file\n"));
+		Sc_fprintf_80(fp, x_("#  File Created by Electric (vhdl-compiler) on:\n"));
+		Sc_fprintf_80(fp, x_("#  %s\n"), strtime);
+		Sc_fprintf_80(fp, x_("#  For main cell:    %s\n"), pars[0]);
+		Sc_fprintf_80(fp, x_("#-------------------------------------------------\n\n"));
+		err = Sc_simwrite_model(cell, x_("main"), fp);
+		Sc_fprintf_80(fp, x_("\n#********* End of netlist file *******************\n"));
 	} else if (sc_sim_format == SC_SILOS_FORMAT)
 	{
-		Sc_fprintf_80(fp, "$*************************************************\n");
-		Sc_fprintf_80(fp, "$  SILOS netlist file\n");
-		Sc_fprintf_80(fp, "$  File Created by Electric (vhdl-compiler) on:\n");
-		Sc_fprintf_80(fp, "$  %s\n", strtime);
-		Sc_fprintf_80(fp, "$  For main cell:    %s\n", pars[0]);
-		Sc_fprintf_80(fp, "$-------------------------------------------------\n\n");
-		Sc_fprintf_80(fp, ".GLOBAL power\npower .CLK 0 S1\n");
-		Sc_fprintf_80(fp, ".GLOBAL ground\nground .CLK 0 S0\n\n");
+		Sc_fprintf_80(fp, x_("$*************************************************\n"));
+		Sc_fprintf_80(fp, x_("$  SILOS netlist file\n"));
+		Sc_fprintf_80(fp, x_("$  File Created by Electric (vhdl-compiler) on:\n"));
+		Sc_fprintf_80(fp, x_("$  %s\n"), strtime);
+		Sc_fprintf_80(fp, x_("$  For main cell:    %s\n"), pars[0]);
+		Sc_fprintf_80(fp, x_("$-------------------------------------------------\n\n"));
+		Sc_fprintf_80(fp, x_(".GLOBAL power\npower .CLK 0 S1\n"));
+		Sc_fprintf_80(fp, x_(".GLOBAL ground\nground .CLK 0 S0\n\n"));
 		err = Sc_simwrite_model(cell, cell->name, fp);
-		Sc_fprintf_80(fp, "(%s %s ",cell->name, cell->name);	/* top level call*/
+		Sc_fprintf_80(fp, x_("(%s %s "),cell->name, cell->name);	/* top level call*/
 		for (port = cell->ports; port; port = port->next)
 		{
 			switch (port->bits & SCPORTTYPE)
@@ -372,12 +372,12 @@ int Sc_simwrite(int count, char *pars[])
 				case SCGNDPORT:
 					break;
 				default:
-					Sc_fprintf_80(fp, " %s", port->name);
+					Sc_fprintf_80(fp, x_(" %s"), port->name);
 					break;
 			}
 		}
-		Sc_fprintf_80(fp, "\n");
-		Sc_fprintf_80(fp, "\n$********* End of netlist file *******************\n");
+		Sc_fprintf_80(fp, x_("\n"));
+		Sc_fprintf_80(fp, x_("\n$********* End of netlist file *******************\n"));
 	}
 	xclose(fp);
 	return(err);
@@ -395,7 +395,7 @@ Description:
 void Sc_simwrite_clear_flags(void)
 {
 	SCCELL	*cell;
-	char	*leafcell;
+	CHAR	*leafcell;
 	int		*bits;
 
 	/* clear flags on all complex cells */
@@ -419,7 +419,7 @@ Description:
 ------------------------------------------------------------------------
 */
 
-int Sc_simwrite_model(SCCELL *cell, char *name, FILE *fp)
+int Sc_simwrite_model(SCCELL *cell, CHAR *name, FILE *fp)
 {
 	SCPORT	*port;
 	int		err, first;
@@ -435,7 +435,7 @@ int Sc_simwrite_model(SCCELL *cell, char *name, FILE *fp)
 				ttyputmsg(simline->model);
 			} else
 			{
-				ttyputmsg(" ");
+				ttyputmsg(x_(" "));
 			}
 		}
 	} else
@@ -447,10 +447,10 @@ int Sc_simwrite_model(SCCELL *cell, char *name, FILE *fp)
 
 	if (sc_sim_format == SC_ALS_FORMAT)
 	{
-		Sc_fprintf_80(fp, "model %s(", name);
+		Sc_fprintf_80(fp, x_("model %s("), name);
 	} else if (sc_sim_format == SC_SILOS_FORMAT)
 	{
-		Sc_fprintf_80(fp, ".MACRO %s", name);
+		Sc_fprintf_80(fp, x_(".MACRO %s"), name);
 	}
 	first = TRUE;
 	for (port = cell->ports; port; port = port->next)
@@ -465,15 +465,15 @@ int Sc_simwrite_model(SCCELL *cell, char *name, FILE *fp)
 				{
 					if (first)
 					{
-						Sc_fprintf_80(fp, "%s", port->name);
+						Sc_fprintf_80(fp, x_("%s"), port->name);
 						first = FALSE;
 					} else
 					{
-						Sc_fprintf_80(fp, ", %s", port->name);
+						Sc_fprintf_80(fp, x_(", %s"), port->name);
 					}
 				} else if (sc_sim_format == SC_SILOS_FORMAT)
 				{
-					Sc_fprintf_80(fp, " %s",
+					Sc_fprintf_80(fp, x_(" %s"),
 					Sc_sim_isaport(cell, port->name));
 				}
 				break;
@@ -481,10 +481,10 @@ int Sc_simwrite_model(SCCELL *cell, char *name, FILE *fp)
 	}
 	if (sc_sim_format == SC_ALS_FORMAT)
 	{
-		Sc_fprintf_80(fp, ")\n");
+		Sc_fprintf_80(fp, x_(")\n"));
 	} else if (sc_sim_format == SC_SILOS_FORMAT)
 	{
-		Sc_fprintf_80(fp, "\n");
+		Sc_fprintf_80(fp, x_("\n"));
 	}
 
 	/* print instances of cells */
@@ -496,10 +496,10 @@ int Sc_simwrite_model(SCCELL *cell, char *name, FILE *fp)
 
 	if (sc_sim_format == SC_SILOS_FORMAT)
 	{
-		Sc_fprintf_80(fp, ".EOM\n\n");
+		Sc_fprintf_80(fp, x_(".EOM\n\n"));
 	} else
 	{
-		Sc_fprintf_80(fp, "\n");
+		Sc_fprintf_80(fp, x_("\n"));
 	}
 	return(SC_NOERROR);
 }
@@ -567,11 +567,11 @@ int Sc_simwrite_cell_instances(SCCELL *cell, FILE *fp)
 			case SCCOMPLEXCELL:
 				if (sc_sim_format == SC_ALS_FORMAT)
 				{
-					Sc_fprintf_80(fp, "%s: ", nptr->name);
-					Sc_fprintf_80(fp, "%s(", ((SCCELL *)(nptr->np))->name);
+					Sc_fprintf_80(fp, x_("%s: "), nptr->name);
+					Sc_fprintf_80(fp, x_("%s("), ((SCCELL *)(nptr->np))->name);
 				} else if (sc_sim_format == SC_SILOS_FORMAT)
 				{
-					Sc_fprintf_80(fp, "(%s %s", nptr->name,
+					Sc_fprintf_80(fp, x_("(%s %s"), nptr->name,
 						((SCCELL *)(nptr->np))->name);
 				}
 				first = TRUE;
@@ -581,47 +581,47 @@ int Sc_simwrite_cell_instances(SCCELL *cell, FILE *fp)
 					{
 						if (first)
 						{
-							Sc_fprintf_80(fp, "%s", port->ext_node->name);
+							Sc_fprintf_80(fp, x_("%s"), port->ext_node->name);
 							first = FALSE;
 						} else
 						{
-							Sc_fprintf_80(fp, ", %s", port->ext_node->name);
+							Sc_fprintf_80(fp, x_(", %s"), port->ext_node->name);
 						}
 					} else if (sc_sim_format == SC_SILOS_FORMAT)
 					{
 						if (port->ext_node->firstport->next == NULL)
 						{
-							Sc_fprintf_80(fp, " .SKIP");
+							Sc_fprintf_80(fp, x_(" .SKIP"));
 						} else
 						{
-							Sc_fprintf_80(fp, " %s",
+							Sc_fprintf_80(fp, x_(" %s"),
 							Sc_sim_isaport(cell,port->ext_node->name));
 						}
 					}
-					if (namesame(port->ext_node->name, "ground") == 0)
+					if (namesame(port->ext_node->name, x_("ground")) == 0)
 					{
 						ground = TRUE;
-					} else if (namesame(port->ext_node->name, "power") == 0)
+					} else if (namesame(port->ext_node->name, x_("power")) == 0)
 					{
 						power = TRUE;
 					}
 				}
 				if (sc_sim_format == SC_ALS_FORMAT)
 				{
-					Sc_fprintf_80(fp, ")\n");
+					Sc_fprintf_80(fp, x_(")\n"));
 				} else
 				{
-					Sc_fprintf_80(fp, "\n");
+					Sc_fprintf_80(fp, x_("\n"));
 				}
 				break;
 			case SCLEAFCELL:
 				if (sc_sim_format == SC_ALS_FORMAT)
 				{
-					Sc_fprintf_80(fp, "%s: ", nptr->name);
-					Sc_fprintf_80(fp, "%s(", Sc_leaf_facet_name(nptr->np));
+					Sc_fprintf_80(fp, x_("%s: "), nptr->name);
+					Sc_fprintf_80(fp, x_("%s("), Sc_leaf_facet_name(nptr->np));
 				} else if (sc_sim_format == SC_SILOS_FORMAT)
 				{
-					Sc_fprintf_80(fp, "(%s %s ", nptr->name,
+					Sc_fprintf_80(fp, x_("(%s %s "), nptr->name,
 						Sc_leaf_facet_name(nptr->np));
 				}
 				first = TRUE;
@@ -631,37 +631,37 @@ int Sc_simwrite_cell_instances(SCCELL *cell, FILE *fp)
 					{
 						if (first)
 						{
-							Sc_fprintf_80(fp, "%s", port->ext_node->name);
+							Sc_fprintf_80(fp, x_("%s"), port->ext_node->name);
 							first = FALSE;
 						} else
 						{
-							Sc_fprintf_80(fp, ", %s", port->ext_node->name);
+							Sc_fprintf_80(fp, x_(", %s"), port->ext_node->name);
 						}
 					} else if (sc_sim_format == SC_SILOS_FORMAT)
 					{
 						if (port->ext_node->firstport->next == NULL)
 						{
-							Sc_fprintf_80(fp, " .SKIP");
+							Sc_fprintf_80(fp, x_(" .SKIP"));
 						} else
 						{
-							Sc_fprintf_80(fp, " %s",
+							Sc_fprintf_80(fp, x_(" %s"),
 							Sc_sim_isaport(cell, port->ext_node->name));
 						}
 					}
-					if (namesame(port->ext_node->name, "ground") == 0)
+					if (namesame(port->ext_node->name, x_("ground")) == 0)
 					{
 						ground = TRUE;
-					} else if (namesame(port->ext_node->name, "power") == 0)
+					} else if (namesame(port->ext_node->name, x_("power")) == 0)
 					{
 						power = TRUE;
 					}
 				}
 				if (sc_sim_format == SC_ALS_FORMAT)
 				{
-					Sc_fprintf_80(fp, ")\n");
+					Sc_fprintf_80(fp, x_(")\n"));
 				} else
 				{
-					Sc_fprintf_80(fp, "\n");
+					Sc_fprintf_80(fp, x_("\n"));
 				}
 				break;
 			case SCSPECIALCELL:
@@ -672,9 +672,9 @@ int Sc_simwrite_cell_instances(SCCELL *cell, FILE *fp)
 	if (sc_sim_format == SC_ALS_FORMAT)
 	{
 		if (ground)
-			Sc_fprintf_80(fp, "set ground=L@3\n");
+			Sc_fprintf_80(fp, x_("set ground=L@3\n"));
 		if (power)
-			Sc_fprintf_80(fp, "set power=H@3\n");
+			Sc_fprintf_80(fp, x_("set power=H@3\n"));
 	}
 	return(0);
 }
@@ -696,13 +696,13 @@ the '[' with '_'
 ----------------------------------------------------------------------
 */
 
-char *Sc_sim_isaport(SCCELL *cell, char *portname)
+CHAR *Sc_sim_isaport(SCCELL *cell, CHAR *portname)
 {
 	SCPORT *test;
-	char *ptr;
-	static char newname[100];
+	CHAR *ptr;
+	static CHAR newname[100];
 
-	if (strchr(portname, '[') == 0) return(portname);
+	if (estrchr(portname, '[') == 0) return(portname);
 
 	for (test = cell->ports; test != NULL; test = test->next)
 	{
@@ -712,7 +712,7 @@ char *Sc_sim_isaport(SCCELL *cell, char *portname)
 			{
 				if (*portname == '[')
 				{
-					strcpy(ptr, "__");
+					estrcpy(ptr, x_("__"));
 					ptr++;
 				} else if (*ptr == ']')
 				{
@@ -737,9 +737,9 @@ Description:
 ------------------------------------------------------------------------
 */
 
-int Sc_simwrite_gate(char *leafcell, FILE *fp)
+int Sc_simwrite_gate(CHAR *leafcell, FILE *fp)
 {
-	char	**simlist;
+	CHAR	**simlist;
 	int		i, *bits;
 
 	bits = Sc_leaf_facet_bits_address(leafcell);
@@ -749,9 +749,9 @@ int Sc_simwrite_gate(char *leafcell, FILE *fp)
 		for (i = 0; simlist[i]; i++)
 		{
 			Sc_fprintf_80(fp, simlist[i]);
-			Sc_fprintf_80(fp, "\n");
+			Sc_fprintf_80(fp, x_("\n"));
 		}
-		Sc_fprintf_80(fp, "\n");
+		Sc_fprintf_80(fp, x_("\n"));
 		return(0);
 	} else
 	{
@@ -779,17 +779,17 @@ arg1,arg2,...	int			Generic values (pointers) to items.
 ------------------------------------------------------------------------
 */
 
-void Sc_fprintf_80(FILE *fp, char *fstring, ...)
+void Sc_fprintf_80(FILE *fp, CHAR *fstring, ...)
 {
 	static int	lline = 0;
 	int			length;
-	char		buff[256], *sptr, save[10];
+	CHAR		buff[256], *sptr, save[10];
 	va_list		ap;
 
 	var_start(ap, fstring);
 	evsnprintf(buff, 256, fstring, ap);
 	va_end(ap);
-	length = strlen(buff);
+	length = estrlen(buff);
 	sptr = buff;
 	if ((lline + length) > 70)
 	{
@@ -798,18 +798,18 @@ void Sc_fprintf_80(FILE *fp, char *fstring, ...)
 		{
 			if (isspace(*sptr))
 			{
-				strncpy(save, sptr, 3);
-				strcpy(sptr, "\n");
+				estrncpy(save, sptr, 3);
+				estrcpy(sptr, x_("\n"));
 				if (sc_sim_format == SC_SILOS_FORMAT)
 				{
-					strcat(sptr, "+");
+					estrcat(sptr, x_("+"));
 					lline = 1;
 				} else
 				{
 					lline = 0;
 				}
 				xprintf(fp, buff);
-				strncpy(sptr, save, 3);
+				estrncpy(sptr, save, 3);
 				break;
 			}
 			sptr++;
