@@ -55,9 +55,9 @@ static CONPTR      simals_conptr2;
        LINKPTR     simals_setroot = 0;
        TRAKPTR     simals_trakroot = 0;
        LOADPTR     simals_chekroot;
-       char      **simals_rowptr1;
-       char      **simals_ioptr1;
-       char       *simals_instbuf = 0;
+       CHAR      **simals_rowptr1;
+       CHAR      **simals_ioptr1;
+       CHAR       *simals_instbuf = 0;
 static INTBIG      simals_loop_count;
        INTBIG      simals_pseq;
        INTBIG      simals_nseq;
@@ -77,20 +77,21 @@ static float       simals_random_def;
 static float       simals_abs_def;
        NODEPROTO  *simals_mainproto = NONODEPROTO;
        INTBIG      simals_trace_size = 0;
+       CHAR       *simals_title = 0;
 
 /********************************* LOCALS *********************************/
 
 static INTBIG     i_ptr;
-static char       delay[16];
+static CHAR       delay[16];
 
 /* prototypes for local routines */
-static BOOLEAN simals_alloc_char_buffer(char**, INTBIG*, INTBIG);
-static BOOLEAN simals_get_string(char*);
+static BOOLEAN simals_alloc_char_buffer(CHAR**, INTBIG*, INTBIG);
+static BOOLEAN simals_get_string(CHAR*);
 static BOOLEAN simals_get_int(INTBIG*);
 static BOOLEAN simals_get_float(float*);
-static BOOLEAN simals_get_name(char*);
-static BOOLEAN simals_fragment_line(char*);
-static BOOLEAN simals_parse_struct_header(char);
+static BOOLEAN simals_get_name(CHAR*);
+static BOOLEAN simals_fragment_line(CHAR*);
+static BOOLEAN simals_parse_struct_header(CHAR);
 static BOOLEAN simals_parse_gate(void);
 static BOOLEAN simals_parse_node(void);
 static BOOLEAN simals_parse_timing(void);
@@ -120,7 +121,7 @@ void simals_init(void)
 	}
 	if (simals_trace_size == 0)
 	{
-		var = getval((INTBIG)sim_tool, VTOOL, VINTEGER, "SIM_als_num_events");
+		var = getval((INTBIG)sim_tool, VTOOL, VINTEGER, x_("SIM_als_num_events"));
 		if (var == NOVARIABLE) simals_trace_size = DEFAULT_TRACE_SIZE; else
 			simals_trace_size = var->addr;
 	}
@@ -129,15 +130,15 @@ void simals_init(void)
 		simals_trakroot = (TRAKPTR)simals_alloc_mem((INTBIG)(simals_trace_size * sizeof(TRAK)));
 		if (simals_trakroot == 0) return;
 	}
-	simals_no_update_key = makekey("SIM_als_no_update");
+	simals_no_update_key = makekey(x_("SIM_als_no_update"));
 }
 
 void simals_term(void)
 {
 	simals_erase_model();
-	if (simals_instbuf != 0) efree((char *)simals_instbuf);
-	if (simals_instptr != 0) efree((char *)simals_instptr);
-	if (simals_trakroot != 0) efree((char *)simals_trakroot);
+	if (simals_instbuf != 0) efree((CHAR *)simals_instbuf);
+	if (simals_instptr != 0) efree((CHAR *)simals_instptr);
+	if (simals_trakroot != 0) efree((CHAR *)simals_trakroot);
 	simals_freeflatmemory();
 	simals_freesimmemory();
 }
@@ -148,7 +149,7 @@ void simals_term(void)
 void simals_init_display(void)
 {
 	CONPTR cellptr;
-	char *pt;
+	CHAR *pt;
 	REGISTER void *infstr;
 
 	if (simals_mainproto == NONODEPROTO)
@@ -170,80 +171,87 @@ void simals_init_display(void)
 		ttyputerr(_("No simulation to resume"));
 		return;
 	}
+#if 1
 	if (simals_set_current_level()) return;
 
 	/* run simulation */
 	(void)simals_initialize_simulator(TRUE);
+#else
+	/* it crashed here and I think it should be reversed, but I'm too chicken to try */
+	(void)simals_initialize_simulator(TRUE);
+
+	if (simals_set_current_level()) return;
+#endif
 }
 
-void simals_com_comp(INTBIG count, char *par[10])
+void simals_com_comp(INTBIG count, CHAR *par[10])
 {
-	char *pp;
+	CHAR *pp;
 	INTBIG l;
 
-	l = strlen(pp = par[0]);
+	l = estrlen(pp = par[0]);
 
-	if (namesamen(pp, "build-actel-models", l) == 0 && l >= 1)
+	if (namesamen(pp, x_("build-actel-models"), l) == 0 && l >= 1)
 	{
 		simals_build_actel_command(count-1, &par[1]);
 		return;
 	}
-	if (namesamen(pp, "clock", l) == 0 && l >= 1)
+	if (namesamen(pp, x_("clock"), l) == 0 && l >= 1)
 	{
 		simals_clock_command(count-1, &par[1]);
 		return;
 	}
-	if (namesamen(pp, "erase", l) == 0 && l >= 1)
+	if (namesamen(pp, x_("erase"), l) == 0 && l >= 1)
 	{
 		simals_erase_model();
 		return;
 	}
-	if (namesamen(pp, "go", l) == 0 && l >= 1)
+	if (namesamen(pp, x_("go"), l) == 0 && l >= 1)
 	{
 		simals_go_command(count-1, &par[1]);
 		return;
 	}
-	if (namesamen(pp, "help", l) == 0 && l >= 1)
+	if (namesamen(pp, x_("help"), l) == 0 && l >= 1)
 	{
 		simals_help_command();
 		return;
 	}
-	if (namesamen(pp, "print", l) == 0 && l >= 1)
+	if (namesamen(pp, x_("print"), l) == 0 && l >= 1)
 	{
 		simals_print_command(count-1, &par[1]);
 		return;
 	}
-	if (namesamen(pp, "seed", l) == 0 && l >= 3)
+	if (namesamen(pp, x_("seed"), l) == 0 && l >= 3)
 	{
 		simals_seed_command(count-1, &par[1]);
 		return;
 	}
-	if (namesamen(pp, "set", l) == 0 && l >= 3)
+	if (namesamen(pp, x_("set"), l) == 0 && l >= 3)
 	{
 		simals_set_command(count-1, &par[1]);
 		return;
 	}
-	if (namesamen(pp, "trace", l) == 0 && l >= 1)
+	if (namesamen(pp, x_("trace"), l) == 0 && l >= 1)
 	{
 		simals_trace_command(count-1, &par[1]);
 		return;
 	}
-	if (namesamen(pp, "vector", l) == 0 && l >= 1)
+	if (namesamen(pp, x_("vector"), l) == 0 && l >= 1)
 	{
 		simals_vector_command(count-1, &par[1]);
 		return;
 	}
-	if (namesamen(pp, "annotate", l) == 0 && l >= 1)
+	if (namesamen(pp, x_("annotate"), l) == 0 && l >= 1)
 	{
 		simals_annotate_command(count-1, &par[1]);
 		return;
 	}
-	if (namesamen(pp, "order", l) == 0 && l >= 1)
+	if (namesamen(pp, x_("order"), l) == 0 && l >= 1)
 	{
 		simals_order_command(count-1, &par[1]);
 		return;
 	}
-	ttyputbadusage("telltool simulation als");
+	ttyputbadusage(x_("telltool simulation als"));
 }
 
 /*
@@ -260,18 +268,18 @@ void simals_com_comp(INTBIG count, char *par[10])
  *	size = integer value representing size of data element
  */
 #ifdef DEBUGMEMORY
-char *_simals_alloc_mem(INTBIG size, char *filename, INTBIG lineno)
+CHAR *_simals_alloc_mem(INTBIG size, CHAR *filename, INTBIG lineno)
 #else
-char *simals_alloc_mem(INTBIG size)
+CHAR *simals_alloc_mem(INTBIG size)
 #endif
 {
-	char   *ptr;
+	CHAR   *ptr;
 	INTBIG   i;
 
 #ifdef DEBUGMEMORY
-	ptr = (char *)_emalloc(size, sim_tool->cluster, filename, lineno);
+	ptr = (CHAR *)_emalloc(size, sim_tool->cluster, filename, lineno);
 #else
-	ptr = (char *)emalloc(size, sim_tool->cluster);
+	ptr = (CHAR *)emalloc(size, sim_tool->cluster);
 #endif
 	if (ptr == 0)
 	{
@@ -296,17 +304,17 @@ char *simals_alloc_mem(INTBIG size)
  *	old     = address of int value indicating the old size of the buffer
  *	newsize = integer value indicating the new size to be created
  */
-BOOLEAN simals_alloc_char_buffer(char **root, INTBIG *old, INTBIG newsize)
+BOOLEAN simals_alloc_char_buffer(CHAR **root, INTBIG *old, INTBIG newsize)
 {
 	INTBIG   i;
-	char  *head;
+	CHAR  *head;
 
-	head = (char *) simals_alloc_mem((INTBIG)(newsize * sizeof(char)));
+	head = (CHAR *) simals_alloc_mem((INTBIG)(newsize * sizeof(CHAR)));
 	if (head == 0) return(TRUE);
 	if (*root)
 	{
 		for (i = 0; i < (*old); ++i) head[i] = (*root)[i];
-		efree((char *)*root);
+		efree((CHAR *)*root);
 	}
 
 	*root = head;
@@ -338,7 +346,7 @@ BOOLEAN simals_alloc_ptr_buffer(INTBIG **root, INTBIG *old, INTBIG newsize)
 	if (*root)
 	{
 		for (i = 0; i < (*old); ++i) head[i] = (INTBIG*) (*root)[i];
-		efree((char *)*root);
+		efree((CHAR *)*root);
 	}
 
 	*root = (INTBIG*) head;
@@ -357,10 +365,10 @@ BOOLEAN simals_alloc_ptr_buffer(INTBIG **root, INTBIG *old, INTBIG newsize)
  * Calling Arguments:
  *	sp = pointer to char string where results are to be saved
  */
-BOOLEAN simals_get_string(char *sp)
+BOOLEAN simals_get_string(CHAR *sp)
 {
 	INTBIG   i;
-	char  line[260];
+	CHAR  line[260];
 	extern TOOL *vhdl_tool;
 
 	if (((simals_instptr[i_ptr] < 0) || (simals_instbuf[simals_instptr[i_ptr]] == '#')) && simals_loop_count)
@@ -371,7 +379,7 @@ BOOLEAN simals_get_string(char *sp)
 
 	while ((simals_instptr[i_ptr] < 0) || (simals_instbuf[simals_instptr[i_ptr]] == '#'))
 	{
-		i = asktool(vhdl_tool, "get-line", (INTBIG)line);
+		i = asktool(vhdl_tool, x_("get-line"), (INTBIG)line);
 
 		if (i == 0)
 		{
@@ -379,7 +387,7 @@ BOOLEAN simals_get_string(char *sp)
 			return(TRUE);
 		}
 
-		if (strlen(line) > 255)
+		if (estrlen(line) > 255)
 		{
 			ttyputerr(_("ERROR: Input record too large.  Make them smaller"));
 			return(TRUE);
@@ -388,7 +396,7 @@ BOOLEAN simals_get_string(char *sp)
 		i_ptr = 0;
 	}
 
-	(void)strcpy(sp, &(simals_instbuf[simals_instptr[i_ptr]]));
+	(void)estrcpy(sp, &(simals_instbuf[simals_instptr[i_ptr]]));
 	++i_ptr;
 	return(FALSE);
 }
@@ -407,7 +415,7 @@ BOOLEAN simals_get_string(char *sp)
 BOOLEAN simals_get_int(INTBIG *value)
 {
 	BOOLEAN   i;
-	char  s1[256], s2[256];
+	CHAR  s1[256], s2[256];
 
 	i = simals_get_string(s1);
 	if (i) return(TRUE);
@@ -416,7 +424,7 @@ BOOLEAN simals_get_int(INTBIG *value)
 	{
 		i = simals_get_string(s2);
 		if (i) return(TRUE);
-		(void)strcat(s1, s2);
+		(void)estrcat(s1, s2);
 	}
 
 	*value = simals_atoi(s1);
@@ -435,7 +443,7 @@ BOOLEAN simals_get_int(INTBIG *value)
  * Calling Arguments:
  *	s1 = pointer to a string containing the integer value to be interpreted
  */
-INTBIG simals_atoi(char *s1)
+INTBIG simals_atoi(CHAR *s1)
 {
 	INTBIG  i, sum;
 
@@ -486,7 +494,7 @@ INTBIG simals_atoi(char *s1)
 			break;
 
 		default:
-			sum = atol(s1);
+			sum = eatol(s1);
 	}
 
 	return(sum);
@@ -502,7 +510,7 @@ INTBIG simals_atoi(char *s1)
  * Calling Arguments:
  *	s1 = pointer to char string that is to be converted to upper case
  */
-void simals_convert_to_upper(char *s1)
+void simals_convert_to_upper(CHAR *s1)
 {
 	for (; *s1; ++s1)
 	{
@@ -526,7 +534,7 @@ BOOLEAN simals_get_float(float *value)
 {
 	BOOLEAN   eof;
 	INTBIG    i;
-	char  s1[256], s2[256];
+	CHAR  s1[256], s2[256];
 
 	eof = simals_get_string(s1);
 	if (eof) return(TRUE);
@@ -535,28 +543,28 @@ BOOLEAN simals_get_float(float *value)
 	{
 		eof = simals_get_string(s2);
 		if (eof) return(TRUE);
-		(void)strcat(s1, s2);
+		(void)estrcat(s1, s2);
 	}
 
-	i = strlen(s1);
+	i = estrlen(s1);
 	if (s1[i-1] != 'E')
 	{
-		*value = (float)atof(s1);
+		*value = (float)eatof(s1);
 		return(FALSE);
 	}
 
 	eof = simals_get_string(s2);
 	if (eof) return(TRUE);
-	(void)strcat(s1, s2);
+	(void)estrcat(s1, s2);
 
 	if ((s2[0] == '+') || (s2[0] == '-'))
 	{
 		eof = simals_get_string(s2);
 		if (eof) return(TRUE);
-		(void)strcat(s1, s2);
+		(void)estrcat(s1, s2);
 	}
 
-	*value = (float)atof(s1);
+	*value = (float)eatof(s1);
 	return(FALSE);
 }
 
@@ -571,10 +579,10 @@ BOOLEAN simals_get_float(float *value)
  * Calling Arguments:
  *	sp = pointer to a character string where results are to be saved
  */
-BOOLEAN simals_get_name(char *sp)
+BOOLEAN simals_get_name(CHAR *sp)
 {
 	BOOLEAN   eof;
-	char  s1[256], s2[256];
+	CHAR  s1[256], s2[256];
 
 	eof = simals_get_string(s1);
 	if (eof) return(TRUE);
@@ -582,21 +590,21 @@ BOOLEAN simals_get_name(char *sp)
 	eof = simals_get_string(s2);
 	if (eof || (s2[0] != '['))
 	{
-		(void)strcpy(sp, s1);
+		(void)estrcpy(sp, s1);
 		--i_ptr;
 		return(FALSE);
 	}
 
-	(void)strcat(s1, s2);
+	(void)estrcat(s1, s2);
 	for(;;)
 	{
 		eof = simals_get_string(s2);
 		if (eof) return(TRUE);
-		(void)strcat(s1, s2);
+		(void)estrcat(s1, s2);
 		if (s2[0] == ']') break;
 	}
 
-	(void)strcpy(sp, s1);
+	(void)estrcpy(sp, s1);
 	return(FALSE);
 }
 
@@ -611,7 +619,7 @@ BOOLEAN simals_get_name(char *sp)
  * Calling Arguments:
  *	line = pointer to the character string to be fragmented
  */
-BOOLEAN simals_fragment_line(char *line)
+BOOLEAN simals_fragment_line(CHAR *line)
 {
 	INTBIG   i, j, k, count;
 
@@ -720,12 +728,12 @@ BOOLEAN simals_fragment_line(char *line)
  */
 BOOLEAN simals_read_net_desc(NODEPROTO *np)
 {
-	char    s1[256], *intended;
+	CHAR    s1[256], *intended;
 	BOOLEAN    eof;
 	extern TOOL *vhdl_tool;
 
 	simals_mainproto = np;
-	if (asktool(vhdl_tool, "begin-netlist-input", (INTBIG)np, sim_filetypeals, (INTBIG)&intended) != 0)
+	if (asktool(vhdl_tool, x_("begin-netlist-input"), (INTBIG)np, sim_filetypeals, (INTBIG)&intended) != 0)
 	{
 		ttyputerr(_("Cannot read %s"), intended);
 		return(TRUE);
@@ -741,21 +749,21 @@ BOOLEAN simals_read_net_desc(NODEPROTO *np)
 		eof = simals_get_string(s1);
 		if (eof) break;
 
-		if (! (strcmp(s1, "GATE") && strcmp(s1, "FUNCTION") && strcmp(s1, "MODEL")))
+		if (! (estrcmp(s1, x_("GATE")) && estrcmp(s1, x_("FUNCTION")) && estrcmp(s1, x_("MODEL"))))
 		{
 			if (simals_parse_struct_header(s1[0]))
 			{
-				(void)asktool(vhdl_tool, "end-input");
+				(void)asktool(vhdl_tool, x_("end-input"));
 				return(TRUE);
 			}
 			continue;
 		}
 
 		ttyputerr(_("ERROR: String '%s' invalid (expecting gate, function, or model)"), s1);
-		(void)asktool(vhdl_tool, "end-input");
+		(void)asktool(vhdl_tool, x_("end-input"));
 		return(TRUE);
 	}
-	(void)asktool(vhdl_tool, "end-input");
+	(void)asktool(vhdl_tool, x_("end-input"));
 	return(FALSE);
 }
 
@@ -771,10 +779,10 @@ BOOLEAN simals_read_net_desc(NODEPROTO *np)
  * Calling Arguments:
  *	flag = char representing the type of structure to be parsed
  */
-BOOLEAN simals_parse_struct_header(char flag)
+BOOLEAN simals_parse_struct_header(CHAR flag)
 {
 	BOOLEAN   eof;
-	char  s1[256];
+	CHAR  s1[256];
 	MODEL **modptr1;
 	EXPORT **exptr1;
 
@@ -792,9 +800,9 @@ BOOLEAN simals_parse_struct_header(char flag)
 		{
 			simals_modptr2 = (MODPTR) simals_alloc_mem((INTBIG)sizeof(MODEL));
 			if (simals_modptr2 == 0) return(TRUE);
-			simals_modptr2->name = simals_alloc_mem((INTBIG)(strlen(s1) + 1));
+			simals_modptr2->name = simals_alloc_mem((INTBIG)(estrlen(s1) + 1));
 			if (simals_modptr2->name == 0) return(TRUE);
-			(void)strcpy(simals_modptr2->name, s1);
+			(void)estrcpy(simals_modptr2->name, s1);
 			simals_modptr2->type = flag;
 			simals_modptr2->ptr = 0;
 			simals_modptr2->exptr  = 0;
@@ -807,7 +815,7 @@ BOOLEAN simals_parse_struct_header(char flag)
 			break;
 		}
 		simals_modptr2 = *modptr1;
-		if (! strcmp(simals_modptr2->name, s1))
+		if (! estrcmp(simals_modptr2->name, s1))
 		{
 			ttyputerr(_("ERROR: Structure %s already defined"), s1);
 			return(TRUE);
@@ -844,16 +852,16 @@ BOOLEAN simals_parse_struct_header(char flag)
 			{
 				simals_exptr2 = (EXPTR) simals_alloc_mem((INTBIG)sizeof(EXPORT));
 				if (simals_exptr2 == 0) return(TRUE);
-				simals_exptr2->node_name = simals_alloc_mem((INTBIG)(strlen(s1) + 1));
+				simals_exptr2->node_name = simals_alloc_mem((INTBIG)(estrlen(s1) + 1));
 				if (simals_exptr2->node_name == 0) return(TRUE);
-				(void)strcpy(simals_exptr2->node_name, s1);
+				(void)estrcpy(simals_exptr2->node_name, s1);
 				simals_exptr2->nodeptr = 0;
 				simals_exptr2->next = 0;
 				*exptr1 = simals_exptr2;
 				break;
 			}
 			simals_exptr2 = *exptr1;
-			if (! strcmp(simals_exptr2->node_name, s1))
+			if (! estrcmp(simals_exptr2->node_name, s1))
 			{
 				ttyputerr(_("Node %s specified more than once in argument list"), s1);
 				return(TRUE);
@@ -890,23 +898,23 @@ BOOLEAN simals_parse_gate(void)
 {
 	INTBIG   j;
 	BOOLEAN eof;
-	char  s1[256];
+	CHAR  s1[256];
 
 	/* init delay transition name */
-	(void)sprintf(delay, "XX");
+	(void)esnprintf(delay, 16, x_("XX"));
 
 	simals_delta_def = simals_linear_def = simals_exp_def = simals_random_def = simals_abs_def = 0;
 	simals_rowptr1 = &(simals_modptr2->ptr);
 	for(;;)
 	{
 		eof = simals_get_string(s1);
-		if (eof || (! (strcmp(s1, "GATE") && strcmp(s1, "FUNCTION") && strcmp(s1, "MODEL"))))
+		if (eof || (! (estrcmp(s1, x_("GATE")) && estrcmp(s1, x_("FUNCTION")) && estrcmp(s1, x_("MODEL")))))
 		{
 			--i_ptr;
 			break;
 		}
 
-		if (! strcmp(s1, "I"))
+		if (! estrcmp(s1, x_("I")))
 		{
 			simals_rowptr2 = (ROWPTR) simals_alloc_mem((INTBIG)sizeof(ROW));
 			if (simals_rowptr2 == 0) return(TRUE);
@@ -918,47 +926,47 @@ BOOLEAN simals_parse_gate(void)
 			simals_rowptr2->random = simals_random_def;
 			simals_rowptr2->abs = simals_abs_def;
 			(void)allocstring(&(simals_rowptr2->delay), delay, sim_tool->cluster);
-			(void)sprintf(delay, "XX");  /* reset name */
+			(void)esnprintf(delay, 16, x_("XX"));  /* reset name */
 			simals_rowptr2->next = 0;
-			*simals_rowptr1 = (char*) simals_rowptr2;
-			simals_rowptr1 = (char**) &(simals_rowptr2->next);
-			simals_ioptr1 = (char**) &(simals_rowptr2->inptr);
+			*simals_rowptr1 = (CHAR*) simals_rowptr2;
+			simals_rowptr1 = (CHAR**) &(simals_rowptr2->next);
+			simals_ioptr1 = (CHAR**) &(simals_rowptr2->inptr);
 			if (simals_parse_node()) return(TRUE);
 			continue;
 		}
 
-		if (! strcmp(s1, "O"))
+		if (! estrcmp(s1, x_("O")))
 		{
-			simals_ioptr1 = (char**) &(simals_rowptr2->outptr);
+			simals_ioptr1 = (CHAR**) &(simals_rowptr2->outptr);
 			if (simals_parse_node()) return(TRUE);
 			continue;
 		}
 
-		if (! strcmp(s1, "T"))
+		if (! estrcmp(s1, x_("T")))
 		{
 			if (simals_parse_timing()) return(TRUE);
 			continue;
 		}
 
-		if (! strcmp(s1, "D"))
+		if (! estrcmp(s1, x_("D")))
 		{
 			if (simals_parse_delay()) return(TRUE);
 			continue;
 		}
 
-		if (! strcmp(s1, "FANOUT"))
+		if (! estrcmp(s1, x_("FANOUT")))
 		{
 			if (simals_parse_fanout()) return(TRUE);
 			continue;
 		}
 
-		if (! strcmp(s1, "LOAD"))
+		if (! estrcmp(s1, x_("LOAD")))
 		{
 			if (simals_parse_load()) return(TRUE);
 			continue;
 		}
 
-		if (! strcmp(s1, "PRIORITY"))
+		if (! estrcmp(s1, x_("PRIORITY")))
 		{
 			eof = simals_get_int(&j);
 			if (eof)
@@ -970,13 +978,13 @@ BOOLEAN simals_parse_gate(void)
 			continue;
 		}
 
-		if (! strcmp(s1, "SET"))
+		if (! estrcmp(s1, x_("SET")))
 		{
-			simals_ioptr1 = (char**) &(simals_modptr2->setptr);
+			simals_ioptr1 = (CHAR**) &(simals_modptr2->setptr);
 			for (simals_ioptr2 = simals_modptr2->setptr; simals_ioptr2;
 				simals_ioptr2 = simals_ioptr2->next)
 			{
-				simals_ioptr1 = (char**) &(simals_ioptr2->next);
+				simals_ioptr1 = (CHAR**) &(simals_ioptr2->next);
 			}
 			if (simals_parse_node()) return(TRUE);
 			continue;
@@ -999,15 +1007,15 @@ BOOLEAN simals_parse_node(void)
 {
 	INTBIG   j;
 	BOOLEAN  eof;
-	char  s1[256];
+	CHAR  s1[256];
 
 	for(;;)
 	{
 		eof = simals_get_name(s1);
-		if (eof || (! (strcmp(s1, "GATE") && strcmp(s1, "FUNCTION")
-			&& strcmp(s1, "MODEL") && strcmp(s1, "I") && strcmp(s1, "O")
-			&& strcmp(s1, "T") && strcmp(s1, "FANOUT") && strcmp(s1, "LOAD")
-			&& strcmp(s1, "PRIORITY") && strcmp(s1, "SET"))))
+		if (eof || (! (estrcmp(s1, x_("GATE")) && estrcmp(s1, x_("FUNCTION"))
+			&& estrcmp(s1, x_("MODEL")) && estrcmp(s1, x_("I")) && estrcmp(s1, x_("O"))
+			&& estrcmp(s1, x_("T")) && estrcmp(s1, x_("FANOUT")) && estrcmp(s1, x_("LOAD"))
+			&& estrcmp(s1, x_("PRIORITY")) && estrcmp(s1, x_("SET")))))
 		{
 			--i_ptr;
 			break;
@@ -1015,13 +1023,13 @@ BOOLEAN simals_parse_node(void)
 
 		simals_ioptr2 = (IOPTR) simals_alloc_mem((INTBIG)sizeof(IO));
 		if (simals_ioptr2 == 0) return(TRUE);
-		simals_ioptr2->nodeptr = (NODE *)simals_alloc_mem((INTBIG)(strlen(s1) + 1));
+		simals_ioptr2->nodeptr = (NODE *)simals_alloc_mem((INTBIG)(estrlen(s1) + 1));
 		if (simals_ioptr2->nodeptr == 0) return(TRUE);
-		(void)strcpy((char *)simals_ioptr2->nodeptr, s1);
+		(void)estrcpy((CHAR *)simals_ioptr2->nodeptr, s1);
 		simals_ioptr2->strength = GATE_STRENGTH;
 		simals_ioptr2->next = 0;
-		*simals_ioptr1 = (char*) simals_ioptr2;
-		simals_ioptr1 = (char**) &(simals_ioptr2->next);
+		*simals_ioptr1 = (CHAR*) simals_ioptr2;
+		simals_ioptr1 = (CHAR**) &(simals_ioptr2->next);
 
 		eof = simals_get_string(s1);
 		if (eof)
@@ -1053,9 +1061,9 @@ BOOLEAN simals_parse_node(void)
 			ttyputerr(_("Node declaration: EOF unexpectedly found"));
 			return(TRUE);
 		}
-		if (! (strcmp(s1, "L") && strcmp(s1, "X") && strcmp(s1, "H")))
+		if (! (estrcmp(s1, x_("L")) && estrcmp(s1, x_("X")) && estrcmp(s1, x_("H"))))
 		{
-			simals_ioptr2->operand = (char*) simals_trans_state_to_number(s1);
+			simals_ioptr2->operand = (CHAR*) simals_trans_state_to_number(s1);
 		} else
 		{
 			--i_ptr;
@@ -1075,9 +1083,9 @@ BOOLEAN simals_parse_node(void)
 					ttyputerr(_("Node declaration: EOF unexpectedly found"));
 					return(TRUE);
 				}
-				simals_ioptr2->operand = simals_alloc_mem((INTBIG)(strlen(s1) + 1));
+				simals_ioptr2->operand = simals_alloc_mem((INTBIG)(estrlen(s1) + 1));
 				if (simals_ioptr2->operand == 0) return(TRUE);
-				(void)strcpy(simals_ioptr2->operand, s1);
+				(void)estrcpy(simals_ioptr2->operand, s1);
 				simals_ioptr2->operatr += 128;
 			}
 		}
@@ -1109,7 +1117,7 @@ BOOLEAN simals_parse_node(void)
  * Calling Arguments:
  *	s1 = pointer to character string that contains state value
  */
-INTBIG simals_trans_state_to_number(char *s1)
+INTBIG simals_trans_state_to_number(CHAR *s1)
 {
 	switch (s1[0])
 	{
@@ -1134,7 +1142,7 @@ INTBIG simals_trans_state_to_number(char *s1)
 BOOLEAN simals_parse_timing(void)
 {
 	BOOLEAN    eof;
-	char   s1[256], s2[256];
+	CHAR   s1[256], s2[256];
 	float  value;
 
 	simals_delta_def = simals_linear_def = simals_exp_def = simals_random_def = simals_abs_def = 0;
@@ -1208,7 +1216,7 @@ BOOLEAN simals_parse_timing(void)
 BOOLEAN simals_parse_delay(void)
 {
 	BOOLEAN   eof;
-	char  s1[256];
+	CHAR  s1[256];
 
 	eof = simals_get_string(s1);
 	if (eof)
@@ -1217,15 +1225,15 @@ BOOLEAN simals_parse_delay(void)
 		return(TRUE);
 	}
 
-	if (strcmp(s1, "01") && strcmp(s1, "10") && strcmp(s1, "OZ") && strcmp(s1, "Z1")
-		&& strcmp(s1, "1Z") && strcmp(s1, "Z0") && strcmp(s1, "0X") && strcmp(s1, "X1")
-		&& strcmp(s1, "1X") && strcmp(s1, "X0") && strcmp(s1, "XZ") && strcmp(s1, "ZX"))
+	if (estrcmp(s1, x_("01")) && estrcmp(s1, x_("10")) && estrcmp(s1, x_("OZ")) && estrcmp(s1, x_("Z1"))
+		&& estrcmp(s1, x_("1Z")) && estrcmp(s1, x_("Z0")) && estrcmp(s1, x_("0X")) && estrcmp(s1, x_("X1"))
+		&& estrcmp(s1, x_("1X")) && estrcmp(s1, x_("X0")) && estrcmp(s1, x_("XZ")) && estrcmp(s1, x_("ZX")))
 	{
 		ttyputerr(_("Invalid delay transition name '%s'"), s1);
 		return(TRUE);
 	}
 	else
-		(void)sprintf(delay, "%s", s1);
+		(void)esnprintf(delay, 16, x_("%s"), s1);
 
 	return(FALSE);
 }
@@ -1242,7 +1250,7 @@ BOOLEAN simals_parse_delay(void)
 BOOLEAN simals_parse_fanout(void)
 {
 	BOOLEAN   eof;
-	char  s1[256];
+	CHAR  s1[256];
 
 	eof = simals_get_string(s1);
 	if (eof)
@@ -1263,13 +1271,13 @@ BOOLEAN simals_parse_fanout(void)
 		return(TRUE);
 	}
 
-	if (strcmp(s1, "ON") == 0)
+	if (estrcmp(s1, x_("ON")) == 0)
 	{
 		simals_modptr2->fanout = 1;
 		return(FALSE);
 	}
 
-	if (strcmp(s1, "OFF") == 0)
+	if (estrcmp(s1, x_("OFF")) == 0)
 	{
 		simals_modptr2->fanout = 0;
 		return(FALSE);
@@ -1289,7 +1297,7 @@ BOOLEAN simals_parse_fanout(void)
 BOOLEAN simals_parse_load(void)
 {
 	BOOLEAN	eof;
-	char    s1[256], s2[256];
+	CHAR    s1[256], s2[256];
 	float    load;
 	LOADPTR  loadptr2;
 	LOAD   **loadptr1;
@@ -1301,10 +1309,10 @@ BOOLEAN simals_parse_load(void)
 	for(;;)
 	{
 		eof = simals_get_name(s1);
-		if (eof || (! (strcmp(s1, "GATE") && strcmp(s1, "FUNCTION")
-			&& strcmp(s1, "MODEL") && strcmp(s1, "I") && strcmp(s1, "O")
-			&& strcmp(s1, "T") && strcmp(s1, "FANOUT") && strcmp(s1, "LOAD")
-			&& strcmp(s1, "PRIORITY") && strcmp(s1, "SET"))))
+		if (eof || (! (estrcmp(s1, x_("GATE")) && estrcmp(s1, x_("FUNCTION"))
+			&& estrcmp(s1, x_("MODEL")) && estrcmp(s1, x_("I")) && estrcmp(s1, x_("O"))
+			&& estrcmp(s1, x_("T")) && estrcmp(s1, x_("FANOUT")) && estrcmp(s1, x_("LOAD"))
+			&& estrcmp(s1, x_("PRIORITY")) && estrcmp(s1, x_("SET")))))
 		{
 			--i_ptr;
 			break;
@@ -1331,9 +1339,9 @@ BOOLEAN simals_parse_load(void)
 
 		loadptr2 = (LOADPTR) simals_alloc_mem((INTBIG)sizeof(LOAD));
 		if (loadptr2 == 0) return(TRUE);
-		loadptr2->ptr = simals_alloc_mem((INTBIG)(strlen(s1) + 1));
+		loadptr2->ptr = simals_alloc_mem((INTBIG)(estrlen(s1) + 1));
 		if (loadptr2->ptr == 0) return(TRUE);
-		(void)strcpy(loadptr2->ptr, s1);
+		(void)estrcpy(loadptr2->ptr, s1);
 		loadptr2->load = load;
 		loadptr2->next = 0;
 		*loadptr1 = loadptr2;
@@ -1353,14 +1361,14 @@ BOOLEAN simals_parse_load(void)
 BOOLEAN simals_parse_model(void)
 {
 	BOOLEAN    eof;
-	char    s1[256];
+	CHAR    s1[256];
 	EXPORT **exptr1;
 	CONNECT **conptr1;
 
 	for(;;)
 	{
 		eof = simals_get_name(s1);
-		if (eof || (! (strcmp(s1, "GATE") && strcmp(s1, "FUNCTION") && strcmp(s1, "MODEL"))))
+		if (eof || (! (estrcmp(s1, x_("GATE")) && estrcmp(s1, x_("FUNCTION")) && estrcmp(s1, x_("MODEL")))))
 		{
 			--i_ptr;
 			break;
@@ -1368,13 +1376,13 @@ BOOLEAN simals_parse_model(void)
 
 		if (s1[0] == '}') continue;
 
-		if (! strcmp(s1, "SET"))
+		if (! estrcmp(s1, x_("SET")))
 		{
-			simals_ioptr1 = (char**) &(simals_modptr2->setptr);
+			simals_ioptr1 = (CHAR**) &(simals_modptr2->setptr);
 			for (simals_ioptr2 = simals_modptr2->setptr; simals_ioptr2;
 				simals_ioptr2 = simals_ioptr2->next)
 			{
-				simals_ioptr1 = (char**) &(simals_ioptr2->next);
+				simals_ioptr1 = (CHAR**) &(simals_ioptr2->next);
 			}
 			if (simals_parse_node()) return(TRUE);
 			continue;
@@ -1387,9 +1395,9 @@ BOOLEAN simals_parse_model(void)
 			{
 				simals_conptr2 = (CONPTR) simals_alloc_mem((INTBIG)sizeof(CONNECT));
 				if (simals_conptr2 == 0) return(TRUE);
-				simals_conptr2->inst_name = simals_alloc_mem((INTBIG)(strlen(s1) + 1));
+				simals_conptr2->inst_name = simals_alloc_mem((INTBIG)(estrlen(s1) + 1));
 				if (simals_conptr2->inst_name == 0) return(TRUE);
-				(void)strcpy(simals_conptr2->inst_name, s1);
+				(void)estrcpy(simals_conptr2->inst_name, s1);
 				simals_conptr2->model_name = 0;
 				simals_conptr2->exptr = 0;
 				simals_conptr2->next = 0;
@@ -1398,7 +1406,7 @@ BOOLEAN simals_parse_model(void)
 				break;
 			}
 			simals_conptr2 = *conptr1;
-			if (! strcmp(simals_conptr2->inst_name, s1))
+			if (! estrcmp(simals_conptr2->inst_name, s1))
 			{
 				ttyputerr(_("ERROR: Instance name '%s' defined more than once"), s1);
 				return(TRUE);
@@ -1412,9 +1420,9 @@ BOOLEAN simals_parse_model(void)
 			ttyputerr(_("Model declaration: EOF unexpectedly found"));
 			return(TRUE);
 		}
-		simals_conptr2->model_name = simals_alloc_mem((INTBIG)(strlen(s1) + 1));
+		simals_conptr2->model_name = simals_alloc_mem((INTBIG)(estrlen(s1) + 1));
 		if (simals_conptr2->model_name == 0) return(TRUE);
-		(void)strcpy(simals_conptr2->model_name, s1);
+		(void)estrcpy(simals_conptr2->model_name, s1);
 
 
 		eof = simals_get_string(s1);
@@ -1442,9 +1450,9 @@ BOOLEAN simals_parse_model(void)
 			simals_exptr2 = (EXPTR) simals_alloc_mem((INTBIG)sizeof(EXPORT));
 			if (simals_exptr2 == 0) return(TRUE);
 			simals_exptr2->nodeptr = 0;
-			simals_exptr2->node_name = simals_alloc_mem((INTBIG)(strlen(s1) + 1));
+			simals_exptr2->node_name = simals_alloc_mem((INTBIG)(estrlen(s1) + 1));
 			if (simals_exptr2->node_name == 0) return(TRUE);
-			(void)strcpy(simals_exptr2->node_name, s1);
+			(void)estrcpy(simals_exptr2->node_name, s1);
 			simals_exptr2->next = 0;
 			*exptr1 = simals_exptr2;
 			exptr1 = &simals_exptr2->next;
@@ -1464,7 +1472,7 @@ BOOLEAN simals_parse_model(void)
 BOOLEAN simals_parse_function(void)
 {
 	BOOLEAN    eof;
-	char     s1[256];
+	CHAR     s1[256];
 	INTBIG    j;
 	FUNCPTR  funchead;
 	EXPORT **exptr1;
@@ -1487,13 +1495,13 @@ BOOLEAN simals_parse_function(void)
 	for(;;)
 	{
 		eof = simals_get_string(s1);
-		if (eof || (!(strcmp(s1, "GATE") && strcmp(s1, "FUNCTION") && strcmp(s1, "MODEL"))))
+		if (eof || (!(estrcmp(s1, x_("GATE")) && estrcmp(s1, x_("FUNCTION")) && estrcmp(s1, x_("MODEL")))))
 		{
 			--i_ptr;
 			break;
 		}
 
-		if (!strcmp(s1, "I"))
+		if (!estrcmp(s1, x_("I")))
 		{
 			exptr1 = &funchead->inptr;
 			for (simals_exptr2 = funchead->inptr; simals_exptr2;
@@ -1505,13 +1513,13 @@ BOOLEAN simals_parse_function(void)
 			continue;
 		}
 
-		if (!strcmp(s1, "O"))
+		if (!estrcmp(s1, x_("O")))
 		{
 			if (simals_parse_func_output()) return(TRUE);
 			continue;
 		}
 
-		if (!strcmp(s1, "T"))
+		if (!estrcmp(s1, x_("T")))
 		{
 			if (simals_parse_timing()) return(TRUE);
 			funchead->delta = simals_delta_def;
@@ -1522,13 +1530,13 @@ BOOLEAN simals_parse_function(void)
 			continue;
 		}
 
-		if (!strcmp(s1, "LOAD"))
+		if (!estrcmp(s1, x_("LOAD")))
 		{
 			if (simals_parse_load()) return(TRUE);
 			continue;
 		}
 
-		if (!strcmp(s1, "PRIORITY"))
+		if (!estrcmp(s1, x_("PRIORITY")))
 		{
 			eof = simals_get_int(&j);
 			if (eof)
@@ -1540,13 +1548,13 @@ BOOLEAN simals_parse_function(void)
 			continue;
 		}
 
-		if (!strcmp(s1, "SET"))
+		if (!estrcmp(s1, x_("SET")))
 		{
-			simals_ioptr1 = (char**) &(simals_modptr2->setptr);
+			simals_ioptr1 = (CHAR**) &(simals_modptr2->setptr);
 			for (simals_ioptr2 = simals_modptr2->setptr; simals_ioptr2;
 				simals_ioptr2 = simals_ioptr2->next)
 			{
-				simals_ioptr1 = (char**) &(simals_ioptr2->next);
+				simals_ioptr1 = (CHAR**) &(simals_ioptr2->next);
 			}
 			(void)simals_parse_node();
 			continue;
@@ -1568,15 +1576,15 @@ BOOLEAN simals_parse_function(void)
 BOOLEAN simals_parse_func_input(EXPORT **exptr1)
 {
 	BOOLEAN   eof;
-	char    s1[256];
+	CHAR    s1[256];
 
 	for(;;)
 	{
 		eof = simals_get_name(s1);
-		if (eof || (!(strcmp(s1, "GATE") && strcmp(s1, "FUNCTION")
-			&& strcmp(s1, "MODEL") && strcmp(s1, "I") && strcmp(s1, "O")
-			&& strcmp(s1, "T") && strcmp(s1, "FANOUT") && strcmp(s1, "LOAD")
-			&& strcmp(s1, "PRIORITY") && strcmp(s1, "SET"))))
+		if (eof || (!(estrcmp(s1, x_("GATE")) && estrcmp(s1, x_("FUNCTION"))
+			&& estrcmp(s1, x_("MODEL")) && estrcmp(s1, x_("I")) && estrcmp(s1, x_("O"))
+			&& estrcmp(s1, x_("T")) && estrcmp(s1, x_("FANOUT")) && estrcmp(s1, x_("LOAD"))
+			&& estrcmp(s1, x_("PRIORITY")) && estrcmp(s1, x_("SET")))))
 		{
 			--i_ptr;
 			break;
@@ -1585,9 +1593,9 @@ BOOLEAN simals_parse_func_input(EXPORT **exptr1)
 		simals_exptr2 = (EXPTR)simals_alloc_mem(sizeof(EXPORT));
 		if (simals_exptr2 == 0) return(TRUE);
 		simals_exptr2->nodeptr = 0;
-		simals_exptr2->node_name = simals_alloc_mem(strlen(s1) + 1);
+		simals_exptr2->node_name = simals_alloc_mem(estrlen(s1) + 1);
 		if (simals_exptr2->node_name == 0) return(TRUE);
-		(void)strcpy(simals_exptr2->node_name, s1);
+		(void)estrcpy(simals_exptr2->node_name, s1);
 		simals_exptr2->next = 0;
 		*exptr1 = simals_exptr2;
 		exptr1 = &simals_exptr2->next;
@@ -1604,15 +1612,15 @@ BOOLEAN simals_parse_func_input(EXPORT **exptr1)
 BOOLEAN simals_parse_func_output(void)
 {
 	BOOLEAN   eof;
-	char    s1[256];
+	CHAR    s1[256];
 
 	for(;;)
 	{
 		eof = simals_get_name(s1);
-		if (eof || (!(strcmp(s1, "GATE") && strcmp(s1, "FUNCTION")
-			&& strcmp(s1, "MODEL") && strcmp(s1, "I") && strcmp(s1, "O")
-			&& strcmp(s1, "T") && strcmp(s1, "FANOUT") && strcmp(s1, "LOAD")
-			&& strcmp(s1, "PRIORITY") && strcmp(s1, "SET"))))
+		if (eof || (!(estrcmp(s1, x_("GATE")) && estrcmp(s1, x_("FUNCTION"))
+			&& estrcmp(s1, x_("MODEL")) && estrcmp(s1, x_("I")) && estrcmp(s1, x_("O"))
+			&& estrcmp(s1, x_("T")) && estrcmp(s1, x_("FANOUT")) && estrcmp(s1, x_("LOAD"))
+			&& estrcmp(s1, x_("PRIORITY")) && estrcmp(s1, x_("SET")))))
 		{
 			--i_ptr;
 			break;
@@ -1625,7 +1633,7 @@ BOOLEAN simals_parse_func_output(void)
 				ttyputerr(_("ERROR: Unable to find node %s in port list"), s1);
 				return(TRUE);
 			}
-			if (!strcmp(s1, simals_exptr2->node_name))
+			if (!estrcmp(s1, simals_exptr2->node_name))
 			{
 				simals_exptr2->nodeptr = (NODEPTR)1;
 				break;
@@ -1646,7 +1654,7 @@ BOOLEAN simals_parse_func_output(void)
  * Calling Arguments:
  *	line = pointer to the character string to be fragmented
  */
-BOOLEAN simals_fragment_command(char *line)
+BOOLEAN simals_fragment_command(CHAR *line)
 {
 	INTBIG   i, j, k, count;
 
@@ -1715,20 +1723,20 @@ BOOLEAN simals_fragment_command(char *line)
  *	nodehead = pointer to desired node in database
  *	sp	= pointer to char string where complete name is to be saved
  */
-void simals_compute_node_name(NODEPTR nodehead, char *sp)
+void simals_compute_node_name(NODEPTR nodehead, CHAR *sp)
 {
 	CONPTR  cellhead;
 	EXPTR   exhead;
 
 	cellhead = nodehead->cellptr;
-	strcpy(sp, simals_compute_path_name(cellhead));
+	estrcpy(sp, simals_compute_path_name(cellhead));
 
 	for (exhead = cellhead->exptr; ; exhead = exhead->next)
 	{
 		if (nodehead == exhead->nodeptr)
 		{
-			(void)strcat(sp, ".");
-			(void)strcat(sp, exhead->node_name);
+			(void)estrcat(sp, x_("."));
+			(void)estrcat(sp, exhead->node_name);
 			return;
 		}
 	}
@@ -1745,13 +1753,13 @@ void simals_compute_node_name(NODEPTR nodehead, char *sp)
  *	cellhead = pointer to desired level of hierarchy
  *	sp	= pointer to char string where path name is to be saved
  */
-char *simals_compute_path_name(CONPTR cellhead)
+CHAR *simals_compute_path_name(CONPTR cellhead)
 {
 	REGISTER void *infstr;
 
 	infstr = initinfstr();
 	for ( ; cellhead; cellhead = cellhead->parent)
-		formatinfstr(infstr, ".%s", cellhead->inst_name);
+		formatinfstr(infstr, x_(".%s"), cellhead->inst_name);
 	return(returninfstr(infstr));
 }
 
@@ -1766,17 +1774,17 @@ char *simals_compute_path_name(CONPTR cellhead)
  * Calling Argument:
  *	sp = pointer to char string containing path name to node
  */
-NODEPTR simals_find_node(char *sp)
+NODEPTR simals_find_node(CHAR *sp)
 {
 	INTBIG	i;
-	char    s1[80], *s2;
+	CHAR    s1[80], *s2;
 	CONPTR   cellptr;
 	EXPTR    exhead;
 	NODEPTR  nodehead;
 
 	if ((sp[0] == '$') && (sp[1] == 'N'))
 	{
-		i = atoi(&(sp[2]));
+		i = eatoi(&(sp[2]));
 		for (nodehead = simals_noderoot; nodehead; nodehead = nodehead->next)
 		{
 			if (nodehead->num == i) return(nodehead);
@@ -1784,7 +1792,7 @@ NODEPTR simals_find_node(char *sp)
 		return(0);
 	}
 
-	(void)strcpy(s1, sp);
+	(void)estrcpy(s1, sp);
 	s2 = s1;
 	for (i = 0; s1[i]; ++i)
 	{
@@ -1803,7 +1811,7 @@ NODEPTR simals_find_node(char *sp)
 
 	for (exhead = cellptr->exptr; exhead; exhead = exhead->next)
 	{
-		if (! strcmp(exhead->node_name, s2)) return(exhead->nodeptr);
+		if (! estrcmp(exhead->node_name, s2)) return(exhead->nodeptr);
 	}
 
 	return(0);
@@ -1814,20 +1822,21 @@ NODEPTR simals_find_node(char *sp)
  */
 static CONPTR  sim_als_cellptr;
 
-BOOLEAN simals_topofinstances(char **c)
+BOOLEAN simals_topofinstances(CHAR **c)
 {
+	Q_UNUSED( c );
 	if (simals_levelptr == 0) return(FALSE);
 	sim_als_cellptr = simals_levelptr->child;
 	return(TRUE);
 }
 
-char *simals_nextinstance(void)
+CHAR *simals_nextinstance(void)
 {
 	REGISTER void *infstr;
 
 	if (sim_als_cellptr == 0) return(0);
 	infstr = initinfstr();
-	formatinfstr(infstr, "%s (%s)", sim_als_cellptr->inst_name, sim_als_cellptr->model_name);
+	formatinfstr(infstr, x_("%s (%s)"), sim_als_cellptr->inst_name, sim_als_cellptr->model_name);
 	sim_als_cellptr = sim_als_cellptr->next;
 	return(returninfstr(infstr));
 }
@@ -1843,10 +1852,10 @@ char *simals_nextinstance(void)
  * Calling Argument:
  *	sp = pointer to char string containing path name to level in xref table
  */
-CONPTR simals_find_level(char *sp)
+CONPTR simals_find_level(CHAR *sp)
 {
 	INTBIG    i, j;
-	char    s1[80];
+	CHAR    s1[80];
 	CONPTR  cellptr;
 
 	if (sp[0] == '.')
@@ -1868,7 +1877,7 @@ CONPTR simals_find_level(char *sp)
 			for(s1[j] = 0; ; cellptr = cellptr->next)
 			{
 				if (! cellptr) return(0);
-				if (! strcmp(s1, cellptr->inst_name))
+				if (! estrcmp(s1, cellptr->inst_name))
 				{
 					if (! (sp[i])) return(cellptr);
 					cellptr = cellptr->child;
@@ -1893,23 +1902,26 @@ CONPTR simals_find_level(char *sp)
  * Calling Arguments:
  *	state_num = integer value that is to be converted to a character
  */
-void simals_trans_number_to_state(INTBIG state_num, char *s1)
+CHAR *simals_trans_number_to_state(INTBIG state_num)
 {
+	static CHAR s1[20];
+
 	switch (state_num)
 	{
 		case LOGIC_LOW:
-			(void)strcpy(s1, "L");
-			return;
+			(void)estrcpy(s1, x_("L"));
+			break;
 		case LOGIC_X:
-			(void)strcpy(s1, "X");
-			return;
+			(void)estrcpy(s1, x_("X"));
+			break;
 		case LOGIC_HIGH:
-			(void)strcpy(s1, "H");
-			return;
+			(void)estrcpy(s1, x_("H"));
+			break;
 		default:
-			(void)sprintf(s1, "0x%lX", state_num);
-			return;
+			(void)esnprintf(s1, 20, x_("0x%lX"), state_num);
+			break;
 	}
+	return(s1);
 }
 
 #endif  /* SIMTOOL - at top */
