@@ -39,18 +39,18 @@
 
 static MODPTR simals_primptr2;
 static MODEL **simals_primptr1;
-static char *simals_mainname = 0;
+static CHAR *simals_mainname = 0;
 
 /* prototypes for local routines */
 static BOOLEAN simals_flatten_model(CONPTR);
 static BOOLEAN simals_process_connect_list(CONPTR, CONPTR);
-static MODPTR  simals_find_model(char*);
-static EXPTR   simals_find_xref_entry(CONPTR, char*);
+static MODPTR  simals_find_model(CHAR*);
+static EXPTR   simals_find_xref_entry(CONPTR, CHAR*);
 static BOOLEAN simals_process_gate(CONPTR, MODPTR);
-static BOOLEAN simals_process_io_entry(MODPTR, CONPTR, IOPTR, char);
-static BOOLEAN simals_create_pin_entry(MODPTR, char*, NODEPTR);
-static STATPTR simals_create_stat_entry(MODPTR, char*, NODEPTR);
-static float   simals_find_load_value(MODPTR, char*);
+static BOOLEAN simals_process_io_entry(MODPTR, CONPTR, IOPTR, CHAR);
+static BOOLEAN simals_create_pin_entry(MODPTR, CHAR*, NODEPTR);
+static STATPTR simals_create_stat_entry(MODPTR, CHAR*, NODEPTR);
+static float   simals_find_load_value(MODPTR, CHAR*);
 static BOOLEAN simals_process_set_entry(CONPTR, IOPTR);
 static BOOLEAN simals_process_function(CONPTR, MODPTR);
 
@@ -59,7 +59,7 @@ static BOOLEAN simals_process_function(CONPTR, MODPTR);
  */
 void simals_freeflatmemory(void)
 {
-	if (simals_mainname != 0) efree((char *)simals_mainname);
+	if (simals_mainname != 0) efree((CHAR *)simals_mainname);
 }
 
 /*
@@ -89,7 +89,7 @@ BOOLEAN simals_flatten_network(void)
 	 */
 	simals_cellroot = (CONPTR) simals_alloc_mem((INTBIG)sizeof(CONNECT));
 	if (simals_cellroot == 0) return(TRUE);
-	simals_cellroot->inst_name = "[MIXED_SIGNAL_LEVEL]";
+	simals_cellroot->inst_name = x_("[MIXED_SIGNAL_LEVEL]");
 	simals_cellroot->model_name = simals_cellroot->inst_name;
 	simals_cellroot->exptr = 0;
 	simals_cellroot->parent = 0;
@@ -252,7 +252,7 @@ BOOLEAN simals_process_connect_list(CONPTR cellhead, CONPTR conhead)
 					break;
 				}
 				xrefptr2 = *xrefptr1;
-				if (! strcmp(xrefptr2->node_name, simals_exptr2->node_name))
+				if (! estrcmp(xrefptr2->node_name, simals_exptr2->node_name))
 				{
 					ttyputerr(_("Node '%s' in model '%s' connected more than once"),
 						simals_exptr2->node_name, conhead->model_name);
@@ -280,13 +280,13 @@ BOOLEAN simals_process_connect_list(CONPTR cellhead, CONPTR conhead)
  *	model_name = pointer to a string which contains the name of the model
  *		    to be located by the search procedure
  */
-MODPTR  simals_find_model(char *model_name)
+MODPTR  simals_find_model(CHAR *model_name)
 {
 	MODPTR  modhead;
-	char	propername[256], *pt;
+	CHAR	propername[256], *pt;
 
 	/* convert to proper name */
-	strcpy(propername, model_name);
+	estrcpy(propername, model_name);
 	for(pt = propername; *pt != 0; pt++)
 		if (!isalnum(*pt)) *pt = '_';
 
@@ -298,7 +298,7 @@ MODPTR  simals_find_model(char *model_name)
 			ttyputerr(_("ERROR: Model '%s' not found, simulation aborted"), propername);
 			break;
 		}
-		if (! strcmp(modhead->name, propername)) return(modhead);
+		if (! estrcmp(modhead->name, propername)) return(modhead);
 		modhead = modhead->next;
 	}
 	return(0);
@@ -315,7 +315,7 @@ MODPTR  simals_find_model(char *model_name)
  *	cellhead = pointer to the xref table for the model being processed
  *	name    = pointer to a char string containing the node name
  */
-EXPTR simals_find_xref_entry(CONPTR cellhead, char *name)
+EXPTR simals_find_xref_entry(CONPTR cellhead, CHAR *name)
 {
 	EXPORT **xrefptr1;
 	EXPTR    xrefptr2;
@@ -335,7 +335,7 @@ EXPTR simals_find_xref_entry(CONPTR cellhead, char *name)
 			break;
 		}
 		xrefptr2 = *xrefptr1;
-		if (! strcmp(xrefptr2->node_name, name)) return(xrefptr2);
+		if (! estrcmp(xrefptr2->node_name, name)) return(xrefptr2);
 		xrefptr1 = &xrefptr2->next;
 	}
 
@@ -407,13 +407,13 @@ BOOLEAN simals_process_gate(CONPTR cellhead, MODPTR modhead)
 		if (rowhead->delay == 0) simals_rowptr2->delay = 0; else
 			(void)allocstring(&(simals_rowptr2->delay), rowhead->delay, sim_tool->cluster);
 		simals_rowptr2->next = 0;
-		*simals_rowptr1 = (char*) simals_rowptr2;
-		simals_rowptr1 = (char**) &(simals_rowptr2->next);
+		*simals_rowptr1 = (CHAR*) simals_rowptr2;
+		simals_rowptr1 = (CHAR**) &(simals_rowptr2->next);
 
-		simals_ioptr1 = (char**) &(simals_rowptr2->inptr);
+		simals_ioptr1 = (CHAR**) &(simals_rowptr2->inptr);
 		if (simals_process_io_entry(modhead, cellhead, rowhead->inptr, 'I')) return(TRUE);
 
-		simals_ioptr1 = (char**) &(simals_rowptr2->outptr);
+		simals_ioptr1 = (CHAR**) &(simals_rowptr2->outptr);
 		if (simals_process_io_entry(modhead, cellhead, rowhead->outptr, 'O')) return(TRUE);
 
 		rowhead = rowhead->next;
@@ -438,13 +438,13 @@ BOOLEAN simals_process_gate(CONPTR cellhead, MODPTR modhead)
  *		  entry into the cross reference table
  *	flag    = character indicating if the node is an input or output
  */
-BOOLEAN simals_process_io_entry(MODPTR modhead, CONPTR cellhead, IOPTR iohead, char flag)
+BOOLEAN simals_process_io_entry(MODPTR modhead, CONPTR cellhead, IOPTR iohead, CHAR flag)
 {
 	EXPTR    xrefhead;
 
 	while (iohead)
 	{
-		xrefhead = simals_find_xref_entry(cellhead, (char *)iohead->nodeptr);
+		xrefhead = simals_find_xref_entry(cellhead, (CHAR *)iohead->nodeptr);
 		if (xrefhead == 0) return(TRUE);
 		simals_ioptr2 = (IOPTR) simals_alloc_mem((INTBIG)sizeof(IO));
 		if (simals_ioptr2 == 0) return(TRUE);
@@ -455,7 +455,7 @@ BOOLEAN simals_process_io_entry(MODPTR modhead, CONPTR cellhead, IOPTR iohead, c
 		{
 			xrefhead = simals_find_xref_entry(cellhead, iohead->operand);
 			if (xrefhead == 0) return(TRUE);
-			simals_ioptr2->operand = (char *) xrefhead->nodeptr;
+			simals_ioptr2->operand = (CHAR *) xrefhead->nodeptr;
 		} else
 		{
 			simals_ioptr2->operand = iohead->operand;
@@ -463,24 +463,24 @@ BOOLEAN simals_process_io_entry(MODPTR modhead, CONPTR cellhead, IOPTR iohead, c
 
 		simals_ioptr2->strength = iohead->strength;
 		simals_ioptr2->next = 0;
-		*simals_ioptr1 = (char*) simals_ioptr2;
-		simals_ioptr1 = (char**) &(simals_ioptr2->next);
+		*simals_ioptr1 = (CHAR*) simals_ioptr2;
+		simals_ioptr1 = (CHAR**) &(simals_ioptr2->next);
 
 		switch (flag)
 		{
 			case 'I':
-				if (simals_create_pin_entry(modhead, (char *)iohead->nodeptr,
+				if (simals_create_pin_entry(modhead, (CHAR *)iohead->nodeptr,
 					simals_ioptr2->nodeptr)) return(TRUE);
 				break;
 			case 'O':
 				simals_ioptr2->nodeptr = (NODE *)simals_create_stat_entry(modhead,
-					(char *)iohead->nodeptr, simals_ioptr2->nodeptr);
+					(CHAR *)iohead->nodeptr, simals_ioptr2->nodeptr);
 				if (simals_ioptr2->nodeptr == 0) return(TRUE);
 		}
 
 		if (simals_ioptr2->operatr > 127)
 		{
-			if (simals_create_pin_entry(modhead, (char *)iohead->operand,
+			if (simals_create_pin_entry(modhead, (CHAR *)iohead->operand,
 				(NODEPTR)simals_ioptr2->operand)) return(TRUE);
 		}
 
@@ -504,7 +504,7 @@ BOOLEAN simals_process_io_entry(MODPTR modhead, CONPTR cellhead, IOPTR iohead, c
  *		   whose input list is being updated
  *	nodehead  = pointer to the node data structure allocated for this node
  */
-BOOLEAN simals_create_pin_entry(MODPTR modhead, char *node_name, NODEPTR nodehead)
+BOOLEAN simals_create_pin_entry(MODPTR modhead, CHAR *node_name, NODEPTR nodehead)
 {
 	LOAD    **pinptr1;
 	LOADPTR  pinptr2;
@@ -516,7 +516,7 @@ BOOLEAN simals_create_pin_entry(MODPTR modhead, char *node_name, NODEPTR nodehea
 		{
 			pinptr2 = (LOADPTR)simals_alloc_mem((INTBIG)sizeof(LOAD));
 			if (pinptr2 == 0) return(TRUE);
-			pinptr2->ptr = (char *) simals_primptr2;
+			pinptr2->ptr = (CHAR *) simals_primptr2;
 			pinptr2->next = 0;
 			*pinptr1 = pinptr2;
 			nodehead->load += simals_find_load_value(modhead, node_name);
@@ -544,7 +544,7 @@ BOOLEAN simals_create_pin_entry(MODPTR modhead, char *node_name, NODEPTR nodehea
  *		   whose output list is being updated
  *	nodehead  = pointer to the node data structure allocated for this node
  */
-STATPTR  simals_create_stat_entry(MODPTR modhead, char *node_name, NODEPTR nodehead)
+STATPTR  simals_create_stat_entry(MODPTR modhead, CHAR *node_name, NODEPTR nodehead)
 {
 	STAT    **statptr1;
 	STATPTR  statptr2;
@@ -584,13 +584,13 @@ STATPTR  simals_create_stat_entry(MODPTR modhead, char *node_name, NODEPTR nodeh
  *	node_name = pointer to a char string containing the name of the node
  *		   whose load value is to be determined
  */
-float  simals_find_load_value(MODPTR modhead, char *node_name)
+float  simals_find_load_value(MODPTR modhead, CHAR *node_name)
 {
 	LOADPTR  loadhead;
 
 	for (loadhead = modhead->loadptr; loadhead != 0; loadhead = loadhead->next)
 	{
-		if (! strcmp(loadhead->ptr, node_name)) return(loadhead->load);
+		if (! estrcmp(loadhead->ptr, node_name)) return(loadhead->load);
 	}
 
 	if (modhead->type == 'F') return(0.0);
@@ -617,13 +617,13 @@ BOOLEAN simals_process_set_entry(CONPTR cellhead, IOPTR iohead)
 
 	for (; iohead; iohead = iohead->next)
 	{
-		xrefhead = simals_find_xref_entry(cellhead, (char *)iohead->nodeptr);
+		xrefhead = simals_find_xref_entry(cellhead, (CHAR *)iohead->nodeptr);
 		if (xrefhead == 0) return(TRUE);
 
 		sethead = simals_alloc_link_mem();
 		if (sethead == 0) return(TRUE);
 		sethead->type = 'N';
-		sethead->ptr = (char *) xrefhead->nodeptr;
+		sethead->ptr = (CHAR *) xrefhead->nodeptr;
 		sethead->state = (INTBIG) iohead->operand;
 		sethead->strength = iohead->strength;
 		sethead->priority = 2;
@@ -661,7 +661,7 @@ BOOLEAN simals_process_function(CONPTR cellhead, MODPTR modhead)
 	++simals_pseq;
 	simals_primptr2->name = modhead->name;
 	simals_primptr2->type = 'F';
-	simals_primptr2->ptr = (char*) simals_alloc_mem((INTBIG)sizeof(FUNC));
+	simals_primptr2->ptr = (CHAR*) simals_alloc_mem((INTBIG)sizeof(FUNC));
 	if (simals_primptr2->ptr == 0) return(TRUE);
 	simals_primptr2->exptr = 0;
 	simals_primptr2->setptr = 0;
@@ -697,7 +697,7 @@ BOOLEAN simals_process_function(CONPTR cellhead, MODPTR modhead)
 		if (simals_exptr2 == 0) return(TRUE);
 		if (exhead->nodeptr)
 		{
-			simals_exptr2->node_name = (char *) simals_create_stat_entry(modhead,
+			simals_exptr2->node_name = (CHAR *) simals_create_stat_entry(modhead,
 				exhead->node_name, xrefhead->nodeptr);
 			if (simals_exptr2->node_name == 0) return(TRUE);
 		} else
