@@ -40,25 +40,26 @@
 #include "network.h"
 #include "edialogs.h"
 
-static INTBIG sim_window_iter;
+static INTBIG  sim_window_iter;
 static BOOLEAN sim_als_wantweak = FALSE, sim_als_wantstrong = FALSE, sim_als_wantfull = FALSE;
 
 /* prototypes for local routines */
-static BOOLEAN  simals_topofsignals(char**);
-static char    *simals_nextsignals(void);
+static BOOLEAN  simals_topofsignals(CHAR**);
+static CHAR    *simals_nextsignals(void);
 static INTBIG   simals_count_channels(CONPTR);
 static void     simals_helpwindow(BOOLEAN waveform);
 static int      simals_sortbusnames(const void *e1, const void *e2);
 
-BOOLEAN simals_topofsignals(char **c)
+BOOLEAN simals_topofsignals(CHAR **c)
 {
+	Q_UNUSED( c );
 	sim_window_iter = 0;
 	return(TRUE);
 }
 
-char *simals_nextsignals(void)
+CHAR *simals_nextsignals(void)
 {
-	char *nextname;
+	CHAR *nextname;
 
 	for(; ; sim_window_iter++)
 	{
@@ -72,7 +73,7 @@ char *simals_nextsignals(void)
 }
 
 static COMCOMP sim_window_pickalstrace = {NOKEYWORD, simals_topofsignals,
-	simals_nextsignals, NOPARAMS, 0, " \t", N_("pick a signal to display"), ""};
+	simals_nextsignals, NOPARAMS, 0, x_(" \t"), N_("pick a signal to display"), x_("")};
 
 /*
  * Routine to start ALS simulation of facet "np".
@@ -86,7 +87,7 @@ BOOLEAN simals_startsimulation(NODEPROTO *np)
 	simals_init();
 
 	/* demand an ALS netlist */
-	error = asktool(vhdl_tool, "want-netlist-input", (INTBIG)np, sim_filetypeals);
+	error = asktool(vhdl_tool, x_("want-netlist-input"), (INTBIG)np, sim_filetypeals);
 	if (error != 0) return(TRUE);
 
 	/* read netlist */
@@ -94,6 +95,12 @@ BOOLEAN simals_startsimulation(NODEPROTO *np)
 	if (simals_read_net_desc(np)) return(TRUE);
 	if (simals_flatten_network()) return(TRUE);
 
+	if (simals_title != 0)
+	{
+		efree((CHAR *)simals_title);
+		simals_title = 0;
+	}
+
 	/* initialize display */
 	simals_init_display();
 	return(FALSE);
@@ -107,7 +114,7 @@ BOOLEAN simals_charhandlerwave(WINDOWPART *w, INTSML chr, INTBIG special)
 	REGISTER INTBIG i, j, traces, pos, thispos, strength, *tracelist,
 		tr, trl, nexttr, prevtr, highsig, *highsigs, numbits, bitoffset;
 	INTBIG state, *theBits;
-	char *par[30], *name;
+	CHAR *par[30], *name;
 	NODEPTR node, nodehead;
 	NODEPROTO *np;
 	double endtime;
@@ -139,6 +146,7 @@ BOOLEAN simals_charhandlerwave(WINDOWPART *w, INTSML chr, INTBIG special)
 	if (sim_window_isactive(&np) == 0)
 		return(us_charhandler(w, chr, special));
 
+	numbits = 0;
 	switch (chr)
 	{
 		/* update display */
@@ -268,6 +276,7 @@ BOOLEAN simals_charhandlerwave(WINDOWPART *w, INTSML chr, INTBIG special)
 		case 'e':
 		case 'r':
 		case DELETEKEY:
+			strength = OFF_STRENGTH;
 			break;
 
 		default:
@@ -289,6 +298,7 @@ BOOLEAN simals_charhandlerwave(WINDOWPART *w, INTSML chr, INTBIG special)
 		sim_window_clearframehighlight();
 
 		/* delete them */
+		nexttr = prevtr = 0;
 		for(j=0; highsigs[j] != 0; j++)
 		{
 			highsig = highsigs[j];
@@ -350,7 +360,7 @@ BOOLEAN simals_charhandlerwave(WINDOWPART *w, INTSML chr, INTBIG special)
 	}
 	if (chr == 'i')		/* print signal info */
 	{
-		par[0] = "state";
+		par[0] = x_("state");
 		par[1] = sim_window_gettracename(highsig);
 		simals_print_command(2, par);
 		return(FALSE);
@@ -362,16 +372,16 @@ BOOLEAN simals_charhandlerwave(WINDOWPART *w, INTSML chr, INTBIG special)
 		{
 			for(i=0; tracelist[i] != 0; i++)
 			{
-				par[0] = "delete";
+				par[0] = x_("delete");
 				par[1] = sim_window_gettracename(tracelist[i]);
-				par[2] = "all";
+				par[2] = x_("all");
 				simals_vector_command(3, par);
 			}
 		} else
 		{
-			par[0] = "delete";
+			par[0] = x_("delete");
 			par[1] = sim_window_gettracename(highsig);
-			par[2] = "all";
+			par[2] = x_("all");
 			simals_vector_command(3, par);
 		}
 		return(FALSE);
@@ -395,7 +405,7 @@ BOOLEAN simals_charhandlerwave(WINDOWPART *w, INTSML chr, INTBIG special)
 			sethead = simals_alloc_link_mem();
 			if (sethead == 0) return(FALSE);
 			sethead->type = 'N';
-			sethead->ptr = (char *)nodehead;
+			sethead->ptr = (CHAR *)nodehead;
 			if (i+bitoffset < 0 || theBits[i+bitoffset] == 0) sethead->state = LOGIC_LOW; else
 				sethead->state = LOGIC_HIGH;
 			sethead->strength = (INTSML)strength;
@@ -411,7 +421,7 @@ BOOLEAN simals_charhandlerwave(WINDOWPART *w, INTSML chr, INTBIG special)
 		sethead = simals_alloc_link_mem();
 		if (sethead == 0) return(FALSE);
 		sethead->type = 'N';
-		sethead->ptr = (char *)nodehead;
+		sethead->ptr = (CHAR *)nodehead;
 		sethead->state = state;
 		sethead->strength = (INTSML)strength;
 		sethead->priority = 2;
@@ -430,10 +440,10 @@ BOOLEAN simals_charhandlerwave(WINDOWPART *w, INTSML chr, INTBIG special)
  */
 BOOLEAN simals_charhandlerschem(WINDOWPART *w, INTSML chr, INTBIG special)
 {
-	INTBIG state, highsig;
+	INTBIG state, i, highsigcount, *highsiglist;
 	REGISTER INTSML strength;
-	REGISTER NETWORK *net;
-	char *par[30], *pt;
+	REGISTER NETWORK *net, **netlist;
+	CHAR *par[30], *pt;
 	double endtime;
 	NODEPTR nodehead;
 	LINKPTR sethead;
@@ -483,6 +493,7 @@ BOOLEAN simals_charhandlerschem(WINDOWPART *w, INTSML chr, INTBIG special)
 		case 'i':
 		case 't':
 		case 'e':
+			strength = OFF_STRENGTH;
 			break;
 		default:
 			sim_als_wantweak = sim_als_wantstrong = FALSE;
@@ -491,35 +502,37 @@ BOOLEAN simals_charhandlerschem(WINDOWPART *w, INTSML chr, INTBIG special)
 	sim_als_wantweak = sim_als_wantstrong = FALSE;
 
 	/* find the net in the waveform window */
-	net = net_gethighlightednet(FALSE, FALSE);
+	netlist = net_gethighlightednets(FALSE);
+	net = netlist[0];
 	if (net == NONETWORK) return(FALSE);
-	if (net->namecount > 0) pt = net->netname; else
+	if (net->namecount > 0) pt = networkname(net, 0); else
 		pt = describenetwork(net);
-	highsig = sim_window_findtrace(pt);
-	if (highsig == 0)
+	highsiglist = sim_window_findtrace(pt, &highsigcount);
+	if (highsigcount == 0)
 	{
 		ttyputerr(_("Cannot find network %s in simulation"), pt);
 		return(FALSE);
 	}
 	sim_window_cleartracehighlight();
-	sim_window_addhighlighttrace(highsig);
+	for(i=0; i<highsigcount; i++)
+		sim_window_addhighlighttrace(highsiglist[i]);
 
 	if (chr == 'c')
 	{
-		par[0] = sim_window_gettracename(highsig);
+		par[0] = sim_window_gettracename(highsiglist[0]);
 		simals_clock_command(1, par);
 		return(FALSE);
 	}
 	if (chr == 'i')
 	{
-		par[0] = "state";
-		par[1] = sim_window_gettracename(highsig);
+		par[0] = x_("state");
+		par[1] = sim_window_gettracename(highsiglist[0]);
 		simals_print_command(2, par);
 		return(FALSE);
 	}
 	if (chr == 't')
 	{
-		nodehead = (NODEPTR)sim_window_gettracedata(highsig);
+		nodehead = (NODEPTR)sim_window_gettracedata(highsiglist[0]);
 		nodehead->tracenode = TRUE;
 		(void)simals_initialize_simulator(TRUE);
 		nodehead->tracenode = FALSE;
@@ -527,22 +540,22 @@ BOOLEAN simals_charhandlerschem(WINDOWPART *w, INTSML chr, INTBIG special)
 	}
 	if (chr == 'e')
 	{
-		par[0] = "delete";
-		par[1] = sim_window_gettracename(highsig);
-		par[2] = "all";
+		par[0] = x_("delete");
+		par[1] = sim_window_gettracename(highsiglist[0]);
+		par[2] = x_("all");
 		simals_vector_command(3, par);
 		simals_fill_display_arrays();
 		sim_window_redraw();
 		return(FALSE);
 	}
 
-	nodehead = simals_find_node(sim_window_gettracename(highsig));
+	nodehead = simals_find_node(sim_window_gettracename(highsiglist[0]));
 	if (nodehead == 0) return(FALSE);
 
 	sethead = simals_alloc_link_mem();
 	if (sethead == 0) return(FALSE);
 	sethead->type = 'N';
-	sethead->ptr = (char *)nodehead;
+	sethead->ptr = (CHAR *)nodehead;
 	sethead->state = state;
 	sethead->strength = strength;
 	sethead->priority = 2;
@@ -570,34 +583,34 @@ void simals_helpwindow(BOOLEAN waveform)
 	if (waveform)
 		ttyputmsg(_("These keys may be typed in the ALS Waveform window:")); else
 			ttyputmsg(_("These keys may be typed in the ALS Schematic window:"));
-	ttyputinstruction("L,0", 4, _("Set signal low (normal strength)"));
-	ttyputinstruction("WL",  4, _("Set signal low (weak strength)"));
-	ttyputinstruction("SL",  4, _("Set signal low (strong strength)"));
-	ttyputinstruction("H,1", 4, _("Set signal high (normal strength)"));
-	ttyputinstruction("WH",  4, _("Set signal high (weak strength)"));
-	ttyputinstruction("SH",  4, _("Set signal high (strong strength)"));
-	ttyputinstruction(" X",  4, _("Set signal undefined (normal strength)"));
-	ttyputinstruction("WX",  4, _("Set signal undefined (weak strength)"));
-	ttyputinstruction("SX",  4, _("Set signal undefined (strong strength)"));
+	ttyputinstruction(x_(";,0"), 4, _("Set signal low (normal strength)"));
+	ttyputinstruction(x_("wl"),  4, _("Set signal low (weak strength)"));
+	ttyputinstruction(x_("sl"),  4, _("Set signal low (strong strength)"));
+	ttyputinstruction(x_("h,1"), 4, _("Set signal high (normal strength)"));
+	ttyputinstruction(x_("wh"),  4, _("Set signal high (weak strength)"));
+	ttyputinstruction(x_("sh"),  4, _("Set signal high (strong strength)"));
+	ttyputinstruction(x_(" x"),  4, _("Set signal undefined (normal strength)"));
+	ttyputinstruction(x_("wx"),  4, _("Set signal undefined (weak strength)"));
+	ttyputinstruction(x_("sx"),  4, _("Set signal undefined (strong strength)"));
 	if (waveform)
 	{
-		ttyputinstruction(" V",  4, _("Set bus to wide value (normal strength)"));
-		ttyputinstruction("WV",  4, _("Set bus to wide value (weak strength)"));
-		ttyputinstruction("SV",  4, _("Set bus to wide value (strong strength)"));
+		ttyputinstruction(x_(" v"),  4, _("Set bus to wide value (normal strength)"));
+		ttyputinstruction(x_("wv"),  4, _("Set bus to wide value (weak strength)"));
+		ttyputinstruction(x_("sv"),  4, _("Set bus to wide value (strong strength)"));
 	}
-	ttyputinstruction(" C",  4, _("Set signal to be a clock"));
-	ttyputinstruction(" E",  4, _("Delete all vectors on signal"));
-	ttyputinstruction(" I",  4, _("Print information about signal"));
-	ttyputinstruction(" T",  4, _("Trace events on signal(s)"));
-	ttyputinstruction(" U",  4, _("Update display (resimulate)"));
+	ttyputinstruction(x_(" c"),  4, _("Set signal to be a clock"));
+	ttyputinstruction(x_(" e"),  4, _("Delete all vectors on signal"));
+	ttyputinstruction(x_(" i"),  4, _("Print information about signal"));
+	ttyputinstruction(x_(" t"),  4, _("Trace events on signal(s)"));
+	ttyputinstruction(x_(" u"),  4, _("Update display (resimulate)"));
 
 	if (waveform)
 	{
-		ttyputinstruction(" A", 4, _("Add signal to simulation window"));
-		ttyputinstruction(" R", 4, _("Remove signal from the window"));
-		ttyputinstruction(" B", 4, _("Combine selected signals into a bus"));
-		ttyputinstruction("FT", 4, _("Full Trace of all events"));
-		ttyputinstruction(" P", 4, _("Preserve snapshot of simulation window in database"));
+		ttyputinstruction(x_(" a"), 4, _("Add signal to simulation window"));
+		ttyputinstruction(x_(" r"), 4, _("Remove signal from the window"));
+		ttyputinstruction(x_(" b"), 4, _("Combine selected signals into a bus"));
+		ttyputinstruction(x_("ft"), 4, _("Full Trace of all events"));
+		ttyputinstruction(x_(" p"), 4, _("Preserve snapshot of simulation window in database"));
 	}
 }
 
@@ -630,12 +643,12 @@ BOOLEAN simals_set_current_level(void)
 {
 	INTBIG i, j, k, buscount, oldsigcount, chn, bussignals[MAXSIMWINDOWBUSWIDTH],
 		len, olen;
-	char **oldsignames;
+	CHAR **oldsignames;
 	REGISTER VARIABLE *var;
 	NODEPTR nodehead;
 	NODE *node, *subnode;
 	EXPTR exhead;
-	char *name, *subname, *pt, *opt, *start, save;
+	CHAR *name, *subname, *pt, *opt, *start, save;
 	void *sa;
 	NODEPROTO *np;
 	REGISTER void *infstr;
@@ -672,14 +685,14 @@ BOOLEAN simals_set_current_level(void)
 				exhead = exhead->next;
 			} else
 			{
-				name = "";
+				name = x_("");
 				simals_levelptr->display_page[i].nodeptr = 0;
 			}
 			(void)allocstring(&simals_levelptr->display_page[i].name, name, sim_tool->cluster);
 
 			/* convert names to proper bracketed form */
 			name = simals_levelptr->display_page[i].name;
-			len = strlen(name) - 1;
+			len = estrlen(name) - 1;
 			if (name[len] == '_')
 			{
 				olen = len;
@@ -696,8 +709,15 @@ BOOLEAN simals_set_current_level(void)
 
 	/* prepare the simulation window */
 	oldsigcount = 0;
-	if (sim_window_isactive(&np) == 0)
+	i = sim_window_isactive(&np);
+	if ((i&SIMWINDOWWAVEFORM) == 0)
 	{
+		if (i != 0 && np != simals_mainproto)
+		{
+			/* stop simulation of facet "np" */
+			sim_window_stopsimulation();
+		}
+
 		/* no simulation running: start it up */
 		if (simals_levelptr->num_chn <= 0) return(TRUE);
 
@@ -710,7 +730,7 @@ BOOLEAN simals_set_current_level(void)
 			{
 				sa = newstringarray(sim_tool->cluster);
 				for(i=0; i<oldsigcount; i++)
-					addtostringarray(sa, ((char **)var->addr)[i]);
+					addtostringarray(sa, ((CHAR **)var->addr)[i]);
 				oldsignames = getstringarray(sa, &oldsigcount);
 			}
 		}
@@ -721,6 +741,13 @@ BOOLEAN simals_set_current_level(void)
 			if (oldsigcount > 0) killstringarray(sa);
 			return(TRUE);
 		}
+		sim_window_state = (sim_window_state & ~SIMENGINECUR) | SIMENGINECURALS;
+	}
+
+	/* set the window title */
+	if (simals_title == 0) sim_window_titleinfo(_("Top Level")); else
+	{
+		sim_window_titleinfo(simals_title);
 	}
 
 	/* load the traces */
@@ -846,7 +873,7 @@ BOOLEAN simals_set_current_level(void)
  */
 int simals_sortbusnames(const void *e1, const void *e2)
 {
-	REGISTER char *n1, *n2;
+	REGISTER CHAR *n1, *n2;
 	REGISTER INTBIG i1, i2;
 
 	i1 = *((INTBIG *)e1);
@@ -936,13 +963,13 @@ void simals_fill_display_arrays(void)
 		if (nodelist[j] == 0) continue;
 		displayobj = simals_levelptr->display_page[j+1].displayptr;
 		sim_window_loaddigtrace(displayobj, numsteps[j], timearrays[j], statearrays[j]);
-		efree((char *)timearrays[j]);
-		efree((char *)statearrays[j]);
+		efree((CHAR *)timearrays[j]);
+		efree((CHAR *)statearrays[j]);
 	}
-	efree((char *)nodelist);
-	efree((char *)numsteps);
-	efree((char *)timearrays);
-	efree((char *)statearrays);
+	efree((CHAR *)nodelist);
+	efree((CHAR *)numsteps);
+	efree((CHAR *)timearrays);
+	efree((CHAR *)statearrays);
 }
 
 #endif  /* SIMTOOL - at top */
