@@ -39,8 +39,8 @@
 
 static LINKPTR simals_freelink = 0;
 BOOLEAN  simals_tracing = FALSE;
-static char *simals_statedesc[] = {N_("High"), N_("Undefined"), N_("Low")};
-static char *simals_strengthdesc[] = {N_("Off-"), N_("Weak-"), N_("Weak-"), "", "",
+static CHAR *simals_statedesc[] = {N_("High"), N_("Undefined"), N_("Low")};
+static CHAR *simals_strengthdesc[] = {N_("Off-"), N_("Weak-"), N_("Weak-"), x_(""), x_(""),
 	N_("Strong-"), N_("Strong-")};
 
 /* prototypes for local routines */
@@ -61,7 +61,7 @@ void simals_freesimmemory(void)
 	{
 		link = simals_freelink;
 		simals_freelink = simals_freelink->left;
-		efree((char *)link);
+		efree((CHAR *)link);
 	}
 }
 
@@ -80,7 +80,6 @@ double simals_initialize_simulator(BOOLEAN force)
 	LINKPTR linkptr2, linkhead, link;
 	NODEPTR nodehead;
 	STATPTR stathead;
-	char s1[40];
 	double tmin, tmax;
 	REGISTER VARIABLE *var;
 	double mintime, maxtime;
@@ -181,8 +180,8 @@ double simals_initialize_simulator(BOOLEAN force)
 		if (simals_levelptr != 0) simals_fill_display_arrays();
 		sim_window_redraw();
 		sim_window_updatelayoutwindow();
-		sim_windowconvertengineeringnotation(simals_time_abs, s1);
-		ttyputverbose(M_("Simulation completed at time %s"), s1);
+		ttyputverbose(M_("Simulation completed at time %s"),
+			sim_windowconvertengineeringnotation(simals_time_abs));
 	}
 
 	return(simals_time_abs);
@@ -201,13 +200,13 @@ double simals_initialize_simulator(BOOLEAN force)
 BOOLEAN simals_fire_event(void)
 {
 	INTBIG operand, state;
-	unsigned char operatr;
+	UCHAR  operatr;
 	double time;
 	LINKPTR	linkhead, linkptr2, vecthead;
 	NODEPTR	nodehead;
 	ROWPTR rowhead;
 	STATPTR	stathead;
-	char s1[30], s2[300];
+	CHAR s2[300];
 
 	simals_time_abs = simals_linkfront->time;
 	linkhead = simals_linkfront;
@@ -243,9 +242,9 @@ BOOLEAN simals_fire_event(void)
 			stathead = (STATPTR)linkhead->ptr;
 			if (simals_trace_all_nodes || stathead->nodeptr->tracenode)
 			{
-				sim_windowconvertengineeringnotation(simals_time_abs, s1);
 				simals_compute_node_name(stathead->nodeptr, s2);
-				ttyputmsg("%s: Firing gate %s%s, net %s", s1, stathead->primptr->name, stathead->primptr->level, s2);
+				ttyputmsg(x_("%s: Firing gate %s%s, net %s"), sim_windowconvertengineeringnotation(simals_time_abs),
+					stathead->primptr->name, stathead->primptr->level, s2);
 				simals_tracing = TRUE;
 			}
 			if (stathead->sched_state != linkhead->state ||
@@ -306,9 +305,8 @@ BOOLEAN simals_fire_event(void)
 			nodehead = (NODEPTR)linkhead->ptr;
 			if (simals_trace_all_nodes || nodehead->tracenode)
 			{
-				sim_windowconvertengineeringnotation(simals_time_abs, s1);
 				simals_compute_node_name(nodehead, s2);
-				ttyputmsg("%s: Changed state of net %s", s1, s2);
+				ttyputmsg(x_("%s: Changed state of net %s"), sim_windowconvertengineeringnotation(simals_time_abs), s2);
 				simals_tracing = TRUE;
 			}
 			if (linkhead->state == nodehead->new_state &&
@@ -372,6 +370,7 @@ void simals_create_check_list(NODEPTR nodehead, LINKPTR linkhead)
 	INTSML	strength, thisstrength;
 	STATPTR stathead;
 	TRAKPTR trakhead;
+	Q_UNUSED( linkhead );
 
 	/* get initial state of the node */
 	state = nodehead->new_state;
@@ -380,9 +379,11 @@ void simals_create_check_list(NODEPTR nodehead, LINKPTR linkhead)
 	/* print state of signal if this signal is being traced */
 	if (simals_tracing)
 	{
-		ttyputmsg("  Formerly %s%s, starts at %s%s",
-			_(simals_strengthdesc[nodehead->sum_strength]), _(simals_statedesc[nodehead->sum_state+3]),
-			_(simals_strengthdesc[strength]), _(simals_statedesc[state+3]));
+		ttyputmsg(x_("  Formerly %s%s, starts at %s%s"),
+			TRANSLATE(simals_strengthdesc[nodehead->sum_strength]),
+			TRANSLATE(simals_statedesc[nodehead->sum_state+3]),
+			TRANSLATE(simals_strengthdesc[strength]),
+			TRANSLATE(simals_statedesc[state+3]));
 	}
 
 	/* look at all factors affecting the node */
@@ -391,8 +392,8 @@ void simals_create_check_list(NODEPTR nodehead, LINKPTR linkhead)
 		thisstate = stathead->new_state;
 		thisstrength = stathead->new_strength;
 		if (simals_tracing)
-			ttyputmsg("    %s%s from %s%s", _(simals_strengthdesc[thisstrength]),
-			_(simals_statedesc[thisstate+3]), stathead->primptr->name, stathead->primptr->level);
+			ttyputmsg(x_("    %s%s from %s%s"), TRANSLATE(simals_strengthdesc[thisstrength]),
+			TRANSLATE(simals_statedesc[thisstate+3]), stathead->primptr->name, stathead->primptr->level);
 
 		/* higher strength overrides previous node state */
 		if (thisstrength > strength)
@@ -420,7 +421,7 @@ void simals_create_check_list(NODEPTR nodehead, LINKPTR linkhead)
 	/* stop now if node state did not change */
 	if (nodehead->sum_state == state && nodehead->sum_strength == strength)
 	{
-		if (simals_tracing) ttyputmsg("    NO CHANGE");
+		if (simals_tracing) ttyputmsg(x_("    NO CHANGE"));
 		return;
 	}
 
@@ -436,7 +437,8 @@ void simals_create_check_list(NODEPTR nodehead, LINKPTR linkhead)
 			simals_trakfull = 1;
 	}
 	if (simals_tracing)
-		ttyputmsg("    BECOMES %s%s", _(simals_strengthdesc[strength]), _(simals_statedesc[state+3]));
+		ttyputmsg(x_("    BECOMES %s%s"), TRANSLATE(simals_strengthdesc[strength]),
+			TRANSLATE(simals_statedesc[state+3]));
 
 	nodehead->sum_state = state;
 	nodehead->sum_strength = strength;
@@ -458,7 +460,8 @@ void simals_create_check_list(NODEPTR nodehead, LINKPTR linkhead)
 BOOLEAN simals_schedule_new_events(void)
 {
 	INTBIG operand;
-	unsigned char flag, operatr;
+	UCHAR1 flag;
+	UCHAR operatr;
 	LOADPTR	chekhead;
 	MODPTR primhead;
 	ROWPTR rowhead;
@@ -583,7 +586,6 @@ BOOLEAN simals_calculate_event_time(MODPTR primhead, ROWPTR rowhead)
 	STATPTR	stathead;
 	IOPTR iohead;
 	LINKPTR	linkptr2;
-	char s1[30];
 
 	time = 0.0;
 	priority = primhead->priority;
@@ -633,7 +635,7 @@ BOOLEAN simals_calculate_event_time(MODPTR primhead, ROWPTR rowhead)
 		linkptr2 = simals_alloc_link_mem();
 		if (linkptr2 == 0) return(TRUE);
 		linkptr2->type = 'G';
-		linkptr2->ptr = (char *)stathead;
+		linkptr2->ptr = (CHAR *)stathead;
 		linkptr2->operatr = stathead->sched_op = iohead->operatr;
 		linkptr2->state = stathead->sched_state = (INTBIG)iohead->operand;
 		linkptr2->strength = stathead->sched_strength = iohead->strength;
@@ -642,9 +644,8 @@ BOOLEAN simals_calculate_event_time(MODPTR primhead, ROWPTR rowhead)
 		linkptr2->primhead = primhead;
 		if (simals_tracing)
 		{
-			sim_windowconvertengineeringnotation(time, s1);
 			ttyputmsg(_("      Schedule(G): %s%s at %s"), stathead->primptr->name,
-				stathead->primptr->level, s1);
+				stathead->primptr->level, sim_windowconvertengineeringnotation(time));
 		}
 		simals_insert_link_list(linkptr2);
 	}
@@ -704,17 +705,17 @@ void simals_free_link_mem(LINKPTR linkhead)
  * Calling Arguments:
  *	linkhead = pointer to the data element that is going to be inserted
  */
-char **simals_insert_set_list(LINKPTR linkhead)
+CHAR **simals_insert_set_list(LINKPTR linkhead)
 {
-	char **linkptr1;
+	CHAR **linkptr1;
 	LINKPTR linkptr2;
 
-	linkptr1 = (char **)&simals_setroot;
+	linkptr1 = (CHAR **)&simals_setroot;
 	for(;;)
 	{
 		if ((*linkptr1) == 0)
 		{
-			*linkptr1 = (char *)linkhead;
+			*linkptr1 = (CHAR *)linkhead;
 			break;
 		}
 		linkptr2 = (LINKPTR)*linkptr1;
@@ -722,10 +723,10 @@ char **simals_insert_set_list(LINKPTR linkhead)
 			linkptr2->priority > linkhead->priority))
 		{
 			linkhead->right = linkptr2;
-			*linkptr1 = (char *)linkhead;
+			*linkptr1 = (CHAR *)linkhead;
 			break;
 		}
-		linkptr1 = (char **)&(linkptr2->right);
+		linkptr1 = (CHAR **)&(linkptr2->right);
 	}
 	return(linkptr1);
 }
@@ -743,17 +744,17 @@ char **simals_insert_set_list(LINKPTR linkhead)
  */
 void simals_insert_link_list(LINKPTR linkhead)
 {
-	char **linkptr1;
+	CHAR **linkptr1;
 	LINKPTR linkptr2, linkptr3;
 
-	linkptr1 = (char **)&simals_linkback;
+	linkptr1 = (CHAR **)&simals_linkback;
 	linkptr2 = simals_linkback;
 	linkptr3 = 0;
 	for(;;)
 	{
 		if (! linkptr2)
 		{
-			simals_linkfront = (LINKPTR)(*linkptr1 = (char *)linkhead);
+			simals_linkfront = (LINKPTR)(*linkptr1 = (CHAR *)linkhead);
 			linkhead->left = 0;
 			linkhead->right = linkptr3;
 			linkhead->up = linkhead;
@@ -763,7 +764,7 @@ void simals_insert_link_list(LINKPTR linkhead)
 
 		if (linkptr2->time < linkhead->time)
 		{
-			*linkptr1 = (char *)(linkptr2->right = linkhead);
+			*linkptr1 = (CHAR *)(linkptr2->right = linkhead);
 			linkhead->left = linkptr2;
 			linkhead->right = linkptr3;
 			linkhead->up = linkhead;
@@ -779,7 +780,7 @@ void simals_insert_link_list(LINKPTR linkhead)
 				linkhead->right = linkptr2->right;
 				linkhead->down = linkptr2;
 				linkhead->up = linkptr2->up;
-				linkptr2->up = (LINKPTR)(*linkptr1 = (char *)linkhead);
+				linkptr2->up = (LINKPTR)(*linkptr1 = (CHAR *)linkhead);
 				if (linkhead->left)
 				{
 					linkhead->left->right = linkhead;
@@ -790,27 +791,27 @@ void simals_insert_link_list(LINKPTR linkhead)
 				return;
 			}
 
-			linkptr1 = (char **)&(linkptr2->up);
+			linkptr1 = (CHAR **)&(linkptr2->up);
 			linkptr2 = linkptr2->up;
 			linkptr3 = 0;
 			for(;;)
 			{
 				if (linkptr2->priority <= linkhead->priority)
 				{
-					*linkptr1 = (char *)(linkptr2->down = linkhead);
+					*linkptr1 = (CHAR *)(linkptr2->down = linkhead);
 					linkhead->up = linkptr2;
 					linkhead->down = linkptr3;
 					return;
 				}
 
 				linkptr3 = linkptr2;
-				linkptr1 = (char **)&(linkptr2->up);
+				linkptr1 = (CHAR **)&(linkptr2->up);
 				linkptr2 = linkptr2->up;
 			}
 		}
 
 		linkptr3 = linkptr2;
-		linkptr1 = (char **)&(linkptr2->left);
+		linkptr1 = (CHAR **)&(linkptr2->left);
 		linkptr2 = linkptr2->left;
 	}
 }
