@@ -60,7 +60,7 @@ static INTBIG           sim_irsimlambda;
 static INTBIG           sim_irsiminternal;
 static INTBIG           sim_irsimglobalnetcount;	/* number of global nets */
 static INTBIG           sim_irsimglobalnettotal = 0;/* size of global net array */
-static char           **sim_irsimglobalnets;		/* global net names */
+static CHAR           **sim_irsimglobalnets;		/* global net names */
 static INTBIG          *sim_irsimglobalnetsnumbers;	/* global net numbers */
 static void            *sim_irsimmerge;				/* for polygon merging */
 
@@ -68,7 +68,7 @@ static void            *sim_irsimmerge;				/* for polygon merging */
 static void             sim_irsimaddarctomerge(ARCINST *ai, XARRAY trans);
 static void             sim_irsimaddnodetomerge(NODEINST *ni, XARRAY localtrans);
 static IRSIMTRANSISTOR *sim_irsimalloctransistor(void);
-static char            *sim_irsimbuildnetname(char *name);
+static CHAR            *sim_irsimbuildnetname(CHAR *name);
 static BOOLEAN          sim_irsimclipagainstgates(POLYGON *poly, ARCINST *ai, XARRAY trans);
 static BOOLEAN          sim_irsimcropbox(INTBIG *lx, INTBIG *hx, INTBIG *ly, INTBIG *hy, INTBIG bx,
 							INTBIG ux, INTBIG by, INTBIG uy);
@@ -80,9 +80,11 @@ static void             sim_irsimgetallgeometry(INTBIG layer, TECHNOLOGY *tech,
 static void             sim_irsimgetareaperimeter(INTBIG *x, INTBIG *y, INTBIG count,
 							float *a, INTBIG *p);
 static INTBIG           sim_irsimgetglobal(NETWORK *net);
-static INTBIG           sim_irsimnewnetnumber(char *name);
-static void             sim_irsimnewalias(INTBIG netnum, char *alias);
-static INTBIG           sim_irsimrecurse(NODEPROTO *facet, XARRAY trans);
+static INTBIG           sim_irsimnewnetnumber(CHAR *name);
+#if SIMFSDBWRITE != 0
+static void             sim_irsimnewalias(INTBIG netnum, CHAR *alias);
+#endif
+static INTBIG           sim_irsimrecurse(NODEPROTO *facet, XARRAY trans, float m);
 
 /*
  * Routine to free all memory associated with this module.
@@ -97,18 +99,18 @@ void sim_freeirsimmemory(void)
 	{
 		it = sim_irsimtransistorfree;
 		sim_irsimtransistorfree = it->nextirsimtransistor;
-		efree((char *)it);
+		efree((CHAR *)it);
 	}
 	if (sim_irsimnettotal > 0)
-		efree((char *)sim_irsimnets);
+		efree((CHAR *)sim_irsimnets);
 
 	for(i=0; i<sim_irsimglobalnettotal; i++)
 		if (sim_irsimglobalnets[i] != 0)
-			efree((char *)sim_irsimglobalnets[i]);
+			efree((CHAR *)sim_irsimglobalnets[i]);
 	if (sim_irsimglobalnettotal > 0)
 	{
-		efree((char *)sim_irsimglobalnets);
-		efree((char *)sim_irsimglobalnetsnumbers);
+		efree((CHAR *)sim_irsimglobalnets);
+		efree((CHAR *)sim_irsimglobalnetsnumbers);
 	}
 }
 
@@ -119,8 +121,8 @@ void sim_freeirsimmemory(void)
 void sim_writeirsim(NODEPROTO *facet)
 {
 	REGISTER FILE *f;
-	char *truename;
-	REGISTER char *netfile;
+	CHAR *truename;
+	REGISTER CHAR *netfile;
 	REGISTER void *infstr;
 
 	/* make sure network tool is on */
@@ -135,7 +137,7 @@ void sim_writeirsim(NODEPROTO *facet)
 	/* construct the simulation description file name from the facet */
 	infstr = initinfstr();
 	addstringtoinfstr(infstr, facet->cell->cellname);
-	addstringtoinfstr(infstr, ".sim");
+	addstringtoinfstr(infstr, x_(".sim"));
 	netfile = returninfstr(infstr);
 
 	/* create the simulation file */
@@ -154,6 +156,26 @@ void sim_writeirsim(NODEPROTO *facet)
 	ttyputmsg(_("%s written"), truename);
 }
 
+typedef struct
+{
+	CHAR *signalname;
+	INTBIG signalindex;
+} UNIQUESIGNALSORT;
+
+int sim_irsimsortsignalnames(const void *e1, const void *e2);
+
+int sim_irsimsortsignalnames(const void *e1, const void *e2)
+{
+	UNIQUESIGNALSORT *uss1, *uss2;
+	INTBIG diff;
+
+	uss1 = (UNIQUESIGNALSORT *)e1;
+	uss2 = (UNIQUESIGNALSORT *)e2;
+	diff = namesame(uss1->signalname, uss2->signalname);
+	if (diff != 0) return(diff);
+	return(uss1->signalindex - uss2->signalindex);
+}
+
 /*
  * Routine to generate an IRSIM deck for facet "facet" and write it to stream "f".
  */
@@ -161,7 +183,7 @@ void sim_irsimgeneratedeck(NODEPROTO *facet, FILE *f)
 {
 	REGISTER INTBIG backannotate;
 	REGISTER TECHNOLOGY *tech;
-	char numberstring[80];
+	CHAR numberstring[80];
 	REGISTER IRSIMTRANSISTOR *it;
 	REGISTER PORTPROTO *pp;
 	REGISTER NETWORK *net;
@@ -169,8 +191,10 @@ void sim_irsimgeneratedeck(NODEPROTO *facet, FILE *f)
 	REGISTER NODEPROTO *np;
 	REGISTER NODEINST *ni;
 	REGISTER VARIABLE *var;
-	REGISTER char *name;
+	REGISTER CHAR *name;
 	REGISTER INTBIG sa, sp, da, dp, i, j;
+	UNIQUESIGNALSORT *uss;
+	INTBIG index, nextindex;
 
 	/* get value of lambda */
 	tech = facet->tech;
@@ -210,7 +234,7 @@ void sim_irsimgeneratedeck(NODEPROTO *facet, FILE *f)
 	 */
 	sim_firstirsimtransistor = NOIRSIMTRANSISTOR;
 	backannotate = 0;
-	if (asktool(net_tool, "name-nets", (INTBIG)facet) != 0) backannotate++;
+	if (asktool(net_tool, x_("name-nets"), (INTBIG)facet) != 0) backannotate++;
 	for(net = facet->firstnetwork; net != NONETWORK; net = net->nextnetwork)
 		net->temp1 = -1;
 	for(pp = facet->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
@@ -224,7 +248,7 @@ void sim_irsimgeneratedeck(NODEPROTO *facet, FILE *f)
 				if (net->globalnet >= 0) net->temp1 = sim_irsimgetglobal(net); else
 				{
 					if (net->namecount <= 0) continue;
-					net->temp1 = sim_irsimnewnetnumber(net->netname);
+					net->temp1 = sim_irsimnewnetnumber(networkname(net, 0));
 				}
 			}
 		} else
@@ -233,9 +257,9 @@ void sim_irsimgeneratedeck(NODEPROTO *facet, FILE *f)
 			if (net->globalnet >= 0) net->temp1 = sim_irsimgetglobal(net); else
 			{
 				name = pp->protoname;
-				if (net->namecount > 0) name = net->netname;
-				if (portispower(pp)) name = "vdd"; else
-					if (portisground(pp)) name = "gnd";
+				if (net->namecount > 0) name = networkname(net, 0);
+				if (portispower(pp)) name = x_("vdd"); else
+					if (portisground(pp)) name = x_("gnd");
 				net->temp1 = sim_irsimnewnetnumber(name);
 			}
 		}
@@ -246,7 +270,7 @@ void sim_irsimgeneratedeck(NODEPROTO *facet, FILE *f)
 	begintraversehierarchy();
 	if ((sim_irsim_state&IRSIMPARASITICS) == IRSIMPARAFULL)
 		sim_irsimmerge = mergenew(sim_tool->cluster);
-	if (sim_irsimrecurse(facet, el_matid) != 0) backannotate++;
+	if (sim_irsimrecurse(facet, el_matid, 1.0) != 0) backannotate++;
 	if ((sim_irsim_state&IRSIMPARASITICS) == IRSIMPARAFULL)
 	{
 		sim_irsimfacetlisthead = NOIRSIMTRANSISTOR;
@@ -256,44 +280,47 @@ void sim_irsimgeneratedeck(NODEPROTO *facet, FILE *f)
 	endtraversehierarchy();
 
 	/* write deck to "f" */	
-	var = getval((INTBIG)facet, VNODEPROTO, VSTRING, "SIM_irsim_behave_file");
+	var = getval((INTBIG)facet, VNODEPROTO, VSTRING, x_("SIM_irsim_behave_file"));
 	if (var != NOVARIABLE)
 	{
 		/* this facet has a disk file of IRSIM associated with it */
-		xprintf(f, "|\n"); /* First comment line is treated by IRSIM in a special way */
-		xprintf(f, "| Facet %s is described in this file:\n", describenodeproto(np));
-		xprintf(f, "@ %s\n", (char *)var->addr);
+		xprintf(f, x_("|\n")); /* First comment line is treated by IRSIM in a special way */
+		xprintf(f, x_("| Facet %s is described in this file:\n"), describenodeproto(facet));
+		xprintf(f, x_("@ %s\n"), (CHAR *)var->addr);
 	} else
 	{
-		xprintf(f,"| units: %g tech: %s format: SU\n",
+		xprintf(f,x_("| units: %g tech: %s format: SU\n"),
 			scaletodispunit(sim_irsimlambda, DISPUNITCMIC), tech->techname);
-		xprintf(f, "| IRSIM file for facet %s from Library %s\n",
+		xprintf(f, x_("| IRSIM file for facet %s from Library %s\n"),
 			describenodeproto(facet), facet->cell->lib->libname);
+		us_emitcopyright(f, x_("| "), x_(""));
 		if ((us_useroptions&NODATEORVERSION) == 0)
 		{
 			if (facet->creationdate)
-				xprintf(f, "| Created on %s\n", timetostring((time_t)facet->creationdate));
+				xprintf(f, x_("| Created on %s\n"), timetostring((time_t)facet->creationdate));
 			if (facet->revisiondate)
-				xprintf(f, "| Last revised on %s\n", timetostring((time_t)facet->revisiondate));
-			(void)sprintf(numberstring, "%s", timetostring(getcurrenttime()));
-			xprintf(f, "| Written on %s by Electric VLSI Design System, version %s\n",
+				xprintf(f, x_("| Last revised on %s\n"), timetostring((time_t)facet->revisiondate));
+			(void)esnprintf(numberstring, 80, x_("%s"), timetostring(getcurrenttime()));
+			xprintf(f, x_("| Written on %s by Electric VLSI Design System, version %s\n"),
 				numberstring, el_version);
 		} else
 		{
-			xprintf(f, "| Written by Electric VLSI Design System\n");
+			xprintf(f, x_("| Written by Electric VLSI Design System\n"));
 		}
 
 		for(it = sim_firstirsimtransistor; it != NOIRSIMTRANSISTOR; it = it->nextirsimtransistor)
 		{
-			if (it->transistortype == NPTRANMOS) xprintf(f, "n"); else
-				xprintf(f, "p");
-			xprintf(f, " %s", sim_irsimnets[it->gate].name);
-			xprintf(f, " %s", sim_irsimnets[it->source].name);
-			xprintf(f, " %s", sim_irsimnets[it->drain].name);
-			xprintf(f, " %s %s", latoa(it->length, sim_irsimlambda), latoa(it->width, sim_irsimlambda));
-			xprintf(f, " %s %s", latoa(it->xpos, sim_irsimlambda), latoa(it->ypos, sim_irsimlambda));
-			if (it->transistortype == NPTRANMOS) xprintf(f, " g=S_gnd"); else
-				xprintf(f, " g=S_vdd");
+			if (it->m != (INTBIG)it->m)
+				ttyputmsg("Noninteger m factor in Irsim deck: %f\n", it->m);
+			if (it->transistortype == NPTRANMOS) xprintf(f, x_("n")); else
+				xprintf(f, x_("p"));
+			xprintf(f, x_(" %s"), sim_irsimnets[it->gate].name);
+			xprintf(f, x_(" %s"), sim_irsimnets[it->source].name);
+			xprintf(f, x_(" %s"), sim_irsimnets[it->drain].name);
+			xprintf(f, x_(" %s %s"), latoa(it->length, sim_irsimlambda), latoa((INTBIG)(it->width*it->m), sim_irsimlambda));
+			xprintf(f, x_(" %s %s"), latoa(it->xpos, sim_irsimlambda), latoa(it->ypos, sim_irsimlambda));
+			if (it->transistortype == NPTRANMOS) xprintf(f, x_(" g=S_gnd")); else
+				xprintf(f, x_(" g=S_vdd"));
 			sa = (INTBIG)(it->sarea / sim_irsimlambda);
 			if (sa == 0.0) sa = it->width * 6;
 
@@ -305,8 +332,8 @@ void sim_irsimgeneratedeck(NODEPROTO *facet, FILE *f)
 			da = (da + sim_irsimlambda/2) / sim_irsimlambda * sim_irsimlambda;
 			dp = (it->dperimeter + sim_irsimlambda/2) / sim_irsimlambda * sim_irsimlambda;
 			if (dp == 0) dp = it->width + 12*sim_irsimlambda;
-			xprintf(f, " s=A_%s,P_%s", latoa(sa, sim_irsimlambda), latoa(sp, sim_irsimlambda));
-			xprintf(f, " d=A_%s,P_%s\n", latoa(da, sim_irsimlambda), latoa(dp, sim_irsimlambda));
+			xprintf(f, x_(" s=A_%s,P_%s"), latoa((INTBIG)(sa*it->m), sim_irsimlambda), latoa((INTBIG)(sp*it->m), sim_irsimlambda));
+			xprintf(f, x_(" d=A_%s,P_%s\n"), latoa((INTBIG)(da*it->m), sim_irsimlambda), latoa((INTBIG)(dp*it->m), sim_irsimlambda));
 		}
 	}
 
@@ -314,26 +341,37 @@ void sim_irsimgeneratedeck(NODEPROTO *facet, FILE *f)
 		ttyputmsg(_("Back-annotation information has been added (library must be saved)"));
 
 	/* mark redundant signals */
+	uss = (UNIQUESIGNALSORT *)emalloc(sim_irsimnetnumber * (sizeof (UNIQUESIGNALSORT)), sim_tool->cluster);
+	if (uss == 0) return;
 	for(i=0; i<sim_irsimnetnumber; i++)
 	{
-		sim_irsimnets[i].flags = IRSIMNETVALID;
-		if (namesame(sim_irsimnets[i].name, "vdd") == 0 ||
-			namesame(sim_irsimnets[i].name, "gnd") == 0)
-		{
-			sim_irsimnets[i].flags = 0;
-			continue;
-		}
-		for(j=0; j<i; j++)
-			if (namesame(sim_irsimnets[j].name, sim_irsimnets[i].name) == 0) break;
-		if (j < i) sim_irsimnets[i].flags = 0;
+		uss[i].signalindex = i;
+		uss[i].signalname = sim_irsimnets[i].name;
 	}
+	esort(uss, sim_irsimnetnumber, sizeof (UNIQUESIGNALSORT), sim_irsimsortsignalnames);
+	for(i=0; i<sim_irsimnetnumber; i++)
+	{
+		index = uss[i].signalindex;
+		name = uss[i].signalname;
+		if (namesame(name, x_("vdd")) == 0 || namesame(name, x_("gnd")) == 0)
+			sim_irsimnets[index].flags = 0; else
+				sim_irsimnets[index].flags = IRSIMNETVALID;
+		for(j=i+1; j<sim_irsimnetnumber; j++)
+		{
+			nextindex = uss[j].signalindex;
+			if (namesame(sim_irsimnets[index].name, sim_irsimnets[nextindex].name) != 0) break;
+			sim_irsimnets[nextindex].flags = 0;
+		}
+		i = j - 1;
+	}
+	efree((CHAR *)uss);
 }
 
 /*
  * Routine to recursively examine facet "facet" with transformation matrix "trans"
  * and gather transistor information.
  */
-INTBIG sim_irsimrecurse(NODEPROTO *facet, XARRAY trans)
+INTBIG sim_irsimrecurse(NODEPROTO *facet, XARRAY trans, float m)
 {
 	REGISTER NETWORK *net, *gate, *source, *drain;
 	REGISTER PORTPROTO *pp, *s, *g1, *g2, *d, *cpp;
@@ -342,16 +380,17 @@ INTBIG sim_irsimrecurse(NODEPROTO *facet, XARRAY trans)
 	REGISTER PORTARCINST *pi;
 	REGISTER PORTEXPINST *pe;
 	REGISTER ARCINST *ai;
-	REGISTER VARIABLE *var;
+	REGISTER VARIABLE *var, *varm;
 	REGISTER INTBIG i, backannotate, type, realtype, firsttransistor, nodewidth, nindex, sigcount;
 	INTBIG x, y;
 	REGISTER IRSIMTRANSISTOR *it, *previt;
 	XARRAY singletrans, localtrans, subrot;
-	char internalname[50], **nodenames, *onenodename[1];
+	float mi;
+	CHAR internalname[50], **nodenames, *onenodename[1];
 	REGISTER void *infstr;
 
 	backannotate = 0;
-	if (asktool(net_tool, "name-nodes", (INTBIG)facet) != 0) backannotate++;
+	if (asktool(net_tool, x_("name-nodes"), (INTBIG)facet) != 0) backannotate++;
 
 	/* create unique numbers for internal nets */
 	for(net = facet->firstnetwork; net != NONETWORK; net = net->nextnetwork)
@@ -361,7 +400,7 @@ INTBIG sim_irsimrecurse(NODEPROTO *facet, XARRAY trans)
 		{
 #if SIMFSDBWRITE != 0
 			if (net->namecount > 0 && net->globalnet < 0 && net->temp1 >= sim_irsimtopnetnumber)
-				sim_irsimnewalias(net->temp1, sim_irsimbuildnetname(net->netname));
+				sim_irsimnewalias(net->temp1, sim_irsimbuildnetname(networkname(net, 0)));
 #endif
 			continue;
 		}
@@ -369,10 +408,10 @@ INTBIG sim_irsimrecurse(NODEPROTO *facet, XARRAY trans)
 		{
 			if (net->namecount > 0)
 			{
-				net->temp1 = sim_irsimnewnetnumber(sim_irsimbuildnetname(net->netname));
+				net->temp1 = sim_irsimnewnetnumber(sim_irsimbuildnetname(networkname(net, 0)));
 			} else
 			{
-				sprintf(internalname, "INTERNAL%ld", sim_irsiminternal++);
+				esnprintf(internalname, 50, x_("INTERNAL%ld"), sim_irsiminternal++);
 				net->temp1 = sim_irsimnewnetnumber(internalname);
 			}
 		}
@@ -386,6 +425,15 @@ INTBIG sim_irsimrecurse(NODEPROTO *facet, XARRAY trans)
 		np = ni->proto;
 		makerot(ni, singletrans);
 		transmult(singletrans, trans, localtrans);
+		mi = m;
+		varm = getvalkey((INTBIG)ni, VNODEINST, -1, el_attrkey_M);
+		if (varm != NOVARIABLE)
+		{
+			CHAR *pt = describevariable(varm, -1, -1);
+			if (isanumber(pt))
+				mi = m * (float)atof(pt);
+			else ttyputmsg("Attribute \"m\" is not a number: %s\n", pt);
+		}
 		if (np->primindex == 0)
 		{
 			/* ignore recursive references (showing icon in contents) */
@@ -395,7 +443,7 @@ INTBIG sim_irsimrecurse(NODEPROTO *facet, XARRAY trans)
 			cnp = contentsview(np);
 			if (cnp == NONODEPROTO) cnp = np;
 
-			if (asktool(net_tool, "name-nets", (INTBIG)cnp) != 0) backannotate++;
+			if (asktool(net_tool, x_("name-nets"), (INTBIG)cnp) != 0) backannotate++;
 
 			/* see if the node is arrayed */
 			nodewidth = ni->arraysize;
@@ -407,15 +455,15 @@ INTBIG sim_irsimrecurse(NODEPROTO *facet, XARRAY trans)
 			{
 				if (var == NOVARIABLE) nodewidth = 1; else
 				{
-					sigcount = net_evalbusname(APBUS, (char *)var->addr, &nodenames,
+					sigcount = net_evalbusname(APBUS, (CHAR *)var->addr, &nodenames,
 						NOARCINST, NONODEPROTO, 0);
 					if (sigcount != nodewidth) nodewidth = 1;
 				}
 			}
 			if (nodewidth == 1)
 			{
-				if (var == NOVARIABLE) onenodename[0] = ""; else
-					onenodename[0] = (char *)var->addr;
+				if (var == NOVARIABLE) onenodename[0] = x_(""); else
+					onenodename[0] = (CHAR *)var->addr;
 				nodenames = onenodename;
 			}
 			for(nindex=0; nindex<nodewidth; nindex++)
@@ -484,7 +532,7 @@ INTBIG sim_irsimrecurse(NODEPROTO *facet, XARRAY trans)
 							{
 								if (net->namecount <= 0) continue;
 								infstr = initinfstr();
-								formatinfstr(infstr, "%s/%s", nodenames[nindex], net->netname);
+								formatinfstr(infstr, x_("%s/%s"), nodenames[nindex], networkname(net, 0));
 								net->temp1 = sim_irsimnewnetnumber(sim_irsimbuildnetname(returninfstr(infstr)));
 							}
 						}
@@ -494,8 +542,8 @@ INTBIG sim_irsimrecurse(NODEPROTO *facet, XARRAY trans)
 						if (net->globalnet >= 0) net->temp1 = sim_irsimgetglobal(net); else
 						{
 							infstr = initinfstr();
-							formatinfstr(infstr, "%s/", nodenames[nindex]);
-							if (net->namecount > 0) addstringtoinfstr(infstr, net->netname); else
+							formatinfstr(infstr, x_("%s/"), nodenames[nindex]);
+							if (net->namecount > 0) addstringtoinfstr(infstr, networkname(net, 0)); else
 								addstringtoinfstr(infstr, pp->protoname);
 							net->temp1 = sim_irsimnewnetnumber(sim_irsimbuildnetname(returninfstr(infstr)));
 						}
@@ -504,7 +552,7 @@ INTBIG sim_irsimrecurse(NODEPROTO *facet, XARRAY trans)
 				maketrans(ni, singletrans);
 				transmult(singletrans, localtrans, subrot);
 				downhierarchy(ni, cnp, nindex);
-				if (sim_irsimrecurse(cnp, subrot) != 0) backannotate = 1;
+				if (sim_irsimrecurse(cnp, subrot, mi) != 0) backannotate = 1;
 				uphierarchy();
 			}
 		} else
@@ -567,6 +615,7 @@ INTBIG sim_irsimrecurse(NODEPROTO *facet, XARRAY trans)
 						it->darea = previt->darea;
 						it->sperimeter = previt->sperimeter;
 						it->dperimeter = previt->dperimeter;
+						it->m = mi;
 					} else
 					{
 						portposition(ni, s, &x, &y);
@@ -578,6 +627,7 @@ INTBIG sim_irsimrecurse(NODEPROTO *facet, XARRAY trans)
 						if (it->width < 0) it->width = 0;
 						it->sarea = it->darea = 0.0;
 						it->sperimeter = it->dperimeter = 0;
+						it->m = mi;
 						firsttransistor++;
 						ni->temp1 = (INTBIG)it;
 					}
@@ -682,7 +732,7 @@ void sim_irsimaddnodetomerge(NODEINST *ni, XARRAY trans)
 			}
 		}
 		if (netnumber < 0)
-			netnumber = sim_irsimnewnetnumber(sim_irsimbuildnetname("unattached"));
+			netnumber = sim_irsimnewnetnumber(sim_irsimbuildnetname(x_("unattached")));
 		xformpoly(poly, trans);
 		mergeaddpolygon(sim_irsimmerge, netnumber, poly->tech, poly);
 	}
@@ -779,6 +829,8 @@ void sim_irsimgetallgeometry(INTBIG layer, TECHNOLOGY *tech, INTBIG *x, INTBIG *
 	INTBIG perimeter;
 	float area;
 
+	Q_UNUSED( layer );
+	Q_UNUSED( tech );
 	/* get bounds of this geometry */
 	lx = hx = x[0];
 	ly = hy = y[0];
@@ -891,16 +943,16 @@ void sim_irsimgetareaperimeter(INTBIG *x, INTBIG *y, INTBIG count, float *a, INT
  * Routine to construct the IRSIM name of a node, given that its name is "name" and that
  * it is down in the hierarchy (use "gettraversalpath" to determine its location).
  */
-char *sim_irsimbuildnetname(char *name)
+CHAR *sim_irsimbuildnetname(CHAR *name)
 {
 	REGISTER INTBIG i, nodewidth, sigcount;
 	NODEINST **nilist, *ni;
-	char **nodenames;
+	CHAR **nodenames;
 	INTBIG depth, *indexlist;
 	REGISTER VARIABLE *var;
 	REGISTER void *infstr;
 
-	gettraversalpath(el_curlib->curnodeproto, &nilist, &indexlist, &depth, 0);
+	gettraversalpath(el_curlib->curnodeproto, el_curwindowpart, &nilist, &indexlist, &depth, 0);
 	infstr = initinfstr();
 	for(i=0; i<depth; i++)
 	{
@@ -912,7 +964,7 @@ char *sim_irsimbuildnetname(char *name)
 		{
 			if (var == NOVARIABLE) nodewidth = 1; else
 			{
-				sigcount = net_evalbusname(APBUS, (char *)var->addr, &nodenames,
+				sigcount = net_evalbusname(APBUS, (CHAR *)var->addr, &nodenames,
 					NOARCINST, NONODEPROTO, 0);
 				if (sigcount != nodewidth) nodewidth = 1;
 			}
@@ -921,7 +973,7 @@ char *sim_irsimbuildnetname(char *name)
 		if (var != NOVARIABLE)
 		{
 			if (nodewidth > 1) addstringtoinfstr(infstr, nodenames[indexlist[i]]); else
-				addstringtoinfstr(infstr, (char *)var->addr);
+				addstringtoinfstr(infstr, (CHAR *)var->addr);
 		} else
 		{
 			addstringtoinfstr(infstr, ni->proto->cell->cellname);
@@ -980,7 +1032,7 @@ void sim_irsimfreenetworkinfo(void)
 /*
  * Routine to create a new IRSIM network object with name "name" and return its number.
  */
-INTBIG sim_irsimnewnetnumber(char *name)
+INTBIG sim_irsimnewnetnumber(CHAR *name)
 {
 	REGISTER INTBIG newtotal, i;
 	IRSIMNETWORK *newnets;
@@ -997,7 +1049,7 @@ INTBIG sim_irsimnewnetnumber(char *name)
 			newnets[i].signal = sim_irsimnets[i].signal;
 			newnets[i].flags = sim_irsimnets[i].flags;
 		}
-		if (sim_irsimnettotal > 0) efree((char *)sim_irsimnets);
+		if (sim_irsimnettotal > 0) efree((CHAR *)sim_irsimnets);
 		sim_irsimnets = newnets;
 		sim_irsimnettotal = newtotal;
 	}
@@ -1013,7 +1065,7 @@ INTBIG sim_irsimnewnetnumber(char *name)
 /*
  * Routine to create an alias to IRSIM network object netnum
  */
-void sim_irsimnewalias(INTBIG netnum, char *alias)
+void sim_irsimnewalias(INTBIG netnum, CHAR *alias)
 {
 	REGISTER INTBIG newtotal, i;
 	IRSIMALIAS *newaliases;
@@ -1029,27 +1081,24 @@ void sim_irsimnewalias(INTBIG netnum, char *alias)
 			newaliases[i].name = sim_irsimaliases[i].name;
 			newaliases[i].alias = sim_irsimaliases[i].alias;
 		}
-		if (sim_irsimaliastotal > 0) efree((char *)sim_irsimaliases);
+		if (sim_irsimaliastotal > 0) efree((CHAR *)sim_irsimaliases);
 		sim_irsimaliases = newaliases;
 		sim_irsimaliastotal = newtotal;
 	}
 	i = sim_irsimaliasnumber++;
 	sim_irsimaliases[i].name = sim_irsimnets[netnum].name;
 	(void)allocstring(&sim_irsimaliases[i].alias, alias, sim_tool->cluster);
-#if 0
-	printf("irsimalias <%s> of <%s> %d\n", alias, sim_irsimnets[netnum].name, netnum);
-#endif
 }
 #endif
 
 INTBIG sim_irsimgetglobal(NETWORK *net)
 {
 	REGISTER INTBIG i;
-	REGISTER char *name;
+	REGISTER CHAR *name;
 
 	if (net->globalnet < 0 || net->globalnet >= net->parent->globalnetcount) return(0);
-	if (net->globalnet == GLOBALNETPOWER) name = "vdd"; else
-		if (net->globalnet == GLOBALNETGROUND) name = "gnd"; else
+	if (net->globalnet == GLOBALNETPOWER) name = x_("vdd"); else
+		if (net->globalnet == GLOBALNETGROUND) name = x_("gnd"); else
 			name = describenetwork(net);
 	for(i=0; i<sim_irsimglobalnetcount; i++)
 		if (namesame(name, sim_irsimglobalnets[i]) == 0) break;
@@ -1064,7 +1113,7 @@ void sim_irsimgatherglobals(NODEPROTO *np)
 {
 	REGISTER INTBIG i, newtotal, *newnumbers;
 	NETWORK *net;
-	REGISTER char *gname, **newlist;
+	REGISTER CHAR *gname, **newlist;
 	REGISTER NODEPROTO *onp, *cnp;
 	REGISTER NODEINST *ni;
 
@@ -1075,8 +1124,8 @@ void sim_irsimgatherglobals(NODEPROTO *np)
 		if (net->globalnet < 0) continue;
 
 		/* global net found: see if it is already in the list */
-		if (net->globalnet == GLOBALNETPOWER) gname = "vdd"; else
-			if (net->globalnet == GLOBALNETGROUND) gname = "gnd"; else
+		if (net->globalnet == GLOBALNETPOWER) gname = x_("vdd"); else
+			if (net->globalnet == GLOBALNETGROUND) gname = x_("gnd"); else
 				gname = describenetwork(net);
 		for(i=0; i<sim_irsimglobalnetcount; i++)
 			if (namesame(gname, sim_irsimglobalnets[i]) == 0) break;
@@ -1088,7 +1137,7 @@ void sim_irsimgatherglobals(NODEPROTO *np)
 			newtotal = sim_irsimglobalnettotal * 2;
 			if (sim_irsimglobalnetcount >= newtotal)
 				newtotal = sim_irsimglobalnetcount + 5;
-			newlist = (char **)emalloc(newtotal * (sizeof (char *)), sim_tool->cluster);
+			newlist = (CHAR **)emalloc(newtotal * (sizeof (CHAR *)), sim_tool->cluster);
 			if (newlist == 0) return;
 			newnumbers = (INTBIG *)emalloc(newtotal * SIZEOFINTBIG, sim_tool->cluster);
 			if (newnumbers == 0) return;
@@ -1102,15 +1151,15 @@ void sim_irsimgatherglobals(NODEPROTO *np)
 				newlist[i] = 0;
 			if (sim_irsimglobalnettotal > 0)
 			{
-				efree((char *)sim_irsimglobalnets);
-				efree((char *)sim_irsimglobalnetsnumbers);
+				efree((CHAR *)sim_irsimglobalnets);
+				efree((CHAR *)sim_irsimglobalnetsnumbers);
 			}
 			sim_irsimglobalnets = newlist;
 			sim_irsimglobalnetsnumbers = newnumbers;
 			sim_irsimglobalnettotal = newtotal;
 		}
 		if (sim_irsimglobalnets[sim_irsimglobalnetcount] != 0)
-			efree((char *)sim_irsimglobalnets[sim_irsimglobalnetcount]);
+			efree((CHAR *)sim_irsimglobalnets[sim_irsimglobalnetcount]);
 		(void)allocstring(&sim_irsimglobalnets[sim_irsimglobalnetcount], gname,
 			sim_tool->cluster);
 		sim_irsimglobalnetsnumbers[sim_irsimglobalnetcount] = 0;
