@@ -55,14 +55,14 @@ static INTBIG sim_mossim_strength_key = 0;
 /* prototypes for local routines */
 static BOOLEAN sim_writemossimfacet(NODEPROTO*, BOOLEAN);
 static void    sim_addmossimnode(void*, NODEINST*, PORTPROTO*);
-static char   *sim_mossim_netname(ARCINST*);
+static CHAR   *sim_mossim_netname(ARCINST*);
 
 /*
  * routine to write a ".ntk" file from the facet "np"
  */
 void sim_writemossim(NODEPROTO *np)
 {
-	char name[100], *truename;
+	CHAR name[100], *truename;
 	REGISTER NODEPROTO *lnp;
 	REGISTER LIBRARY *lib;
 
@@ -75,8 +75,8 @@ void sim_writemossim(NODEPROTO *np)
 		return;
 	}
 
-	(void)strcpy(name, np->cell->cellname);
-	(void)strcat(name, ".ntk");
+	(void)estrcpy(name, np->cell->cellname);
+	(void)estrcat(name, x_(".ntk"));
 	sim_mossimfile = xcreate(name, sim_filetypemossim, _("MOSSIM File"), &truename);
 	if (sim_mossimfile == NULL)
 	{
@@ -86,7 +86,7 @@ void sim_writemossim(NODEPROTO *np)
 
 	/* get variable names (only once) */
 	if (sim_mossim_strength_key == 0)
-		sim_mossim_strength_key = makekey("SIM_mossim_strength");
+		sim_mossim_strength_key = makekey(x_("SIM_mossim_strength"));
 
 	/* reset flags for facets that have been written */
 	for(lib = el_curlib; lib != NOLIBRARY; lib = lib->nextlibrary)
@@ -109,7 +109,7 @@ BOOLEAN sim_writemossimfacet(NODEPROTO *np, BOOLEAN top)
 	REGISTER BOOLEAN backannotate;
 	REGISTER VARIABLE *var;
 	REGISTER NODEPROTO *snp, *subnp;
-	char temp[20], *str;
+	CHAR temp[20], *str;
 	REGISTER NODEINST *ni;
 	REGISTER ARCINST *ai, *nai;
 	REGISTER PORTPROTO *pp, *opp, *gate, *source, *drain, *spp;
@@ -137,7 +137,7 @@ BOOLEAN sim_writemossimfacet(NODEPROTO *np, BOOLEAN top)
 	}
 
 	/* make sure that all nodes have names on them */
-	if (asktool(net_tool, "name-nodes", (INTBIG)np) != 0) backannotate = TRUE;
+	if (asktool(net_tool, x_("name-nodes"), (INTBIG)np) != 0) backannotate = TRUE;
 
 	/* initialize instance counter */
 	inst = 1;
@@ -145,15 +145,15 @@ BOOLEAN sim_writemossimfacet(NODEPROTO *np, BOOLEAN top)
 	if (top)
 	{
 		/* declare power and ground nodes if this is top facet */
-		xprintf(sim_mossimfile, "| Top-level facet %s ;\n", describenodeproto(np));
-		xprintf(sim_mossimfile, "i VDD ;\ni GND ;\n");
+		xprintf(sim_mossimfile, x_("| Top-level facet %s ;\n"), describenodeproto(np));
+		xprintf(sim_mossimfile, x_("i VDD ;\ni GND ;\n"));
 	} else
 	{
 		/* write ports if this facet is sub-facet */
-		xprintf(sim_mossimfile, "| Facet %s ;\nc %s", describenodeproto(np), np->cell->cellname);
+		xprintf(sim_mossimfile, x_("| Facet %s ;\nc %s"), describenodeproto(np), np->cell->cellname);
 		for(pp = np->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
-			xprintf(sim_mossimfile, " %s", pp->protoname);
-		xprintf(sim_mossimfile, " ;\n");
+			xprintf(sim_mossimfile, x_(" %s"), pp->protoname);
+		xprintf(sim_mossimfile, x_(" ;\n"));
 	}
 
 	/* mark all ports that are equivalent */
@@ -164,32 +164,32 @@ BOOLEAN sim_writemossimfacet(NODEPROTO *np, BOOLEAN top)
 		pp->temp1 = 1;
 		if (top && portispower(pp))
 		{
-			if (namesame(pp->protoname, "vdd") != 0)
-				xprintf(sim_mossimfile, "e VDD %s ;\n", pp->protoname);
+			if (namesame(pp->protoname, x_("vdd")) != 0)
+				xprintf(sim_mossimfile, x_("e VDD %s ;\n"), pp->protoname);
 			continue;
 		}
 		if (top && portisground(pp))
 		{
-			if (namesame(pp->protoname, "gnd") != 0)
-				xprintf(sim_mossimfile, "e GND %s ;\n", pp->protoname);
+			if (namesame(pp->protoname, x_("gnd")) != 0)
+				xprintf(sim_mossimfile, x_("e GND %s ;\n"), pp->protoname);
 			continue;
 		}
 		if (top)
 		{
 			if ((pp->userbits&STATEBITS) == INPORT)
-				xprintf(sim_mossimfile, "i %s ;\n", pp->protoname); else
-					xprintf(sim_mossimfile, "s 1 %s ;\n", pp->protoname);
+				xprintf(sim_mossimfile, x_("i %s ;\n"), pp->protoname); else
+					xprintf(sim_mossimfile, x_("s 1 %s ;\n"), pp->protoname);
 		}
 		i = 0;
 		for(opp = pp->nextportproto; opp != NOPORTPROTO; opp = opp->nextportproto)
 			if (opp->network == pp->network)
 		{
-			if (i == 0) xprintf(sim_mossimfile, "e %s", pp->protoname);
-			xprintf(sim_mossimfile, " %s", opp->protoname);
+			if (i == 0) xprintf(sim_mossimfile, x_("e %s"), pp->protoname);
+			xprintf(sim_mossimfile, x_(" %s"), opp->protoname);
 			i++;
 			opp->temp1 = 1;
 		}
-		if (i != 0) xprintf(sim_mossimfile, " ;\n");
+		if (i != 0) xprintf(sim_mossimfile, x_(" ;\n"));
 	}
 
 	/* determine internal networks and give them a name */
@@ -227,7 +227,7 @@ BOOLEAN sim_writemossimfacet(NODEPROTO *np, BOOLEAN top)
 				if (nai->end[i].nodeinst->proto->primindex != 0) continue;
 				infstr = initinfstr();
 				addstringtoinfstr(infstr, nai->end[i].portarcinst->proto->protoname);
-				(void)sprintf(temp, "-%ld", sim_mossiminternal);
+				(void)esnprintf(temp, 20, x_("-%ld"), sim_mossiminternal);
 				addstringtoinfstr(infstr, temp);
 				(void)allocstring(&str, returninfstr(infstr), el_tempcluster);
 				break;
@@ -237,9 +237,9 @@ BOOLEAN sim_writemossimfacet(NODEPROTO *np, BOOLEAN top)
 		{
 			if (ai->network == NONETWORK || ai->network->namecount == 0)
 			{
-				(void)sprintf(temp, "node%ld", sim_mossiminternal);
+				(void)esnprintf(temp, 20, x_("node%ld"), sim_mossiminternal);
 				(void)allocstring(&str, temp, el_tempcluster);
-			} else (void)allocstring(&str, ai->network->netname, el_tempcluster);
+			} else (void)allocstring(&str, networkname(ai->network, 0), el_tempcluster);
 		}
 
 		/* store this name on every connected internal arc */
@@ -269,7 +269,7 @@ BOOLEAN sim_writemossimfacet(NODEPROTO *np, BOOLEAN top)
 
 		/* print the internal node name */
 		if (strength < 0) strength = 1;
-		xprintf(sim_mossimfile, "s %ld %s ;\n", strength, str);
+		xprintf(sim_mossimfile, x_("s %ld %s ;\n"), strength, str);
 	}
 
 	/* now write the transistors */
@@ -305,30 +305,29 @@ BOOLEAN sim_writemossimfacet(NODEPROTO *np, BOOLEAN top)
 
 			/* write the transistor */
 			infstr = initinfstr();
-			addtoinfstr(infstr, (char)(type == NPTRANMOS ? 'n' : (type == NPTRADMOS ? 'd' : 'p')));
+			addtoinfstr(infstr, (CHAR)(type == NPTRANMOS ? 'n' : (type == NPTRADMOS ? 'd' : 'p')));
 
 			/* write the strength of the transistor */
 			var = getvalkey((INTBIG)ni, VNODEINST, VINTEGER, sim_mossim_strength_key);
 			if (var != NOVARIABLE)
 			{
-				(void)sprintf(temp, " %ld", var->addr);
-				addstringtoinfstr(infstr, temp);
-			} else addstringtoinfstr(infstr, " 2");
+				formatinfstr(infstr, x_(" %ld"), var->addr);
+			} else addstringtoinfstr(infstr, x_(" 2"));
 
 			/* write the gate/source/drain nodes */
 			sim_addmossimnode(infstr, ni, gate);
 			sim_addmossimnode(infstr, ni, source);
 			sim_addmossimnode(infstr, ni, drain);
-			addstringtoinfstr(infstr, " ;");
+			addstringtoinfstr(infstr, x_(" ;"));
 			var = getvalkey((INTBIG)ni, VNODEINST, VSTRING, el_node_name_key);
 			if (var != NOVARIABLE)
 			{
-				addstringtoinfstr(infstr, "   | ");
-				addstringtoinfstr(infstr, (char *)var->addr);
-				addstringtoinfstr(infstr, ";");
+				addstringtoinfstr(infstr, x_("   | "));
+				addstringtoinfstr(infstr, (CHAR *)var->addr);
+				addstringtoinfstr(infstr, x_(";"));
 			}
-			addstringtoinfstr(infstr, "\n");
-			xprintf(sim_mossimfile, "%s", returninfstr(infstr));
+			addstringtoinfstr(infstr, x_("\n"));
+			xprintf(sim_mossimfile, x_("%s"), returninfstr(infstr));
 		} else
 		{
 			/* ignore recursive references (showing icon in contents) */
@@ -336,7 +335,7 @@ BOOLEAN sim_writemossimfacet(NODEPROTO *np, BOOLEAN top)
 
 			/* complex node: make instance call */
 			infstr = initinfstr();
-			addstringtoinfstr(infstr, "h ");
+			addstringtoinfstr(infstr, x_("h "));
 
 			/* see if this facet is an icon for the real thing */
 			snp = contentsview(subnp);
@@ -351,10 +350,9 @@ BOOLEAN sim_writemossimfacet(NODEPROTO *np, BOOLEAN top)
 			{
 				ttyputerr(_("MOSSIM generation warning: no name on node %s"),
 					describenodeinst(ni));
-				addstringtoinfstr(infstr, "INST");
-				(void)sprintf(temp, "%ld", inst++);
-				addstringtoinfstr(infstr, temp);
-			} else addstringtoinfstr(infstr, (char *)var->addr);
+				addstringtoinfstr(infstr, x_("INST"));
+				formatinfstr(infstr, x_("%ld"), inst++);
+			} else addstringtoinfstr(infstr, (CHAR *)var->addr);
 
 			if (snp != NONODEPROTO)
 			{
@@ -371,19 +369,19 @@ BOOLEAN sim_writemossimfacet(NODEPROTO *np, BOOLEAN top)
 				for(pp = subnp->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
 					sim_addmossimnode(infstr, ni, pp);
 			}
-			addstringtoinfstr(infstr, " ;\n");
-			xprintf(sim_mossimfile, "%s", returninfstr(infstr));
+			addstringtoinfstr(infstr, x_(" ;\n"));
+			xprintf(sim_mossimfile, x_("%s"), returninfstr(infstr));
 		}
 	}
 
 	/* finish up */
-	xprintf(sim_mossimfile, ".\n");
+	xprintf(sim_mossimfile, x_(".\n"));
 
 	/* free space from internal node names */
 	for(ai = np->firstarcinst; ai != NOARCINST; ai = ai->nextarcinst)
 	{
 		if (ai->temp1 <= 0) continue;
-		efree((char *)ai->temp2);
+		efree((CHAR *)ai->temp2);
 		for(nai = np->firstarcinst; nai != NOARCINST; nai = nai->nextarcinst)
 			if (nai->network == ai->network) nai->temp1 = 0;
 	}
@@ -401,7 +399,7 @@ void sim_addmossimnode(void *infstr, NODEINST *ni, PORTPROTO *pp)
 	REGISTER PORTPROTO *opp;
 	REGISTER ARCINST *ai;
 	REGISTER INTBIG i;
-	char temp[20];
+	CHAR temp[20];
 
 	/* initialize for internal node memory (see comment below) */
 	pp->temp2 = 0;
@@ -448,12 +446,12 @@ void sim_addmossimnode(void *infstr, NODEINST *ni, PORTPROTO *pp)
 	{
 		sim_mossiminternal++;
 		i = sim_mossiminternal;
-		(void)sprintf(temp, "node%ld", i);
-		xprintf(sim_mossimfile, "s 1 %s ;\n", temp);
+		(void)esnprintf(temp, 20, x_("node%ld"), i);
+		xprintf(sim_mossimfile, x_("s 1 %s ;\n"), temp);
 	} else
 	{
 		i = opp->temp2;
-		(void)sprintf(temp, "node%ld", i);
+		(void)esnprintf(temp, 20, x_("node%ld"), i);
 	}
 	pp->temp2 = i;
 
@@ -468,10 +466,10 @@ void sim_addmossimnode(void *infstr, NODEINST *ni, PORTPROTO *pp)
  * is saved in the "temp2" field.  In other cases, the actual string name
  * of the net is in the "temp2" field.
  */
-char *sim_mossim_netname(ARCINST *ai)
+CHAR *sim_mossim_netname(ARCINST *ai)
 {
 	if (ai->temp1 == -1) return(((PORTPROTO *)ai->temp2)->protoname);
-	return((char *)ai->temp2);
+	return((CHAR *)ai->temp2);
 }
 
 #endif  /* SIMTOOL - at top */
