@@ -67,7 +67,7 @@
 /********************** global variables *********************/
 
 static FILE  *sim_silfile;
-extern INTBIG sim_pseudonet;		/* for internal networks */
+static INTBIG sim_pseudonet;		/* for internal networks */
 static INTBIG sim_silos_global_name_key = 0;
 static INTBIG sim_silos_model_key = 0;		/* for model on cell */
 
@@ -76,28 +76,28 @@ static INTBIG sim_silos_model_key = 0;		/* for model on cell */
 /* prototypes for local routines */
 static INTBIG  sim_writesilfacet(NODEPROTO*, BOOLEAN);
 static void    sim_writesilinstances(NODEPROTO*, BOOLEAN);
-static char   *sim_silportname(BOOLEAN, NODEINST*, PORTPROTO*, NODEPROTO*);
-static char   *sim_silname(NODEINST*);
-static char   *sim_silproto(NODEINST*, BOOLEAN);
-static char   *sim_siltext(char*);
-static void    sim_sendtosil(char*);
-static char   *sim_silarcname(ARCINST*);
+static CHAR   *sim_silportname(BOOLEAN, NODEINST*, PORTPROTO*, NODEPROTO*);
+static CHAR   *sim_silname(NODEINST*);
+static CHAR   *sim_silproto(NODEINST*, BOOLEAN);
+static CHAR   *sim_siltext(CHAR*);
+static void    sim_sendtosil(CHAR*);
+static CHAR   *sim_silarcname(ARCINST*);
 static BOOLEAN sim_silnegated(PORTARCINST*);
-static char   *sim_silspecials(char*);
+static CHAR   *sim_silspecials(CHAR*);
 static INTBIG  sim_silostype(NODEINST*);
-static char   *sim_silrisetime(NODEINST*);
-static char   *sim_silfalltime(NODEINST*);
+static CHAR   *sim_silrisetime(NODEINST*);
+static CHAR   *sim_silfalltime(NODEINST*);
 static INTBIG  sim_silgetcapacitance(NODEINST*);
 static void    sim_silwriteflipflop(BOOLEAN, NODEINST*, NODEPROTO*, INTBIG);
-static char   *sim_sil_isaport(NODEPROTO*, char*);
-static char   *sim_convertsub(char*);
+static CHAR   *sim_sil_isaport(NODEPROTO*, CHAR*);
+static CHAR   *sim_convertsub(CHAR*);
 
 /*
  * routine to write a ".sil" file from the facet "np"
  */
 void sim_writesilnetlist(NODEPROTO *np)
 {
-	char name[100], numberstring[100], *truename;
+	CHAR name[100], numberstring[100], *truename;
 	REGISTER NODEPROTO *lnp;
 	REGISTER LIBRARY *lib;
 
@@ -111,58 +111,60 @@ void sim_writesilnetlist(NODEPROTO *np)
 	}
 
 	/* first write the "sil" file */
-	(void)strcpy(name, np->cell->cellname);
-	(void)strcat(name, ".sil");
+	(void)estrcpy(name, np->cell->cellname);
+	(void)estrcat(name, x_(".sil"));
 	sim_silfile = xcreate(name, sim_filetypesilos, _("SILOS File"), &truename);
 	if (sim_silfile == NULL)
 	{
 		if (truename != 0) ttyputerr(_("Cannot write %s"), truename);
 		return;
 	}
-	sim_sendtosil("\n");
-	sim_sendtosil("$ FACET ");
+	sim_sendtosil(x_("\n"));
+	sim_sendtosil(x_("$ FACET "));
 	sim_sendtosil(describenodeproto(np));
-	sim_sendtosil(" FROM LIBRARY:");
+	sim_sendtosil(x_(" FROM LIBRARY:"));
 	sim_sendtosil(np->cell->lib->libname);
-	sim_sendtosil("\n");
+	sim_sendtosil(x_("\n"));
 	if ((us_useroptions&NODATEORVERSION) == 0)
 	{
 		if (np->creationdate)
 		{
-			(void)sprintf(numberstring,"$ FACET CREATED ON %s", timetostring((time_t)np->creationdate));
+			(void)esnprintf(numberstring, 100, x_("$ FACET CREATED ON %s"),
+				timetostring((time_t)np->creationdate));
 			sim_sendtosil(numberstring);
-			sim_sendtosil("\n");
+			sim_sendtosil(x_("\n"));
 		}
 		if (np->version)
 		{
-			(void)sprintf(numberstring,"$ VERSION %ld", np->version);
+			(void)esnprintf(numberstring, 100, x_("$ VERSION %ld"), np->version);
 			sim_sendtosil(numberstring);
-			sim_sendtosil("\n");
+			sim_sendtosil(x_("\n"));
 		}
 		if (np->revisiondate)
 		{
-			(void)sprintf(numberstring,"$ LAST REVISED %s", timetostring((time_t)np->revisiondate));
+			(void)esnprintf(numberstring, 100, x_("$ LAST REVISED %s"),
+				timetostring((time_t)np->revisiondate));
 			sim_sendtosil(numberstring);
-			sim_sendtosil("\n");
+			sim_sendtosil(x_("\n"));
 		}
-		(void)sprintf(numberstring, "$ SILOS netlist written by Electric Design System; Version %s",
-			el_version);
+		(void)esnprintf(numberstring, 100,
+			x_("$ SILOS netlist written by Electric Design System; Version %s"), el_version);
 		sim_sendtosil(numberstring);
-		sim_sendtosil("\n");
+		sim_sendtosil(x_("\n"));
 
-		(void)sprintf(numberstring, "%s", timetostring(getcurrenttime()));
-		sim_sendtosil("$ WRITTEN ON ");
+		(void)esnprintf(numberstring, 100, x_("%s"), timetostring(getcurrenttime()));
+		sim_sendtosil(x_("$ WRITTEN ON "));
 		sim_sendtosil(numberstring);
-		sim_sendtosil("\n");
+		sim_sendtosil(x_("\n"));
 	} else
 	{
-		sim_sendtosil("$ SILOS netlist written by Electric Design System\n");
+		sim_sendtosil(x_("$ SILOS netlist written by Electric Design System\n"));
 	}
 
 	if (sim_silos_global_name_key == 0)
-		sim_silos_global_name_key = makekey("SIM_silos_global_name");
+		sim_silos_global_name_key = makekey(x_("SIM_silos_global_name"));
 	if (sim_silos_model_key == 0)
-		sim_silos_model_key = makekey("SC_silos");
+		sim_silos_model_key = makekey(x_("SC_silos"));
 
 	/* reset flags for facets that have been written */
 	for(lib = el_curlib; lib != NOLIBRARY; lib = lib->nextlibrary)
@@ -170,7 +172,7 @@ void sim_writesilnetlist(NODEPROTO *np)
 			lnp->temp1 = 0;
 	if (sim_writesilfacet(np, TRUE) != 0)
 		ttyputmsg(_("Back-annotation information has been added (library must be saved)"));
-	sim_sendtosil("\n");
+	sim_sendtosil(x_("\n"));
 
 	/* clean up */
 	xclose(sim_silfile);
@@ -185,7 +187,7 @@ void sim_writesilnetlist(NODEPROTO *np)
  */
 INTBIG sim_writesilfacet(NODEPROTO *np, BOOLEAN top)
 {
-	char buf[256];
+	UCHAR1 buf[256];
 	REGISTER INTBIG i, j, nodetype, clktype, count, backannotate;
 	REGISTER NODEINST *ni;
 	REGISTER PORTPROTO *pp;
@@ -193,8 +195,8 @@ INTBIG sim_writesilfacet(NODEPROTO *np, BOOLEAN top)
 	REGISTER NETWORK *net;
 	REGISTER VARIABLE *var;
 	REGISTER FILE *f;
-	char line[100], *filename, *extra;
-	char **model, *name;
+	CHAR line[100], *filename, *extra;
+	CHAR **model, *name;
 
 	/* stop if requested */
 	if (el_pleasestop != 0)
@@ -217,10 +219,10 @@ INTBIG sim_writesilfacet(NODEPROTO *np, BOOLEAN top)
 			var = getvalkey((INTBIG)ni, VNODEINST, VSTRING, sim_silos_global_name_key);
 			if (var != NOVARIABLE)	/* is this a global source ? */
 			{
-				name = (char *)var->addr;
-				(void)sprintf(line, ".GLOBAL %s", sim_silspecials(name));
+				name = (CHAR *)var->addr;
+				(void)esnprintf(line, 100, x_(".GLOBAL %s"), sim_silspecials(name));
 				sim_sendtosil(line);
-				sim_sendtosil("\n");
+				sim_sendtosil(x_("\n"));
 			}
 
 			/* Get the source type */
@@ -228,44 +230,44 @@ INTBIG sim_writesilfacet(NODEPROTO *np, BOOLEAN top)
 			if (var == NOVARIABLE)
 			{
 				ttyputerr(_("Unspecified source:"));
-				sprintf(line,"$$$$$ Unspecified source: \n");
+				esnprintf(line, 100, x_("$$$$$ Unspecified source: \n"));
 			} else	/* There is more */
 			{
 				clktype = 0;	/* Extra data required if variable there */
-				for(extra = (char *)var->addr; *extra != 0 && *extra != '/'; extra++)
+				for(extra = (CHAR *)var->addr; *extra != 0 && *extra != '/'; extra++)
 				{
 					switch (*extra)
 					{
 						case 'g':	/* a global clock (THIS IS WRONG!!!) */
-							(void)sprintf(line, "%s .CLK ", name);
+							(void)esnprintf(line, 100, x_("%s .CLK "), name);
 							clktype = 1;
 							break;
 						case 'h':	/* a fixed high source (THIS IS WRONG!!!) */
-							(void)sprintf(line, "%s .CLK 0 S1 $ HIGH LEVEL", name);
+							(void)esnprintf(line, 100, x_("%s .CLK 0 S1 $ HIGH LEVEL"), name);
 							break;
 						case 'l':	/* a fixed low source (THIS IS WRONG!!!) */
-							(void)sprintf(line, "%s .CLK 0 S0 $ LOW LEVEL", name);
+							(void)esnprintf(line, 100, x_("%s .CLK 0 S0 $ LOW LEVEL"), name);
 							break;
 					}
 				}
 				if (*extra == '/') extra++;
-				if (clktype == 1) strcat(line, extra);
+				if (clktype == 1) estrcat(line, extra);
 			}
 			sim_sendtosil(line);
-			sim_sendtosil("\n");
+			sim_sendtosil(x_("\n"));
 		}
 	}
 
 	/* Read a behavior file if it is available */
 	for (onp = np->cell->firstincell; onp != NONODEPROTO; onp = onp->nextincell)
 	{
-		var = getval((INTBIG)onp, VNODEPROTO, VSTRING, "SIM_silos_behavior_file");
+		var = getval((INTBIG)onp, VNODEPROTO, VSTRING, x_("SIM_silos_behavior_file"));
 		if (var != NOVARIABLE)
 		{
-			f = xopen(truepath((char *)var->addr), sim_filetypesilos, "", &filename);
+			f = xopen(truepath((CHAR *)var->addr), sim_filetypesilos, x_(""), &filename);
 			if (f == NULL)
 				ttyputerr(_("Cannot find SILOS behavior file %s on facet %s"),
-					(char *)var->addr, describenodeproto(onp)); else
+					(CHAR *)var->addr, describenodeproto(onp)); else
 			{
 				/* copy the file */
 				for(;;)
@@ -276,7 +278,7 @@ INTBIG sim_writesilfacet(NODEPROTO *np, BOOLEAN top)
 						ttyputerr(_("Error copying file"));
 				}
 				xclose(f);
-				sim_sendtosil("\n");
+				sim_sendtosil(x_("\n"));
 
 				/* mark this facet as written */
 				np->temp1++;
@@ -294,11 +296,11 @@ INTBIG sim_writesilfacet(NODEPROTO *np, BOOLEAN top)
 		var = getvalkey((INTBIG)onp, VNODEPROTO, VSTRING|VISARRAY, sim_silos_model_key);
 		if (var != NOVARIABLE)
 		{
-			model = (char **)var->addr;
+			model = (CHAR **)var->addr;
 			j = getlength(var);
 			for(i = 0; i < j; i++)
-				xprintf(sim_silfile, "%s\n", model[i]);
-			sim_sendtosil("\n");
+				xprintf(sim_silfile, x_("%s\n"), model[i]);
+			sim_sendtosil(x_("\n"));
 
 			/* mark this facet as written */
 			np->temp1++;
@@ -331,7 +333,7 @@ INTBIG sim_writesilfacet(NODEPROTO *np, BOOLEAN top)
 	}
 
 	/* make sure that all nodes have names on them */
-	if (asktool(net_tool, "name-nodes", (INTBIG)np) != 0) backannotate++;
+	if (asktool(net_tool, x_("name-nodes"), (INTBIG)np) != 0) backannotate++;
 
 	/* mark this facet as written */
 	np->temp1++;
@@ -339,19 +341,19 @@ INTBIG sim_writesilfacet(NODEPROTO *np, BOOLEAN top)
 	/* write the header if this not the top level */
 	if (!top)
 	{
-		sim_sendtosil("\n");
-		sim_sendtosil(".MACRO");
-		(void)strcpy(line, (np->cell->cellname));
+		sim_sendtosil(x_("\n"));
+		sim_sendtosil(x_(".MACRO"));
+		(void)estrcpy(line, (np->cell->cellname));
 		for (i=0; line[i] && line[i] != '{'; i++)
 			;
 		line[i] = 0;			/* explicit termination of line */
-		if(strlen(line) > MAXNAME)
+		if(estrlen(line) > MAXNAME)
 		{
 			ttyputerr(_(".MACRO name %s is too long;"), line);
 			line[MAXNAME] = 0;
 			ttyputerr(_("truncated to %s"), line);
 		}
-		sim_sendtosil(" ");
+		sim_sendtosil(x_(" "));
 		sim_sendtosil(sim_siltext(line));
 
 		/*
@@ -363,12 +365,12 @@ INTBIG sim_writesilfacet(NODEPROTO *np, BOOLEAN top)
 			for(pp = np->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
 			{
 				if (portispower(pp) || portisground(pp)) continue;
-				(void)strcpy(line, sim_convertsub(pp->protoname));
-				sim_sendtosil(" ");
+				(void)estrcpy(line, sim_convertsub(pp->protoname));
+				sim_sendtosil(x_(" "));
 				sim_sendtosil(sim_siltext(line));
 			}
 		}
-		sim_sendtosil("\n");
+		sim_sendtosil(x_("\n"));
 	}
 
 	/* initialize ports that get used */
@@ -376,8 +378,8 @@ INTBIG sim_writesilfacet(NODEPROTO *np, BOOLEAN top)
 		net->temp1 = 0;
 	if (np->firstnodeinst != NONODEINST)	/* any valid nodes ? */
 		sim_writesilinstances(np, top);
-	if (top == 0) sim_sendtosil(".EOM\n");
-	sim_sendtosil("\n");
+	if (top == 0) sim_sendtosil(x_(".EOM\n"));
+	sim_sendtosil(x_("\n"));
 	return(backannotate);
 }						/* end sim_writesilfacet() */
 
@@ -393,7 +395,7 @@ void sim_writesilinstances(NODEPROTO *np, BOOLEAN top)
 	REGISTER NODEPROTO *cnp;
 	REGISTER PORTPROTO *pp, *lastpp, *outpp, *ipp;
 	REGISTER PORTARCINST *pi;
-	char line[100];
+	CHAR line[100];
 
 	sim_pseudonet = 1;
 	schem_ref = 1;
@@ -421,9 +423,9 @@ void sim_writesilinstances(NODEPROTO *np, BOOLEAN top)
 		switch (nodetype)
 		{
 			case SILOSFACET:		/* Complex cell uses instance name */
-				sim_sendtosil("(");
+				sim_sendtosil(x_("("));
 				sim_sendtosil(sim_silname(ni));
-				sim_sendtosil(" ");
+				sim_sendtosil(x_(" "));
 				sim_sendtosil(sim_silproto(ni, FALSE));	/* write the type */
 
 				/* write the rest of the port(s), connected or not */
@@ -445,7 +447,7 @@ void sim_writesilinstances(NODEPROTO *np, BOOLEAN top)
 			case SILOSSRFF:
 				/* Transistors and flip-flops need a part number */
 				sim_sendtosil(sim_silname(ni));
-				sim_sendtosil(" ");
+				sim_sendtosil(x_(" "));
 				sim_sendtosil(sim_silproto(ni, FALSE));
 
 				/* write the names of the port(s) */
@@ -480,7 +482,7 @@ void sim_writesilinstances(NODEPROTO *np, BOOLEAN top)
 
 						/* Record that we used it */
 						outpp = pp;
-						sim_sendtosil(" ");
+						sim_sendtosil(x_(" "));
 
 						/*
 						 * determine if this proto is negated...
@@ -535,13 +537,13 @@ void sim_writesilinstances(NODEPROTO *np, BOOLEAN top)
 					/* write port name as output */
 					sim_sendtosil(sim_silportname(top, ni, pp, np));
 
-					sim_sendtosil(" ");
+					sim_sendtosil(x_(" "));
 					sim_sendtosil(sim_silproto(ni, FALSE));
 
 					j = sim_silgetcapacitance(ni);
 					if (j >= 0)
 					{
-						(void)sprintf(line, " %ld", j);
+						(void)esnprintf(line, 100, x_(" %ld"), j);
 						sim_sendtosil(line);
 					} else
 						ttyputerr(_("Warning: capacitor with no value"));
@@ -552,7 +554,7 @@ void sim_writesilinstances(NODEPROTO *np, BOOLEAN top)
 			default:	/* some compilers may not like this empty default */
 				break;
 		}
-		sim_sendtosil("\n");
+		sim_sendtosil(x_("\n"));
 	}
 }
 
@@ -566,17 +568,17 @@ void sim_writesilinstances(NODEPROTO *np, BOOLEAN top)
  * If the port is a power or ground port, ignore it
  * If this is not the top level facet (ie. a .macro) remove [] notation.
  */
-char *sim_silportname(BOOLEAN top, NODEINST *ni, PORTPROTO *pp, NODEPROTO *np)
+CHAR *sim_silportname(BOOLEAN top, NODEINST *ni, PORTPROTO *pp, NODEPROTO *np)
 {
 	REGISTER PORTPROTO *epp;
 	REGISTER PORTARCINST *pi;
 	REGISTER PORTEXPINST *pe;
 	REGISTER ARCINST *ai = NOARCINST;
-	char *portname;
+	CHAR *portname;
 	BOOLEAN noarcs;
 	REGISTER void *infstr;
 
-	if (portispower(pp) || portisground(pp)) return("");
+	if (portispower(pp) || portisground(pp)) return(x_(""));
 
 	infstr = initinfstr();
 
@@ -592,7 +594,7 @@ char *sim_silportname(BOOLEAN top, NODEINST *ni, PORTPROTO *pp, NODEPROTO *np)
 
 			/* if an input connection has a bubble, negate the signal */
 			if (sim_silnegated(pi) && ((pp->userbits&STATEBITS) == INPORT))
-				addstringtoinfstr(infstr, " -"); else
+				addstringtoinfstr(infstr, x_(" -")); else
 					addtoinfstr(infstr, ' ');
 
 			/* find the arc connected to this pi */
@@ -609,7 +611,7 @@ char *sim_silportname(BOOLEAN top, NODEINST *ni, PORTPROTO *pp, NODEPROTO *np)
 			} else /* this is a database error, and won't ever occur */
 			{
 				ttyputerr(_("Error: there is a PORTARCINST without a CONARCINST"));
-				return("");
+				return(x_(""));
 			}
 
 			/* if PORTISOLATED, then there may be more unconnected arcs */
@@ -633,12 +635,12 @@ char *sim_silportname(BOOLEAN top, NODEINST *ni, PORTPROTO *pp, NODEPROTO *np)
 				epp = pe->exportproto;
 				if (epp->network->namecount > 0)
 				{
-					if (top) addstringtoinfstr(infstr, sim_silspecials(epp->network->netname)); else
-						addstringtoinfstr(infstr, sim_sil_isaport(np, sim_silspecials(epp->network->netname)));
+					if (top) addstringtoinfstr(infstr, sim_silspecials(networkname(epp->network, 0))); else
+						addstringtoinfstr(infstr, sim_sil_isaport(np, sim_silspecials(networkname(epp->network, 0))));
 				} else	/* this would be a database error - won't happen */
 				{
 					ttyputerr(_("Error: there is a net on an export, but no net name"));
-					return("");
+					return(x_(""));
 				}
 				break;	/* out of "for (pe..." */
 			}
@@ -649,7 +651,7 @@ char *sim_silportname(BOOLEAN top, NODEINST *ni, PORTPROTO *pp, NODEPROTO *np)
 	portname = returninfstr(infstr);
 
 	/* nothing connected to this port...leave a position */
-	if (portname[0] == '\0') return(" .SKIP");
+	if (portname[0] == '\0') return(x_(" .SKIP"));
 	return(portname);
 }
 
@@ -657,24 +659,24 @@ char *sim_silportname(BOOLEAN top, NODEINST *ni, PORTPROTO *pp, NODEPROTO *np)
  * routine to return a string describing the SILOS part name of nodeinst
  * "ni"
  */
-char *sim_silname(NODEINST *ni)
+CHAR *sim_silname(NODEINST *ni)
 {
-	static char name[100];
+	static CHAR name[100];
 	REGISTER VARIABLE *var;
 	static INTBIG SIM_silos_node_name_key = 0;
 
 	if (SIM_silos_node_name_key == 0)
-		SIM_silos_node_name_key = makekey("SIM_silos_node_name");
+		SIM_silos_node_name_key = makekey(x_("SIM_silos_node_name"));
 	var = getvalkey((INTBIG)ni, VNODEINST, VSTRING, SIM_silos_node_name_key);
-	if (var != NOVARIABLE) return((char *)var->addr);
+	if (var != NOVARIABLE) return((CHAR *)var->addr);
 	var = getvalkey((INTBIG)ni, VNODEINST, VSTRING, el_node_name_key);
 	if (var != NOVARIABLE)
 	{
-		strcpy(name, (char *)var->addr);
+		estrcpy(name, (CHAR *)var->addr);
 		if (isalpha(name[0])) return(name);
 		if (name[0] == '[') return(sim_convertsub(name));
 	}
-	(void)sprintf(name, "U%ld", ni->temp1);
+	(void)esnprintf(name, 100, x_("U%ld"), ni->temp1);
 	return(name);
 }
 
@@ -682,16 +684,16 @@ char *sim_silname(NODEINST *ni)
  * routine to return a string describing the SILOS type of nodeinst "ni"
  * if 'neg' is true, then the negated version is needed
  */
-char *sim_silproto(NODEINST *ni, BOOLEAN neg)
+CHAR *sim_silproto(NODEINST *ni, BOOLEAN neg)
 {
 	REGISTER INTBIG f;
-	static char name[100];
+	static CHAR name[100];
 
 	/* facets use their real name */
 	if (ni->proto->primindex == 0)
 	{
-		sprintf(name,"%s", sim_siltext(ni->proto->cell->cellname));
-		if (strlen(name) > MAXNAME) name[MAXNAME] = 0;
+		esnprintf(name, 100, x_("%s"), sim_siltext(ni->proto->cell->cellname));
+		if (estrlen(name) > MAXNAME) name[MAXNAME] = 0;
 		return(name);
 	}
 
@@ -699,38 +701,38 @@ char *sim_silproto(NODEINST *ni, BOOLEAN neg)
 	switch (f)
 	{
 		case SILOSNMOS:
-			return(".NMOS");
+			return(x_(".NMOS"));
 		case SILOSPMOS:
-			return(".PMOS");
+			return(x_(".PMOS"));
 		case SILOSBUF:
 		case SILOSINV:
-			if (neg) return(".INV");
-			return(".BUF");
+			if (neg) return(x_(".INV"));
+			return(x_(".BUF"));
 		case SILOSXOR:
-			if (neg) return(".XNOR");
-			return(".XOR");
+			if (neg) return(x_(".XNOR"));
+			return(x_(".XOR"));
 		case SILOSAND:
-			if (neg) return(".NAND");
-			return(".AND");
+			if (neg) return(x_(".NAND"));
+			return(x_(".AND"));
 		case SILOSOR:
-			if (neg) return(".NOR");
-			return(".OR");
+			if (neg) return(x_(".NOR"));
+			return(x_(".OR"));
 		case SILOSRES:
-			return(".RES");
+			return(x_(".RES"));
 		case SILOSCAP:
-			return(".CAP");
+			return(x_(".CAP"));
 		case SILOSJKFF:
-			if ((ni->userbits&FFCLOCK) == FFCLOCKN) return(".JKNEFF");
-			return(".JKPEFF");
+			if ((ni->userbits&FFCLOCK) == FFCLOCKN) return(x_(".JKNEFF"));
+			return(x_(".JKPEFF"));
 		case SILOSDFF:
-			if ((ni->userbits&FFCLOCK) == FFCLOCKN) return(".DNEFF");
-			return(".DPEFF");
+			if ((ni->userbits&FFCLOCK) == FFCLOCKN) return(x_(".DNEFF"));
+			return(x_(".DPEFF"));
 		case SILOSSRFF:
-			if ((ni->userbits&FFCLOCK) == FFCLOCKN) return(".SRNEFF");
-			return(".SRPEFF");
+			if ((ni->userbits&FFCLOCK) == FFCLOCKN) return(x_(".SRNEFF"));
+			return(x_(".SRPEFF"));
 		case SILOSTFF:
-			if ((ni->userbits&FFCLOCK) == FFCLOCKN) return(".TNEFF");
-			return(".TPEFF");
+			if ((ni->userbits&FFCLOCK) == FFCLOCKN) return(x_(".TNEFF"));
+			return(x_(".TPEFF"));
 	}
 	return(sim_siltext(ni->proto->primname));
 }
@@ -741,9 +743,9 @@ char *sim_silproto(NODEINST *ni, BOOLEAN neg)
  * We will not permit a digit in the first location; replace it
  * with '_'
  */
-char *sim_siltext(char *p)
+CHAR *sim_siltext(CHAR *p)
 {
-	REGISTER char *t;
+	REGISTER CHAR *t;
 	REGISTER void *infstr;
 
 	for(t = p; *t != 0; t++) if (!isprint(*t)) break;
@@ -759,25 +761,25 @@ char *sim_siltext(char *p)
 
 /* Write to the .sil file, but break into printable lines */
 
-void sim_sendtosil(char *str)
+void sim_sendtosil(CHAR *str)
 {
 	static INTBIG count = 0;
 	INTBIG i;
 
 	if (*str == '\n') count = 0;
-	if ((count + (i = strlen(str))) > MAXSTR)
+	if ((count + (i = estrlen(str))) > MAXSTR)
 	{
 		if (*str == '$')
 		{
-			xprintf(sim_silfile, "\n");
+			xprintf(sim_silfile, x_("\n"));
 			count = 0;
 		} else
 		{
-			xprintf(sim_silfile, "\n+");
+			xprintf(sim_silfile, x_("\n+"));
 			count = 1;
 		}
 	}
-	xprintf(sim_silfile, "%s", str);
+	xprintf(sim_silfile, x_("%s"), str);
 	count += i;
 	return;
 }
@@ -786,13 +788,13 @@ void sim_sendtosil(char *str)
  * routine to return the name of arc "ai" (either its network name or
  * a generated name
  */
-char *sim_silarcname(ARCINST *ai)
+CHAR *sim_silarcname(ARCINST *ai)
 {
-	static char line[50];
+	static CHAR line[50];
 
-	if (ai->network->namecount > 0) return(ai->network->netname);
+	if (ai->network->namecount > 0) return(networkname(ai->network, 0));
 	if (ai->network->temp1 == 0) ai->network->temp1 = sim_pseudonet++;
-	(void)sprintf(line, "NET%ld", ai->network->temp1);
+	(void)esnprintf(line, 50, x_("NET%ld"), ai->network->temp1);
 	return(line);
 }
 
@@ -819,14 +821,14 @@ BOOLEAN sim_silnegated(PORTARCINST *pi)
  * function to convert special names to SILOS format
  */
 
-char *sim_silspecials(char *str)
+CHAR *sim_silspecials(CHAR *str)
 {
-	if (namesamen(str, "vdd", 3) == 0) return(".VDD");
-	if (namesamen(str, "vss", 3) == 0) return(".VSS");
-	if (namesamen(str, "vcc", 3) == 0) return(".VCC");
-	if (namesamen(str, "gnd", 3) == 0) return(".GND");
-	if (namesamen(str, "low", 3) == 0) return(".GND");
-	if (namesamen(str, "hig", 3) == 0) return(".VDD");
+	if (namesamen(str, x_("vdd"), 3) == 0) return(x_(".VDD"));
+	if (namesamen(str, x_("vss"), 3) == 0) return(x_(".VSS"));
+	if (namesamen(str, x_("vcc"), 3) == 0) return(x_(".VCC"));
+	if (namesamen(str, x_("gnd"), 3) == 0) return(x_(".GND"));
+	if (namesamen(str, x_("low"), 3) == 0) return(x_(".GND"));
+	if (namesamen(str, x_("hig"), 3) == 0) return(x_(".VDD"));
 	return(str);
 }
 
@@ -888,29 +890,29 @@ INTBIG sim_silostype(NODEINST *ni)
  * A space is inserted as the first character in the string.
  * Returns an empty string if no variable found.
  */
-char *sim_silrisetime(NODEINST *ni)
+CHAR *sim_silrisetime(NODEINST *ni)
 {
 	REGISTER VARIABLE *var;
 	static INTBIG SIM_sil_risetime_key = 0;
-	static char s[80];
+	static CHAR s[80];
 
 	if (SIM_sil_risetime_key == 0)
-		SIM_sil_risetime_key = makekey("SIM_rise_delay");
+		SIM_sil_risetime_key = makekey(x_("SIM_rise_delay"));
 	var = getvalkey((INTBIG)ni, VNODEINST, -1, SIM_sil_risetime_key);
 	if (var != NOVARIABLE)
 	{
 		if ((var->type&VTYPE) == VINTEGER)
 		{
-			(void)sprintf(s, " %ld", var->addr);
+			(void)esnprintf(s, 80, x_(" %ld"), var->addr);
 			return(s);
 		}
 		if ((var->type&VTYPE) == VSTRING)
 		{
-			(void)sprintf(s, " %s", (char *)var->addr);
+			(void)esnprintf(s, 80, x_(" %s"), (CHAR *)var->addr);
 			return(s);
 		}
 	}
-	return("");
+	return(x_(""));
 }
 
 /*
@@ -922,29 +924,29 @@ char *sim_silrisetime(NODEINST *ni)
  * A space is inserted as the first character in the string.
  * Returns an empty string if no variable found.
  */
-char *sim_silfalltime(NODEINST *ni)
+CHAR *sim_silfalltime(NODEINST *ni)
 {
 	REGISTER VARIABLE *var;
 	static INTBIG SIM_sil_falltime_key = 0;
-	static char s[80];
+	static CHAR s[80];
 
 	if (SIM_sil_falltime_key == 0)
-		SIM_sil_falltime_key = makekey("SIM_fall_delay");
+		SIM_sil_falltime_key = makekey(x_("SIM_fall_delay"));
 	var = getvalkey((INTBIG)ni, VNODEINST, -1, SIM_sil_falltime_key);
 	if (var != NOVARIABLE)
 	{
 		if ((var->type&VTYPE) == VINTEGER)
 		{
-			(void)sprintf(s, " %ld", var->addr);
+			(void)esnprintf(s, 80, x_(" %ld"), var->addr);
 			return(s);
 		}
 		if ((var->type&VTYPE) == VSTRING)
 		{
-			(void)sprintf(s, " %s", (char *)var->addr);
+			(void)esnprintf(s, 80, x_(" %s"), (CHAR *)var->addr);
 			return(s);
 		}
 	}
-	return("");
+	return(x_(""));
 }
 
 /*
@@ -962,8 +964,8 @@ INTBIG sim_silgetcapacitance(NODEINST *ni)
 	var = getvalkey((INTBIG)ni, VNODEINST, -1, sch_capacitancekey);
 	if (var != NOVARIABLE)
 	{
-		farads = (float)atof(describesimplevariable(var));
-		microfarads = atoi(displayedunits(farads, VTUNITSCAP, INTCAPUNITUFARAD));
+		farads = (float)eatof(describesimplevariable(var));
+		microfarads = eatoi(displayedunits(farads, VTUNITSCAP, INTCAPUNITUFARAD));
 		return(microfarads);
 	}
 	return(-1);
@@ -984,23 +986,23 @@ INTBIG sim_silgetcapacitance(NODEINST *ni)
 void sim_silwriteflipflop(BOOLEAN top, NODEINST *ni, NODEPROTO *np, INTBIG type)
 {
 	REGISTER PORTPROTO *pp;
-	char line[8][50], out[100];
+	CHAR line[8][50], out[100];
 	INTBIG i;
 
 	for(pp = ni->proto->firstportproto, i=0; pp != NOPORTPROTO && i < 7; pp = pp->nextportproto, i++)
 	{
 		/* find arcs on this port */
-		(void)sprintf(line[i]," %s", sim_silportname(top, ni, pp, np));
+		(void)esnprintf(line[i], 50, x_(" %s"), sim_silportname(top, ni, pp, np));
 	}
-	if (namesamen(line[PRE], " .SKIP", 4) == 0 && namesamen(line[CLR], " .SKIP", 4) == 0)
+	if (namesamen(line[PRE], x_(" .SKIP"), 4) == 0 && namesamen(line[CLR], x_(" .SKIP"), 4) == 0)
 	{
 		*line[CLR] = 0;		/* If neither on, don't print */
 		*line[PRE] = 0;
 	}
-	if (type == SILOSDFF) (void)sprintf(out,"%s%s%s%s /%s%s", line[CK], line[JORD], line[PRE],
-		line[CLR], line[Q], line[QB]); else
-			(void)sprintf(out,"%s%s%s%s%s /%s%s", line[CK], line[JORD], line[K], line[PRE],
-				line[CLR], line[Q], line[QB]);
+	if (type == SILOSDFF) (void)esnprintf(out, 100, x_("%s%s%s%s /%s%s"),
+		line[CK], line[JORD], line[PRE], line[CLR], line[Q], line[QB]); else
+			(void)esnprintf(out, 100, x_("%s%s%s%s%s /%s%s"), line[CK], line[JORD],
+				line[K], line[PRE], line[CLR], line[Q], line[QB]);
 	sim_sendtosil(out);
 }
 
@@ -1008,27 +1010,27 @@ void sim_silwriteflipflop(BOOLEAN top, NODEINST *ni, NODEPROTO *np, INTBIG type)
 the ports of the containing instance. If so, get rid of the '[]' format;
 replace '[' with '__', ignore ']'.
 */
-char *sim_sil_isaport(NODEPROTO *np, char *portname)
+CHAR *sim_sil_isaport(NODEPROTO *np, CHAR *portname)
 {
 	REGISTER PORTPROTO *pp;
 
-	if (strchr(portname, '[') == NULL) return(portname);		/* no references anyhow */
+	if (estrchr(portname, '[') == NULL) return(portname);		/* no references anyhow */
 	pp = getportproto(np, portname);
 	if (pp != NOPORTPROTO) return(sim_convertsub(portname));
 	return(portname);
 }
 
 /* replace subscripted name with __ format */
-static char *sim_convertsub(char *string)
+static CHAR *sim_convertsub(CHAR *string)
 {
-	char *ptr;
-	static char newname[100];
+	CHAR *ptr;
+	static CHAR newname[100];
 
 	for (ptr = newname; *string; string++)
 	{
 		if (*string == '[')
 		{
-			strcpy(ptr, "__");
+			estrcpy(ptr, x_("__"));
 			ptr+=2;
 		} else if (*string == ']')
 		{
