@@ -42,45 +42,45 @@
 #define NPGATENOR -NPGATEOR
 #define NPGATENXOR -NPGATEXOR
 #define NPGATENAND -NPGATEAND
-#define NULLSTR ""
+#define NULLSTR x_("")
 
-#define RESFILE "reservedwords.dat"			/* optional used to check for reserved words */
+#define RESFILE x_("reservedwords.dat")			/* optional used to check for reserved words */
 
 static FILE *sim_texfile, *reservefile;
 
 /* prototypes for local routines */
 static void         sim_writetexcell(NODEPROTO*, INTBIG);
-static char        *sim_textdlpower(NODEINST*, INTBIG, INTBIG*, INTBIG*, INTBIG*);
+static CHAR        *sim_textdlpower(NODEINST*, INTBIG, INTBIG*, INTBIG*, INTBIG*);
 static INTBIG       sim_texcountwires(NODEINST*);
-static char        *sim_texsrcname(NODEINST*, PORTARCINST*);
-static char        *sim_texwritesignals(NODEINST*, INTBIG, INTBIG*);
-static char        *sim_texwriteffsignals(NODEINST*, INTBIG*);
-static char        *sim_textracesignal(PORTARCINST*, NODEINST*);
-static void         sim_texwriteinv(PORTARCINST*, char*, char*);
-static char        *sim_textdlinst(NODEINST*, INTBIG);
-static void         sim_texerror(INTBIG, INTBIG*, char*);
-static void         sim_texstrprint(char*);
-static char        *sim_texname(char*);
-static char        *sim_texproto(NODEINST*, INTBIG, INTBIG*);
-static char        *sim_texffname(NODEINST*, INTBIG*);
-static char        *sim_texgetdelay(NODEINST*, INTBIG);
+static CHAR        *sim_texsrcname(NODEINST*, PORTARCINST*);
+static CHAR        *sim_texwritesignals(NODEINST*, INTBIG, INTBIG*);
+static CHAR        *sim_texwriteffsignals(NODEINST*, INTBIG*);
+static CHAR        *sim_textracesignal(PORTARCINST*, NODEINST*);
+static void         sim_texwriteinv(PORTARCINST*, CHAR*, CHAR*);
+static CHAR        *sim_textdlinst(NODEINST*, INTBIG);
+static void         sim_texerror(INTBIG, INTBIG*, CHAR*);
+static void         sim_texstrprint(CHAR*);
+static CHAR        *sim_texname(CHAR*);
+static CHAR        *sim_texproto(NODEINST*, INTBIG, INTBIG*);
+static CHAR        *sim_texffname(NODEINST*, INTBIG*);
+static CHAR        *sim_texgetdelay(NODEINST*, INTBIG);
 static BOOLEAN      sim_texnegatedoutput(NODEINST*);
-static char        *sim_texlibname(NODEPROTO*);
+static CHAR        *sim_texlibname(NODEPROTO*);
 static PORTARCINST *sim_oppendpai(PORTARCINST*);
 static NODEINST    *sim_oppendni(PORTARCINST*);
-static BOOLEAN      sim_texcheckname(char*);
-static INTBIG       sim_strcspn(char *str, char *set);
+static BOOLEAN      sim_texcheckname(CHAR*);
+static INTBIG       sim_strcspn(CHAR *str, CHAR *set);
 
 void sim_writetexnetlist(NODEPROTO *np)
 {
 	NODEPROTO *lnp;
 	REGISTER LIBRARY *lib;
 	INTBIG length;
-	char str1[30], filename[200], *libname, *resfilename, *truename;
+	CHAR str1[30], filename[200], *libname, *resfilename, *truename;
 
 	/* write the "TDL" file */
-	(void)strcpy(filename, np->cell->cellname);
-	(void)strcat(filename, ".tdl");
+	(void)estrcpy(filename, np->cell->cellname);
+	(void)estrcat(filename, x_(".tdl"));
 	sim_texfile = xcreate(filename, sim_filetypetegas, _("TEGAS File"), &truename);
 	if (sim_texfile == NULL)
 	{
@@ -89,16 +89,16 @@ void sim_writetexnetlist(NODEPROTO *np)
 	}
 
 	/* read list of reserved words into an infinite string, each separated by "\n" */
-	reservefile = xopen(RESFILE, sim_filetypetegastab, "", &resfilename);
+	reservefile = xopen(RESFILE, sim_filetypetegastab, x_(""), &resfilename);
 
-	sim_texstrprint("/* GENERATED BY THE ELECTRIC VLSI DESIGN SYSTEM */\n\n");
-	sim_texstrprint("COMPILE  ;\n\n");
+	sim_texstrprint(x_("/* GENERATED BY THE ELECTRIC VLSI DESIGN SYSTEM */\n\n"));
+	sim_texstrprint(x_("COMPILE  ;\n\n"));
 
 	/* get library name, check validity */
-	strcpy(str1, "DIRECTORY:  ");
+	estrcpy(str1, x_("DIRECTORY:  "));
 	libname = sim_texlibname(np);
 
-	length = strlen(libname);
+	length = estrlen(libname);
 	if (length > 12)
 	{
 		ttyputmsg(_("Library name exceeds 12 characters, The name used for the"));
@@ -107,7 +107,7 @@ void sim_writetexnetlist(NODEPROTO *np)
 
 	/* check library name */
 	if (sim_texcheckname(sim_texname(libname)))
-		strcat(str1, sim_texname(libname)); else
+		estrcat(str1, sim_texname(libname)); else
 	{
 		ttyputerr(_("%s IS A RESERVED WORD, RENAME LIBRARY AND RE-RUN"), sim_texname(libname));
 		return;
@@ -115,9 +115,9 @@ void sim_writetexnetlist(NODEPROTO *np)
 
 	/* write "directory line" to file */
 	sim_texstrprint(str1);
-	xprintf(sim_texfile, " ;\n\n");
+	xprintf(sim_texfile, x_(" ;\n\n"));
 
-	sim_texstrprint("OPTIONS:   REPLACE  ;\n\n");
+	sim_texstrprint(x_("OPTIONS:   REPLACE  ;\n\n"));
 
 	/* reset flags for cells that have been written */
 	for(lib = el_curlib; lib != NOLIBRARY; lib = lib->nextlibrary)
@@ -127,7 +127,7 @@ void sim_writetexnetlist(NODEPROTO *np)
 	/* write TDL descriptions into file */
 	sim_writetexcell(np, 1);
 
-	sim_texstrprint(" END COMPILE;\n\n ");
+	sim_texstrprint(x_(" END COMPILE;\n\n "));
 
 	/* close files */
 	if (reservefile != NULL) xclose(reservefile);
@@ -141,11 +141,12 @@ void sim_writetexcell(NODEPROTO *np, INTBIG top)
 	PORTPROTO *pp, *xpp;
 	NODEINST *ni, *nextni;
 	ARCINST *ai;
-	char str1[MAXLENGTH], *ptr;
+	CHAR str1[MAXLENGTH], *ptr;
 	INTBIG inputs, nextniinputs, ninegated, nextninegated, f, x, separator,
 		count, length, tempa, tempb, module_err=0;
 	INTBIG pwr=0, gnd=0;
 	REGISTER void *infstr;
+	Q_UNUSED( top );
 
 	/* recurse on sub-cels first */
 	for(ni = np->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
@@ -163,15 +164,15 @@ void sim_writetexcell(NODEPROTO *np, INTBIG top)
 	np->temp1++;
 
 	/* MODULE */
-	sim_texstrprint("MODULE:  ");
+	sim_texstrprint(x_("MODULE:  "));
 	sim_texstrprint(sim_texname(describenodeproto(np)));
-	sim_texstrprint(";\n\n");
+	sim_texstrprint(x_(";\n\n"));
 
 	/* INPUTS */
 	if (np->firstportproto != NOPORTPROTO)
 	{
 		infstr = initinfstr();
-		addstringtoinfstr(infstr, "INPUTS:\n");
+		addstringtoinfstr(infstr, x_("INPUTS:\n"));
 
 		for(pp = np->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
 		{
@@ -181,37 +182,37 @@ void sim_writetexcell(NODEPROTO *np, INTBIG top)
 			pp->temp1 = pp->temp2 = 0;
 			if ((pp->userbits&STATEBITS) == INPORT)
 			{
-				addstringtoinfstr(infstr, "   ");
+				addstringtoinfstr(infstr, x_("   "));
 				addstringtoinfstr(infstr, sim_texname(pp->protoname));
-				addstringtoinfstr(infstr, "\n");
+				addstringtoinfstr(infstr, x_("\n"));
 				pp->temp1 = 1;
 			}
 		}
-		addstringtoinfstr(infstr, ";\n\n");
+		addstringtoinfstr(infstr, x_(";\n\n"));
 		sim_texstrprint(returninfstr(infstr));
 
 		/* OUTPUTS */
 		infstr = initinfstr();
-		addstringtoinfstr(infstr, "OUTPUTS:\n");
+		addstringtoinfstr(infstr, x_("OUTPUTS:\n"));
 
 		for(pp = np->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
 		{
 			if ((pp->userbits&STATEBITS) == OUTPORT)
 			{
-				addstringtoinfstr(infstr, "   ");
+				addstringtoinfstr(infstr, x_("   "));
 				addstringtoinfstr(infstr, sim_texname(pp->protoname));
-				addstringtoinfstr(infstr, "\n");
+				addstringtoinfstr(infstr, x_("\n"));
 				pp->temp1 = 1;
 			}
 			if (pp->temp1 == 0) sim_texerror(2, &module_err, pp->protoname);
 		}
-		addstringtoinfstr(infstr, ";\n\n");
+		addstringtoinfstr(infstr, x_(";\n\n"));
 		sim_texstrprint(returninfstr(infstr));
 	}
 
 	/* USE */
 	infstr = initinfstr();
-	addstringtoinfstr(infstr, "USE:\n\n");  /* write USE: */
+	addstringtoinfstr(infstr, x_("USE:\n\n"));  /* write USE: */
 
 	for(ni = np->firstnodeinst, ni->temp2=0; ni != NONODEINST; ni = ni->nextnodeinst)
 	{
@@ -261,22 +262,28 @@ void sim_writetexcell(NODEPROTO *np, INTBIG top)
 				switch (x)
 				{
 					case NPGATEAND:
-						(void)sprintf(str1, "  %ld-AND = AND(%ld,1),\n", inputs, inputs);
+						(void)esnprintf(str1, MAXLENGTH, x_("  %ld-AND = AND(%ld,1),\n"),
+							inputs, inputs);
 						break;
 					case NPGATEOR:
-						(void)sprintf(str1, "  %ld-OR = OR(%ld,1),\n", inputs, inputs);
+						(void)esnprintf(str1, MAXLENGTH, x_("  %ld-OR = OR(%ld,1),\n"),
+							inputs, inputs);
 						break;
 					case NPGATEXOR:
-						(void)sprintf(str1, "  %ld-XOR = XOR(%ld,1),\n", inputs, inputs);
+						(void)esnprintf(str1, MAXLENGTH, x_("  %ld-XOR = XOR(%ld,1),\n"),
+							inputs, inputs);
 						break;
 					case NPGATENAND:
-						(void)sprintf(str1, "  %ld-NAND = NAND(%ld,1),\n", inputs, inputs);
+						(void)esnprintf(str1, MAXLENGTH, x_("  %ld-NAND = NAND(%ld,1),\n"),
+							inputs, inputs);
 						break;
 					case NPGATENOR:
-						(void)sprintf(str1, "  %ld-NOR = NOR(%ld,1),\n", inputs, inputs);
+						(void)esnprintf(str1, MAXLENGTH, x_("  %ld-NOR = NOR(%ld,1),\n"),
+							inputs, inputs);
 						break;
 					case NPGATENXOR:
-						(void)sprintf(str1, "  %ld-NXOR = NXOR(%ld,1),\n", inputs, inputs);
+						(void)esnprintf(str1, MAXLENGTH, x_("  %ld-NXOR = NXOR(%ld,1),\n"),
+							inputs, inputs);
 						break;
 				}
 				addstringtoinfstr(infstr, str1);
@@ -296,21 +303,21 @@ void sim_writetexcell(NODEPROTO *np, INTBIG top)
 			case NPUNKNOWN:
 				/* ignore recursive references (showing icon in contents) */
 				if (ni->proto->cell == np->cell) continue;
-				addstringtoinfstr(infstr, "  ");
+				addstringtoinfstr(infstr, x_("  "));
 				addstringtoinfstr(infstr, sim_texproto(ni, f, &module_err));
-				addstringtoinfstr(infstr, " = ");
+				addstringtoinfstr(infstr, x_(" = "));
 				addstringtoinfstr(infstr, sim_texproto(ni, f, &module_err));
-				addstringtoinfstr(infstr, "///");
-				length = strlen(describenodeproto(ni->proto));
+				addstringtoinfstr(infstr, x_("///"));
+				length = estrlen(describenodeproto(ni->proto));
 
 				/* if there is a separator, directory name comes after it */
-				if ((separator = sim_strcspn(describenodeproto(ni->proto), "/")) != length)
+				if ((separator = sim_strcspn(describenodeproto(ni->proto), x_("/"))) != length)
 					addstringtoinfstr(infstr, sim_texname(
 						describenodeproto(ni->proto) + separator + 1)); else
 
 				/* no separator, hence directory name = library name */
 				addstringtoinfstr(infstr, sim_texlibname(ni->proto));
-				addstringtoinfstr(infstr, ",\n");
+				addstringtoinfstr(infstr, x_(",\n"));
 
 				/* if another node is the same as this one mark it seen */
 				for(nextni = ni->nextnodeinst; nextni != NONODEINST; nextni = nextni->nextnodeinst)
@@ -323,13 +330,13 @@ void sim_writetexcell(NODEPROTO *np, INTBIG top)
 
 	/* get USE string, replace last ',' with a ';' and write to TDL file */
 	ptr = returninfstr(infstr);
-	length = strlen(ptr);
+	length = estrlen(ptr);
 	*(ptr+length-2) = ';';
 	sim_texstrprint(ptr);
-	sim_texstrprint("\n");
+	sim_texstrprint(x_("\n"));
 
 	/* DEFINE */
-	sim_texstrprint("DEFINE:\n");
+	sim_texstrprint(x_("DEFINE:\n"));
 
 	/* count no. of inverters (negated arcs not attached to logic primitives */
 	count = 1;
@@ -385,13 +392,13 @@ void sim_writetexcell(NODEPROTO *np, INTBIG top)
 			case NPBUFFER:
 			case NPFLIPFLOP:
 				ni->temp2 = count++;
-				strcpy(str1, sim_textdlinst(ni, f));
-				strcat(str1, " = ");
-				strcat(str1, sim_texproto(ni, f, &module_err));
-				strcat(str1, sim_texwritesignals(ni, f, &module_err));
-				strcat(str1, sim_texgetdelay(ni, f));
+				estrcpy(str1, sim_textdlinst(ni, f));
+				estrcat(str1, x_(" = "));
+				estrcat(str1, sim_texproto(ni, f, &module_err));
+				estrcat(str1, sim_texwritesignals(ni, f, &module_err));
+				estrcat(str1, sim_texgetdelay(ni, f));
 				sim_texstrprint(str1);
-				sim_texstrprint(";\n");
+				sim_texstrprint(x_(";\n"));
 				break;
 
 			default:
@@ -410,48 +417,48 @@ void sim_writetexcell(NODEPROTO *np, INTBIG top)
 			if (xpp->network != pp->network) continue;
 			if (xpp->temp2 != 0) continue;
 			sim_texstrprint(sim_texname(pp->protoname));
-			sim_texstrprint(" &= ");
+			sim_texstrprint(x_(" &= "));
 			sim_texstrprint(sim_texname(xpp->protoname));
-			sim_texstrprint(";\n\n");
+			sim_texstrprint(x_(";\n\n"));
 			xpp->temp2++;
 		}
 		pp->temp2++;
 	}
 
 	/* end module */
-	sim_texstrprint(" END MODULE;\n\n");
+	sim_texstrprint(x_(" END MODULE;\n\n"));
 
 	/* if compiled correctly then reset variable */
 	if (module_err != 0) ttyputerr(_("*** Errors in module %s"),
 		sim_texname(describenodeproto(np)));
 }
 
-char *sim_textdlpower(NODEINST *ni, INTBIG f, INTBIG *pwr, INTBIG *gnd, INTBIG *module_err)
+CHAR *sim_textdlpower(NODEINST *ni, INTBIG f, INTBIG *pwr, INTBIG *gnd, INTBIG *module_err)
 {
-	static char str[20];
+	static CHAR str[20];
 
 	/* To prevent Un-connected power nodes */
 	if (ni->firstportarcinst == NOPORTARCINST)
 	{
 		sim_texerror(7, module_err, NULLSTR);
-		return("");
+		return(x_(""));
 	}
 
 	if (f == NPCONGROUND && *gnd != 1)
 	{
-		sprintf(str, "NET%ld = GRND;\n", (INTBIG)ni->firstportarcinst->conarcinst->network);
+		esnprintf(str, 20, x_("NET%ld = GRND;\n"), (INTBIG)ni->firstportarcinst->conarcinst->network);
 		*gnd = 1;
 		return(str);
 	}
 
 	if (f == NPCONPOWER && *pwr != 1)
 	{
-		sprintf(str, "NET%ld = PWR;\n", (INTBIG)ni->firstportarcinst->conarcinst->network);
+		esnprintf(str, 20, x_("NET%ld = PWR;\n"), (INTBIG)ni->firstportarcinst->conarcinst->network);
 		*pwr = 1;
 		return(str);
 	}
 
-	return("");
+	return(x_(""));
 }
 
 /* routine to count the wires on a primitive with only one inport */
@@ -474,35 +481,35 @@ INTBIG sim_texcountwires(NODEINST *ni)
  * a routine to return the name of the network which may be net<x> or the
  * name of an export on the net
  */
-char *sim_texsrcname(NODEINST *ni, PORTARCINST *pai)
+CHAR *sim_texsrcname(NODEINST *ni, PORTARCINST *pai)
 {
 	PORTPROTO *pp;
 	INTBIG exp_found=0;
-	static char str[MAXNAMECHARS + 1];
+	static CHAR str[MAXNAMECHARS + 1];
 
 	for(pp = ni->parent->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
 	{
 		if (pp->network == pai->conarcinst->network)
 		{
-			sprintf(str, "%s", sim_texname(pp->protoname));
+			esnprintf(str, MAXNAMECHARS+1, x_("%s"), sim_texname(pp->protoname));
 			exp_found++;
 			break;
 		}
 	}
 	if (exp_found == 0)
-		sprintf(str, "NET%ld", (INTBIG)pai->conarcinst->network);
+		esnprintf(str, MAXNAMECHARS+1, x_("NET%ld"), (INTBIG)pai->conarcinst->network);
 
 	return(str);
 }
 
 /* a routine to write the sources of signals on the input ports of a nodeinst */
-char *sim_texwritesignals(NODEINST *ni, INTBIG f, INTBIG *module_err)
+CHAR *sim_texwritesignals(NODEINST *ni, INTBIG f, INTBIG *module_err)
 {
 	PORTPROTO *pp;
 	PORTARCINST *pai;
 	PORTEXPINST *pei;
 	INTBIG portwired=0, length;
-	char *string;
+	CHAR *string;
 	REGISTER void *infstr;
 
 	if (f == NPFLIPFLOP)
@@ -511,7 +518,7 @@ char *sim_texwritesignals(NODEINST *ni, INTBIG f, INTBIG *module_err)
 	if (ni->proto->firstportproto != NOPORTPROTO)
 	{
 		infstr = initinfstr();
-		addstringtoinfstr(infstr, "(");
+		addstringtoinfstr(infstr, x_("("));
 	} else return(NULLSTR);
 
 	for(pp = ni->proto->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
@@ -520,7 +527,7 @@ char *sim_texwritesignals(NODEINST *ni, INTBIG f, INTBIG *module_err)
 
 		/* The transistor "s" port is treated as an inport by electric but is used */
 		/* as an outport by TDL */
-		if (f == NPTRANS && namesamen(pp->protoname, "s", 1) == 0) continue;
+		if (f == NPTRANS && namesamen(pp->protoname, x_("s"), 1) == 0) continue;
 
 		/* Buffer primitive has a "c" port not used by TDL */
 		if (f == NPBUFFER && *pp->protoname == 'c') continue;
@@ -531,7 +538,7 @@ char *sim_texwritesignals(NODEINST *ni, INTBIG f, INTBIG *module_err)
 			if (pai->proto == pp)
 			{
 				addstringtoinfstr(infstr, sim_textracesignal(pai, ni));
-				addstringtoinfstr(infstr, ",");
+				addstringtoinfstr(infstr, x_(","));
 				portwired++;
 
 				/* if port is not isolated then write one signal only */
@@ -543,21 +550,21 @@ char *sim_texwritesignals(NODEINST *ni, INTBIG f, INTBIG *module_err)
 			if (pei->proto == pp)
 			{
 				addstringtoinfstr(infstr, sim_texname(pei->exportproto->protoname));
-				addstringtoinfstr(infstr, ",");
+				addstringtoinfstr(infstr, x_(","));
 				portwired++;
 			}
 		}
 		if (portwired == 0)
 		{
 			sim_texerror(8, module_err, pp->protoname);
-			addstringtoinfstr(infstr, "NC,");
+			addstringtoinfstr(infstr, x_("NC,"));
 		}
 	}
 	string = returninfstr(infstr);
 	if (portwired == 0) return(NULLSTR);
 
 	/* replace last ',' with a ')' */
-	length = strlen(string);
+	length = estrlen(string);
 	*(string + length - 1) = ')';
 	*(string+length) = '\0';
 	return(string);
@@ -567,28 +574,29 @@ char *sim_texwritesignals(NODEINST *ni, INTBIG f, INTBIG *module_err)
  * routine to write the signals in the correct pin order for TDL for flip
  * flops n.b this is essentially the same as sim_texwritesignals
  */
-char *sim_texwriteffsignals(NODEINST *ni, INTBIG *module_err)
+CHAR *sim_texwriteffsignals(NODEINST *ni, INTBIG *module_err)
 {
 	PORTPROTO *pp;
 	PORTARCINST *pai;
 	PORTEXPINST *pei;
-	char signals[5][MAXNAMECHARS + 1], *string;
-	char *ptr;
+	CHAR signals[5][MAXNAMECHARS + 1], *string;
+	CHAR *ptr;
 	INTBIG x, length;
 	REGISTER void *infstr;
+	Q_UNUSED( module_err );
 
 	for(pp = ni->proto->firstportproto, x=0; pp != NOPORTPROTO; pp = pp->nextportproto)
 	{
 		if((pp->userbits&STATEBITS) == OUTPORT) continue;
 		ptr = &signals[x++][0];
-		strcpy(ptr, "NC,");   /* if no-connection write NC */
+		estrcpy(ptr, x_("NC,"));   /* if no-connection write NC */
 
 		for(pai = ni->firstportarcinst; pai != NOPORTARCINST; pai = pai->nextportarcinst)
 		{
 			if (pai->proto == pp)
 			{
-				strcpy(ptr,sim_textracesignal(pai, ni));
-				strcat(ptr, ",");
+				estrcpy(ptr,sim_textracesignal(pai, ni));
+				estrcat(ptr, x_(","));
 				break;
 			}
 		}
@@ -596,8 +604,8 @@ char *sim_texwriteffsignals(NODEINST *ni, INTBIG *module_err)
 		{
 			if (pei->proto == pp)
 			{
-				strcpy(ptr, sim_texname(pei->exportproto->protoname));
-				strcat(ptr, ",");
+				estrcpy(ptr, sim_texname(pei->exportproto->protoname));
+				estrcat(ptr, x_(","));
 				break;
 			}
 		}
@@ -607,7 +615,7 @@ char *sim_texwriteffsignals(NODEINST *ni, INTBIG *module_err)
 	/* order which is 2,0,1,3,4.If the flip flop is a D or T type don't put */
 	/* out array[1][]. */
 	infstr = initinfstr();
-	addstringtoinfstr(infstr, "(");
+	addstringtoinfstr(infstr, x_("("));
 	addstringtoinfstr(infstr, signals[2]);
 	addstringtoinfstr(infstr, signals[0]);
 
@@ -619,7 +627,7 @@ char *sim_texwriteffsignals(NODEINST *ni, INTBIG *module_err)
 	addstringtoinfstr(infstr, signals[4]);
 
 	string = returninfstr(infstr);
-	length = strlen(string);
+	length = estrlen(string);
 	*(string+length-1) = ')';
 	return(string);
 }
@@ -628,9 +636,9 @@ char *sim_texwriteffsignals(NODEINST *ni, INTBIG *module_err)
  * routine to trace back to the output source supplying a signal to the
  * portarcinst of a nodeinst
  */
-char *sim_textracesignal(PORTARCINST *pai, NODEINST *ni)
+CHAR *sim_textracesignal(PORTARCINST *pai, NODEINST *ni)
 {
-	static char str[MAXNAMECHARS];
+	static CHAR str[MAXNAMECHARS];
 
 	if ((pai->conarcinst->userbits&ISNEGATED) == 0) return(sim_texsrcname(ni, pai));
 
@@ -638,7 +646,7 @@ char *sim_textracesignal(PORTARCINST *pai, NODEINST *ni)
 	/* other than AND,OR,XOR */
 	if (pai->conarcinst->temp1 != -1)
 	{
-		sprintf(str, "I%ld.O", pai->conarcinst->temp1);
+		esnprintf(str, MAXNAMECHARS, x_("I%ld.O"), pai->conarcinst->temp1);
 		sim_texwriteinv(pai, str, sim_texsrcname(ni, pai));
 		return(str);
 	}
@@ -646,15 +654,15 @@ char *sim_textracesignal(PORTARCINST *pai, NODEINST *ni)
 }
 
 /* write out an inverter description for a negated arc */
-void sim_texwriteinv(PORTARCINST *pai, char *str1, char *str2)
+void sim_texwriteinv(PORTARCINST *pai, CHAR *str1, CHAR *str2)
 {
-	static char invstring[MAXNAMECHARS * 4];
-	char tempstr[MAXNAMECHARS];
+	static CHAR invstring[MAXNAMECHARS * 4];
+	CHAR tempstr[MAXNAMECHARS];
 
 	if (pai->conarcinst->temp1 == -1) return;
 
-	strcpy(tempstr, sim_texname(str1));
-	sprintf(invstring, "I%ld(%s) = NOT(%s);\n", pai->conarcinst->temp1, tempstr, sim_texname(str2));
+	estrcpy(tempstr, sim_texname(str1));
+	esnprintf(invstring, MAXNAMECHARS*4, x_("I%ld(%s) = NOT(%s);\n"), pai->conarcinst->temp1, tempstr, sim_texname(str2));
 	sim_texstrprint(invstring);
 	pai->conarcinst->temp1 = -1; /* write once only */
 }
@@ -664,25 +672,25 @@ void sim_texwriteinv(PORTARCINST *pai, char *str1, char *str2)
  * this nodeinst. if neccessary arcs that are negated will have inverter
  * descriptions written.
  */
-char *sim_textdlinst(NODEINST *ni, INTBIG f)
+CHAR *sim_textdlinst(NODEINST *ni, INTBIG f)
 {
 	NODEINST *xni;
 	PORTARCINST  *xpai, *ppai, *pai;
 	PORTPROTO   *pp;
 	PORTEXPINST *pei;
-	char str1[5], str2[MAXNAMECHARS + 10], *netstr;
+	CHAR str1[10], str2[MAXNAMECHARS + 10], *netstr;
 	INTBIG length, portcount=0, instcount=0;
 	REGISTER void *infstr;
 
-	sprintf(str1, "U%ld", ni->temp2);
+	esnprintf(str1, 10, x_("U%ld"), ni->temp2);
 	infstr = initinfstr();
 	addstringtoinfstr(infstr, str1);
-	addstringtoinfstr(infstr, "(");
+	addstringtoinfstr(infstr, x_("("));
 
 	for(pp = ni->proto->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
 	{
 		if (((pp->userbits&STATEBITS) == INPORT) && f != NPTRANS) continue;
-		if (f == NPTRANS && namesamen(pp->protoname, "g", 1) == 0) continue;
+		if (f == NPTRANS && namesamen(pp->protoname, x_("g"), 1) == 0) continue;
 
 		portcount++;
 		for(pai = ni->firstportarcinst; pai != NOPORTARCINST; pai = pai->nextportarcinst)
@@ -697,7 +705,7 @@ char *sim_textdlinst(NODEINST *ni, INTBIG f)
 			if ((pai->conarcinst->userbits&ISNEGATED) == 0 || pai->conarcinst->temp1 == -1)
 			{
 				addstringtoinfstr(infstr, sim_texsrcname(ni, pai));
-				addstringtoinfstr(infstr, ",");
+				addstringtoinfstr(infstr, x_(","));
 				break;
 			} else
 
@@ -706,9 +714,9 @@ char *sim_textdlinst(NODEINST *ni, INTBIG f)
 			/* arc as inverter output. The source name is the net name of the arc */
 			if ((pai->conarcinst->userbits&REVERSEEND) == 0)
 			{
-				sprintf(str2, "U%ld.%s", ni->temp2, sim_texname(pai->proto->protoname));
+				esnprintf(str2, MAXNAMECHARS + 10, x_("U%ld.%s"), ni->temp2, sim_texname(pai->proto->protoname));
 				addstringtoinfstr(infstr, str2);
-				addstringtoinfstr(infstr, ",");
+				addstringtoinfstr(infstr, x_(","));
 				sim_texwriteinv(pai, sim_texsrcname(ni, pai), str2);
 			} else
 
@@ -724,7 +732,7 @@ char *sim_textdlinst(NODEINST *ni, INTBIG f)
 				if ((xpai->proto->userbits&STATEBITS) ==INPORT)
 				{
 					addstringtoinfstr(infstr, sim_texsrcname(ni, pai));
-					addstringtoinfstr(infstr, ",");
+					addstringtoinfstr(infstr, x_(","));
 				} else
 				{
 					/* if the port at the opposite end is not an inport, look at all other    */
@@ -741,7 +749,7 @@ char *sim_textdlinst(NODEINST *ni, INTBIG f)
 						}
 					}
 					addstringtoinfstr(infstr, netstr);
-					addstringtoinfstr(infstr, ",");
+					addstringtoinfstr(infstr, x_(","));
 					sim_texwriteinv(pai, netstr, sim_texsrcname(ni, pai));
 				} /* end of else*/
 			}/* end of else*/
@@ -753,22 +761,22 @@ char *sim_textdlinst(NODEINST *ni, INTBIG f)
 			if (portcount == instcount) continue;
 			instcount++;
 			addstringtoinfstr(infstr, sim_texname(pei->exportproto->protoname));
-			addstringtoinfstr(infstr, ",");
+			addstringtoinfstr(infstr, x_(","));
 			break;
 		}
-		if (instcount < portcount) addstringtoinfstr(infstr, "NC,");
+		if (instcount < portcount) addstringtoinfstr(infstr, x_("NC,"));
 	}
 	netstr = returninfstr(infstr);
 	if (portcount == 0) return(NULLSTR);
-	length = strlen(netstr);
+	length = estrlen(netstr);
 	*(netstr+length-1) = ')';
 	return(netstr);
 }
 
 /* To handle all error conditions */
-void sim_texerror(INTBIG error, INTBIG *lasterror, char *str)
+void sim_texerror(INTBIG error, INTBIG *lasterror, CHAR *str)
 {
-	char *msg;
+	CHAR *msg;
 	REGISTER void *infstr;
 
 	infstr = initinfstr();
@@ -812,8 +820,8 @@ void sim_texerror(INTBIG error, INTBIG *lasterror, char *str)
 	msg = returninfstr(infstr);
 	sim_texstrprint(_("\n/************* ERROR **************/\n/*** "));
 	sim_texstrprint(msg);
-	sim_texstrprint(" ***\n\n");
-	ttyputerr("%s", msg);
+	sim_texstrprint(x_(" ***\n\n"));
+	ttyputerr(x_("%s"), msg);
 	*lasterror = error;
 }
 
@@ -823,20 +831,20 @@ void sim_texerror(INTBIG error, INTBIG *lasterror, char *str)
  * it searches for the last space character and inserts a new line character
  * at that point
  */
-void sim_texstrprint(char *str)
+void sim_texstrprint(CHAR *str)
 {
 	INTBIG length, charcount;
-	char *start_ptr, *max_line_ptr, newline[2];
-	char outstring[MAXLENGTH+3];
+	CHAR *start_ptr, *max_line_ptr, newline[2];
+	CHAR outstring[MAXLENGTH+3];
 
 	start_ptr = str;
-	strcpy(newline, "\n");
-	length = strlen(start_ptr);
+	estrcpy(newline, x_("\n"));
+	length = estrlen(start_ptr);
 
 	while (*start_ptr != '\0')
 	{
 		/* no new line chars and length > MAX */
-		if (length > MAXLENGTH && (!strchr(start_ptr, '\n')))
+		if (length > MAXLENGTH && (!estrchr(start_ptr, '\n')))
 		{
 			max_line_ptr = start_ptr + MAXLENGTH;
 			charcount = MAXLENGTH;
@@ -854,28 +862,28 @@ void sim_texstrprint(char *str)
 			}
 
 			/* copy string from start up to break point (max_line_ptr) */
-			strncpy(outstring, start_ptr, charcount + 1);
-			strcat(outstring, newline);
-			xprintf(sim_texfile, "%s", outstring);
+			estrncpy(outstring, start_ptr, charcount + 1);
+			estrcat(outstring, newline);
+			xprintf(sim_texfile, x_("%s"), outstring);
 			start_ptr = max_line_ptr + 1;
-			length = strlen(start_ptr);
+			length = estrlen(start_ptr);
 		} else
 		{
-			xprintf(sim_texfile, "%s", start_ptr);
+			xprintf(sim_texfile, x_("%s"), start_ptr);
 			break;
 		}
 	}
 }
 
 /* returns a string of max 12 chars and in upper case for TDL */
-char *sim_texname(char *str)
+CHAR *sim_texname(CHAR *str)
 {
-	static char buffer[MAXNAMECHARS +1], letter;
-	char tempbuffer[MAXNAMECHARS +1];
+	static CHAR buffer[MAXNAMECHARS +1], letter;
+	CHAR tempbuffer[MAXNAMECHARS +1];
 	INTBIG i, length;
 
-	if ((length=strlen(str)) > MAXNAMECHARS) length = MAXNAMECHARS;
-	strncpy(tempbuffer, str, length);
+	if ((length=estrlen(str)) > MAXNAMECHARS) length = MAXNAMECHARS;
+	estrncpy(tempbuffer, str, length);
 	for(i=0; i != length; i++)
 	{
 		letter = tempbuffer[i];
@@ -889,48 +897,48 @@ char *sim_texname(char *str)
  * routine to return the TDL name of a nodeinst
  * this routine will strip out a TDL directory name if present
  */
-char *sim_texproto(NODEINST *ni, INTBIG f, INTBIG *module_err)
+CHAR *sim_texproto(NODEINST *ni, INTBIG f, INTBIG *module_err)
 {
 	INTBIG x, length, span;
-	static char buffer[MAXNAMECHARS];
+	static CHAR buffer[MAXNAMECHARS];
 
 	if (f == NPGATEAND || f == NPGATEOR || f == NPGATEXOR)
 	{
-		if((x=sim_texcountwires(ni)) > 1) sprintf(buffer, "%ld-", x); else
+		if((x=sim_texcountwires(ni)) > 1) esnprintf(buffer, MAXNAMECHARS, x_("%ld-"), x); else
 		{
 			sim_texerror(9, module_err, describenodeproto(ni->proto));
-			sprintf(buffer, "2-");
+			esnprintf(buffer, MAXNAMECHARS, x_("2-"));
 		}
 
-		if (sim_texnegatedoutput(ni)) strcat(buffer, "N");
-	} else strcpy(buffer, "");
+		if (sim_texnegatedoutput(ni)) estrcat(buffer, x_("N"));
+	} else estrcpy(buffer, x_(""));
 
 	switch(f)
 	{
 		case NPGATEAND:
-			strcat(buffer, "AND");
+			estrcat(buffer, x_("AND"));
 			return(buffer);
 		case NPGATEOR:
-			strcat(buffer, "OR");
+			estrcat(buffer, x_("OR"));
 			return(buffer);
 		case NPGATEXOR:
-			strcat(buffer, "XOR");
+			estrcat(buffer, x_("XOR"));
 			return(buffer);
 		case NPBUFFER:
-			if (sim_texnegatedoutput(ni)) strcat(buffer, "NOT");
-				else strcat(buffer, "DELAY");
+			if (sim_texnegatedoutput(ni)) estrcat(buffer, x_("NOT"));
+				else estrcat(buffer, x_("DELAY"));
 			return(buffer);
 		case NPFLIPFLOP:
 			return(sim_texffname(ni, module_err));
 		case NPTRANS:
-			strcat(buffer, "BDSWITCH");
+			estrcat(buffer, x_("BDSWITCH"));
 			return(buffer);
 		case NPUNKNOWN:
-			length = strlen(describenodeproto(ni->proto));
-			if ((span = sim_strcspn(describenodeproto(ni->proto), "/")) != length)
+			length = estrlen(describenodeproto(ni->proto));
+			if ((span = sim_strcspn(describenodeproto(ni->proto), x_("/"))) != length)
 			{
 				if (span > MAXNAMECHARS) span = MAXNAMECHARS;
-				strncpy(buffer, describenodeproto(ni->proto), span);
+				estrncpy(buffer, describenodeproto(ni->proto), span);
 				return(sim_texname(buffer));
 			}
 			return(sim_texname(describenodeproto(ni->proto)));
@@ -940,27 +948,27 @@ char *sim_texproto(NODEINST *ni, INTBIG f, INTBIG *module_err)
 }
 
 /* routine to return the TDL primitive name of a flip-flop in electric */
-char *sim_texffname(NODEINST *ni, INTBIG *module_err)
+CHAR *sim_texffname(NODEINST *ni, INTBIG *module_err)
 {
-	static char name[5];
+	static CHAR name[5];
 
 	name[0] = 0;
 	switch (ni->userbits&FFTYPE)
 	{
-		case FFTYPERS: strcpy(name, "SR");   break;
-		case FFTYPEJK: strcpy(name, "JK");   break;
-		case FFTYPED:  strcpy(name, "D");    break;
+		case FFTYPERS: estrcpy(name, x_("SR"));   break;
+		case FFTYPEJK: estrcpy(name, x_("JK"));   break;
+		case FFTYPED:  estrcpy(name, x_("D"));    break;
 		case FFTYPET:
 			if ((ni->userbits&FFCLOCK) != FFCLOCKMS)
 				sim_texerror(10, module_err, NULLSTR);
-			strcpy(name, "TMNE");
+			estrcpy(name, x_("TMNE"));
 			break;
 	}
 	switch (ni->userbits&FFCLOCK)
 	{
-		case FFCLOCKMS: strcat(name, "MNE");   break;
-		case FFCLOCKP:  strcat(name, "EPE");   break;
-		case FFCLOCKN:  strcat(name, "ENE");   break;
+		case FFCLOCKMS: estrcat(name, x_("MNE"));   break;
+		case FFCLOCKP:  estrcat(name, x_("EPE"));   break;
+		case FFCLOCKN:  estrcat(name, x_("ENE"));   break;
 	}
 	return(name);
 }
@@ -969,35 +977,35 @@ char *sim_texffname(NODEINST *ni, INTBIG *module_err)
  * this routine returns a string containing the TDL delay. if no delay variable
  * present the default "/1,1/" is returned
  */
-char *sim_texgetdelay(NODEINST *ni, INTBIG f)
+CHAR *sim_texgetdelay(NODEINST *ni, INTBIG f)
 {
 	VARIABLE *var;
-	static char str1[30], str2[30];
+	static CHAR str1[30], str2[30];
 	static INTBIG SIM_rise_delay_key = 0, SIM_fall_delay_key = 0;
 
 	/* user defined modules are not allowed delays */
-	if (f == NPUNKNOWN) return("");
+	if (f == NPUNKNOWN) return(x_(""));
 
 	/* initialise variable for signal source names to be held on portarcinsts */
 	/* and TEX rise and fall time delays */
-	if (SIM_rise_delay_key == 0) SIM_rise_delay_key = makekey("SIM_rise_delay");
-	if (SIM_fall_delay_key == 0) SIM_fall_delay_key = makekey("SIM_fall_delay");
+	if (SIM_rise_delay_key == 0) SIM_rise_delay_key = makekey(x_("SIM_rise_delay"));
+	if (SIM_fall_delay_key == 0) SIM_fall_delay_key = makekey(x_("SIM_fall_delay"));
 
 	var = getvalkey((INTBIG)ni, VNODEINST, -1, SIM_rise_delay_key);
-	if (var == NOVARIABLE) sprintf(str1, "/1,"); else
+	if (var == NOVARIABLE) esnprintf(str1, 30, x_("/1,")); else
 	{
-		if ((var->type&VTYPE) == VINTEGER) sprintf(str1, "/%1ld,", var->addr);
-		if ((var->type&VTYPE) == VSTRING) sprintf(str1, "/%s,", (char *)var->addr);
+		if ((var->type&VTYPE) == VINTEGER) esnprintf(str1, 30, x_("/%1ld,"), var->addr);
+		if ((var->type&VTYPE) == VSTRING) esnprintf(str1, 30, x_("/%s,"), (CHAR *)var->addr);
 	}
 
 	var = getvalkey((INTBIG)ni, VNODEINST, VSTRING, SIM_fall_delay_key);
-	if (var == NOVARIABLE) sprintf(str2, "1/"); else
+	if (var == NOVARIABLE) esnprintf(str2, 30, x_("1/")); else
 	{
-		if ((var->type&VTYPE) == VINTEGER) sprintf(str2, "%1ld/", var->addr);
-		if ((var->type&VTYPE) == VSTRING) sprintf(str2, "%s/", (char *)var->addr);
+		if ((var->type&VTYPE) == VINTEGER) esnprintf(str2, 30, x_("%1ld/"), var->addr);
+		if ((var->type&VTYPE) == VSTRING) esnprintf(str2, 30, x_("%s/"), (CHAR *)var->addr);
 	}
 
-	strcat(str1, str2);
+	estrcat(str1, str2);
 	return(str1);
 }
 
@@ -1015,14 +1023,14 @@ BOOLEAN sim_texnegatedoutput(NODEINST *ni)
 }
 
 /* routine to remove the path specification from the electric library name */
-char *sim_texlibname(NODEPROTO *np)
+CHAR *sim_texlibname(NODEPROTO *np)
 {
 	INTBIG separator;
 
-	if (np->primindex != 0) return("MASTER");
+	if (np->primindex != 0) return(x_("MASTER"));
 
-	separator = sim_strcspn(np->cell->lib->libname, ":]") + 1;
-	if (separator == (INTBIG)(strlen(np->cell->lib->libname)+1)) separator = 0;
+	separator = sim_strcspn(np->cell->lib->libname, x_(":]")) + 1;
+	if (separator == (INTBIG)(estrlen(np->cell->lib->libname)+1)) separator = 0;
 	return(sim_texname((np->cell->lib->libname + separator)));
 }
 
@@ -1052,9 +1060,9 @@ NODEINST *sim_oppendni(PORTARCINST *pai)
  * routine that takes a string of max. length 12 and checks to see if it is a
  * reserved word
  */
-BOOLEAN sim_texcheckname(char *str)
+BOOLEAN sim_texcheckname(CHAR *str)
 {
-	char name[MAXNAMECHARS], *p, fileline[MAXLENGTH];
+	CHAR name[MAXNAMECHARS], *p, fileline[MAXLENGTH];
 	INTBIG i=0, x=0;
 
 	if (reservefile != NULL)
@@ -1068,7 +1076,7 @@ BOOLEAN sim_texcheckname(char *str)
 			while (!(*p == '\n' || *p =='\0')) name[i++] = *p++;
 
 			p = fileline;
-			if ((x = strlen(str)) < 2) x = 2;  /* minimum abbrev. is 2 chars */
+			if ((x = estrlen(str)) < 2) x = 2;  /* minimum abbrev. is 2 chars */
 			if (namesamen(name, str, x) == 0) return(FALSE);
 		}
 		return(TRUE);
@@ -1077,10 +1085,10 @@ BOOLEAN sim_texcheckname(char *str)
 }
 
 /* private version of library function (may not be on all systems) */
-INTBIG sim_strcspn(char *str, char *set)
+INTBIG sim_strcspn(CHAR *str, CHAR *set)
 {
 	INTBIG pos;
-	char *pt;
+	CHAR *pt;
 
 	for(pos=0; str[pos] != 0; pos++)
 	{
