@@ -41,12 +41,12 @@
 /* the options table */
 static KEYWORD artopt[] =
 {
-	{"arrows-filled",     0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
-	{"arrows-outline",    0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
+	{x_("arrows-filled"),     0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
+	{x_("arrows-outline"),    0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
 	TERMKEY
 };
 COMCOMP art_parse = {artopt, NOTOPLIST, NONEXTLIST, NOPARAMS,
-	0, " \t", M_("ARTWORK option"), M_("show current option")};
+	0, x_(" \t"), M_("ARTWORK option"), M_("show current option")};
 
 typedef struct
 {
@@ -56,33 +56,33 @@ typedef struct
 
 ARTPOLYLOOP art_oneprocpolyloop;
 
-TECHNOLOGY *art_tech;
+       TECHNOLOGY *art_tech;
 static INTBIG      art_state;			/* state bits */
-INTBIG      art_messagekey;		/* key for "ART_message" */
-INTBIG      art_colorkey;		/* key for "ART_color" */
-INTBIG      art_degreeskey;		/* key for "ART_degrees" */
-INTBIG      art_patternkey;		/* key for "ART_pattern" */
-NODEPROTO  *art_pinprim;
-NODEPROTO  *art_openedpolygonprim;
-NODEPROTO  *art_boxprim;
-NODEPROTO  *art_crossedboxprim;
-NODEPROTO  *art_filledboxprim;
-NODEPROTO  *art_circleprim;
-NODEPROTO  *art_thickcircleprim;
-NODEPROTO  *art_filledcircleprim;
-NODEPROTO  *art_splineprim;
-NODEPROTO  *art_triangleprim;
-NODEPROTO  *art_filledtriangleprim;
-NODEPROTO  *art_arrowprim;
-NODEPROTO  *art_openeddottedpolygonprim;
-NODEPROTO  *art_openeddashedpolygonprim;
-NODEPROTO  *art_openedthickerpolygonprim;
-NODEPROTO  *art_closedpolygonprim;
-NODEPROTO  *art_filledpolygonprim;
-ARCPROTO   *art_solidarc;
-ARCPROTO   *art_dottedarc;
-ARCPROTO   *art_dashedarc;
-ARCPROTO   *art_thickerarc;
+       INTBIG      art_messagekey;		/* key for "ART_message" */
+       INTBIG      art_colorkey;		/* key for "ART_color" */
+       INTBIG      art_degreeskey;		/* key for "ART_degrees" */
+       INTBIG      art_patternkey;		/* key for "ART_pattern" */
+       NODEPROTO  *art_pinprim;
+       NODEPROTO  *art_openedpolygonprim;
+       NODEPROTO  *art_boxprim;
+       NODEPROTO  *art_crossedboxprim;
+       NODEPROTO  *art_filledboxprim;
+       NODEPROTO  *art_circleprim;
+       NODEPROTO  *art_thickcircleprim;
+       NODEPROTO  *art_filledcircleprim;
+       NODEPROTO  *art_splineprim;
+       NODEPROTO  *art_triangleprim;
+       NODEPROTO  *art_filledtriangleprim;
+       NODEPROTO  *art_arrowprim;
+       NODEPROTO  *art_openeddottedpolygonprim;
+       NODEPROTO  *art_openeddashedpolygonprim;
+       NODEPROTO  *art_openedthickerpolygonprim;
+       NODEPROTO  *art_closedpolygonprim;
+       NODEPROTO  *art_filledpolygonprim;
+       ARCPROTO   *art_solidarc;
+       ARCPROTO   *art_dottedarc;
+       ARCPROTO   *art_dashedarc;
+       ARCPROTO   *art_thickerarc;
 
 /* prototypes for local routines */
 static void   art_getgraphics(INTBIG, INTBIG, ARTPOLYLOOP*);
@@ -103,18 +103,22 @@ static void   art_intshapearcpoly(ARCINST *ai, INTBIG box, POLYGON *poly, POLYLO
 
 static GRAPHICS art_o_lay = {LAYERO, MENGLY, SOLIDC, SOLIDC,
 /* graphics layer */		{0xFFFF,0xFFFF,0xFFFF,0xFFFF,
+							0xFFFF,0xFFFF,0xFFFF,0xFFFF,
+							0xFFFF,0xFFFF,0xFFFF,0xFFFF,
 							0xFFFF,0xFFFF,0xFFFF,0xFFFF}, NOVARIABLE, 0};
 static GRAPHICS art_st_lay= {LAYERO, MENGLY, PATTERNED, PATTERNED,
 							{0xFFFF,0xFFFF,0xFFFF,0xFFFF,
+							0xFFFF,0xFFFF,0xFFFF,0xFFFF,
+							0xFFFF,0xFFFF,0xFFFF,0xFFFF,
 							0xFFFF,0xFFFF,0xFFFF,0xFFFF}, NOVARIABLE, 0};
 
 /* these tables must be updated together */
 GRAPHICS *art_layers[MAXLAYERS+1] = {&art_o_lay, NOGRAPHICS};
-static char *art_layer_names[MAXLAYERS] = {"Graphics"};
-static char *art_dxf_layers[MAXLAYERS] = {"OBJECT"};
+static CHAR *art_layer_names[MAXLAYERS] = {x_("Graphics")};
+static CHAR *art_dxf_layers[MAXLAYERS] = {x_("OBJECT")};
 static INTBIG art_layer_function[MAXLAYERS] = {LFART};
-static char *art_layer_letters[MAXLAYERS] = {"g"};
-static INTBIG art_gds_layers[MAXLAYERS] = {1};
+static CHAR *art_layer_letters[MAXLAYERS] = {x_("g")};
+static CHAR *art_gds_layers[MAXLAYERS] = {x_("1")};
 
 /******************** ARCS ********************/
 
@@ -127,28 +131,28 @@ static INTBIG art_gds_layers[MAXLAYERS] = {1};
 /* solid arc */
 static TECH_ARCLAY art_al_s[] = {{LOPAQUE, 0, FILLED}};
 static TECH_ARCS art_a_s = {
-	"Solid",0,ASOLID,NOARCPROTO,									/* name */
+	x_("Solid"),0,ASOLID,NOARCPROTO,								/* name */
 	1,art_al_s,														/* layers */
 	(APNONELEC<<AFUNCTIONSH)|CANWIPE|CANCURVE|(0<<AANGLEINCSH)};	/* userbits */
 
 /* dotted arc */
 static TECH_ARCLAY art_al_d1[] = {{LOPAQUE, 0, FILLED}};
 static TECH_ARCS art_a_d1 = {
-	"Dotted",0,ADOTTED,NOARCPROTO,									/* name */
+	x_("Dotted"),0,ADOTTED,NOARCPROTO,								/* name */
 	1,art_al_d1,													/* layers */
 	(APNONELEC<<AFUNCTIONSH)|CANWIPE|CANCURVE|(0<<AANGLEINCSH)};	/* userbits */
 
 /* dashed arc */
 static TECH_ARCLAY art_al_d2[] = {{LOPAQUE, 0, FILLED}};
 static TECH_ARCS art_a_d2 = {
-	"Dashed",0,ADASHED,NOARCPROTO,									/* name */
+	x_("Dashed"),0,ADASHED,NOARCPROTO,								/* name */
 	1,art_al_d2,													/* layers */
 	(APNONELEC<<AFUNCTIONSH)|CANWIPE|CANCURVE|(0<<AANGLEINCSH)};	/* userbits */
 
 /* thicker arc */
 static TECH_ARCLAY art_al_d3[] = {{LOPAQUE, 0, FILLED}};
 static TECH_ARCS art_a_d3 = {
-	"Thicker",0,ATHICKER,NOARCPROTO,								/* name */
+	x_("Thicker"),0,ATHICKER,NOARCPROTO,							/* name */
 	1,art_al_d3,													/* layers */
 	(APNONELEC<<AFUNCTIONSH)|CANWIPE|CANCURVE|(0<<AANGLEINCSH)};	/* userbits */
 
@@ -181,11 +185,11 @@ static INTBIG art_pc_d[] = {-1, ASOLID, ADOTTED, ADASHED, ATHICKER, ALLGEN, -1};
 #define NFILLED        16		/* filled polygon */
 #define NTCIRCLE       17		/* thick circle */
 
-#define SX   (WHOLE/6)
+#define EI   (WHOLE/8)
 static INTBIG art_fullbox[8]  = {LEFTEDGE, LEFTEDGE, RIGHTEDGE, TOPEDGE};
 static INTBIG art_circ[8]     = {CENTER, CENTER,     RIGHTEDGE, CENTER};
-static INTBIG art_opnd[16]    = {LEFTEDGE, BOTEDGE,  -SX,0,TOPEDGE,
-								SX,0,BOTEDGE,       RIGHTEDGE,TOPEDGE};
+static INTBIG art_opnd[16]    = {LEFTEDGE, BOTEDGE,  -EI,0,TOPEDGE,
+								EI,0,BOTEDGE,       RIGHTEDGE,TOPEDGE};
 static INTBIG art_clsd[16]    = {LEFTEDGE, CENTER,   CENTER,TOPEDGE,
 								RIGHTEDGE, BOTEDGE, CENTER, BOTEDGE};
 static INTBIG art_tri[12]     = {LEFTEDGE, BOTEDGE,  RIGHTEDGE, BOTEDGE,
@@ -199,12 +203,12 @@ static INTBIG art_arr2[12]    = {LEFTEDGE, BOTEDGE,  RIGHTEDGE, CENTER,
 
 /* Pin */
 static TECH_PORTS art_pin_p[] = {					/* ports */
-	{art_pc_d, "site", NOPORTPROTO, (180<<PORTARANGESH),
+	{art_pc_d, x_("site"), NOPORTPROTO, (180<<PORTARANGESH),
 		CENTER, CENTER, CENTER, CENTER}};
 static TECH_POLYGON art_pin_l[] = {					/* layers */
 	{LOPAQUE, -1, 2, DISC, POINTS, art_circ}};
 static TECH_NODES art_pin = {
-	"Pin",NPIN,NONODEPROTO,							/* name */
+	x_("Pin"),NPIN,NONODEPROTO,						/* name */
 	K1,K1,											/* size */
 	1,art_pin_p,									/* ports */
 	1,art_pin_l,									/* layers */
@@ -213,13 +217,13 @@ static TECH_NODES art_pin = {
 
 /* Box */
 static TECH_PORTS art_box_p[] = {					/* ports */
-	{art_pc_d, "box",    NOPORTPROTO, (180<<PORTANGLESH),
+	{art_pc_d, x_("box"),    NOPORTPROTO, (180<<PORTANGLESH),
 		LEFTEDGE, TOPEDGE, RIGHTEDGE, BOTEDGE}};
 static TECH_POLYGON art_box_l[] = {					/* layers */
 	{LOPAQUE, -1, 4, CLOSEDRECT, BOX, art_fullbox}};
 static TECH_NODES art_box = {
-	"Box",NBOX,NONODEPROTO,							/* name */
-	K4,K4,											/* size */
+	x_("Box"),NBOX,NONODEPROTO,						/* name */
+	K6,K6,											/* size */
 	1,art_box_p,									/* ports */
 	1,art_box_l,									/* layers */
 	(NPART<<NFUNCTIONSH)|NEDGESELECT,				/* userbits */
@@ -227,13 +231,13 @@ static TECH_NODES art_box = {
 
 /* Crossed Box */
 static TECH_PORTS art_cbox_p[] = {					/* ports */
-	{art_pc_d, "fbox",    NOPORTPROTO, (180<<PORTANGLESH),
+	{art_pc_d, x_("fbox"),    NOPORTPROTO, (180<<PORTANGLESH),
 		LEFTEDGE, TOPEDGE, RIGHTEDGE, BOTEDGE}};
 static TECH_POLYGON art_cbox_l[] = {				/* layers */
 	{LOPAQUE, -1, 4, CROSSED, BOX, art_fullbox}};
 static TECH_NODES art_cbox = {
-	"Crossed-Box",NCBOX,NONODEPROTO,				/* name */
-	K4,K4,											/* size */
+	x_("Crossed-Box"),NCBOX,NONODEPROTO,			/* name */
+	K6,K6,											/* size */
 	1,art_cbox_p,									/* ports */
 	1,art_cbox_l,									/* layers */
 	(NPART<<NFUNCTIONSH),							/* userbits */
@@ -241,13 +245,13 @@ static TECH_NODES art_cbox = {
 
 /* Filled Box */
 static TECH_PORTS art_fbox_p[] = {					/* ports */
-	{art_pc_d, "fbox",    NOPORTPROTO, (180<<PORTANGLESH),
+	{art_pc_d, x_("fbox"),    NOPORTPROTO, (180<<PORTANGLESH),
 		LEFTEDGE, TOPEDGE, RIGHTEDGE, BOTEDGE}};
 static TECH_POLYGON art_fbox_l[] = {				/* layers */
 	{LOPAQUE, -1, 4, FILLEDRECT, BOX, art_fullbox}};
 static TECH_NODES art_fbox = {
-	"Filled-Box",NFBOX,NONODEPROTO,					/* name */
-	K4,K4,											/* size */
+	x_("Filled-Box"),NFBOX,NONODEPROTO,				/* name */
+	K6,K6,											/* size */
 	1,art_fbox_p,									/* ports */
 	1,art_fbox_l,									/* layers */
 	(NPART<<NFUNCTIONSH)|NEDGESELECT,				/* userbits */
@@ -255,13 +259,13 @@ static TECH_NODES art_fbox = {
 
 /* Circle (or Arc or Ellipse) */
 static TECH_PORTS art_circle_p[] = {				/* ports */
-	{art_pc_d, "site", NOPORTPROTO, (180<<PORTARANGESH),
+	{art_pc_d, x_("site"), NOPORTPROTO, (180<<PORTARANGESH),
 		CENTER, CENTER, CENTER, CENTER}};
 static TECH_POLYGON art_circle_l[] = {				/* layers */
 	{LOPAQUE, -1, 2, CIRCLE, POINTS, art_circ}};
 static TECH_NODES art_circle = {
-	"Circle",NCIRCLE,NONODEPROTO,					/* name */
-	K4,K4,											/* size */
+	x_("Circle"),NCIRCLE,NONODEPROTO,				/* name */
+	K6,K6,											/* size */
 	1,art_circle_p,									/* ports */
 	1,art_circle_l,									/* layers */
 	(NPART<<NFUNCTIONSH)|NEDGESELECT,				/* userbits */
@@ -269,13 +273,13 @@ static TECH_NODES art_circle = {
 
 /* Filled Circle */
 static TECH_PORTS art_fcircle_p[] = {				/* ports */
-	{art_pc_d, "site", NOPORTPROTO, (180<<PORTARANGESH),
+	{art_pc_d, x_("site"), NOPORTPROTO, (180<<PORTARANGESH),
 		CENTER, CENTER, CENTER, CENTER}};
 static TECH_POLYGON art_fcircle_l[] = {				/* layers */
 	{LOPAQUE, -1, 2, DISC, POINTS, art_circ}};
 static TECH_NODES art_fcircle = {
-	"Filled-Circle",NFCIRCLE,NONODEPROTO,			/* name */
-	K4,K4,											/* size */
+	x_("Filled-Circle"),NFCIRCLE,NONODEPROTO,		/* name */
+	K6,K6,											/* size */
 	1,art_fcircle_p,								/* ports */
 	1,art_fcircle_l,								/* layers */
 	(NPART<<NFUNCTIONSH)|NSQUARE|NEDGESELECT,		/* userbits */
@@ -283,13 +287,13 @@ static TECH_NODES art_fcircle = {
 
 /* Spline Curve */
 static TECH_PORTS art_spline_p[] = {				/* ports */
-	{art_pc_d, "site", NOPORTPROTO, (180<<PORTARANGESH),
+	{art_pc_d, x_("site"), NOPORTPROTO, (180<<PORTARANGESH),
 		CENTER, CENTER, CENTER, CENTER}};
 static TECH_POLYGON art_spline_l[] = {				/* layers */
 	{LOPAQUE, -1, 4, OPENED, POINTS, art_opnd}};
 static TECH_NODES art_spline = {
-	"Spline",NSPLINE,NONODEPROTO,					/* name */
-	K4,K4,											/* size */
+	x_("Spline"),NSPLINE,NONODEPROTO,				/* name */
+	K6,K6,											/* size */
 	1,art_spline_p,									/* ports */
 	1,art_spline_l,									/* layers */
 	(NPART<<NFUNCTIONSH)|HOLDSTRACE|NEDGESELECT,	/* userbits */
@@ -297,13 +301,13 @@ static TECH_NODES art_spline = {
 
 /* Triangle */
 static TECH_PORTS art_triangle_p[] = {				/* ports */
-	{art_pc_d, "triangle",    NOPORTPROTO, (180<<PORTANGLESH),
+	{art_pc_d, x_("triangle"),    NOPORTPROTO, (180<<PORTANGLESH),
 		LEFTEDGE, TOPEDGE, RIGHTEDGE, BOTEDGE}};
 static TECH_POLYGON art_triangle_l[] = {			/* layers */
 	{LOPAQUE, -1, 3, CLOSED, POINTS, art_tri}};
 static TECH_NODES art_triangle = {
-	"Triangle",NTRIANGLE,NONODEPROTO,				/* name */
-	K4,K4,											/* size */
+	x_("Triangle"),NTRIANGLE,NONODEPROTO,			/* name */
+	K6,K6,											/* size */
 	1,art_triangle_p,								/* ports */
 	1,art_triangle_l,								/* layers */
 	(NPART<<NFUNCTIONSH)|NEDGESELECT,				/* userbits */
@@ -311,13 +315,13 @@ static TECH_NODES art_triangle = {
 
 /* Filled Triangle */
 static TECH_PORTS art_ftriangle_p[] = {				/* ports */
-	{art_pc_d, "ftriangle",    NOPORTPROTO, (180<<PORTANGLESH),
+	{art_pc_d, x_("ftriangle"),    NOPORTPROTO, (180<<PORTANGLESH),
 		LEFTEDGE, TOPEDGE, RIGHTEDGE, BOTEDGE}};
 static TECH_POLYGON art_ftriangle_l[] = {			/* layers */
 	{LOPAQUE, -1, 3, FILLED, POINTS, art_tri}};
 static TECH_NODES art_ftriangle = {
-	"Filled-Triangle",NFTRIANGLE,NONODEPROTO,		/* name */
-	K4,K4,											/* size */
+	x_("Filled-Triangle"),NFTRIANGLE,NONODEPROTO,	/* name */
+	K6,K6,											/* size */
 	1,art_ftriangle_p,								/* ports */
 	1,art_ftriangle_l,								/* layers */
 	(NPART<<NFUNCTIONSH)|NEDGESELECT,				/* userbits */
@@ -325,13 +329,13 @@ static TECH_NODES art_ftriangle = {
 
 /* Arrow Head */
 static TECH_PORTS art_arrow_p[] = {					/* ports */
-	{art_pc_d, "arrow", NOPORTPROTO, (180<<PORTARANGESH),
+	{art_pc_d, x_("arrow"), NOPORTPROTO, (180<<PORTARANGESH),
 		 RIGHTEDGE, CENTER, RIGHTEDGE, CENTER}};
 static TECH_POLYGON art_arrow_l[] = {				/* layers */
 	{LOPAQUE, -1, 3, OPENED, POINTS, art_arr},
 	{LOPAQUE, -1, 3, FILLED, POINTS, art_arr2}};
 static TECH_NODES art_arrow = {
-	"Arrow",NARROW,NONODEPROTO,						/* name */
+	x_("Arrow"),NARROW,NONODEPROTO,					/* name */
 	K2,K2,											/* size */
 	1,art_arrow_p,									/* ports */
 	1,art_arrow_l,									/* layers */
@@ -340,13 +344,13 @@ static TECH_NODES art_arrow = {
 
 /* Opened Solid Polygon */
 static TECH_PORTS art_freeform_p[] = {				/* ports */
-	{art_pc_d, "site", NOPORTPROTO, (180<<PORTARANGESH),
+	{art_pc_d, x_("site"), NOPORTPROTO, (180<<PORTARANGESH),
 		CENTER, CENTER, CENTER, CENTER}};
 static TECH_POLYGON art_freeform_l[] = {			/* layers */
 	{LOPAQUE, -1, 4, OPENED, POINTS, art_opnd}};
 static TECH_NODES art_freeform = {
-	"Opened-Polygon",NOPENED,NONODEPROTO,			/* name */
-	K4,K4,											/* size */
+	x_("Opened-Polygon"),NOPENED,NONODEPROTO,		/* name */
+	K6,K6,											/* size */
 	1,art_freeform_p,								/* ports */
 	1,art_freeform_l,								/* layers */
 	(NPART<<NFUNCTIONSH)|HOLDSTRACE|NEDGESELECT,	/* userbits */
@@ -354,13 +358,13 @@ static TECH_NODES art_freeform = {
 
 /* Opened Dotted Polygon */
 static TECH_PORTS art_freeformdot_p[] = {			/* ports */
-	{art_pc_d, "site", NOPORTPROTO, (180<<PORTARANGESH),
+	{art_pc_d, x_("site"), NOPORTPROTO, (180<<PORTARANGESH),
 		CENTER, CENTER, CENTER, CENTER}};
 static TECH_POLYGON art_freeformdot_l[] = {			/* layers */
 	{LOPAQUE, -1, 4, OPENEDT1, POINTS, art_opnd}};
 static TECH_NODES art_freeformdot = {
-	"Opened-Dotted-Polygon",NOPENEDT1,NONODEPROTO,	/* name */
-	K4,K4,											/* size */
+	x_("Opened-Dotted-Polygon"),NOPENEDT1,NONODEPROTO,	/* name */
+	K6,K6,											/* size */
 	1,art_freeformdot_p,							/* ports */
 	1,art_freeformdot_l,							/* layers */
 	(NPART<<NFUNCTIONSH)|HOLDSTRACE|NEDGESELECT,	/* userbits */
@@ -368,13 +372,13 @@ static TECH_NODES art_freeformdot = {
 
 /* Opened Dashed Polygon */
 static TECH_PORTS art_freeformdash_p[] = {			/* ports */
-	{art_pc_d, "site", NOPORTPROTO, (180<<PORTARANGESH),
+	{art_pc_d, x_("site"), NOPORTPROTO, (180<<PORTARANGESH),
 		CENTER, CENTER, CENTER, CENTER}};
 static TECH_POLYGON art_freeformdash_l[] = {		/* layers */
 	{LOPAQUE, -1, 4, OPENEDT2, POINTS, art_opnd}};
 static TECH_NODES art_freeformdash = {
-	"Opened-Dashed-Polygon",NOPENEDT2,NONODEPROTO,	/* name */
-	K4,K4,											/* size */
+	x_("Opened-Dashed-Polygon"),NOPENEDT2,NONODEPROTO,	/* name */
+	K6,K6,											/* size */
 	1,art_freeformdash_p,							/* ports */
 	1,art_freeformdash_l,							/* layers */
 	(NPART<<NFUNCTIONSH)|HOLDSTRACE|NEDGESELECT,	/* userbits */
@@ -382,13 +386,13 @@ static TECH_NODES art_freeformdash = {
 
 /* Opened Thicker Polygon */
 static TECH_PORTS art_freeformfdot_p[] = {			/* ports */
-	{art_pc_d, "site", NOPORTPROTO, (180<<PORTARANGESH),
+	{art_pc_d, x_("site"), NOPORTPROTO, (180<<PORTARANGESH),
 		CENTER, CENTER, CENTER, CENTER}};
 static TECH_POLYGON art_freeformfdot_l[] = {		/* layers */
 	{LOPAQUE, -1, 4, OPENEDT3, POINTS, art_opnd}};
 static TECH_NODES art_freeformfdot = {
-	"Opened-Thicker-Polygon",NOPENEDT3,NONODEPROTO,	/* name */
-	K4,K4,											/* size */
+	x_("Opened-Thicker-Polygon"),NOPENEDT3,NONODEPROTO,	/* name */
+	K6,K6,											/* size */
 	1,art_freeformfdot_p,							/* ports */
 	1,art_freeformfdot_l,							/* layers */
 	(NPART<<NFUNCTIONSH)|HOLDSTRACE|NEDGESELECT,	/* userbits */
@@ -396,13 +400,13 @@ static TECH_NODES art_freeformfdot = {
 
 /* Closed Polygon */
 static TECH_PORTS art_closed_p[] = {				/* ports */
-	{art_pc_d, "site", NOPORTPROTO, (180<<PORTARANGESH),
+	{art_pc_d, x_("site"), NOPORTPROTO, (180<<PORTARANGESH),
 		CENTER, CENTER, CENTER, CENTER}};
 static TECH_POLYGON art_closed_l[] = {				/* layers */
 	{LOPAQUE, -1, 4, CLOSED, POINTS, art_clsd}};
 static TECH_NODES art_closed = {
-	"Closed-Polygon",NCLOSED,NONODEPROTO,			/* name */
-	K4,K4,											/* size */
+	x_("Closed-Polygon"),NCLOSED,NONODEPROTO,		/* name */
+	K6,K6,											/* size */
 	1,art_closed_p,									/* ports */
 	1,art_closed_l,									/* layers */
 	(NPART<<NFUNCTIONSH)|HOLDSTRACE|NEDGESELECT,	/* userbits */
@@ -410,13 +414,13 @@ static TECH_NODES art_closed = {
 
 /* Filled Polygon */
 static TECH_PORTS art_polygon_p[] = {				/* ports */
-	{art_pc_d, "site", NOPORTPROTO, (180<<PORTARANGESH),
+	{art_pc_d, x_("site"), NOPORTPROTO, (180<<PORTARANGESH),
 		CENTER, CENTER, CENTER, CENTER}};
 static TECH_POLYGON art_polygon_l[] = {				/* layers */
 	{LOPAQUE, -1, 4, FILLED, POINTS, art_clsd}};
 static TECH_NODES art_polygon = {
-	"Filled-Polygon",NFILLED,NONODEPROTO,			/* name */
-	K4,K4,											/* size */
+	x_("Filled-Polygon"),NFILLED,NONODEPROTO,		/* name */
+	K6,K6,											/* size */
 	1,art_polygon_p,								/* ports */
 	1,art_polygon_l,								/* layers */
 	(NPART<<NFUNCTIONSH)|HOLDSTRACE|NEDGESELECT,	/* userbits */
@@ -424,13 +428,13 @@ static TECH_NODES art_polygon = {
 
 /* Thick Circle (or Arc or Ellipse) */
 static TECH_PORTS art_tcircle_p[] = {				/* ports */
-	{art_pc_d, "site", NOPORTPROTO, (180<<PORTARANGESH),
+	{art_pc_d, x_("site"), NOPORTPROTO, (180<<PORTARANGESH),
 		CENTER, CENTER, CENTER, CENTER}};
 static TECH_POLYGON art_tcircle_l[] = {				/* layers */
 	{LOPAQUE, -1, 2, THICKCIRCLE, POINTS, art_circ}};
 static TECH_NODES art_tcircle = {
-	"Thick-Circle",NTCIRCLE,NONODEPROTO,			/* name */
-	K4,K4,											/* size */
+	x_("Thick-Circle"),NTCIRCLE,NONODEPROTO,		/* name */
+	K6,K6,											/* size */
 	1,art_tcircle_p,								/* ports */
 	1,art_tcircle_l,								/* layers */
 	(NPART<<NFUNCTIONSH)|NEDGESELECT,				/* userbits */
@@ -447,20 +451,20 @@ TECH_NODES *art_nodeprotos[NODEPROTOCOUNT+1] = {&art_pin,
 TECH_VARIABLES art_variables[] =
 {
 	/* set general information about the technology */
-	{"TECH_layer_names", (char *)art_layer_names, 0.0,
+	{x_("TECH_layer_names"), (CHAR *)art_layer_names, 0.0,
 		VSTRING|VDONTSAVE|VISARRAY|(MAXLAYERS<<VLENGTHSH)},
-	{"TECH_layer_function", (char *)art_layer_function, 0.0,
+	{x_("TECH_layer_function"), (CHAR *)art_layer_function, 0.0,
 		VINTEGER|VDONTSAVE|VISARRAY|(MAXLAYERS<<VLENGTHSH)},
 
 	/* set information for the USER tool */
-	{"USER_layer_letters", (char *)art_layer_letters, 0.0,
+	{x_("USER_layer_letters"), (CHAR *)art_layer_letters, 0.0,
 		VSTRING|VDONTSAVE|VISARRAY|(MAXLAYERS<<VLENGTHSH)},
 
 	/* set information for the IO tool */
-	{"IO_dxf_layer_names", (char *)art_dxf_layers, 0.0,
+	{x_("IO_dxf_layer_names"), (CHAR *)art_dxf_layers, 0.0,
+		VSTRING|VDONTSAVE|VISARRAY|(MAXLAYERS<<VLENGTHSH)},
+	{x_("IO_gds_layer_numbers"), (CHAR *)art_gds_layers, 0.0,
 		VSTRING|VDONTSAVE|VISARRAY|(MAXLAYERS<<VLENGTHSH)},
-	{"IO_gds_layer_numbers", (char *)art_gds_layers, 0.0,
-		VINTEGER|VDONTSAVE|VISARRAY|(MAXLAYERS<<VLENGTHSH)},
 	{NULL, NULL, 0.0, 0}
 };
 
@@ -474,33 +478,33 @@ BOOLEAN art_initprocess(TECHNOLOGY *tech, INTBIG pass)
 		art_tech = tech;
 	} else if (pass == 1)
 	{
-		art_pinprim = getnodeproto("artwork:Pin");
-		art_boxprim = getnodeproto("artwork:Box");
-		art_crossedboxprim = getnodeproto("artwork:Crossed-Box");
-		art_filledboxprim = getnodeproto("artwork:Filled-Box");
-		art_circleprim = getnodeproto("artwork:Circle");
-		art_thickcircleprim = getnodeproto("artwork:Thick-Circle");
-		art_filledcircleprim = getnodeproto("artwork:Filled-Circle");
-		art_splineprim = getnodeproto("artwork:Spline");
-		art_triangleprim = getnodeproto("artwork:Triangle");
-		art_filledtriangleprim = getnodeproto("artwork:Filled-Triangle");
-		art_arrowprim = getnodeproto("artwork:Arrow");
-		art_openedpolygonprim = getnodeproto("artwork:Opened-Polygon");
-		art_openeddottedpolygonprim = getnodeproto("artwork:Opened-Dotted-Polygon");
-		art_openeddashedpolygonprim = getnodeproto("artwork:Opened-Dashed-Polygon");
-		art_openedthickerpolygonprim = getnodeproto("artwork:Opened-Thicker-Polygon");
-		art_closedpolygonprim = getnodeproto("artwork:Closed-Polygon");
-		art_filledpolygonprim = getnodeproto("artwork:Filled-Polygon");
+		art_pinprim = getnodeproto(x_("artwork:Pin"));
+		art_boxprim = getnodeproto(x_("artwork:Box"));
+		art_crossedboxprim = getnodeproto(x_("artwork:Crossed-Box"));
+		art_filledboxprim = getnodeproto(x_("artwork:Filled-Box"));
+		art_circleprim = getnodeproto(x_("artwork:Circle"));
+		art_thickcircleprim = getnodeproto(x_("artwork:Thick-Circle"));
+		art_filledcircleprim = getnodeproto(x_("artwork:Filled-Circle"));
+		art_splineprim = getnodeproto(x_("artwork:Spline"));
+		art_triangleprim = getnodeproto(x_("artwork:Triangle"));
+		art_filledtriangleprim = getnodeproto(x_("artwork:Filled-Triangle"));
+		art_arrowprim = getnodeproto(x_("artwork:Arrow"));
+		art_openedpolygonprim = getnodeproto(x_("artwork:Opened-Polygon"));
+		art_openeddottedpolygonprim = getnodeproto(x_("artwork:Opened-Dotted-Polygon"));
+		art_openeddashedpolygonprim = getnodeproto(x_("artwork:Opened-Dashed-Polygon"));
+		art_openedthickerpolygonprim = getnodeproto(x_("artwork:Opened-Thicker-Polygon"));
+		art_closedpolygonprim = getnodeproto(x_("artwork:Closed-Polygon"));
+		art_filledpolygonprim = getnodeproto(x_("artwork:Filled-Polygon"));
 
-		art_solidarc = getarcproto("Artwork:Solid");
-		art_dottedarc = getarcproto("Artwork:Dotted");
-		art_dashedarc = getarcproto("Artwork:Dashed");
-		art_thickerarc = getarcproto("Artwork:Thicker");
+		art_solidarc = getarcproto(x_("Artwork:Solid"));
+		art_dottedarc = getarcproto(x_("Artwork:Dotted"));
+		art_dashedarc = getarcproto(x_("Artwork:Dashed"));
+		art_thickerarc = getarcproto(x_("Artwork:Thicker"));
 
-		art_messagekey = makekey("ART_message");
-		art_colorkey = makekey("ART_color");
-		art_degreeskey = makekey("ART_degrees");
-		art_patternkey = makekey("ART_pattern");
+		art_messagekey = makekey(x_("ART_message"));
+		art_colorkey = makekey(x_("ART_color"));
+		art_degreeskey = makekey(x_("ART_degrees"));
+		art_patternkey = makekey(x_("ART_pattern"));
 		art_state = 0;
 		nextchangequiet();
 		setvalkey((INTBIG)art_tech, VTECHNOLOGY, el_techstate_key, art_state,
@@ -509,10 +513,10 @@ BOOLEAN art_initprocess(TECHNOLOGY *tech, INTBIG pass)
 	return(FALSE);
 }
 
-void art_setmode(INTBIG count, char *par[])
+void art_setmode(INTBIG count, CHAR *par[])
 {
 	REGISTER INTBIG l;
-	REGISTER char *pp;
+	REGISTER CHAR *pp;
 
 	if (count == 0)
 	{
@@ -522,32 +526,32 @@ void art_setmode(INTBIG count, char *par[])
 		return;
 	}
 
-	l = strlen(pp = par[0]);
-	if (namesamen(pp, "arrows-filled", l) == 0)
+	l = estrlen(pp = par[0]);
+	if (namesamen(pp, x_("arrows-filled"), l) == 0)
 	{
 		/* set the arrow heads to be fancy */
 		art_setstate(art_state | ARTWORKFILLARROWHEADS);
 		ttyputverbose(M_("Artwork arrow heads will be filled"));
 		return;
 	}
-	if (namesamen(pp, "arrows-outline", l) == 0)
+	if (namesamen(pp, x_("arrows-outline"), l) == 0)
 	{
 		/* set the arrow heads to be simple */
 		art_setstate(art_state & ~ARTWORKFILLARROWHEADS);
 		ttyputverbose(M_("Artwork arrow heads will be outline"));
 		return;
 	}
-	ttyputbadusage("technology tell artwork");
+	ttyputbadusage(x_("technology tell artwork"));
 }
 
-INTBIG art_request(char *command, va_list ap)
+INTBIG art_request(CHAR *command, va_list ap)
 {
-	if (namesame(command, "has-state") == 0) return(1);
-	if (namesame(command, "get-state") == 0)
+	if (namesame(command, x_("has-state")) == 0) return(1);
+	if (namesame(command, x_("get-state")) == 0)
 	{
 		return(art_state);
 	}
-	if (namesame(command, "set-state") == 0)
+	if (namesame(command, x_("set-state")) == 0)
 	{
 		art_setstate(va_arg(ap, INTBIG));
 		return(0);
@@ -583,6 +587,7 @@ INTBIG art_intnodepolys(NODEINST *ni, INTBIG *reasonable, WINDOWPART *win, POLYL
 	ARTPOLYLOOP *artpl)
 {
 	REGISTER INTBIG pindex, count;
+	Q_UNUSED( win );
 
 	pindex = ni->proto->primindex;
 
@@ -651,16 +656,26 @@ INTBIG art_allnodepolys(NODEINST *ni, POLYLIST *plist, WINDOWPART *win, BOOLEAN
 
 INTBIG art_nodeEpolys(NODEINST *ni, INTBIG *reasonable, WINDOWPART *win)
 {
+	Q_UNUSED( ni );
+	Q_UNUSED( win );
+
 	if (reasonable != 0) *reasonable = 0;
 	return(0);
 }
 
 void art_shapeEnodepoly(NODEINST *ni, INTBIG box, POLYGON *poly)
 {
+	Q_UNUSED( ni );
+	Q_UNUSED( box );
+	Q_UNUSED( poly );
 }
 
 INTBIG art_allnodeEpolys(NODEINST *ni, POLYLIST *plist, WINDOWPART *win, BOOLEAN onlyreasonable)
 {
+	Q_UNUSED( ni );
+	Q_UNUSED( plist );
+	Q_UNUSED( win );
+	Q_UNUSED( onlyreasonable );
 	return(0);
 }
 
@@ -668,6 +683,7 @@ void art_shapeportpoly(NODEINST *ni, PORTPROTO *pp, POLYGON *poly, XARRAY trans,
 	BOOLEAN purpose)
 {
 	REGISTER INTBIG pindex;
+	Q_UNUSED( purpose );
 
 	pindex = ni->proto->primindex;
 	if (pindex == NPIN || pindex == NARROW)
@@ -813,10 +829,10 @@ void art_fillnodebox(NODEINST *ni, INTBIG box, POLYGON *poly)
 		} else
 		{
 			sx = ni->highx - ni->lowx;   sy = ni->highy - ni->lowy;
-			dummypoints[0] = -sx / 2;   dummypoints[1] =  sy / 2;
-			dummypoints[2] = -sx / 6;   dummypoints[3] = -sy / 2;
-			dummypoints[4] =  sx / 6;   dummypoints[5] =  sy / 2;
-			dummypoints[6] =  sx / 2;   dummypoints[7] = -sy / 2;
+			dummypoints[0] = -sx / 2;   dummypoints[1] = -sy / 2;
+			dummypoints[2] = -sx / 8;   dummypoints[3] =  sy / 2;
+			dummypoints[4] =  sx / 8;   dummypoints[5] = -sy / 2;
+			dummypoints[6] =  sx / 2;   dummypoints[7] =  sy / 2;
 			art_fillspline(dummypoints, 4, cx, cy, poly, SPLINEGRAIN);
 		}
 	} else
@@ -838,7 +854,7 @@ void art_fillnodebox(NODEINST *ni, INTBIG box, POLYGON *poly)
 
 void art_getgraphics(INTBIG addr, INTBIG type, ARTPOLYLOOP *artpl)
 {
-	REGISTER INTBIG i, sty;
+	REGISTER INTBIG i, sty, len;
 
 	/* get the color information */
 	artpl->colorvar = getvalkey(addr, type, VINTEGER, art_colorkey);
@@ -867,10 +883,11 @@ void art_getgraphics(INTBIG addr, INTBIG type, ARTPOLYLOOP *artpl)
 	artpl->patternvar = getvalkey(addr, type, -1, art_patternkey);
 	if (artpl->patternvar != NOVARIABLE)
 	{
-		if (getlength(artpl->patternvar) != 8 ||
+		len = getlength(artpl->patternvar);
+		if ((len != 8 && len != 16) ||
 			((artpl->patternvar->type&VTYPE) != VINTEGER && (artpl->patternvar->type&VTYPE) != VSHORT))
 		{
-			ttyputerr(_("'ART_pattern' must be an 8-member INTEGER or SHORT array"));
+			ttyputerr(_("'ART_pattern' must be a 16-member INTEGER or SHORT array"));
 			artpl->patternvar = NOVARIABLE;
 			return;
 		}
@@ -878,14 +895,18 @@ void art_getgraphics(INTBIG addr, INTBIG type, ARTPOLYLOOP *artpl)
 		sty = PATTERNED;
 		if ((artpl->patternvar->type&VTYPE) == VINTEGER)
 		{
-			for(i=0; i<8; i++)
+			for(i=0; i<len; i++)
 				art_st_lay.raster[i] = (UINTSML)(((INTBIG *)artpl->patternvar->addr)[i]);
 		} else
 		{
-			for(i=0; i<8; i++)
+			for(i=0; i<len; i++)
 				art_st_lay.raster[i] = ((INTSML *)artpl->patternvar->addr)[i];
 			sty |= OUTLINEPAT;
 		}
+		if (len == 8)
+		{
+			for(i=0; i<8; i++) art_st_lay.raster[i+8] = art_st_lay.raster[i];
+		}
 
 		/* set the outline style (outlined if SHORT used) */
 		art_st_lay.colstyle = art_st_lay.bwstyle = (INTSML)sty;
