@@ -65,6 +65,14 @@ static GRAPHICS bipolar_M_lay = {LAYERT1, COLORT1, SOLIDC, PATTERNED,
 	0x8080,  /* X       X        */
 	0x4040,  /*  X       X       */
 	0x2020,  /*   X       X      */
+	0x1010,  /*    X       X     */
+	0x0808,  /*     X       X    */
+	0x0404,  /*      X       X   */
+	0x0202,  /*       X       X  */
+	0x0101,  /*        X       X */
+	0x8080,  /* X       X        */
+	0x4040,  /*  X       X       */
+	0x2020,  /*   X       X      */
 	0x1010}, /*    X       X     */
 	NOVARIABLE, 0};
 static GRAPHICS bipolar_M0_lay = {LAYERT4, COLORT4, SOLIDC, PATTERNED,
@@ -75,6 +83,14 @@ static GRAPHICS bipolar_M0_lay = {LAYERT4, COLORT4, SOLIDC, PATTERNED,
 	0x2222,  /*   X   X   X   X  */
 	0x0000,  /*                  */
 	0x8888,  /* X   X   X   X    */
+	0x0000,  /*                  */
+	0x2222,  /*   X   X   X   X  */
+	0x0000,  /*                  */
+	0x8888,  /* X   X   X   X    */
+	0x0000,  /*                  */
+	0x2222,  /*   X   X   X   X  */
+	0x0000,  /*                  */
+	0x8888,  /* X   X   X   X    */
 	0x0000}, /*                  */
 	NOVARIABLE, 0};
 static GRAPHICS bipolar_N_lay = {LAYERO, DGREEN, PATTERNED, PATTERNED,
@@ -85,6 +101,14 @@ static GRAPHICS bipolar_N_lay = {LAYERO, DGREEN, PATTERNED, PATTERNED,
 	0xcccc,  /* XX  XX  XX  XX   */
 	0xc0c0,  /* XX      XX       */
 	0xcccc,  /* XX  XX  XX  XX   */
+	0xc0c0,  /* XX      XX       */
+	0xcccc,  /* XX  XX  XX  XX   */
+	0xc0c0,  /* XX      XX       */
+	0xcccc,  /* XX  XX  XX  XX   */
+	0xc0c0,  /* XX      XX       */
+	0xcccc,  /* XX  XX  XX  XX   */
+	0xc0c0,  /* XX      XX       */
+	0xcccc,  /* XX  XX  XX  XX   */
 	0xc0c0}, /* XX      XX       */
 	NOVARIABLE, 0};
 static GRAPHICS bipolar_P_lay = {LAYERO, DBLUE, PATTERNED, PATTERNED,
@@ -95,6 +119,14 @@ static GRAPHICS bipolar_P_lay = {LAYERO, DBLUE, PATTERNED, PATTERNED,
 	0x0000,  /*                  */
 	0xcccc,  /* XX  XX  XX  XX   */
 	0x0000,  /*                  */
+	0xcccc,  /* XX  XX  XX  XX   */
+	0x0000,  /*                  */
+	0xcccc,  /* XX  XX  XX  XX   */
+	0x0000,  /*                  */
+	0xcccc,  /* XX  XX  XX  XX   */
+	0x0000,  /*                  */
+	0xcccc,  /* XX  XX  XX  XX   */
+	0x0000,  /*                  */
 	0xcccc}, /* XX  XX  XX  XX   */
 	NOVARIABLE, 0};
 static GRAPHICS bipolar_PD_lay = {LAYERT2, COLORT2, SOLIDC, PATTERNED,
@@ -105,6 +137,14 @@ static GRAPHICS bipolar_PD_lay = {LAYERT2, COLORT2, SOLIDC, PATTERNED,
 	0x1111,  /*    X   X   X   X */
 	0x0303,  /*       XX      XX */
 	0x1717,  /*    X XXX   X XXX */
+	0x0303,  /*       XX      XX */
+	0x1111,  /*    X   X   X   X */
+	0x3030,  /*   XX      XX     */
+	0x7171,  /*  XXX   X XXX   X */
+	0x3030,  /*   XX      XX     */
+	0x1111,  /*    X   X   X   X */
+	0x0303,  /*       XX      XX */
+	0x1717,  /*    X XXX   X XXX */
 	0x0303}, /*       XX      XX */
 	NOVARIABLE, 0};
 static GRAPHICS bipolar_FI_lay = {LAYERO, MAGENTA, PATTERNED, PATTERNED,
@@ -115,6 +155,14 @@ static GRAPHICS bipolar_FI_lay = {LAYERO, MAGENTA, PATTERNED, PATTERNED,
 	0x0000,  /*                  */
 	0x1414,  /*    X X     X X   */
 	0x2222,  /*   X   X   X   X  */
+	0x4141,  /*  X     X X     X */
+	0x0000,  /*                  */
+	0x4141,  /*  X     X X     X */
+	0x2222,  /*   X   X   X   X  */
+	0x1414,  /*    X X     X X   */
+	0x0000,  /*                  */
+	0x1414,  /*    X X     X X   */
+	0x2222,  /*   X   X   X   X  */
 	0x4141}, /*  X     X X     X */
 	NOVARIABLE, 0};
 static GRAPHICS bipolar_I_lay = {LAYERT3, COLORT3, SOLIDC, PATTERNED,
@@ -125,6 +173,14 @@ static GRAPHICS bipolar_I_lay = {LAYERT3, COLORT3, SOLIDC, PATTERNED,
 	0x5555,  /*  X X X X X X X X */
 	0xaaaa,  /* X X X X X X X X  */
 	0x5555,  /*  X X X X X X X X */
+	0xaaaa,  /* X X X X X X X X  */
+	0x5555,  /*  X X X X X X X X */
+	0xaaaa,  /* X X X X X X X X  */
+	0x5555,  /*  X X X X X X X X */
+	0xaaaa,  /* X X X X X X X X  */
+	0x5555,  /*  X X X X X X X X */
+	0xaaaa,  /* X X X X X X X X  */
+	0x5555,  /*  X X X X X X X X */
 	0xaaaa}, /* X X X X X X X X  */
 	NOVARIABLE, 0};
 static GRAPHICS bipolar_SI_lay = {LAYERO, PURPLE, PATTERNED, PATTERNED,
@@ -135,6 +191,14 @@ static GRAPHICS bipolar_SI_lay = {LAYERO, PURPLE, PATTERNED, PATTERNED,
 	0x1111,  /*    X   X   X   X */
 	0xffff,  /* XXXXXXXXXXXXXXXX */
 	0x1111,  /*    X   X   X   X */
+	0x5555,  /*  X X X X X X X X */
+	0x1111,  /*    X   X   X   X */
+	0xffff,  /* XXXXXXXXXXXXXXXX */
+	0x1111,  /*    X   X   X   X */
+	0x5555,  /*  X X X X X X X X */
+	0x1111,  /*    X   X   X   X */
+	0xffff,  /* XXXXXXXXXXXXXXXX */
+	0x1111,  /*    X   X   X   X */
 	0x5555}, /*  X X X X X X X X */
 	NOVARIABLE, 0};
 static GRAPHICS bipolar_NI_lay = {LAYERO, BROWN, PATTERNED, PATTERNED,
@@ -145,6 +209,14 @@ static GRAPHICS bipolar_NI_lay = {LAYERO, BROWN, PATTERNED, PATTERNED,
 	0xc1c1,  /* XX     XXX     X */
 	0xe0e0,  /* XXX     XXX      */
 	0x7070,  /*  XXX     XXX     */
+	0x3838,  /*   XXX     XXX    */
+	0x1c1c,  /*    XXX     XXX   */
+	0x0e0e,  /*     XXX     XXX  */
+	0x0707,  /*      XXX     XXX */
+	0x8383,  /* X     XXX     XX */
+	0xc1c1,  /* XX     XXX     X */
+	0xe0e0,  /* XXX     XXX      */
+	0x7070,  /*  XXX     XXX     */
 	0x3838}, /*   XXX     XXX    */
 	NOVARIABLE, 0};
 static GRAPHICS bipolar_SE_lay = {LAYERT5, COLORT5, SOLIDC, PATTERNED,
@@ -155,6 +227,14 @@ static GRAPHICS bipolar_SE_lay = {LAYERT5, COLORT5, SOLIDC, PATTERNED,
 	0xafaf,  /* X X XXXXX X XXXX */
 	0x8888,  /* X   X   X   X    */
 	0xfafa,  /* XXXXX X XXXXX X  */
+	0x8888,  /* X   X   X   X    */
+	0xafaf,  /* X X XXXXX X XXXX */
+	0x8888,  /* X   X   X   X    */
+	0xfafa,  /* XXXXX X XXXXX X  */
+	0x8888,  /* X   X   X   X    */
+	0xafaf,  /* X X XXXXX X XXXX */
+	0x8888,  /* X   X   X   X    */
+	0xfafa,  /* XXXXX X XXXXX X  */
 	0x8888}, /* X   X   X   X    */
 	NOVARIABLE, 0};
 static GRAPHICS bipolar_C_lay = {LAYERO, YELLOW, SOLIDC, PATTERNED,
@@ -165,6 +245,14 @@ static GRAPHICS bipolar_C_lay = {LAYERO, YELLOW, SOLIDC, PATTERNED,
 	0xffff,  /* XXXXXXXXXXXXXXXX */
 	0xffff,  /* XXXXXXXXXXXXXXXX */
 	0xffff,  /* XXXXXXXXXXXXXXXX */
+	0xffff,  /* XXXXXXXXXXXXXXXX */
+	0xffff,  /* XXXXXXXXXXXXXXXX */
+	0xffff,  /* XXXXXXXXXXXXXXXX */
+	0xffff,  /* XXXXXXXXXXXXXXXX */
+	0xffff,  /* XXXXXXXXXXXXXXXX */
+	0xffff,  /* XXXXXXXXXXXXXXXX */
+	0xffff,  /* XXXXXXXXXXXXXXXX */
+	0xffff,  /* XXXXXXXXXXXXXXXX */
 	0xffff}, /* XXXXXXXXXXXXXXXX */
 	NOVARIABLE, 0};
 static GRAPHICS bipolar_V_lay = {LAYERO, BLACK, SOLIDC, PATTERNED,
@@ -175,6 +263,14 @@ static GRAPHICS bipolar_V_lay = {LAYERO, BLACK, SOLIDC, PATTERNED,
 	0xffff,  /* XXXXXXXXXXXXXXXX */
 	0xffff,  /* XXXXXXXXXXXXXXXX */
 	0xffff,  /* XXXXXXXXXXXXXXXX */
+	0xffff,  /* XXXXXXXXXXXXXXXX */
+	0xffff,  /* XXXXXXXXXXXXXXXX */
+	0xffff,  /* XXXXXXXXXXXXXXXX */
+	0xffff,  /* XXXXXXXXXXXXXXXX */
+	0xffff,  /* XXXXXXXXXXXXXXXX */
+	0xffff,  /* XXXXXXXXXXXXXXXX */
+	0xffff,  /* XXXXXXXXXXXXXXXX */
+	0xffff,  /* XXXXXXXXXXXXXXXX */
 	0xffff}, /* XXXXXXXXXXXXXXXX */
 	NOVARIABLE, 0};
 static GRAPHICS bipolar_SP_lay = {LAYERO, DGRAY, SOLIDC, PATTERNED,
@@ -185,6 +281,14 @@ static GRAPHICS bipolar_SP_lay = {LAYERO, DGRAY, SOLIDC, PATTERNED,
 	0x1c1c,  /*    XXX     XXX   */
 	0x0000,  /*                  */
 	0x0000,  /*                  */
+	0x0000,  /*                  */
+	0x1c1c,  /*    XXX     XXX   */
+	0x3e3e,  /*   XXXXX   XXXXX  */
+	0x3636,  /*   XX XX   XX XX  */
+	0x3e3e,  /*   XXXXX   XXXXX  */
+	0x1c1c,  /*    XXX     XXX   */
+	0x0000,  /*                  */
+	0x0000,  /*                  */
 	0x0000}, /*                  */
 	NOVARIABLE, 0};
 static GRAPHICS bipolar_B_lay = {LAYERO, YELLOW, SOLIDC, PATTERNED,
@@ -195,6 +299,14 @@ static GRAPHICS bipolar_B_lay = {LAYERO, YELLOW, SOLIDC, PATTERNED,
 	0xffff,  /* XXXXXXXXXXXXXXXX */
 	0xffff,  /* XXXXXXXXXXXXXXXX */
 	0xffff,  /* XXXXXXXXXXXXXXXX */
+	0xffff,  /* XXXXXXXXXXXXXXXX */
+	0xffff,  /* XXXXXXXXXXXXXXXX */
+	0xffff,  /* XXXXXXXXXXXXXXXX */
+	0xffff,  /* XXXXXXXXXXXXXXXX */
+	0xffff,  /* XXXXXXXXXXXXXXXX */
+	0xffff,  /* XXXXXXXXXXXXXXXX */
+	0xffff,  /* XXXXXXXXXXXXXXXX */
+	0xffff,  /* XXXXXXXXXXXXXXXX */
 	0xffff}, /* XXXXXXXXXXXXXXXX */
 	NOVARIABLE, 0};
 static GRAPHICS bipolar_PM_lay = {LAYERT1, COLORT1, SOLIDC, PATTERNED,
@@ -205,6 +317,14 @@ static GRAPHICS bipolar_PM_lay = {LAYERT1, COLORT1, SOLIDC, PATTERNED,
 	0x2222,  /*   X   X   X   X  */
 	0x0000,  /*                  */
 	0x8888,  /* X   X   X   X    */
+	0x0000,  /*                  */
+	0x2222,  /*   X   X   X   X  */
+	0x0000,  /*                  */
+	0x8888,  /* X   X   X   X    */
+	0x0000,  /*                  */
+	0x2222,  /*   X   X   X   X  */
+	0x0000,  /*                  */
+	0x8888,  /* X   X   X   X    */
 	0x0000}, /*                  */
 	NOVARIABLE, 0};
 static GRAPHICS bipolar_PM0_lay = {LAYERT4, COLORT4, SOLIDC, PATTERNED,
@@ -215,6 +335,14 @@ static GRAPHICS bipolar_PM0_lay = {LAYERT4, COLORT4, SOLIDC, PATTERNED,
 	0x8080,  /* X       X        */
 	0x4040,  /*  X       X       */
 	0x2020,  /*   X       X      */
+	0x1010,  /*    X       X     */
+	0x0808,  /*     X       X    */
+	0x0404,  /*      X       X   */
+	0x0202,  /*       X       X  */
+	0x0101,  /*        X       X */
+	0x8080,  /* X       X        */
+	0x4040,  /*  X       X       */
+	0x2020,  /*   X       X      */
 	0x1010}, /*    X       X     */
 	NOVARIABLE, 0};
 
@@ -223,21 +351,21 @@ GRAPHICS *bipolar_layers[MAXLAYERS+1] = {&bipolar_M_lay, &bipolar_M0_lay,
 	&bipolar_I_lay, &bipolar_SI_lay, &bipolar_NI_lay, &bipolar_SE_lay,
 	&bipolar_C_lay, &bipolar_V_lay, &bipolar_SP_lay, &bipolar_B_lay,
 	&bipolar_PM_lay, &bipolar_PM0_lay, NOGRAPHICS};
-static char *bipolar_layer_names[MAXLAYERS] = {"Metal1", "Metal2", "NPImplant",
-	"PPImplant", "Poly_Definition", "Field_Implant", "Isolation", "Sink_Implant",
-	"N_Implant", "Silicide_Exclusion", "Contact", "Via", "Scratch_Protection",
-	"Buried", "Pseudo_Metal1", "Pseudo_Metal2"};
-static char *bipolar_cif_layers[MAXLAYERS] = {"IM1", "IM2", "INP", "IPP", "IP", "IF", "II",
-	"IS", "INM", "ISE", "IC", "IV", "ISP", "IB", "", ""};
-static INTBIG bipolar_gds_layers[MAXLAYERS] = {8, 9, 52, 53, 4, 2, 3, 6, 51, 45, 7, 81, 10,
-	1, 18, 19};
+static CHAR *bipolar_layer_names[MAXLAYERS] = {x_("Metal1"), x_("Metal2"), x_("NPImplant"),
+	x_("PPImplant"), x_("Poly_Definition"), x_("Field_Implant"), x_("Isolation"), x_("Sink_Implant"),
+	x_("N_Implant"), x_("Silicide_Exclusion"), x_("Contact"), x_("Via"), x_("Scratch_Protection"),
+	x_("Buried"), x_("Pseudo_Metal1"), x_("Pseudo_Metal2")};
+static CHAR *bipolar_cif_layers[MAXLAYERS] = {x_("IM1"), x_("IM2"), x_("INP"), x_("IPP"), x_("IP"), x_("IF"), x_("II"),
+	x_("IS"), x_("INM"), x_("ISE"), x_("IC"), x_("IV"), x_("ISP"), x_("IB"), x_(""), x_("")};
+static CHAR *bipolar_gds_layers[MAXLAYERS] = {x_("8"), x_("9"), x_("52"), x_("53"), x_("4"), x_("2"), x_("3"), x_("6"), x_("51"), x_("45"), x_("7"), x_("81"), x_("10"),
+	x_("1"), x_("18"), x_("19")};
 static INTBIG bipolar_layer_function[MAXLAYERS] = {LFMETAL1|LFTRANS1,
 	LFMETAL2|LFTRANS4, LFIMPLANT|LFNTYPE, LFIMPLANT|LFPTYPE, LFPOLY1|LFTRANS2,
 	LFIMPLANT|LFLIGHT, LFISOLATION|LFTRANS3, LFDIFF|LFHEAVY, LFIMPLANT|LFNTYPE,
 	LFGUARD|LFTRANS5, LFCONTACT1, LFCONTACT2, LFOVERGLASS, LFDIFF,
 	LFMETAL1|LFPSEUDO|LFTRANS1, LFMETAL2|LFPSEUDO|LFTRANS4};
-static char *bipolar_layer_letters[MAXLAYERS] = {"1", "2", "n", "p", "P", "f", "i", "s",
-	"N", "x", "c", "v", "o", "b", "A", "B"};
+static CHAR *bipolar_layer_letters[MAXLAYERS] = {x_("1"), x_("2"), x_("n"), x_("p"), x_("P"), x_("f"), x_("i"), x_("s"),
+	x_("N"), x_("x"), x_("c"), x_("v"), x_("o"), x_("b"), x_("A"), x_("B")};
 
 static TECH_COLORMAP bipolar_colmap[32] =
 {
@@ -312,25 +440,25 @@ static INTBIG bipolar_unconnectedtable[] = {
 
 static TECH_ARCLAY bipolar_al_0[] = {{LM,0,FILLED}};
 static TECH_ARCS bipolar_a_0 = {
-	"Metal_1", K3, AMETAL_1, NOARCPROTO,
+	x_("Metal_1"), K3, AMETAL_1, NOARCPROTO,
 	1, bipolar_al_0,
 	(APMETAL1<<AFUNCTIONSH)|WANTFIXANG|CANWIPE|(90<<AANGLEINCSH)};
 
 static TECH_ARCLAY bipolar_al_1[] = {{LM0,0,FILLED}};
 static TECH_ARCS bipolar_a_1 = {
-	"Metal_2", K4, AMETAL_2, NOARCPROTO,
+	x_("Metal_2"), K4, AMETAL_2, NOARCPROTO,
 	1, bipolar_al_1,
 	(APMETAL2<<AFUNCTIONSH)|WANTFIXANG|CANWIPE|(90<<AANGLEINCSH)};
 
 static TECH_ARCLAY bipolar_al_2[] = {{LPD,K2,FILLED}, {LN,0,FILLED}};
 static TECH_ARCS bipolar_a_2 = {
-	"NPPoly", K4, ANPPOLY, NOARCPROTO,
+	x_("NPPoly"), K4, ANPPOLY, NOARCPROTO,
 	2, bipolar_al_2,
 	(APPOLY1<<AFUNCTIONSH)|WANTFIXANG|WANTNOEXTEND|(90<<AANGLEINCSH)};
 
 static TECH_ARCLAY bipolar_al_3[] = {{LPD,K2,FILLED}, {LP,0,FILLED}};
 static TECH_ARCS bipolar_a_3 = {
-	"PPPoly", K4, APPPOLY, NOARCPROTO,
+	x_("PPPoly"), K4, APPPOLY, NOARCPROTO,
 	2, bipolar_al_3,
 	(APPOLY2<<AFUNCTIONSH)|WANTFIXANG|WANTNOEXTEND|(90<<AANGLEINCSH)};
 
@@ -415,12 +543,12 @@ static INTBIG bipolar_box31[8] = {LEFTEDGE, BOTEDGE, RIGHTEDGE, TOPEDGE};
 
 /* Metal1_Pin */
 static TECH_PORTS bipolar_mp_p[] = {
-	{bipolar_pc_8, "metal1", NOPORTPROTO, (180<<PORTARANGESH),
+	{bipolar_pc_8, x_("metal1"), NOPORTPROTO, (180<<PORTARANGESH),
 		LEFTIN1, BOTIN1, RIGHTIN1, TOPIN1}};
 static TECH_POLYGON bipolar_mp_l[] = {
 	{LPM, 0, 4, CROSSED, BOX, bipolar_box31}};
 static TECH_NODES bipolar_mp = {
-	"Metal1_Pin", NMP, NONODEPROTO,
+	x_("Metal1_Pin"), NMP, NONODEPROTO,
 	K3, K3,
 	1, bipolar_mp_p,
 	1, bipolar_mp_l,
@@ -429,12 +557,12 @@ static TECH_NODES bipolar_mp = {
 
 /* Metal2_Pin */
 static TECH_PORTS bipolar_mp0_p[] = {
-	{bipolar_pc_7, "metal2", NOPORTPROTO, (180<<PORTARANGESH),
+	{bipolar_pc_7, x_("metal2"), NOPORTPROTO, (180<<PORTARANGESH),
 		LEFTIN1, BOTIN1, RIGHTIN1, TOPIN1}};
 static TECH_POLYGON bipolar_mp0_l[] = {
 	{LPM0, 0, 4, CROSSED, BOX, bipolar_box31}};
 static TECH_NODES bipolar_mp0 = {
-	"Metal2_Pin", NMP0, NONODEPROTO,
+	x_("Metal2_Pin"), NMP0, NONODEPROTO,
 	K4, K4,
 	1, bipolar_mp0_p,
 	1, bipolar_mp0_l,
@@ -443,13 +571,13 @@ static TECH_NODES bipolar_mp0 = {
 
 /* NPPoly_pin */
 static TECH_PORTS bipolar_np_p[] = {
-	{bipolar_pc_6, "p", NOPORTPROTO, (180<<PORTARANGESH),
+	{bipolar_pc_6, x_("p"), NOPORTPROTO, (180<<PORTARANGESH),
 		LEFTIN2, BOTIN2, RIGHTIN2, TOPIN2}};
 static TECH_POLYGON bipolar_np_l[] = {
 	{LPD, 0, 4, FILLEDRECT, BOX, bipolar_box30},
 	{LN, 0, 4, FILLEDRECT, BOX, bipolar_box31}};
 static TECH_NODES bipolar_np = {
-	"NPPoly_pin", NNP, NONODEPROTO,
+	x_("NPPoly_pin"), NNP, NONODEPROTO,
 	K4, K4,
 	1, bipolar_np_p,
 	2, bipolar_np_l,
@@ -458,13 +586,13 @@ static TECH_NODES bipolar_np = {
 
 /* PPPoly_pin */
 static TECH_PORTS bipolar_pp_p[] = {
-	{bipolar_pc_5, "p", NOPORTPROTO, (180<<PORTARANGESH),
+	{bipolar_pc_5, x_("p"), NOPORTPROTO, (180<<PORTARANGESH),
 		LEFTIN2, BOTIN2, RIGHTIN2, TOPIN2}};
 static TECH_POLYGON bipolar_pp_l[] = {
 	{LPD, 0, 4, FILLEDRECT, BOX, bipolar_box30},
 	{LP, 0, 4, FILLEDRECT, BOX, bipolar_box31}};
 static TECH_NODES bipolar_pp = {
-	"PPPoly_pin", NPP, NONODEPROTO,
+	x_("PPPoly_pin"), NPP, NONODEPROTO,
 	K4, K4,
 	1, bipolar_pp_p,
 	2, bipolar_pp_l,
@@ -473,14 +601,14 @@ static TECH_NODES bipolar_pp = {
 
 /* Via */
 static TECH_PORTS bipolar_v_p[] = {
-	{bipolar_pc_4, "via", NOPORTPROTO, (180<<PORTARANGESH),
+	{bipolar_pc_4, x_("via"), NOPORTPROTO, (180<<PORTARANGESH),
 		LEFTIN2, BOTIN2, RIGHTIN2, TOPIN2}};
 static TECH_POLYGON bipolar_v_l[] = {
 	{LM, 0, 4, FILLEDRECT, BOX, bipolar_box29},
 	{LM0, 0, 4, FILLEDRECT, BOX, bipolar_box31},
 	{LV, 0, 4, FILLEDRECT, BOX, bipolar_box28}};
 static TECH_NODES bipolar_v = {
-	"Via", NV, NONODEPROTO,
+	x_("Via"), NV, NONODEPROTO,
 	K4, K4,
 	1, bipolar_v_p,
 	3, bipolar_v_l,
@@ -489,7 +617,7 @@ static TECH_NODES bipolar_v = {
 
 /* M1_PP_Contact */
 static TECH_PORTS bipolar_mpc_p[] = {
-	{bipolar_pc_3, "m", NOPORTPROTO, (180<<PORTARANGESH),
+	{bipolar_pc_3, x_("m"), NOPORTPROTO, (180<<PORTARANGESH),
 		LEFTIN2H, BOTIN2H, RIGHTIN2H, TOPIN2H}};
 static TECH_POLYGON bipolar_mpc_l[] = {
 	{LM, 0, 4, FILLEDRECT, BOX, bipolar_box30},
@@ -497,7 +625,7 @@ static TECH_POLYGON bipolar_mpc_l[] = {
 	{LP, 0, 4, FILLEDRECT, BOX, bipolar_box31},
 	{LC, 0, 4, FILLEDRECT, BOX, bipolar_box28}};
 static TECH_NODES bipolar_mpc = {
-	"M1_PP_Contact", NMPC, NONODEPROTO,
+	x_("M1_PP_Contact"), NMPC, NONODEPROTO,
 	K6, K6,
 	1, bipolar_mpc_p,
 	4, bipolar_mpc_l,
@@ -506,7 +634,7 @@ static TECH_NODES bipolar_mpc = {
 
 /* M1_NP_Contact */
 static TECH_PORTS bipolar_mnc_p[] = {
-	{bipolar_pc_2, "m", NOPORTPROTO, (180<<PORTARANGESH),
+	{bipolar_pc_2, x_("m"), NOPORTPROTO, (180<<PORTARANGESH),
 		LEFTIN2H, BOTIN2H, RIGHTIN2H, TOPIN2H}};
 static TECH_POLYGON bipolar_mnc_l[] = {
 	{LPD, 0, 4, FILLEDRECT, BOX, bipolar_box30},
@@ -514,7 +642,7 @@ static TECH_POLYGON bipolar_mnc_l[] = {
 	{LN, 0, 4, FILLEDRECT, BOX, bipolar_box31},
 	{LC, 0, 4, FILLEDRECT, BOX, bipolar_box28}};
 static TECH_NODES bipolar_mnc = {
-	"M1_NP_Contact", NMNC, NONODEPROTO,
+	x_("M1_NP_Contact"), NMNC, NONODEPROTO,
 	K6, K6,
 	1, bipolar_mnc_p,
 	4, bipolar_mnc_l,
@@ -523,9 +651,9 @@ static TECH_NODES bipolar_mnc = {
 
 /* NPResistor */
 static TECH_PORTS bipolar_n_p[] = {
-	{bipolar_pc_6, "p1", NOPORTPROTO, (0<<PORTARANGESH)|(90<<PORTANGLESH),
+	{bipolar_pc_6, x_("p1"), NOPORTPROTO, (0<<PORTARANGESH)|(90<<PORTANGLESH),
 		LEFTIN2, TOPIN1, RIGHTIN2, TOPIN1},
-	{bipolar_pc_6, "p2", NOPORTPROTO, (0<<PORTARANGESH)|(270<<PORTANGLESH)|(1<<PORTNETSH),
+	{bipolar_pc_6, x_("p2"), NOPORTPROTO, (0<<PORTARANGESH)|(270<<PORTANGLESH)|(1<<PORTNETSH),
 		LEFTIN2, BOTIN1, RIGHTIN2, BOTIN1}};
 static TECH_POLYGON bipolar_n_l[] = {
 	{LPD, 0, 4, FILLEDRECT, BOX, bipolar_box27},
@@ -535,7 +663,7 @@ static TECH_POLYGON bipolar_n_l[] = {
 	{LN, 0, 4, FILLEDRECT, BOX, bipolar_box25},
 	{LN, 1, 4, FILLEDRECT, BOX, bipolar_box23}};
 static TECH_NODES bipolar_n = {
-	"NPResistor", NN, NONODEPROTO,
+	x_("NPResistor"), NN, NONODEPROTO,
 	K5, K7,
 	2, bipolar_n_p,
 	6, bipolar_n_l,
@@ -544,9 +672,9 @@ static TECH_NODES bipolar_n = {
 
 /* NMResistor */
 static TECH_PORTS bipolar_n0_p[] = {
-	{bipolar_pc_6, "p1", NOPORTPROTO, (0<<PORTARANGESH)|(90<<PORTANGLESH),
+	{bipolar_pc_6, x_("p1"), NOPORTPROTO, (0<<PORTARANGESH)|(90<<PORTANGLESH),
 		LEFTIN2, TOPIN1, RIGHTIN2, TOPIN1},
-	{bipolar_pc_6, "p2", NOPORTPROTO, (0<<PORTARANGESH)|(270<<PORTANGLESH)|(1<<PORTNETSH),
+	{bipolar_pc_6, x_("p2"), NOPORTPROTO, (0<<PORTARANGESH)|(270<<PORTANGLESH)|(1<<PORTNETSH),
 		LEFTIN2, BOTIN1, RIGHTIN2, BOTIN1}};
 static TECH_POLYGON bipolar_n0_l[] = {
 	{LPD, 0, 4, FILLEDRECT, BOX, bipolar_box27},
@@ -558,7 +686,7 @@ static TECH_POLYGON bipolar_n0_l[] = {
 	{LNI, -1, 4, FILLEDRECT, BOX, bipolar_box19},
 	{LNI, -1, 4, FILLEDRECT, BOX, bipolar_box18}};
 static TECH_NODES bipolar_n0 = {
-	"NMResistor", NN0, NONODEPROTO,
+	x_("NMResistor"), NN0, NONODEPROTO,
 	K5, K7,
 	2, bipolar_n0_p,
 	8, bipolar_n0_l,
@@ -567,11 +695,11 @@ static TECH_NODES bipolar_n0 = {
 
 /* npn111 */
 static TECH_PORTS bipolar_n1_p[] = {
-	{bipolar_pc_6, "c", NOPORTPROTO, (180<<PORTARANGESH),
+	{bipolar_pc_6, x_("c"), NOPORTPROTO, (180<<PORTARANGESH),
 		LEFTIN4, BOTIN4, LEFTIN7, TOPIN4},
-	{bipolar_pc_6, "e", NOPORTPROTO, (180<<PORTARANGESH)|(1<<PORTNETSH),
+	{bipolar_pc_6, x_("e"), NOPORTPROTO, (180<<PORTARANGESH)|(1<<PORTNETSH),
 		LEFTIN11, BOTIN4, RIGHTIN9, TOPIN4},
-	{bipolar_pc_5, "b", NOPORTPROTO, (180<<PORTARANGESH)|(2<<PORTNETSH),
+	{bipolar_pc_5, x_("b"), NOPORTPROTO, (180<<PORTARANGESH)|(2<<PORTNETSH),
 		RIGHTIN5, BOTIN4, RIGHTIN4, TOPIN4}};
 static TECH_POLYGON bipolar_n1_l[] = {
 	{LPD, 0, 4, FILLEDRECT, BOX, bipolar_box17},
@@ -588,7 +716,7 @@ static TECH_POLYGON bipolar_n1_l[] = {
 	{LFI, 2, 4, FILLEDRECT, BOX, bipolar_box6},
 	{LFI, 1, 4, FILLEDRECT, BOX, bipolar_box5}};
 static TECH_NODES bipolar_n1 = {
-	"npn111", NN1, NONODEPROTO,
+	x_("npn111"), NN1, NONODEPROTO,
 	K20, K11,
 	3, bipolar_n1_p,
 	13, bipolar_n1_l,
@@ -597,9 +725,9 @@ static TECH_NODES bipolar_n1 = {
 
 /* PNJunction */
 static TECH_PORTS bipolar_p_p[] = {
-	{bipolar_pc_5, "p", NOPORTPROTO, (0<<PORTARANGESH),
+	{bipolar_pc_5, x_("p"), NOPORTPROTO, (0<<PORTARANGESH),
 		RIGHTIN1, BOTIN2, RIGHTIN1, TOPIN2},
-	{bipolar_pc_6, "n", NOPORTPROTO, (0<<PORTARANGESH)|(180<<PORTANGLESH),
+	{bipolar_pc_6, x_("n"), NOPORTPROTO, (0<<PORTARANGESH)|(180<<PORTANGLESH),
 		LEFTIN1, BOTIN2, LEFTIN1, TOPIN2}};
 static TECH_POLYGON bipolar_p_l[] = {
 	{LPD, 1, 4, FILLEDRECT, BOX, bipolar_box4},
@@ -607,7 +735,7 @@ static TECH_POLYGON bipolar_p_l[] = {
 	{LN, 1, 4, FILLEDRECT, BOX, bipolar_box3},
 	{LP, 0, 4, FILLEDRECT, BOX, bipolar_box1}};
 static TECH_NODES bipolar_p = {
-	"PNJunction", NP, NONODEPROTO,
+	x_("PNJunction"), NP, NONODEPROTO,
 	K4, K4,
 	2, bipolar_p_p,
 	4, bipolar_p_l,
@@ -616,12 +744,12 @@ static TECH_NODES bipolar_p = {
 
 /* Metal1_Node */
 static TECH_PORTS bipolar_mn_p[] = {
-	{bipolar_pc_8, "metal1", NOPORTPROTO, (180<<PORTARANGESH),
+	{bipolar_pc_8, x_("metal1"), NOPORTPROTO, (180<<PORTARANGESH),
 		CENTER, CENTER, CENTER, CENTER}};
 static TECH_POLYGON bipolar_mn_l[] = {
 	{LM, 0, 4, FILLEDRECT, BOX, bipolar_box31}};
 static TECH_NODES bipolar_mn = {
-	"Metal1_Node", NMN, NONODEPROTO,
+	x_("Metal1_Node"), NMN, NONODEPROTO,
 	K2, K2,
 	1, bipolar_mn_p,
 	1, bipolar_mn_l,
@@ -630,12 +758,12 @@ static TECH_NODES bipolar_mn = {
 
 /* Metal2_Node */
 static TECH_PORTS bipolar_mn0_p[] = {
-	{bipolar_pc_7, "metal2", NOPORTPROTO, (180<<PORTARANGESH),
+	{bipolar_pc_7, x_("metal2"), NOPORTPROTO, (180<<PORTARANGESH),
 		CENTER, CENTER, CENTER, CENTER}};
 static TECH_POLYGON bipolar_mn0_l[] = {
 	{LM0, 0, 4, FILLEDRECT, BOX, bipolar_box31}};
 static TECH_NODES bipolar_mn0 = {
-	"Metal2_Node", NMN0, NONODEPROTO,
+	x_("Metal2_Node"), NMN0, NONODEPROTO,
 	K2, K2,
 	1, bipolar_mn0_p,
 	1, bipolar_mn0_l,
@@ -644,12 +772,12 @@ static TECH_NODES bipolar_mn0 = {
 
 /* NPImplant_Node */
 static TECH_PORTS bipolar_nn_p[] = {
-	{bipolar_pc_1, "N+implant", NOPORTPROTO, (180<<PORTARANGESH),
+	{bipolar_pc_1, x_("N+implant"), NOPORTPROTO, (180<<PORTARANGESH),
 		CENTER, CENTER, CENTER, CENTER}};
 static TECH_POLYGON bipolar_nn_l[] = {
 	{LN, 0, 4, FILLEDRECT, BOX, bipolar_box31}};
 static TECH_NODES bipolar_nn = {
-	"NPImplant_Node", NNN, NONODEPROTO,
+	x_("NPImplant_Node"), NNN, NONODEPROTO,
 	K2, K2,
 	1, bipolar_nn_p,
 	1, bipolar_nn_l,
@@ -658,12 +786,12 @@ static TECH_NODES bipolar_nn = {
 
 /* PPImplant_Node */
 static TECH_PORTS bipolar_pn_p[] = {
-	{bipolar_pc_1, "P+implant", NOPORTPROTO, (180<<PORTARANGESH),
+	{bipolar_pc_1, x_("P+implant"), NOPORTPROTO, (180<<PORTARANGESH),
 		CENTER, CENTER, CENTER, CENTER}};
 static TECH_POLYGON bipolar_pn_l[] = {
 	{LP, 0, 4, FILLEDRECT, BOX, bipolar_box31}};
 static TECH_NODES bipolar_pn = {
-	"PPImplant_Node", NPN, NONODEPROTO,
+	x_("PPImplant_Node"), NPN, NONODEPROTO,
 	K2, K2,
 	1, bipolar_pn_p,
 	1, bipolar_pn_l,
@@ -672,12 +800,12 @@ static TECH_NODES bipolar_pn = {
 
 /* Poly_Def_Node */
 static TECH_PORTS bipolar_pdn_p[] = {
-	{bipolar_pc_1, "poly-def", NOPORTPROTO, (180<<PORTARANGESH),
+	{bipolar_pc_1, x_("poly-def"), NOPORTPROTO, (180<<PORTARANGESH),
 		CENTER, CENTER, CENTER, CENTER}};
 static TECH_POLYGON bipolar_pdn_l[] = {
 	{LPD, 0, 4, FILLEDRECT, BOX, bipolar_box31}};
 static TECH_NODES bipolar_pdn = {
-	"Poly_Def_Node", NPDN, NONODEPROTO,
+	x_("Poly_Def_Node"), NPDN, NONODEPROTO,
 	K2, K2,
 	1, bipolar_pdn_p,
 	1, bipolar_pdn_l,
@@ -686,12 +814,12 @@ static TECH_NODES bipolar_pdn = {
 
 /* Field_Implant_Node */
 static TECH_PORTS bipolar_fin_p[] = {
-	{bipolar_pc_1, "field", NOPORTPROTO, (180<<PORTARANGESH),
+	{bipolar_pc_1, x_("field"), NOPORTPROTO, (180<<PORTARANGESH),
 		CENTER, CENTER, CENTER, CENTER}};
 static TECH_POLYGON bipolar_fin_l[] = {
 	{LFI, 0, 4, CLOSEDRECT, BOX, bipolar_box31}};
 static TECH_NODES bipolar_fin = {
-	"Field_Implant_Node", NFIN, NONODEPROTO,
+	x_("Field_Implant_Node"), NFIN, NONODEPROTO,
 	K4, K4,
 	1, bipolar_fin_p,
 	1, bipolar_fin_l,
@@ -700,12 +828,12 @@ static TECH_NODES bipolar_fin = {
 
 /* Isolation_Implant_Node */
 static TECH_PORTS bipolar_iin_p[] = {
-	{bipolar_pc_1, "isolation", NOPORTPROTO, (180<<PORTARANGESH),
+	{bipolar_pc_1, x_("isolation"), NOPORTPROTO, (180<<PORTARANGESH),
 		CENTER, CENTER, CENTER, CENTER}};
 static TECH_POLYGON bipolar_iin_l[] = {
 	{LI, 0, 4, CLOSEDRECT, BOX, bipolar_box31}};
 static TECH_NODES bipolar_iin = {
-	"Isolation_Implant_Node", NIIN, NONODEPROTO,
+	x_("Isolation_Implant_Node"), NIIN, NONODEPROTO,
 	K4, K4,
 	1, bipolar_iin_p,
 	1, bipolar_iin_l,
@@ -714,12 +842,12 @@ static TECH_NODES bipolar_iin = {
 
 /* Sink_Implant_Node */
 static TECH_PORTS bipolar_sin_p[] = {
-	{bipolar_pc_1, "sink-implant", NOPORTPROTO, (180<<PORTARANGESH),
+	{bipolar_pc_1, x_("sink-implant"), NOPORTPROTO, (180<<PORTARANGESH),
 		CENTER, CENTER, CENTER, CENTER}};
 static TECH_POLYGON bipolar_sin_l[] = {
 	{LSI, 0, 4, CLOSEDRECT, BOX, bipolar_box31}};
 static TECH_NODES bipolar_sin = {
-	"Sink_Implant_Node", NSIN, NONODEPROTO,
+	x_("Sink_Implant_Node"), NSIN, NONODEPROTO,
 	K4, K4,
 	1, bipolar_sin_p,
 	1, bipolar_sin_l,
@@ -728,12 +856,12 @@ static TECH_NODES bipolar_sin = {
 
 /* N_Implant_Node */
 static TECH_PORTS bipolar_nin_p[] = {
-	{bipolar_pc_1, "N-implant", NOPORTPROTO, (180<<PORTARANGESH),
+	{bipolar_pc_1, x_("N-implant"), NOPORTPROTO, (180<<PORTARANGESH),
 		CENTER, CENTER, CENTER, CENTER}};
 static TECH_POLYGON bipolar_nin_l[] = {
 	{LNI, 0, 4, CLOSEDRECT, BOX, bipolar_box31}};
 static TECH_NODES bipolar_nin = {
-	"N_Implant_Node", NNIN, NONODEPROTO,
+	x_("N_Implant_Node"), NNIN, NONODEPROTO,
 	K4, K4,
 	1, bipolar_nin_p,
 	1, bipolar_nin_l,
@@ -742,12 +870,12 @@ static TECH_NODES bipolar_nin = {
 
 /* Silicode_Exclusion_Node */
 static TECH_PORTS bipolar_sen_p[] = {
-	{bipolar_pc_1, "silicide-exclusion", NOPORTPROTO, (180<<PORTARANGESH),
+	{bipolar_pc_1, x_("silicide-exclusion"), NOPORTPROTO, (180<<PORTARANGESH),
 		CENTER, CENTER, CENTER, CENTER}};
 static TECH_POLYGON bipolar_sen_l[] = {
 	{LSE, 0, 4, CLOSEDRECT, BOX, bipolar_box31}};
 static TECH_NODES bipolar_sen = {
-	"Silicode_Exclusion_Node", NSEN, NONODEPROTO,
+	x_("Silicode_Exclusion_Node"), NSEN, NONODEPROTO,
 	K4, K4,
 	1, bipolar_sen_p,
 	1, bipolar_sen_l,
@@ -756,12 +884,12 @@ static TECH_NODES bipolar_sen = {
 
 /* Contact_Node */
 static TECH_PORTS bipolar_cn_p[] = {
-	{bipolar_pc_1, "contact", NOPORTPROTO, (180<<PORTARANGESH),
+	{bipolar_pc_1, x_("contact"), NOPORTPROTO, (180<<PORTARANGESH),
 		CENTER, CENTER, CENTER, CENTER}};
 static TECH_POLYGON bipolar_cn_l[] = {
 	{LC, 0, 4, CROSSED, BOX, bipolar_box31}};
 static TECH_NODES bipolar_cn = {
-	"Contact_Node", NCN, NONODEPROTO,
+	x_("Contact_Node"), NCN, NONODEPROTO,
 	K4, K4,
 	1, bipolar_cn_p,
 	1, bipolar_cn_l,
@@ -770,12 +898,12 @@ static TECH_NODES bipolar_cn = {
 
 /* Via_Node */
 static TECH_PORTS bipolar_vn_p[] = {
-	{bipolar_pc_1, "via", NOPORTPROTO, (180<<PORTARANGESH),
+	{bipolar_pc_1, x_("via"), NOPORTPROTO, (180<<PORTARANGESH),
 		CENTER, CENTER, CENTER, CENTER}};
 static TECH_POLYGON bipolar_vn_l[] = {
 	{LV, 0, 4, FILLEDRECT, BOX, bipolar_box31}};
 static TECH_NODES bipolar_vn = {
-	"Via_Node", NVN, NONODEPROTO,
+	x_("Via_Node"), NVN, NONODEPROTO,
 	K4, K4,
 	1, bipolar_vn_p,
 	1, bipolar_vn_l,
@@ -784,12 +912,12 @@ static TECH_NODES bipolar_vn = {
 
 /* Scratch_Protection_Node */
 static TECH_PORTS bipolar_spn_p[] = {
-	{bipolar_pc_1, "scratch-protection", NOPORTPROTO, (180<<PORTARANGESH),
+	{bipolar_pc_1, x_("scratch-protection"), NOPORTPROTO, (180<<PORTARANGESH),
 		CENTER, CENTER, CENTER, CENTER}};
 static TECH_POLYGON bipolar_spn_l[] = {
 	{LSP, 0, 4, FILLEDRECT, BOX, bipolar_box31}};
 static TECH_NODES bipolar_spn = {
-	"Scratch_Protection_Node", NSPN, NONODEPROTO,
+	x_("Scratch_Protection_Node"), NSPN, NONODEPROTO,
 	K4, K4,
 	1, bipolar_spn_p,
 	1, bipolar_spn_l,
@@ -798,12 +926,12 @@ static TECH_NODES bipolar_spn = {
 
 /* Buried_Node */
 static TECH_PORTS bipolar_bn_p[] = {
-	{bipolar_pc_1, "buried", NOPORTPROTO, (180<<PORTARANGESH),
+	{bipolar_pc_1, x_("buried"), NOPORTPROTO, (180<<PORTARANGESH),
 		CENTER, CENTER, CENTER, CENTER}};
 static TECH_POLYGON bipolar_bn_l[] = {
 	{LB, 0, 4, CLOSEDRECT, BOX, bipolar_box31}};
 static TECH_NODES bipolar_bn = {
-	"Buried_Node", NBN, NONODEPROTO,
+	x_("Buried_Node"), NBN, NONODEPROTO,
 	K4, K4,
 	1, bipolar_bn_p,
 	1, bipolar_bn_l,
@@ -827,23 +955,23 @@ static INTBIG bipolar_node_widoff[NODEPROTOCOUNT*4] = {
 
 TECH_VARIABLES bipolar_variables[] =
 {
-	{"TECH_layer_names", (char *)bipolar_layer_names, 0.0,
+	{x_("TECH_layer_names"), (CHAR *)bipolar_layer_names, 0.0,
 		VSTRING|VDONTSAVE|VISARRAY|(MAXLAYERS<<VLENGTHSH)},
-	{"TECH_layer_function", (char *)bipolar_layer_function, 0.0,
+	{x_("TECH_layer_function"), (CHAR *)bipolar_layer_function, 0.0,
 		VINTEGER|VDONTSAVE|VISARRAY|(MAXLAYERS<<VLENGTHSH)},
-	{"TECH_node_width_offset", (char *)bipolar_node_widoff, 0.0,
+	{x_("TECH_node_width_offset"), (CHAR *)bipolar_node_widoff, 0.0,
 		VFRACT|VDONTSAVE|VISARRAY|((NODEPROTOCOUNT*4)<<VLENGTHSH)},
-	{"TECH_arc_width_offset", (char *)bipolar_arc_widoff, 0.0,
+	{x_("TECH_arc_width_offset"), (CHAR *)bipolar_arc_widoff, 0.0,
 		VFRACT|VDONTSAVE|VISARRAY|(ARCPROTOCOUNT<<VLENGTHSH)},
-	{"USER_layer_letters", (char *)bipolar_layer_letters, 0.0,
+	{x_("USER_layer_letters"), (CHAR *)bipolar_layer_letters, 0.0,
 		VSTRING|VDONTSAVE|VISARRAY|(MAXLAYERS<<VLENGTHSH)},
-	{"USER_color_map", (char *)bipolar_colmap, 0.0,
+	{x_("USER_color_map"), (CHAR *)bipolar_colmap, 0.0,
 		VCHAR|VDONTSAVE|VISARRAY|((sizeof bipolar_colmap)<<VLENGTHSH)},
-	{"IO_cif_layer_names", (char *)bipolar_cif_layers, 0.0,
+	{x_("IO_cif_layer_names"), (CHAR *)bipolar_cif_layers, 0.0,
 		VSTRING|VDONTSAVE|VISARRAY|(MAXLAYERS<<VLENGTHSH)},
-	{"IO_gds_layer_numbers", (char *)bipolar_gds_layers, 0.0,
-		VINTEGER|VDONTSAVE|VISARRAY|(MAXLAYERS<<VLENGTHSH)},
-	{"DRC_min_unconnected_distances", (char *)bipolar_unconnectedtable, 0.0,
+	{x_("IO_gds_layer_numbers"), (CHAR *)bipolar_gds_layers, 0.0,
+		VSTRING|VDONTSAVE|VISARRAY|(MAXLAYERS<<VLENGTHSH)},
+	{x_("DRC_min_unconnected_distances"), (CHAR *)bipolar_unconnectedtable, 0.0,
 		VFRACT|VDONTSAVE|VISARRAY|
 		   (((sizeof bipolar_unconnectedtable)/SIZEOFINTBIG)<<VLENGTHSH)},
 	{NULL, NULL, 0.0, 0}
@@ -853,5 +981,7 @@ TECH_VARIABLES bipolar_variables[] =
 
 BOOLEAN bipolar_initprocess(TECHNOLOGY *tech, INTBIG pass)
 {
+	Q_UNUSED( tech );
+	Q_UNUSED( pass );
 	return(FALSE);
 }
