@@ -58,6 +58,14 @@ BOOLEAN cmos_initprocess(TECHNOLOGY*, INTBIG);
 
 static GRAPHICS cmos_m_lay = {LAYERT1,COLORT1, SOLIDC, PATTERNED,
 /* metal layer */		{0x2222, /*   X   X   X   X  */
+						0x0000,  /*                  */
+						0x8888,  /* X   X   X   X    */
+						0x0000,  /*                  */
+						0x2222,  /*   X   X   X   X  */
+						0x0000,  /*                  */
+						0x8888,  /* X   X   X   X    */
+						0x0000,  /*                  */
+						0x2222,  /*   X   X   X   X  */
 						0x0000,  /*                  */
 						0x8888,  /* X   X   X   X    */
 						0x0000,  /*                  */
@@ -68,6 +76,14 @@ static GRAPHICS cmos_m_lay = {LAYERT1,COLORT1, SOLIDC, PATTERNED,
 						NOVARIABLE, 0};
 static GRAPHICS cmos_p_lay = {LAYERT2,COLORT2, SOLIDC, PATTERNED,
 /* polysilicon layer */	{0x0808, /*     X       X    */
+						0x0404,  /*      X       X   */
+						0x0202,  /*       X       X  */
+						0x0101,  /*        X       X */
+						0x8080,  /* X       X        */
+						0x4040,  /*  X       X       */
+						0x2020,  /*   X       X      */
+						0x1010,  /*    X       X     */
+						0x0808,  /*     X       X    */
 						0x0404,  /*      X       X   */
 						0x0202,  /*       X       X  */
 						0x0101,  /*        X       X */
@@ -78,6 +94,14 @@ static GRAPHICS cmos_p_lay = {LAYERT2,COLORT2, SOLIDC, PATTERNED,
 						NOVARIABLE, 0};
 static GRAPHICS cmos_d_lay = {LAYERT3,COLORT3, SOLIDC, PATTERNED,
 /* diffusion layer */	{0x0000, /*                  */
+						0x0303,  /*       XX      XX */
+						0x4848,  /*  X  X    X  X    */
+						0x0303,  /*       XX      XX */
+						0x0000,  /*                  */
+						0x3030,  /*   XX      XX     */
+						0x8484,  /* X    X  X    X   */
+						0x3030,  /*   XX      XX     */
+						0x0000,  /*                  */
 						0x0303,  /*       XX      XX */
 						0x4848,  /*  X  X    X  X    */
 						0x0303,  /*       XX      XX */
@@ -88,6 +112,14 @@ static GRAPHICS cmos_d_lay = {LAYERT3,COLORT3, SOLIDC, PATTERNED,
 						NOVARIABLE, 0};
 static GRAPHICS cmos_pl_lay = {LAYERT4,COLORT4, SOLIDC, PATTERNED,
 /* P+ layer */			{0x1000, /*    X             */
+						0x0020,  /*           X      */
+						0x0000,  /*                  */
+						0x0000,  /*                  */
+						0x0001,  /*                X */
+						0x0200,  /*       X          */
+						0x0000,  /*                  */
+						0x0000,  /*                  */
+						0x1000,  /*    X             */
 						0x0020,  /*           X      */
 						0x0000,  /*                  */
 						0x0000,  /*                  */
@@ -97,11 +129,19 @@ static GRAPHICS cmos_pl_lay = {LAYERT4,COLORT4, SOLIDC, PATTERNED,
 						0x0000}, /*                  */
 						NOVARIABLE, 0};
 static GRAPHICS cmos_c_lay = {LAYERO,BLACK, SOLIDC, SOLIDC,
-/* contact layer */	{0,0,0,0,0,0,0,0}, NOVARIABLE, 0};
+/* contact layer */	{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0}, NOVARIABLE, 0};
 static GRAPHICS cmos_oc_lay = {LAYERO,BLACK, SOLIDC, SOLIDC,
-/* oversize-cut layer */{0,0,0,0,0,0,0,0}, NOVARIABLE, 0};
+/* oversize-cut layer */{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0}, NOVARIABLE, 0};
 static GRAPHICS cmos_w_lay = {LAYERT5,COLORT5, SOLIDC, PATTERNED,
 /* P-well layer */		{0x0000, /*                  */
+						0x00C0,  /*         XX       */
+						0x0000,  /*                  */
+						0x0000,  /*                  */
+						0x0000,  /*                  */
+						0x00C0,  /*         XX       */
+						0x0000,  /*                  */
+						0x0000,  /*                  */
+						0x0000,  /*                  */
 						0x00C0,  /*         XX       */
 						0x0000,  /*                  */
 						0x0000,  /*                  */
@@ -112,6 +152,14 @@ static GRAPHICS cmos_w_lay = {LAYERT5,COLORT5, SOLIDC, PATTERNED,
 						NOVARIABLE, 0};
 static GRAPHICS cmos_o_lay = {LAYERO,DGRAY, SOLIDC, PATTERNED,
 /* overglass layer */	{0x1C1C, /*    XXX     XXX   */
+						0x3E3E,  /*   XXXXX   XXXXX  */
+						0x3636,  /*   XX XX   XX XX  */
+						0x3E3E,  /*   XXXXX   XXXXX  */
+						0x1C1C,  /*    XXX     XXX   */
+						0x0000,  /*                  */
+						0x0000,  /*                  */
+						0x0000,  /*                  */
+						0x1C1C,  /*    XXX     XXX   */
 						0x3E3E,  /*   XXXXX   XXXXX  */
 						0x3636,  /*   XX XX   XX XX  */
 						0x3E3E,  /*   XXXXX   XXXXX  */
@@ -121,9 +169,17 @@ static GRAPHICS cmos_o_lay = {LAYERO,DGRAY, SOLIDC, PATTERNED,
 						0x0000}, /*                  */
 						NOVARIABLE, 0};
 static GRAPHICS cmos_tr_lay = {LAYERN,ALLOFF, SOLIDC, PATTERNED,
-/* transistor layer */	{0,0,0,0,0,0,0,0}, NOVARIABLE, 0};
+/* transistor layer */	{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0}, NOVARIABLE, 0};
 static GRAPHICS cmos_pm_lay = {LAYERT1,COLORT1, SOLIDC, PATTERNED,
 /* pseudo-metal layer */{0x2222, /*   X   X   X   X  */
+						0x0000,  /*                  */
+						0x8888,  /* X   X   X   X    */
+						0x0000,  /*                  */
+						0x2222,  /*   X   X   X   X  */
+						0x0000,  /*                  */
+						0x8888,  /* X   X   X   X    */
+						0x0000,  /*                  */
+						0x2222,  /*   X   X   X   X  */
 						0x0000,  /*                  */
 						0x8888,  /* X   X   X   X    */
 						0x0000,  /*                  */
@@ -134,6 +190,14 @@ static GRAPHICS cmos_pm_lay = {LAYERT1,COLORT1, SOLIDC, PATTERNED,
 						NOVARIABLE, 0};
 static GRAPHICS cmos_pp_lay = {LAYERT2,COLORT2, SOLIDC, PATTERNED,
 /* pseudo-poly layer */	{0x0808, /*     X       X    */
+						0x0404,  /*      X       X   */
+						0x0202,  /*       X       X  */
+						0x0101,  /*        X       X */
+						0x8080,  /* X       X        */
+						0x4040,  /*  X       X       */
+						0x2020,  /*   X       X      */
+						0x1010,  /*    X       X     */
+						0x0808,  /*     X       X    */
 						0x0404,  /*      X       X   */
 						0x0202,  /*       X       X  */
 						0x0101,  /*        X       X */
@@ -144,6 +208,14 @@ static GRAPHICS cmos_pp_lay = {LAYERT2,COLORT2, SOLIDC, PATTERNED,
 						NOVARIABLE, 0};
 static GRAPHICS cmos_pd_lay = {LAYERT3,COLORT3, SOLIDC, PATTERNED,
 /* pseudo-diff layer */	{0x0000, /*                  */
+						0x0303,  /*       XX      XX */
+						0x4848,  /*  X  X    X  X    */
+						0x0303,  /*       XX      XX */
+						0x0000,  /*                  */
+						0x3030,  /*   XX      XX     */
+						0x8484,  /* X    X  X    X   */
+						0x3030,  /*   XX      XX     */
+						0x0000,  /*                  */
 						0x0303,  /*       XX      XX */
 						0x4848,  /*  X  X    X  X    */
 						0x0303,  /*       XX      XX */
@@ -154,6 +226,14 @@ static GRAPHICS cmos_pd_lay = {LAYERT3,COLORT3, SOLIDC, PATTERNED,
 						NOVARIABLE, 0};
 static GRAPHICS cmos_ppl_lay = {LAYERT4,COLORT4, SOLIDC, PATTERNED,
 /* pseudo-P+ layer */	{0x1000, /*    X             */
+						0x0020,  /*           X      */
+						0x0000,  /*                  */
+						0x0000,  /*                  */
+						0x0001,  /*                X */
+						0x0200,  /*       X          */
+						0x0000,  /*                  */
+						0x0000,  /*                  */
+						0x1000,  /*    X             */
 						0x0020,  /*           X      */
 						0x0000,  /*                  */
 						0x0000,  /*                  */
@@ -164,6 +244,14 @@ static GRAPHICS cmos_ppl_lay = {LAYERT4,COLORT4, SOLIDC, PATTERNED,
 						NOVARIABLE, 0};
 static GRAPHICS cmos_pw_lay = {LAYERT5,COLORT5, SOLIDC, PATTERNED,
 /* pseudo-P-well layer */{0x0000,/*                  */
+						0x00C0,  /*         XX       */
+						0x0000,  /*                  */
+						0x0000,  /*                  */
+						0x0000,  /*                  */
+						0x00C0,  /*         XX       */
+						0x0000,  /*                  */
+						0x0000,  /*                  */
+						0x0000, /*                  */
 						0x00C0,  /*         XX       */
 						0x0000,  /*                  */
 						0x0000,  /*                  */
@@ -178,20 +266,20 @@ GRAPHICS *cmos_layers[MAXLAYERS+1] = {&cmos_m_lay, &cmos_p_lay,
 	&cmos_d_lay, &cmos_pl_lay, &cmos_c_lay, &cmos_oc_lay, &cmos_w_lay,
 	&cmos_o_lay, &cmos_tr_lay, &cmos_pm_lay, &cmos_pp_lay, &cmos_pd_lay,
 	&cmos_ppl_lay, &cmos_pw_lay, NOGRAPHICS};
-static char *cmos_layer_names[MAXLAYERS] = {"Metal", "Polysilicon",
-	"Diffusion", "P+", "Contact-Cut", "Ohmic-Cut", "P-Well",
-	"Overglass", "Transistor", "Pseudo-Metal", "Pseudo-Polysilicon",
-	"Pseudo-Diffusion", "Pseudo-P+", "Pseudo-P-Well"};
-static char *cmos_cif_layers[MAXLAYERS] = {"CM", "CP", "CD", "CS", "CC",
-	"CC", "CW", "CG", "", "", "", "", "", ""};
+static CHAR *cmos_layer_names[MAXLAYERS] = {x_("Metal"), x_("Polysilicon"),
+	x_("Diffusion"), x_("P+"), x_("Contact-Cut"), x_("Ohmic-Cut"), x_("P-Well"),
+	x_("Overglass"), x_("Transistor"), x_("Pseudo-Metal"), x_("Pseudo-Polysilicon"),
+	x_("Pseudo-Diffusion"), x_("Pseudo-P+"), x_("Pseudo-P-Well")};
+static CHAR *cmos_cif_layers[MAXLAYERS] = {x_("CM"), x_("CP"), x_("CD"), x_("CS"), x_("CC"),
+	x_("CC"), x_("CW"), x_("CG"), x_(""), x_(""), x_(""), x_(""), x_(""), x_("")};
 static INTBIG cmos_layer_function[MAXLAYERS] = {LFMETAL1|LFTRANS1, LFPOLY1|LFTRANS2,
 	LFDIFF|LFTRANS3, LFIMPLANT|LFPTYPE|LFTRANS4, LFCONTACT1, LFCONTACT2,
 	LFWELL|LFPTYPE|LFTRANS5, LFOVERGLASS, LFTRANSISTOR|LFPSEUDO,
 	LFMETAL1|LFPSEUDO|LFTRANS1, LFPOLY1|LFPSEUDO|LFTRANS2,
 	LFDIFF|LFPSEUDO|LFTRANS3, LFIMPLANT|LFPTYPE|LFPSEUDO|LFTRANS4,
 	LFWELL|LFPTYPE|LFPSEUDO|LFTRANS5};
-static char *cmos_layer_letters[MAXLAYERS] = {"mb", "pr", "dg", "s",
-	"c", "o", "w", "v", "t", "M", "P", "D", "S", "W"};
+static CHAR *cmos_layer_letters[MAXLAYERS] = {x_("mb"), x_("pr"), x_("dg"), x_("s"),
+	x_("c"), x_("o"), x_("w"), x_("v"), x_("t"), x_("M"), x_("P"), x_("D"), x_("S"), x_("W")};
 
 /* The low 5 bits map Metal, Polysilicon, Diffusion, P+, and P-Well */
 static TECH_COLORMAP cmos_colmap[32] =
@@ -267,28 +355,28 @@ static INTBIG cmos_unconnectedtable[] = {
 /* metal arc */
 static TECH_ARCLAY cmos_al_m[] = {{ LMETAL,0,FILLED }};
 static TECH_ARCS cmos_a_m = {
-	"Metal",K3,AMETAL,NOARCPROTO,									/* name */
+	x_("Metal"),K3,AMETAL,NOARCPROTO,								/* name */
 	1,cmos_al_m,													/* layers */
 	(APMETAL1<<AFUNCTIONSH)|WANTFIXANG|CANWIPE|(90<<AANGLEINCSH)};	/* userbits */
 
 /* polysilicon arc */
 static TECH_ARCLAY cmos_al_p[] = {{ LPOLY,0,FILLED }};
 static TECH_ARCS cmos_a_p = {
-	"Polysilicon",K2,APOLY,NOARCPROTO,								/* name */
+	x_("Polysilicon"),K2,APOLY,NOARCPROTO,							/* name */
 	1,cmos_al_p,													/* layers */
 	(APPOLY1<<AFUNCTIONSH)|WANTFIXANG|CANWIPE|(90<<AANGLEINCSH)};	/* userbits */
 
 /* diffusion-p arc */
 static TECH_ARCLAY cmos_al_dp[] = {{ LDIFF,K4,FILLED}, {LP,0,FILLED }};
 static TECH_ARCS cmos_a_dp = {
-	"Diffusion-p",K6,ADIFP,NOARCPROTO,								/* name */
+	x_("Diffusion-p"),K6,ADIFP,NOARCPROTO,							/* name */
 	2,cmos_al_dp,													/* layers */
 	(APDIFFP<<AFUNCTIONSH)|WANTFIXANG|CANWIPE|(90<<AANGLEINCSH)};	/* userbits */
 
 /* diffusion-well arc */
 static TECH_ARCLAY cmos_al_dw[] = {{ LDIFF,K6,FILLED}, {LWELL,0,FILLED }};
 static TECH_ARCS cmos_a_dw = {
-	"Diffusion-well",K8,ADIFW,NOARCPROTO,							/* name */
+	x_("Diffusion-well"),K8,ADIFW,NOARCPROTO,						/* name */
 	2,cmos_al_dw,													/* layers */
 	(APDIFFN<<AFUNCTIONSH)|WANTFIXANG|CANWIPE|(90<<AANGLEINCSH)};	/* userbits */
 
@@ -354,12 +442,12 @@ static INTBIG cmos_spl7box[8] = {CENTERR1, BOTIN3,  RIGHTIN1, TOPIN3};
 
 /* metal-pin */
 static TECH_PORTS cmos_pm_p[] = {					/* ports */
-	{cmos_pc_m, "metal", NOPORTPROTO, (180<<PORTARANGESH),
+	{cmos_pc_m, x_("metal"), NOPORTPROTO, (180<<PORTARANGESH),
 		LEFTIN1H, BOTIN1H, RIGHTIN1H, TOPIN1H}};
 static TECH_POLYGON cmos_pm_l[] = {					/* layers */
 	{LMETALP, 0, 4, CROSSED, BOX, cmos_fullbox}};
 static TECH_NODES cmos_pm = {
-	"Metal-Pin",NMETALP,NONODEPROTO,				/* name */
+	x_("Metal-Pin"),NMETALP,NONODEPROTO,			/* name */
 	K3,K3,											/* size */
 	1,cmos_pm_p,									/* ports */
 	1,cmos_pm_l,									/* layers */
@@ -368,12 +456,12 @@ static TECH_NODES cmos_pm = {
 
 /* polysilicon-pin */
 static TECH_PORTS cmos_pp_p[] = {					/* ports */
-	{cmos_pc_p, "polysilicon", NOPORTPROTO, (180<<PORTARANGESH),
+	{cmos_pc_p, x_("polysilicon"), NOPORTPROTO, (180<<PORTARANGESH),
 		LEFTIN1, BOTIN1, RIGHTIN1, TOPIN1}};
 static TECH_POLYGON cmos_pp_l[] = {					/* layers */
 	{LPOLYP, 0, 4, CROSSED, BOX, cmos_fullbox}};
 static TECH_NODES cmos_pp = {
-	"Polysilicon-Pin",NPOLYP,NONODEPROTO,			/* name */
+	x_("Polysilicon-Pin"),NPOLYP,NONODEPROTO,		/* name */
 	K2,K2,											/* size */
 	1,cmos_pp_p,									/* ports */
 	1,cmos_pp_l,									/* layers */
@@ -382,13 +470,13 @@ static TECH_NODES cmos_pp = {
 
 /* diffusion-p+-pin */
 static TECH_PORTS cmos_pdp_p[] = {					/* ports */
-	{cmos_pc_dP, "diff-p", NOPORTPROTO, (180<<PORTARANGESH),
+	{cmos_pc_dP, x_("diff-p"), NOPORTPROTO, (180<<PORTARANGESH),
 		LEFTIN3, BOTIN3, RIGHTIN3, TOPIN3}};
 static TECH_POLYGON cmos_pdp_l[] = {				/* layers */
 	{LDIFFP, 0, 4, CROSSED, BOX, cmos_in2box},
 	{LPP,   -1, 4, CROSSED, BOX, cmos_fullbox}};
 static TECH_NODES cmos_pdp = {
-	"Diffusion-P-Pin",NDIFPP,NONODEPROTO,			/* name */
+	x_("Diffusion-P-Pin"),NDIFPP,NONODEPROTO,		/* name */
 	K6,K6,											/* size */
 	1,cmos_pdp_p,									/* ports */
 	2,cmos_pdp_l,									/* layers */
@@ -397,13 +485,13 @@ static TECH_NODES cmos_pdp = {
 
 /* diffusion-p-well-pin */
 static TECH_PORTS cmos_pdw_p[] = {					/* ports */
-	{cmos_pc_dW, "diff-w", NOPORTPROTO, (180<<PORTARANGESH),
+	{cmos_pc_dW, x_("diff-w"), NOPORTPROTO, (180<<PORTARANGESH),
 		LEFTIN4, BOTIN4, RIGHTIN4, TOPIN4}};
 static TECH_POLYGON cmos_pdw_l[] = {				/* layers */
 	{LDIFFP, 0, 4, CROSSED, BOX, cmos_in3box},
 	{LWELLP,-1, 4, CROSSED, BOX, cmos_fullbox}};
 static TECH_NODES cmos_pdw = {
-	"Diffusion-Well-Pin",NDIFWP,NONODEPROTO,		/* name */
+	x_("Diffusion-Well-Pin"),NDIFWP,NONODEPROTO,	/* name */
 	K8,K8,											/* size */
 	1,cmos_pdw_p,									/* ports */
 	2,cmos_pdw_l,									/* layers */
@@ -412,14 +500,14 @@ static TECH_NODES cmos_pdw = {
 
 /* metal-polysilicon-contact */
 static TECH_PORTS cmos_mp_p[] = {					/* ports */
-	{cmos_pc_pm, "metal-poly", NOPORTPROTO, (180<<PORTARANGESH),
+	{cmos_pc_pm, x_("metal-poly"), NOPORTPROTO, (180<<PORTARANGESH),
 		LEFTIN1, BOTIN1, RIGHTIN1, TOPIN1}};
 static TECH_POLYGON cmos_mp_l[] = {					/* layers */
 	{LMETAL, 0, 4, FILLEDRECT, BOX, cmos_fullbox},
 	{LPOLY,  0, 4, FILLEDRECT, BOX, cmos_fullbox},
 	{LCUT,  -1, 4, CLOSEDRECT, BOX, cmos_cutbox}};
 static TECH_NODES cmos_mp = {
-	"Metal-Polysilicon-Con",NMETPOLC,NONODEPROTO,	/* name */
+	x_("Metal-Polysilicon-Con"),NMETPOLC,NONODEPROTO,	/* name */
 	K4,K4,											/* size */
 	1,cmos_mp_p,									/* ports */
 	3,cmos_mp_l,									/* layers */
@@ -428,7 +516,7 @@ static TECH_NODES cmos_mp = {
 
 /* metal-diffusion-p+-contact */
 static TECH_PORTS cmos_mdp_p[] = {					/* ports */
-	{cmos_pc_dPm, "metal-diff-p", NOPORTPROTO, (180<<PORTARANGESH),
+	{cmos_pc_dPm, x_("metal-diff-p"), NOPORTPROTO, (180<<PORTARANGESH),
 		LEFTIN3, BOTIN3, RIGHTIN3, TOPIN3}};
 static TECH_POLYGON cmos_mdp_l[] = {				/* layers */
 	{LMETAL, 0, 4, FILLEDRECT, BOX, cmos_in2box},
@@ -436,7 +524,7 @@ static TECH_POLYGON cmos_mdp_l[] = {				/* layers */
 	{LP,    -1, 4, FILLEDRECT, BOX, cmos_fullbox},
 	{LCUT,  -1, 4, CLOSEDRECT, BOX, cmos_cutbox}};
 static TECH_NODES cmos_mdp = {
-	"Metal-Diff-P-Con",NMETDIFPC,NONODEPROTO,		/* name */
+	x_("Metal-Diff-P-Con"),NMETDIFPC,NONODEPROTO,	/* name */
 	K8,K8,											/* size */
 	1,cmos_mdp_p,									/* ports */
 	4,cmos_mdp_l,									/* layers */
@@ -445,7 +533,7 @@ static TECH_NODES cmos_mdp = {
 
 /* metal-diffusion-p-well-contact */
 static TECH_PORTS cmos_mdw_p[] = {					/* ports */
-	{cmos_pc_dWm, "metal-diff-w", NOPORTPROTO, (180<<PORTARANGESH),
+	{cmos_pc_dWm, x_("metal-diff-w"), NOPORTPROTO, (180<<PORTARANGESH),
 		LEFTIN4, BOTIN4, RIGHTIN4, TOPIN4}};
 static TECH_POLYGON cmos_mdw_l[] = {				/* layers */
 	{LMETAL, 0, 4, FILLEDRECT, BOX, cmos_in3box},
@@ -453,7 +541,7 @@ static TECH_POLYGON cmos_mdw_l[] = {				/* layers */
 	{LWELL, -1, 4, FILLEDRECT, BOX, cmos_fullbox},
 	{LCUT,  -1, 4, CLOSEDRECT, BOX, cmos_cutbox}};
 static TECH_NODES cmos_mdw = {
-	"Metal-Diff-Well-Con",NMETDIFWC,NONODEPROTO,	/* name */
+	x_("Metal-Diff-Well-Con"),NMETDIFWC,NONODEPROTO,	/* name */
 	K10,K10,										/* size */
 	1,cmos_mdw_p,									/* ports */
 	4,cmos_mdw_l,									/* layers */
@@ -462,13 +550,13 @@ static TECH_NODES cmos_mdw = {
 
 /* transistor-p+ */
 static TECH_PORTS cmos_tra_p[] = {					/* ports */
-	{cmos_pc_p, "trans-poly-left",  NOPORTPROTO, (180<<PORTANGLESH)|
+	{cmos_pc_p, x_("trans-poly-left"),  NOPORTPROTO, (180<<PORTANGLESH)|
 		(85<<PORTARANGESH),                LEFTIN1,  BOTIN3, LEFTIN1,  TOPIN3},
-	{cmos_pc_dP,"trans-diff-top",   NOPORTPROTO, (90<<PORTANGLESH)|
+	{cmos_pc_dP,x_("trans-diff-top"),   NOPORTPROTO, (90<<PORTANGLESH)|
 		(85<<PORTARANGESH)|(1<<PORTNETSH), LEFTIN3,  TOPIN1, RIGHTIN3, TOPIN1},
-	{cmos_pc_p, "trans-poly-right", NOPORTPROTO, (0<<PORTANGLESH)|
+	{cmos_pc_p, x_("trans-poly-right"), NOPORTPROTO, (0<<PORTANGLESH)|
 		(85<<PORTARANGESH),                RIGHTIN1, BOTIN3, RIGHTIN1, TOPIN3},
-	{cmos_pc_dP,"trans-diff-bottom",NOPORTPROTO, (270<<PORTANGLESH)|
+	{cmos_pc_dP,x_("trans-diff-bottom"),NOPORTPROTO, (270<<PORTANGLESH)|
 		(85<<PORTARANGESH)|(2<<PORTNETSH), LEFTIN3,  BOTIN1, RIGHTIN3, BOTIN1}};
 static TECH_SERPENT cmos_tra_l[] = {				/* graphical layers */
 	{{LDIFF,  1, 4, FILLEDRECT, BOX, cmos_tradbox}, K3, K3,  0,  0},
@@ -482,7 +570,7 @@ static TECH_SERPENT cmos_traE_l[] = {				/* electric layers */
 	{{LP,    -1, 4, FILLEDRECT, BOX, cmos_fullbox}, K3, K3, K2, K2},
 	{{LTRANS,-1, 4, FILLEDRECT, BOX, cmos_in2box},  K1, K1,  0,  0}};
 static TECH_NODES cmos_tra = {
-	"Transistor",NTRANSP,NONODEPROTO,				/* name */
+	x_("Transistor"),NTRANSP,NONODEPROTO,			/* name */
 	K6,K6,											/* size */
 	4,cmos_tra_p,									/* ports */
 	4,(TECH_POLYGON *)0,							/* layers */
@@ -491,13 +579,13 @@ static TECH_NODES cmos_tra = {
 
 /* transistor-p-well */
 static TECH_PORTS cmos_trw_p[] = {					/* ports */
-	{cmos_pc_p,   "transw-poly-left",  NOPORTPROTO, (180<<PORTANGLESH)|
+	{cmos_pc_p,   x_("transw-poly-left"),  NOPORTPROTO, (180<<PORTANGLESH)|
 		(85<<PORTARANGESH),                LEFTIN2,  BOTIN4, LEFTIN2,  TOPIN4},
-	{cmos_pc_dW,  "transw-diff-top",   NOPORTPROTO, (90<<PORTANGLESH)|
+	{cmos_pc_dW,  x_("transw-diff-top"),   NOPORTPROTO, (90<<PORTANGLESH)|
 		(85<<PORTARANGESH)|(1<<PORTNETSH), LEFTIN4,  TOPIN2, RIGHTIN4, TOPIN2},
-	{cmos_pc_p,   "transw-poly-right", NOPORTPROTO, (0<<PORTANGLESH)|
+	{cmos_pc_p,   x_("transw-poly-right"), NOPORTPROTO, (0<<PORTANGLESH)|
 		(85<<PORTARANGESH),                RIGHTIN2, BOTIN4, RIGHTIN2, TOPIN4},
-	{cmos_pc_dW,  "transw-diff-bottom",NOPORTPROTO, (270<<PORTANGLESH)|
+	{cmos_pc_dW,  x_("transw-diff-bottom"),NOPORTPROTO, (270<<PORTANGLESH)|
 		(85<<PORTARANGESH)|(2<<PORTNETSH), LEFTIN4,  BOTIN2, RIGHTIN4, BOTIN2}};
 static TECH_SERPENT cmos_trw_l[] = {				/* graphical layers */
 	{{LDIFF,  1, 4, FILLEDRECT, BOX, cmos_trwdbox}, K3, K3,  0,  0},
@@ -511,7 +599,7 @@ static TECH_SERPENT cmos_trwE_l[] = {				/* electric layers */
 	{{LWELL, -1, 4, FILLEDRECT, BOX, cmos_fullbox}, K4, K4, K3, K3},
 	{{LTRANS,-1, 4, FILLEDRECT, BOX, cmos_in3box},  K1, K1,  0,  0}};
 static TECH_NODES cmos_trw = {
-	"Transistor-Well",NTRANSW,NONODEPROTO,			/* name */
+	x_("Transistor-Well"),NTRANSW,NONODEPROTO,		/* name */
 	K8,K8,											/* size */
 	4,cmos_trw_p,									/* ports */
 	4,(TECH_POLYGON *)0,							/* layers */
@@ -520,9 +608,9 @@ static TECH_NODES cmos_trw = {
 
 /* metal-diffusion-p-well-split-cut */
 static TECH_PORTS cmos_mds_p[] = {					/* ports */
-	{cmos_pc_dWm, "metal-diff-splw-r", NOPORTPROTO, (0<<PORTANGLESH)|
+	{cmos_pc_dWm, x_("metal-diff-splw-r"), NOPORTPROTO, (0<<PORTANGLESH)|
 		(90<<PORTARANGESH),  CENTERR1, BOTIN4, RIGHTIN4, TOPIN4},
-	{cmos_pc_m,   "metal-diff-splw-l", NOPORTPROTO, (180<<PORTANGLESH)|
+	{cmos_pc_m,   x_("metal-diff-splw-l"), NOPORTPROTO, (180<<PORTANGLESH)|
 		(90<<PORTARANGESH),  LEFTIN4,  BOTIN4, CENTERL1, TOPIN4}};
 static TECH_POLYGON cmos_mds_l[] = {				/* layers */
 	{LMETAL, 1, 4, FILLEDRECT, BOX, cmos_in3box},
@@ -532,7 +620,7 @@ static TECH_POLYGON cmos_mds_l[] = {				/* layers */
 	{LCUT,  -1, 4, CLOSEDRECT, BOX, cmos_spl2box},
 	{LOCUT, -1, 4, CROSSED,    BOX, cmos_spl3box}};
 static TECH_NODES cmos_mds = {
-	"Metal-Diff-Split-Cut",NSPLITWC,NONODEPROTO,	/* name */
+	x_("Metal-Diff-Split-Cut"),NSPLITWC,NONODEPROTO,/* name */
 	K14,K10,										/* size */
 	2,cmos_mds_p,									/* ports */
 	6,cmos_mds_l,									/* layers */
@@ -541,9 +629,9 @@ static TECH_NODES cmos_mds = {
 
 /* metal-diffusion-p+-split-contact */
 static TECH_PORTS cmos_mdsn_p[] = {					/* ports */
-	{cmos_pc_dPm, "metal-diff-splp-l", NOPORTPROTO, (0<<PORTANGLESH)|
+	{cmos_pc_dPm, x_("metal-diff-splp-l"), NOPORTPROTO, (0<<PORTANGLESH)|
 		(90<<PORTARANGESH),  LEFTIN3,  BOTIN3, CENTER,   TOPIN3},
-	{cmos_pc_m,   "metal-diff-splp-r", NOPORTPROTO, (180<<PORTANGLESH)|
+	{cmos_pc_m,   x_("metal-diff-splp-r"), NOPORTPROTO, (180<<PORTANGLESH)|
 		(90<<PORTARANGESH),  CENTERR2, BOTIN3, RIGHTIN1, TOPIN3}};
 static TECH_POLYGON cmos_mdsn_l[] = {				/* layers */
 	{LMETAL, 1, 4, FILLEDRECT, BOX, cmos_spl4box},
@@ -552,7 +640,7 @@ static TECH_POLYGON cmos_mdsn_l[] = {				/* layers */
 	{LCUT,  -1, 4, CLOSEDRECT, BOX, cmos_spl6box},
 	{LOCUT, -1, 4, CROSSED,    BOX, cmos_spl7box}};
 static TECH_NODES cmos_mdsn = {
-	"Metal-Diff-SplitN-Cut",NSPLITPC,NONODEPROTO,	/* name */
+	x_("Metal-Diff-SplitN-Cut"),NSPLITPC,NONODEPROTO,	/* name */
 	K10,K8,											/* size */
 	2,cmos_mdsn_p,									/* ports */
 	5,cmos_mdsn_l,									/* layers */
@@ -561,12 +649,12 @@ static TECH_NODES cmos_mdsn = {
 
 /* metal-node */
 static TECH_PORTS cmos_m_p[] = {					/* ports */
-	{cmos_pc_m, "metal", NOPORTPROTO, (180<<PORTARANGESH),
+	{cmos_pc_m, x_("metal"), NOPORTPROTO, (180<<PORTARANGESH),
 		LEFTIN1H, BOTIN1H, RIGHTIN1H, TOPIN1H}};
 static TECH_POLYGON cmos_m_l[] = {					/* layers */
 	{LMETAL, 0,  4, FILLEDRECT, BOX, cmos_fullbox}};
 static TECH_NODES cmos_m = {
-	"Metal-Node",NMETALN,NONODEPROTO,				/* name */
+	x_("Metal-Node"),NMETALN,NONODEPROTO,			/* name */
 	K3,K3,											/* size */
 	1,cmos_m_p,										/* ports */
 	1,cmos_m_l,										/* layers */
@@ -575,12 +663,12 @@ static TECH_NODES cmos_m = {
 
 /* polysilicon-node */
 static TECH_PORTS cmos_p_p[] = {					/* ports */
-	{cmos_pc_p, "polysilicon", NOPORTPROTO, (180<<PORTARANGESH),
+	{cmos_pc_p, x_("polysilicon"), NOPORTPROTO, (180<<PORTARANGESH),
 		LEFTIN1, BOTIN1, RIGHTIN1, TOPIN1}};
 static TECH_POLYGON cmos_p_l[] = {					/* layers */
 	{LPOLY, 0, 4, FILLEDRECT, BOX, cmos_fullbox}};
 static TECH_NODES cmos_p = {
-	"Polysilicon-Node",NPOLYN,NONODEPROTO,			/* name */
+	x_("Polysilicon-Node"),NPOLYN,NONODEPROTO,		/* name */
 	K2,K2,											/* size */
 	1,cmos_p_p,										/* ports */
 	1,cmos_p_l,										/* layers */
@@ -589,12 +677,12 @@ static TECH_NODES cmos_p = {
 
 /* diffusion-node */
 static TECH_PORTS cmos_d_p[] = {					/* ports */
-	{cmos_pc_null, "diffusion", NOPORTPROTO, (180<<PORTARANGESH),
+	{cmos_pc_null, x_("diffusion"), NOPORTPROTO, (180<<PORTARANGESH),
 		LEFTIN1, BOTIN1, RIGHTIN1, TOPIN1}};
 static TECH_POLYGON cmos_d_l[] = {					/* layers */
 	{LDIFF, 0, 4, FILLEDRECT, BOX, cmos_fullbox}};
 static TECH_NODES cmos_d = {
-	"Diffusion-Node",NDIFN,NONODEPROTO,				/* name */
+	x_("Diffusion-Node"),NDIFN,NONODEPROTO,			/* name */
 	K2,K2,											/* size */
 	1,cmos_d_p,										/* ports */
 	1,cmos_d_l,										/* layers */
@@ -603,12 +691,12 @@ static TECH_NODES cmos_d = {
 
 /* p+-node */
 static TECH_PORTS cmos_i_p[] = {					/* ports */
-	{cmos_pc_null, "p+", NOPORTPROTO, (180<<PORTARANGESH),
+	{cmos_pc_null, x_("p+"), NOPORTPROTO, (180<<PORTARANGESH),
 		LEFTIN1, BOTIN1, RIGHTIN1, TOPIN1}};
 static TECH_POLYGON cmos_i_l[] = {					/* layers */
 	{LP, 0, 4, FILLEDRECT, BOX, cmos_fullbox}};
 static TECH_NODES cmos_i = {
-	"P-Node",NPN,NONODEPROTO,						/* name */
+	x_("P-Node"),NPN,NONODEPROTO,					/* name */
 	K2,K2,											/* size */
 	1,cmos_i_p,										/* ports */
 	1,cmos_i_l,										/* layers */
@@ -617,12 +705,12 @@ static TECH_NODES cmos_i = {
 
 /* cut-node */
 static TECH_PORTS cmos_c_p[] = {					/* ports */
-	{cmos_pc_null, "cut", NOPORTPROTO, (180<<PORTARANGESH),
+	{cmos_pc_null, x_("cut"), NOPORTPROTO, (180<<PORTARANGESH),
 		LEFTIN1, BOTIN1, RIGHTIN1, TOPIN1}};
 static TECH_POLYGON cmos_c_l[] = {					/* layers */
 	{LCUT, 0, 4, CLOSEDRECT, BOX, cmos_fullbox}};
 static TECH_NODES cmos_c = {
-	"Cut-Node",NCUTN,NONODEPROTO,					/* name */
+	x_("Cut-Node"),NCUTN,NONODEPROTO,				/* name */
 	K2,K2,											/* size */
 	1,cmos_c_p,										/* ports */
 	1,cmos_c_l,										/* layers */
@@ -631,12 +719,12 @@ static TECH_NODES cmos_c = {
 
 /* ohmic-cut-node */
 static TECH_PORTS cmos_co_p[] = {					/* ports */
-	{cmos_pc_null, "ohmic-cut", NOPORTPROTO, (180<<PORTARANGESH),
+	{cmos_pc_null, x_("ohmic-cut"), NOPORTPROTO, (180<<PORTARANGESH),
 		LEFTIN1, BOTIN1, RIGHTIN1, TOPIN1}};
 static TECH_POLYGON cmos_co_l[] = {					/* layers */
 	{LOCUT, 0, 4, CROSSED,  BOX, cmos_fullbox}};
 static TECH_NODES cmos_co = {
-	"Ohmic-Cut-Node",NOCUTN,NONODEPROTO,			/* name */
+	x_("Ohmic-Cut-Node"),NOCUTN,NONODEPROTO,		/* name */
 	K2,K2,											/* size */
 	1,cmos_co_p,									/* ports */
 	1,cmos_co_l,									/* layers */
@@ -645,12 +733,12 @@ static TECH_NODES cmos_co = {
 
 /* p-well-node */
 static TECH_PORTS cmos_w_p[] = {					/* ports */
-	{cmos_pc_null, "well", NOPORTPROTO, (180<<PORTARANGESH),
+	{cmos_pc_null, x_("well"), NOPORTPROTO, (180<<PORTARANGESH),
 		LEFTIN1, BOTIN1, RIGHTIN1, TOPIN1}};
 static TECH_POLYGON cmos_w_l[] = {					/* layers */
 	{LWELL, 0, 4, FILLEDRECT, BOX, cmos_fullbox}};
 static TECH_NODES cmos_w = {
-	"Well-Node",NWELLN,NONODEPROTO,					/* name */
+	x_("Well-Node"),NWELLN,NONODEPROTO,				/* name */
 	K4,K4,											/* size */
 	1,cmos_w_p,										/* ports */
 	1,cmos_w_l,										/* layers */
@@ -659,12 +747,12 @@ static TECH_NODES cmos_w = {
 
 /* overglass-node */
 static TECH_PORTS cmos_o_p[] = {					/* ports */
-	{cmos_pc_null, "overglass", NOPORTPROTO, (180<<PORTARANGESH),
+	{cmos_pc_null, x_("overglass"), NOPORTPROTO, (180<<PORTARANGESH),
 		LEFTIN1, BOTIN1, RIGHTIN1, TOPIN1}};
 static TECH_POLYGON cmos_o_l[] = {					/* layers */
 	{LOVERGL, 0, 4, FILLEDRECT, BOX, cmos_fullbox}};
 static TECH_NODES cmos_o = {
-	"Overglass-Node",NGLASSN,NONODEPROTO,			/* name */
+	x_("Overglass-Node"),NGLASSN,NONODEPROTO,		/* name */
 	K2,K2,											/* size */
 	1,cmos_o_p,										/* ports */
 	1,cmos_o_l,										/* layers */
@@ -686,27 +774,27 @@ static INTBIG cmos_node_widoff[NODEPROTOCOUNT*4] = {0,0,0,0, 0,0,0,0,
 TECH_VARIABLES cmos_variables[] =
 {
 	/* set general information about the technology */
-	{"TECH_layer_names", (char *)cmos_layer_names, 0.0,
+	{x_("TECH_layer_names"), (CHAR *)cmos_layer_names, 0.0,
 		VSTRING|VDONTSAVE|VISARRAY|(MAXLAYERS<<VLENGTHSH)},
-	{"TECH_layer_function", (char *)cmos_layer_function, 0.0,
+	{x_("TECH_layer_function"), (CHAR *)cmos_layer_function, 0.0,
 		VINTEGER|VDONTSAVE|VISARRAY|(MAXLAYERS<<VLENGTHSH)},
-	{"TECH_arc_width_offset", (char *)cmos_arc_widoff, 0.0,
+	{x_("TECH_arc_width_offset"), (CHAR *)cmos_arc_widoff, 0.0,
 		VFRACT|VDONTSAVE|VISARRAY|(ARCPROTOCOUNT<<VLENGTHSH)},
-	{"TECH_node_width_offset", (char *)cmos_node_widoff, 0.0,
+	{x_("TECH_node_width_offset"), (CHAR *)cmos_node_widoff, 0.0,
 		VFRACT|VDONTSAVE|VISARRAY|((NODEPROTOCOUNT*4)<<VLENGTHSH)},
 
 	/* set information for the USER tool */
-	{"USER_color_map", (char *)cmos_colmap, 0.0,
+	{x_("USER_color_map"), (CHAR *)cmos_colmap, 0.0,
 		VCHAR|VDONTSAVE|VISARRAY|((sizeof cmos_colmap)<<VLENGTHSH)},
-	{"USER_layer_letters", (char *)cmos_layer_letters, 0.0,
+	{x_("USER_layer_letters"), (CHAR *)cmos_layer_letters, 0.0,
 		VSTRING|VDONTSAVE|VISARRAY|(MAXLAYERS<<VLENGTHSH)},
 
 	/* set information for the I/O tool */
-	{"IO_cif_layer_names", (char *)cmos_cif_layers, 0.0,
+	{x_("IO_cif_layer_names"), (CHAR *)cmos_cif_layers, 0.0,
 		VSTRING|VDONTSAVE|VISARRAY|(MAXLAYERS<<VLENGTHSH)},
 
 	/* set information for the DRC tool */
-	{"DRC_min_unconnected_distances", (char *)cmos_unconnectedtable, 0.0,
+	{x_("DRC_min_unconnected_distances"), (CHAR *)cmos_unconnectedtable, 0.0,
 		VFRACT|VDONTSAVE|VISARRAY|
 			(((sizeof cmos_unconnectedtable)/SIZEOFINTBIG)<<VLENGTHSH)},
 	{NULL, NULL, 0.0, 0}
@@ -716,5 +804,7 @@ TECH_VARIABLES cmos_variables[] =
 
 BOOLEAN cmos_initprocess(TECHNOLOGY *tech, INTBIG pass)
 {
+	Q_UNUSED( tech );
+	Q_UNUSED( pass );
 	return(FALSE);
 }
