@@ -51,19 +51,19 @@ BOOLEAN efido_initprocess(TECHNOLOGY*, INTBIG);
 #define LOUTPAD   2
 
 static GRAPHICS efido_n_lay = {LAYERT1, COLORT1, SOLIDC, SOLIDC,
-/* node layer */    {0,0,0,0,0,0,0,0}, NOVARIABLE, 0};
+/* node layer */    {0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0}, NOVARIABLE, 0};
 static GRAPHICS efido_a_lay = {LAYERT2, COLORT2, SOLIDC, SOLIDC,
-/* arc layer */	    {0,0,0,0,0,0,0,0}, NOVARIABLE, 0};
+/* arc layer */	    {0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0}, NOVARIABLE, 0};
 static GRAPHICS efido_o_lay = {LAYERT3, COLORT3, SOLIDC, SOLIDC,
-/* outpad layer */  {0,0,0,0,0,0,0,0}, NOVARIABLE, 0};
+/* outpad layer */  {0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0}, NOVARIABLE, 0};
 
 /* these tables must be updated together */
 GRAPHICS *efido_layers[MAXLAYERS+1] = {&efido_n_lay, &efido_a_lay,
 											&efido_o_lay, NOGRAPHICS};
-static char *efido_layer_names[MAXLAYERS] = {"Node", "Arc", "Outpad"};
+static CHAR *efido_layer_names[MAXLAYERS] = {x_("Node"), x_("Arc"), x_("Outpad")};
 static INTBIG efido_layer_function[MAXLAYERS] = {LFART|LFNONELEC|LFTRANS1,
 	LFUNKNOWN|LFTRANS2, LFOVERGLASS|LFTRANS3};
-static char *efido_layer_letters[MAXLAYERS] = {"n","a","o"};
+static CHAR *efido_layer_letters[MAXLAYERS] = {x_("n"),x_("a"),x_("o")};
 
 /* The low 5 bits map LNODE and LARC */
 static TECH_COLORMAP efido_colmap[32] =
@@ -111,14 +111,14 @@ static TECH_COLORMAP efido_colmap[32] =
 /* wire arc */
 static TECH_ARCLAY efido_al_w[] = {{ LARC,0,FILLED }};
 static TECH_ARCS efido_a_w = {
-	"wire",0,AWIRE,NOARCPROTO,										/* name */
+	x_("wire"),0,AWIRE,NOARCPROTO,									/* name */
 	1,efido_al_w,													/* layers */
 	(APMETAL1<<AFUNCTIONSH)|WANTFIXANG|(45<<AANGLEINCSH)};			/* userbits */
 
 /* bus arc */
 static TECH_ARCLAY efido_al_b[] = {{ LARC,0,CLOSED }};
 static TECH_ARCS efido_a_b = {
-	"bus",K2,ABUS,NOARCPROTO,										/* name */
+	x_("bus"),K2,ABUS,NOARCPROTO,									/* name */
 	1,efido_al_b,													/* layers */
 	(APBUS<<AFUNCTIONSH)|WANTFIXANG|(45<<AANGLEINCSH)};				/* userbits */
 
@@ -171,12 +171,12 @@ static INTBIG efido_disccenter[8] = {CENTER,   CENTER,   RIGHTEDGE, CENTER};
 
 /* wire-pin */
 static TECH_PORTS efido_wp_p[] = {						/* ports */
-	{efido_pc_w, "wire", NOPORTPROTO, (180<<PORTARANGESH),
+	{efido_pc_w, x_("wire"), NOPORTPROTO, (180<<PORTARANGESH),
 		CENTER, CENTER, CENTER, CENTER}};
 static TECH_POLYGON efido_wp_l[] = {					/* layers */
 	{LARC, 0, 2, DISC, POINTS, efido_disccenter}};
 static TECH_NODES efido_wp = {
-	"wire_pin",NWIREPIN,NONODEPROTO,					/* name */
+	x_("wire_pin"),NWIREPIN,NONODEPROTO,				/* name */
 	K1,K1,												/* size */
 	1,efido_wp_p,										/* ports */
 	1,efido_wp_l,										/* layers */
@@ -185,12 +185,12 @@ static TECH_NODES efido_wp = {
 
 /* bus-pin */
 static TECH_PORTS efido_bp_p[] = {						/* ports */
-	{efido_pc_b, "bus", NOPORTPROTO, (180<<PORTARANGESH),
+	{efido_pc_b, x_("bus"), NOPORTPROTO, (180<<PORTARANGESH),
 		CENTER, CENTER, CENTER, CENTER}};
 static TECH_POLYGON efido_bp_l[] = {					/* layers */
 	{LNODE,0, 4, CROSSED, BOX, efido_g_bp}};
 static TECH_NODES efido_bp = {
-	"bus_pin",NBUSPIN,NONODEPROTO,						/* name */
+	x_("bus_pin"),NBUSPIN,NONODEPROTO,					/* name */
 	K2,K2,												/* size */
 	1,efido_bp_p,										/* ports */
 	1,efido_bp_l,										/* layers */
@@ -199,22 +199,22 @@ static TECH_NODES efido_bp = {
 
 /* adder */
 static TECH_PORTS efido_adder_p[] = {					/* ports */
-	{efido_pc_w, "in1", NOPORTPROTO,
+	{efido_pc_w, x_("in1"), NOPORTPROTO,
 		 (270<<PORTANGLESH) | (15<<PORTARANGESH) | (0<<PORTNETSH) | INPORT,
 			CENTER, TOPEDGE, CENTER, TOPEDGE},
-	{efido_pc_w, "in2", NOPORTPROTO,
+	{efido_pc_w, x_("in2"), NOPORTPROTO,
 		 (225<<PORTANGLESH) | (15<<PORTARANGESH) | (1<<PORTNETSH) | INPORT,
 			-TH0, 0,TH0, 0,  -TH0, 0,TH0, 0},
-	{efido_pc_w, "in3", NOPORTPROTO,
+	{efido_pc_w, x_("in3"), NOPORTPROTO,
 		 (180<<PORTANGLESH) | (15<<PORTARANGESH) | (2<<PORTNETSH) | INPORT,
 			LEFTEDGE, CENTER, LEFTEDGE, CENTER},
-	{efido_pc_w, "in4", NOPORTPROTO,
+	{efido_pc_w, x_("in4"), NOPORTPROTO,
 		 (135<<PORTANGLESH) | (15<<PORTARANGESH) | (3<<PORTNETSH) | INPORT,
 			-TH0, 0,-TH0, 0,  -TH0, 0,-TH0, 0},
-	{efido_pc_w, "in5", NOPORTPROTO,
+	{efido_pc_w, x_("in5"), NOPORTPROTO,
 		 (90<<PORTANGLESH) | (15<<PORTARANGESH) | (4<<PORTNETSH) | INPORT,
 			CENTER, BOTEDGE, CENTER, BOTEDGE},
-	{efido_pc_w, "out", NOPORTPROTO,
+	{efido_pc_w, x_("out"), NOPORTPROTO,
 		 (0<<PORTANGLESH) | (45<<PORTARANGESH) | (5<<PORTNETSH) | OUTPORT,
 			RIGHTEDGE, CENTER, RIGHTEDGE, CENTER}};
 static TECH_POLYGON efido_adder_l[] = {					/* layers */
@@ -223,7 +223,7 @@ static TECH_POLYGON efido_adder_l[] = {					/* layers */
 	{LNODE,0, 2, OPENED, POINTS, efido_g_pt2},
 	{LNODE,0, 3, OPENED, POINTS, efido_g_pt1}};
 static TECH_NODES efido_adder = {
-	"adder",NADDER,NONODEPROTO,							/* name */
+	x_("adder"),NADDER,NONODEPROTO,						/* name */
 	K4,K4,												/* size */
 	6,efido_adder_p,									/* ports */
 	4,efido_adder_l,									/* layers */
@@ -232,22 +232,22 @@ static TECH_NODES efido_adder = {
 
 /* multiplier */
 static TECH_PORTS efido_mult_p[] = {					/* ports */
-	{efido_pc_w, "in1", NOPORTPROTO,
+	{efido_pc_w, x_("in1"), NOPORTPROTO,
 		 (270<<PORTANGLESH) | (15<<PORTARANGESH) | (0<<PORTNETSH) | INPORT,
 			CENTER, TOPEDGE, CENTER, TOPEDGE},
-	{efido_pc_w, "in2", NOPORTPROTO,
+	{efido_pc_w, x_("in2"), NOPORTPROTO,
 		 (225<<PORTANGLESH) | (15<<PORTARANGESH) | (1<<PORTNETSH) | INPORT,
 			-TH0, 0,TH0, 0,  -TH0, 0,TH0, 0},
-	{efido_pc_w, "in3", NOPORTPROTO,
+	{efido_pc_w, x_("in3"), NOPORTPROTO,
 		 (180<<PORTANGLESH) | (15<<PORTARANGESH) | (2<<PORTNETSH) | INPORT,
 			LEFTEDGE, CENTER, LEFTEDGE, CENTER},
-	{efido_pc_w, "in4", NOPORTPROTO,
+	{efido_pc_w, x_("in4"), NOPORTPROTO,
 		 (135<<PORTANGLESH) | (15<<PORTARANGESH) | (3<<PORTNETSH) | INPORT,
 			-TH0, 0,-TH0, 0,  -TH0, 0,-TH0, 0},
-	{efido_pc_w, "in5", NOPORTPROTO,
+	{efido_pc_w, x_("in5"), NOPORTPROTO,
 		 (90<<PORTANGLESH) | (15<<PORTARANGESH) | (4<<PORTNETSH) | INPORT,
 			CENTER, BOTEDGE, CENTER, BOTEDGE},
-	{efido_pc_w, "out", NOPORTPROTO,
+	{efido_pc_w, x_("out"), NOPORTPROTO,
 		 (0<<PORTANGLESH) | (45<<PORTARANGESH) | (5<<PORTNETSH) | OUTPORT,
 			RIGHTEDGE, CENTER, RIGHTEDGE, CENTER}};
 static TECH_POLYGON efido_mult_l[] = {					/* layers */
@@ -257,7 +257,7 @@ static TECH_POLYGON efido_mult_l[] = {					/* layers */
 	{LNODE,0, 2, OPENED, POINTS, efido_g_pt2},
 	{LNODE,0, 3, OPENED, POINTS, efido_g_pt1}};
 static TECH_NODES efido_mult = {
-	"multiplier",NMULT,NONODEPROTO,						/* name */
+	x_("multiplier"),NMULT,NONODEPROTO,					/* name */
 	K4,K4,												/* size */
 	6,efido_mult_p,										/* ports */
 	5,efido_mult_l,										/* layers */
@@ -266,10 +266,10 @@ static TECH_NODES efido_mult = {
 
 /* time delay */
 static TECH_PORTS efido_tdelay_p[] = {					/* ports */
-	{efido_pc_w, "in", NOPORTPROTO,
+	{efido_pc_w, x_("in"), NOPORTPROTO,
 		 (180<<PORTANGLESH) | (15<<PORTARANGESH) | (0<<PORTNETSH) | INPORT,
 			LEFTEDGE, CENTER, LEFTEDGE, CENTER},
-	{efido_pc_w, "out", NOPORTPROTO,
+	{efido_pc_w, x_("out"), NOPORTPROTO,
 		 (0<<PORTANGLESH) | (45<<PORTARANGESH) | (1<<PORTNETSH) | OUTPORT,
 			RIGHTEDGE, CENTER, RIGHTEDGE, CENTER}};
 static TECH_POLYGON efido_tdelay_l[] = {				/* layers */
@@ -279,7 +279,7 @@ static TECH_POLYGON efido_tdelay_l[] = {				/* layers */
 	{LNODE,0, 2, OPENED,     POINTS, efido_g_pt2},
 	{LNODE,0, 3, OPENED,     POINTS, efido_g_pt1}};
 static TECH_NODES efido_tdelay = {
-	"timedelay",NTDELAY,NONODEPROTO,					/* name */
+	x_("timedelay"),NTDELAY,NONODEPROTO,				/* name */
 	K4,K4,												/* size */
 	2,efido_tdelay_p,									/* ports */
 	5,efido_tdelay_l,									/* layers */
@@ -288,13 +288,13 @@ static TECH_NODES efido_tdelay = {
 
 /* multiplexer */
 static TECH_PORTS efido_mux_p[] = {						/* ports */
-	{efido_pc_w, "in1", NOPORTPROTO,
+	{efido_pc_w, x_("in1"), NOPORTPROTO,
 		 (270<<PORTANGLESH) | (15<<PORTARANGESH) | (0<<PORTNETSH) | INPORT,
 			LEFTEDGE, Q0, 0, LEFTEDGE, Q0,0},
-	{efido_pc_w, "in2", NOPORTPROTO,
+	{efido_pc_w, x_("in2"), NOPORTPROTO,
 		 (135<<PORTANGLESH) | (15<<PORTARANGESH) | (1<<PORTNETSH) | INPORT,
 			LEFTEDGE, -Q0, 0, LEFTEDGE, -Q0,0},
-	{efido_pc_w, "out", NOPORTPROTO,
+	{efido_pc_w, x_("out"), NOPORTPROTO,
 		 (0<<PORTANGLESH) | (45<<PORTARANGESH) | (2<<PORTNETSH) | OUTPORT,
 			RIGHTEDGE, CENTER, RIGHTEDGE, CENTER}};
 static TECH_POLYGON efido_mux_l[] = {					/* layers */
@@ -303,7 +303,7 @@ static TECH_POLYGON efido_mux_l[] = {					/* layers */
 	{LNODE,0, 4, OPENED,     POINTS, efido_g_mux2},
 	{LNODE,0, 3, OPENED,     POINTS, efido_g_mux3}};
 static TECH_NODES efido_mux = {
-	"multiplexer",NMUX,NONODEPROTO,						/* name */
+	x_("multiplexer"),NMUX,NONODEPROTO,					/* name */
 	K4,K4,												/* size */
 	3,efido_mux_p,										/* ports */
 	4,efido_mux_l,										/* layers */
@@ -312,22 +312,22 @@ static TECH_NODES efido_mux = {
 
 /* subtractor */
 static TECH_PORTS efido_subtr_p[] = {					/* ports */
-	{efido_pc_w, "in1", NOPORTPROTO,
+	{efido_pc_w, x_("in1"), NOPORTPROTO,
 		 (270<<PORTANGLESH) | (15<<PORTARANGESH) | (0<<PORTNETSH) | INPORT,
 			CENTER, TOPEDGE, CENTER, TOPEDGE},
-	{efido_pc_w, "in2", NOPORTPROTO,
+	{efido_pc_w, x_("in2"), NOPORTPROTO,
 		 (225<<PORTANGLESH) | (15<<PORTARANGESH) | (1<<PORTNETSH) | INPORT,
 			-TH0, 0,TH0, 0,  -TH0, 0,TH0, 0},
-	{efido_pc_w, "in3", NOPORTPROTO,
+	{efido_pc_w, x_("in3"), NOPORTPROTO,
 		 (180<<PORTANGLESH) | (15<<PORTARANGESH) | (2<<PORTNETSH) | INPORT,
 			LEFTEDGE, CENTER, LEFTEDGE, CENTER},
-	{efido_pc_w, "in4", NOPORTPROTO,
+	{efido_pc_w, x_("in4"), NOPORTPROTO,
 		 (135<<PORTANGLESH) | (15<<PORTARANGESH) | (3<<PORTNETSH) | INPORT,
 			-TH0, 0,-TH0, 0,  -TH0, 0,-TH0, 0},
-	{efido_pc_w, "in5", NOPORTPROTO,
+	{efido_pc_w, x_("in5"), NOPORTPROTO,
 		 (90<<PORTANGLESH) | (15<<PORTARANGESH) | (4<<PORTNETSH) | INPORT,
 			CENTER, BOTEDGE, CENTER, BOTEDGE},
-	{efido_pc_w, "out", NOPORTPROTO,
+	{efido_pc_w, x_("out"), NOPORTPROTO,
 		 (0<<PORTANGLESH) | (45<<PORTARANGESH) | (5<<PORTNETSH) | OUTPORT,
 			RIGHTEDGE, CENTER, RIGHTEDGE, CENTER}};
 static TECH_POLYGON efido_subtr_l[] = {					/* layers */
@@ -336,7 +336,7 @@ static TECH_POLYGON efido_subtr_l[] = {					/* layers */
 	{LNODE,0, 2, OPENED, POINTS, efido_g_pt2},
 	{LNODE,0, 3, OPENED, POINTS, efido_g_pt1}};
 static TECH_NODES efido_subtr = {
-	"subtractor",NSUBTR,NONODEPROTO,					/* name */
+	x_("subtractor"),NSUBTR,NONODEPROTO,				/* name */
 	K4,K4,												/* size */
 	6,efido_subtr_p,									/* ports */
 	4,efido_subtr_l,									/* layers */
@@ -345,22 +345,22 @@ static TECH_NODES efido_subtr = {
 
 /* divider */
 static TECH_PORTS efido_div_p[] = {						/* ports */
-	{efido_pc_w, "in1", NOPORTPROTO,
+	{efido_pc_w, x_("in1"), NOPORTPROTO,
 		 (270<<PORTANGLESH) | (15<<PORTARANGESH) | (0<<PORTNETSH) | INPORT,
 			CENTER, TOPEDGE, CENTER, TOPEDGE},
-	{efido_pc_w, "in2", NOPORTPROTO,
+	{efido_pc_w, x_("in2"), NOPORTPROTO,
 		 (225<<PORTANGLESH) | (15<<PORTARANGESH) | (1<<PORTNETSH) | INPORT,
 			-TH0, 0,TH0, 0,  -TH0, 0,TH0, 0},
-	{efido_pc_w, "in3", NOPORTPROTO,
+	{efido_pc_w, x_("in3"), NOPORTPROTO,
 		 (180<<PORTANGLESH) | (15<<PORTARANGESH) | (2<<PORTNETSH) | INPORT,
 			LEFTEDGE, CENTER, LEFTEDGE, CENTER},
-	{efido_pc_w, "in4", NOPORTPROTO,
+	{efido_pc_w, x_("in4"), NOPORTPROTO,
 		 (135<<PORTANGLESH) | (15<<PORTARANGESH) | (3<<PORTNETSH) | INPORT,
 			-TH0, 0,-TH0, 0,  -TH0, 0,-TH0, 0},
-	{efido_pc_w, "in5", NOPORTPROTO,
+	{efido_pc_w, x_("in5"), NOPORTPROTO,
 		 (90<<PORTANGLESH) | (15<<PORTARANGESH) | (4<<PORTNETSH) | INPORT,
 			CENTER, BOTEDGE, CENTER, BOTEDGE},
-	{efido_pc_w, "out", NOPORTPROTO,
+	{efido_pc_w, x_("out"), NOPORTPROTO,
 		 (0<<PORTANGLESH) | (45<<PORTARANGESH) | (5<<PORTNETSH) | OUTPORT,
 			RIGHTEDGE, CENTER, RIGHTEDGE, CENTER}};
 static TECH_POLYGON efido_div_l[] = {					/* layers */
@@ -371,7 +371,7 @@ static TECH_POLYGON efido_div_l[] = {					/* layers */
 	{LNODE,0, 2, OPENED, POINTS, efido_g_pt2},
 	{LNODE,0, 3, OPENED, POINTS, efido_g_pt1}};
 static TECH_NODES efido_div = {
-	"divider",NDIV,NONODEPROTO,							/* name */
+	x_("divider"),NDIV,NONODEPROTO,						/* name */
 	K4,K4,												/* size */
 	6,efido_div_p,										/* ports */
 	6,efido_div_l,										/* layers */
@@ -380,13 +380,13 @@ static TECH_NODES efido_div = {
 
 /* pad in */
 static TECH_PORTS efido_padin_p[] = {					/* ports */
-	{efido_pc_w, "out", NOPORTPROTO, (180<<PORTARANGESH) | INPORT,
+	{efido_pc_w, x_("out"), NOPORTPROTO, (180<<PORTARANGESH) | INPORT,
 		CENTER, CENTER, CENTER, CENTER}};
 static TECH_POLYGON efido_padin_l[] = {					/* layers */
 	{LNODE,0, 4, CLOSEDRECT, BOX, efido_g_fullbox},
 	{LNODE,0, 4, CROSSED,    BOX, efido_g_halfbox}};
 static TECH_NODES efido_padin = {
-	"padin",NPADIN,NONODEPROTO,							/* name */
+	x_("padin"),NPADIN,NONODEPROTO,						/* name */
 	K4,K4,												/* size */
 	1,efido_padin_p,									/* ports */
 	2,efido_padin_l,									/* layers */
@@ -395,13 +395,13 @@ static TECH_NODES efido_padin = {
 
 /* pad out */
 static TECH_PORTS efido_padout_p[] = {					/* ports */
-	{efido_pc_w, "in", NOPORTPROTO, (180<<PORTARANGESH) | OUTPORT,
+	{efido_pc_w, x_("in"), NOPORTPROTO, (180<<PORTARANGESH) | OUTPORT,
 			CENTER, CENTER, CENTER, CENTER}};
 static TECH_POLYGON efido_padout_l[] = {				/* layers */
 	{LNODE,  0, 4, CLOSEDRECT, BOX, efido_g_fullbox},
 	{LOUTPAD,0, 4, CROSSED,    BOX, efido_g_halfbox}};
 static TECH_NODES efido_padout = {
-	"padout",NPADOUT,NONODEPROTO,						/* name */
+	x_("padout"),NPADOUT,NONODEPROTO,					/* name */
 	K4,K4,												/* size */
 	1,efido_padout_p,									/* ports */
 	2,efido_padout_l,									/* layers */
@@ -420,15 +420,15 @@ TECH_NODES *efido_nodeprotos[NODEPROTOCOUNT+1] =
 TECH_VARIABLES efido_variables[] =
 {
 	/* set general information about the technology */
-	{"TECH_layer_names", (char *)efido_layer_names, 0.0,
+	{x_("TECH_layer_names"), (CHAR *)efido_layer_names, 0.0,
 		VSTRING|VDONTSAVE|VISARRAY|(MAXLAYERS<<VLENGTHSH)},
-	{"TECH_layer_function", (char *)efido_layer_function, 0.0,
+	{x_("TECH_layer_function"), (CHAR *)efido_layer_function, 0.0,
 		VINTEGER|VDONTSAVE|VISARRAY|(MAXLAYERS<<VLENGTHSH)},
 
 	/* set information for the USER analysis tool */
-	{"USER_color_map", (char *)efido_colmap, 0.0,
+	{x_("USER_color_map"), (CHAR *)efido_colmap, 0.0,
 		VCHAR|VDONTSAVE|VISARRAY|((sizeof efido_colmap)<<VLENGTHSH)},
-	{"USER_layer_letters", (char *)efido_layer_letters, 0.0,
+	{x_("USER_layer_letters"), (CHAR *)efido_layer_letters, 0.0,
 		VSTRING|VDONTSAVE|VISARRAY|(MAXLAYERS<<VLENGTHSH)},
 	{NULL, NULL, 0.0, 0}
 };
@@ -437,5 +437,7 @@ TECH_VARIABLES efido_variables[] =
 
 BOOLEAN efido_initprocess(TECHNOLOGY *tech, INTBIG pass)
 {
+	Q_UNUSED( tech );
+	Q_UNUSED( pass );
 	return(FALSE);
 }
