@@ -67,27 +67,27 @@ static void gen_intshapenodepoly(NODEINST *ni, INTBIG box, POLYGON *poly, POLYLO
 #define LDRC            4		/* drc ignore layer */
 
 static GRAPHICS gen_un_lay = {LAYERO, MENTXT, SOLIDC, SOLIDC,
-/* univ */					{0,0,0,0,0,0,0,0}, NOVARIABLE, 0};
+/* univ */					{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0}, NOVARIABLE, 0};
 static GRAPHICS gen_in_lay = {LAYERO, GRAY,  SOLIDC, SOLIDC,
-/* invis */					{0,0,0,0,0,0,0,0}, NOVARIABLE, 0};
+/* invis */					{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0}, NOVARIABLE, 0};
 static GRAPHICS gen_int_lay = {LAYERO, BLACK,  SOLIDC, SOLIDC,
-/* invis text */			{0,0,0,0,0,0,0,0}, NOVARIABLE, 0};
+/* invis text */			{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0}, NOVARIABLE, 0};
 static GRAPHICS gen_ur_lay = {LAYERO, DGRAY, SOLIDC, SOLIDC,
-/* unrouted */				{0,0,0,0,0,0,0,0}, NOVARIABLE, 0};
+/* unrouted */				{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0}, NOVARIABLE, 0};
 static GRAPHICS gen_gl_lay = {LAYERO, MENGLY, SOLIDC, SOLIDC,
-/* glyph */					{0,0,0,0,0,0,0,0}, NOVARIABLE, 0};
+/* glyph */					{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0}, NOVARIABLE, 0};
 static GRAPHICS gen_dr_lay = {LAYERO, ORANGE, SOLIDC, SOLIDC,
-/* drc */					{0,0,0,0,0,0,0,0}, NOVARIABLE, 0};
+/* drc */					{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0}, NOVARIABLE, 0};
 
 /* these tables must be updated togehter */
 GRAPHICS *gen_layers[MAXLAYERS+1] = {&gen_un_lay, &gen_in_lay,
 	&gen_ur_lay, &gen_gl_lay, &gen_dr_lay, NOGRAPHICS};
-static char *gen_layer_names[MAXLAYERS] = {"Universal", "Invisible",
-	"Unrouted", "Glyph", "DRC"};
-static char *gen_cif_layers[MAXLAYERS] = {"", "", "", "", "DRC"};
+static CHAR *gen_layer_names[MAXLAYERS] = {x_("Universal"), x_("Invisible"),
+	x_("Unrouted"), x_("Glyph"), x_("DRC")};
+static CHAR *gen_cif_layers[MAXLAYERS] = {x_(""), x_(""), x_(""), x_(""), x_("DRC")};
 static INTBIG gen_layer_function[MAXLAYERS] = {LFUNKNOWN, LFUNKNOWN|LFNONELEC,
 	LFUNKNOWN, LFART|LFNONELEC, LFART|LFNONELEC};
-static char *gen_layer_letters[MAXLAYERS] = {"u", "i", "r", "g", "d"};
+static CHAR *gen_layer_letters[MAXLAYERS] = {x_("u"), x_("i"), x_("r"), x_("g"), x_("d")};
 
 /******************** ARCS ********************/
 
@@ -99,21 +99,21 @@ static char *gen_layer_letters[MAXLAYERS] = {"u", "i", "r", "g", "d"};
 /* universal arc */
 static TECH_ARCLAY gen_al_u[] = {{LUNIV,0,FILLED}};
 static TECH_ARCS gen_a_u = {
-	"Universal",0,GENAUNIV,NOARCPROTO,						/* name */
+	x_("Universal"),0,GENAUNIV,NOARCPROTO,					/* name */
 	1,gen_al_u,												/* layers */
 	(APUNKNOWN<<AFUNCTIONSH)|WANTFIXANG|(45<<AANGLEINCSH)};	/* userbits */
 
 /* invisible arc */
 static TECH_ARCLAY gen_al_i[] = {{LINVIS,0,FILLED}};
 static TECH_ARCS gen_a_i = {
-	"Invisible",0,GENAINVIS,NOARCPROTO,						/* name */
+	x_("Invisible"),0,GENAINVIS,NOARCPROTO,					/* name */
 	1,gen_al_i,												/* layers */
 	(APNONELEC<<AFUNCTIONSH)|WANTFIXANG|(45<<AANGLEINCSH)};	/* userbits */
 
 /* unrouted arc */
 static TECH_ARCLAY gen_al_r[] = {{LUNROUTED,0,FILLED}};
 static TECH_ARCS gen_a_r = {
-	"Unrouted",0,GENAUNROUTED,NOARCPROTO,					/* name */
+	x_("Unrouted"),0,GENAUNROUTED,NOARCPROTO,				/* name */
 	1,gen_al_r,												/* layers */
 	(APUNROUTED<<AFUNCTIONSH)|(0<<AANGLEINCSH)};			/* userbits */
 
@@ -147,12 +147,12 @@ static INTBIG gen_essentiall[] = {CENTERL1, CENTER,  CENTER,    CENTER,
 								  CENTER,   CENTERD1};
 /* Universal pin */
 static TECH_PORTS gen_u_p[] = {						/* ports */
-	{(INTBIG *)0, "univ", NOPORTPROTO, (180<<PORTARANGESH),
+	{(INTBIG *)0, x_("univ"), NOPORTPROTO, (180<<PORTARANGESH),
 		CENTER, CENTER, CENTER, CENTER}};
 static TECH_POLYGON gen_u_l[] = {					/* layers */
 	{LUNIV, 0, 2, DISC, POINTS, gen_disccenter}};
 static TECH_NODES gen_u = {
-	"Universal-Pin",NUNIV,NONODEPROTO,				/* name */
+	x_("Universal-Pin"),NUNIV,NONODEPROTO,			/* name */
 	K1,K1,											/* size */
 	1,gen_u_p,										/* ports */
 	1,gen_u_l,										/* layers */
@@ -161,12 +161,12 @@ static TECH_NODES gen_u = {
 
 /* Invisible Pin */
 static TECH_PORTS gen_i_p[] = {{					/* ports */
-	gen_pc_iu, "center", NOPORTPROTO, (180<<PORTARANGESH),
+	gen_pc_iu, x_("center"), NOPORTPROTO, (180<<PORTARANGESH),
 		CENTER, CENTER, CENTER, CENTER}};
 static TECH_POLYGON gen_i_l[] = {					/* layers */
 	{LINVIS, 0, 4, CLOSEDRECT, BOX, gen_fullbox}};
 static TECH_NODES gen_i = {
-	"Invisible-Pin",NINVIS,NONODEPROTO,				/* name */
+	x_("Invisible-Pin"),NINVIS,NONODEPROTO,			/* name */
 	K1,K1,											/* size */
 	1,gen_i_p,										/* ports */
 	1,gen_i_l,										/* layers */
@@ -175,12 +175,12 @@ static TECH_NODES gen_i = {
 
 /* Unrouted Pin */
 static TECH_PORTS gen_r_p[] = {{					/* ports */
-	gen_pc_riu, "unrouted", NOPORTPROTO, (180<<PORTARANGESH),
+	gen_pc_riu, x_("unrouted"), NOPORTPROTO, (180<<PORTARANGESH),
 		CENTER, CENTER, CENTER, CENTER}};
 static TECH_POLYGON gen_r_l[] = {					/* layers */
 	{LUNROUTED, 0, 2, DISC, POINTS, gen_disccenter}};
 static TECH_NODES gen_r = {
-	"Unrouted-Pin",NUNROUTED,NONODEPROTO,			/* name */
+	x_("Unrouted-Pin"),NUNROUTED,NONODEPROTO,		/* name */
 	K1,K1,											/* size */
 	1,gen_r_p,										/* ports */
 	1,gen_r_l,										/* layers */
@@ -189,13 +189,13 @@ static TECH_NODES gen_r = {
 
 /* Facet Center */
 static TECH_PORTS gen_c_p[] = {{					/* ports */
-	gen_pc_iu, "center", NOPORTPROTO, (180<<PORTARANGESH),
+	gen_pc_iu, x_("center"), NOPORTPROTO, (180<<PORTARANGESH),
 		LEFTEDGE, BOTEDGE, LEFTEDGE, BOTEDGE}};
 static TECH_POLYGON gen_c_l[] = {					/* layers */
 	{LGLYPH, 0, 4, CLOSED,   BOX,    gen_fullbox},
 	{LGLYPH, 0, 2, BIGCROSS, POINTS, gen_center_lc}};
 static TECH_NODES gen_c = {
-	"Facet-Center",NCENTER,NONODEPROTO,				/* name */
+	x_("Facet-Center"),NCENTER,NONODEPROTO,			/* name */
 	K0,K0,											/* size */
 	1,gen_c_p,										/* ports */
 	2,gen_c_l,										/* layers */
@@ -204,13 +204,13 @@ static TECH_NODES gen_c = {
 
 /* Port */
 static TECH_PORTS gen_p_p[] = {{					/* ports */
-	gen_pc_iu, "center", NOPORTPROTO, (180<<PORTARANGESH),
+	gen_pc_iu, x_("center"), NOPORTPROTO, (180<<PORTARANGESH),
 		CENTER, CENTER, CENTER, CENTER}};
 static TECH_POLYGON gen_p_l[] = {					/* layers */
 	{LGLYPH, 0,         4, CLOSED,   BOX,    gen_in2box},
 	{LGLYPH, 0,         3, OPENED,   POINTS, gen_portabox}};
 static TECH_NODES gen_p = {
-	"Port",NPORT,NONODEPROTO,						/* name */
+	x_("Port"),NPORT,NONODEPROTO,					/* name */
 	K6,K6,											/* size */
 	1,gen_p_p,										/* ports */
 	2,gen_p_l,										/* layers */
@@ -219,12 +219,12 @@ static TECH_NODES gen_p = {
 
 /* DRC Node */
 static TECH_PORTS gen_d_p[] = {{					/* ports */
-	gen_pc_iu, "center", NOPORTPROTO, (180<<PORTARANGESH),
+	gen_pc_iu, x_("center"), NOPORTPROTO, (180<<PORTARANGESH),
 		CENTER, CENTER, CENTER, CENTER}};
 static TECH_POLYGON gen_d_l[] = {					/* layers */
 	{LDRC, 0, 4, CLOSEDRECT, BOX, gen_fullbox}};
 static TECH_NODES gen_d = {
-	"DRC-Node",NDRC,NONODEPROTO,					/* name */
+	x_("DRC-Node"),NDRC,NONODEPROTO,				/* name */
 	K2,K2,											/* size */
 	1,gen_d_p,										/* ports */
 	1,gen_d_l,										/* layers */
@@ -233,12 +233,12 @@ static TECH_NODES gen_d = {
 
 /* Essential Bounds marker */
 static TECH_PORTS gen_e_p[] = {{					/* ports */
-	gen_pc_iu, "center", NOPORTPROTO, (180<<PORTARANGESH),
+	gen_pc_iu, x_("center"), NOPORTPROTO, (180<<PORTARANGESH),
 		LEFTEDGE, BOTEDGE, LEFTEDGE, BOTEDGE}};
 static TECH_POLYGON gen_e_l[] = {					/* layers */
 	{LGLYPH, 0, 3, OPENED, POINTS, gen_essentiall}};
 static TECH_NODES gen_e = {
-	"Essential-Bounds",NESSENTIAL,NONODEPROTO,		/* name */
+	x_("Essential-Bounds"),NESSENTIAL,NONODEPROTO,	/* name */
 	K0,K0,											/* size */
 	1,gen_e_p,										/* ports */
 	1,gen_e_l,										/* layers */
@@ -256,19 +256,19 @@ static INTBIG gen_node_widoff[NODEPROTOCOUNT*4] = {0,0,0,0, 0,0,0,0, 0,0,0,0,
 TECH_VARIABLES gen_variables[] =
 {
 	/* set general information about the technology */
-	{"TECH_layer_names", (char *)gen_layer_names, 0.0,
+	{x_("TECH_layer_names"), (CHAR *)gen_layer_names, 0.0,
 		VSTRING|VDONTSAVE|VISARRAY|(MAXLAYERS<<VLENGTHSH)},
-	{"TECH_layer_function", (char *)gen_layer_function, 0.0,
+	{x_("TECH_layer_function"), (CHAR *)gen_layer_function, 0.0,
 		VINTEGER|VDONTSAVE|VISARRAY|(MAXLAYERS<<VLENGTHSH)},
-	{"TECH_node_width_offset", (char *)gen_node_widoff, 0.0,
+	{x_("TECH_node_width_offset"), (CHAR *)gen_node_widoff, 0.0,
 		VFRACT|VDONTSAVE|VISARRAY|((NODEPROTOCOUNT*4)<<VLENGTHSH)},
 
 	/* set information for the I/O tool */
-	{"IO_cif_layer_names", (char *)gen_cif_layers, 0.0,
+	{x_("IO_cif_layer_names"), (CHAR *)gen_cif_layers, 0.0,
 		VSTRING|VDONTSAVE|VISARRAY|(MAXLAYERS<<VLENGTHSH)},
 
 	/* set information for the USER tool */
-	{"USER_layer_letters", (char *)gen_layer_letters, 0.0,
+	{x_("USER_layer_letters"), (CHAR *)gen_layer_letters, 0.0,
 		VSTRING|VDONTSAVE|VISARRAY|(MAXLAYERS<<VLENGTHSH)},
 	{NULL, NULL, 0.0, 0}
 };
@@ -288,17 +288,17 @@ BOOLEAN gen_initprocess(TECHNOLOGY *tech, INTBIG pass)
 			/* create list of ALL arcs (now and when technologies change) */
 			registertechnologycache(gen_makeunivlist, 0, 0);
 
-			gen_univpinprim = getnodeproto("Generic:Universal-Pin");
-			gen_invispinprim = getnodeproto("Generic:Invisible-Pin");
-			gen_unroutedpinprim = getnodeproto("Generic:Unrouted-Pin");
-			gen_facetcenterprim = getnodeproto("Generic:Facet-Center");
-			gen_portprim = getnodeproto("Generic:Port");
-			gen_drcprim = getnodeproto("Generic:DRC-Node");
-			gen_essentialprim = getnodeproto("Generic:Essential-Bounds");
+			gen_univpinprim = getnodeproto(x_("Generic:Universal-Pin"));
+			gen_invispinprim = getnodeproto(x_("Generic:Invisible-Pin"));
+			gen_unroutedpinprim = getnodeproto(x_("Generic:Unrouted-Pin"));
+			gen_facetcenterprim = getnodeproto(x_("Generic:Facet-Center"));
+			gen_portprim = getnodeproto(x_("Generic:Port"));
+			gen_drcprim = getnodeproto(x_("Generic:DRC-Node"));
+			gen_essentialprim = getnodeproto(x_("Generic:Essential-Bounds"));
 
-			gen_universalarc = getarcproto("Generic:Universal");
-			gen_invisiblearc = getarcproto("Generic:Invisible");
-			gen_unroutedarc = getarcproto("Generic:Unrouted");
+			gen_universalarc = getarcproto(x_("Generic:Universal"));
+			gen_invisiblearc = getarcproto(x_("Generic:Invisible"));
+			gen_unroutedarc = getarcproto(x_("Generic:Unrouted"));
 			break;
 
 		case 2:
@@ -311,7 +311,7 @@ BOOLEAN gen_initprocess(TECHNOLOGY *tech, INTBIG pass)
 
 void gen_termprocess(void)
 {
-	if (gen_upconn != 0) efree((char *)gen_upconn);
+	if (gen_upconn != 0) efree((CHAR *)gen_upconn);
 }
 
 /*
@@ -334,7 +334,7 @@ void gen_makeunivlist(void)
 	}
 
 	/* make an array for each arc */
-	if (gen_upconn != 0) efree((char *)gen_upconn);
+	if (gen_upconn != 0) efree((CHAR *)gen_upconn);
 	gen_upconn = (ARCPROTO **)emalloc(((tot+2) * (sizeof (ARCPROTO *))), gen_tech->cluster);
 	if (gen_upconn == 0) return;
 
@@ -412,8 +412,8 @@ INTBIG gen_intnodepolys(NODEINST *ni, INTBIG *reasonable, WINDOWPART *win, POLYL
 		}
 	} else if (pindex == NPORT)
 	{
-		if (portanglekey == 0) portanglekey = makekey("EDTEC_portangle");
-		if (portrangekey == 0) portrangekey = makekey("EDTEC_portrange");
+		if (portanglekey == 0) portanglekey = makekey(x_("EDTEC_portangle"));
+		if (portrangekey == 0) portrangekey = makekey(x_("EDTEC_portrange"));
 
 		/* port node becomes a cross when it is 1x1 */
 		lambda = lambdaofnode(ni);
@@ -579,6 +579,7 @@ void gen_shapeportpoly(NODEINST *ni, PORTPROTO *pp, POLYGON *poly, XARRAY trans,
 	BOOLEAN purpose)
 {
 	REGISTER INTBIG pindex;
+	Q_UNUSED( purpose );
 
 	pindex = ni->proto->primindex;
 	tech_fillportpoly(ni, pp, poly, trans, gen_nodeprotos[pindex-1], OPENED, lambdaofnode(ni));
