@@ -133,13 +133,25 @@ extern TECH_ARCS *fpga_arcprotos[];
 extern TECH_NODES *fpga_nodeprotos[];
 extern TECH_VARIABLES fpga_variables[];
 
+#ifdef FORCESUNTOOLS
+extern GRAPHICS *ziptronics_layers[];
+extern TECH_ARCS *ziptronics_arcprotos[];
+extern TECH_NODES *ziptronics_nodeprotos[];
+extern TECH_VARIABLES ziptronics_variables[];
+
+extern GRAPHICS *epic7s_layers[];
+extern TECH_ARCS *epic7s_arcprotos[];
+extern TECH_NODES *epic7s_nodeprotos[];
+extern TECH_VARIABLES epic7s_variables[];
+#endif
+
 /*
  * the first entry in this table MUST BE THE GENERIC TECHNOLOGY!
  */
 TECHNOLOGY el_technologylist[] =
 {
 	/* Generic */
-	{"generic", 0, 2000, NONODEPROTO,NOARCPROTO,NOVARIABLE,0,NOCOMCOMP,NOCLUSTER,	/* info */
+	{x_("generic"), 0, 2000, NONODEPROTO,NOARCPROTO,NOVARIABLE,0,NOCOMCOMP,NOCLUSTER,	/* info */
 	N_("Miscellaneous interconnect, constraint, and glyph"),						/* description */
 	0, gen_layers, 0, gen_arcprotos, 0, gen_nodeprotos, gen_variables,				/* tables */
 	gen_initprocess, gen_termprocess, 0, 0,											/* control routines */
@@ -149,7 +161,7 @@ TECHNOLOGY el_technologylist[] =
 	NOTECHNOLOGY, NONSTANDARD|STATICTECHNOLOGY, 0, 0},								/* miscellaneous */
 
 	/* NMOS */
-	{"nmos", 0, 4000, NONODEPROTO,NOARCPROTO,NOVARIABLE,0,NOCOMCOMP,NOCLUSTER,		/* info */
+	{x_("nmos"), 0, 4000, NONODEPROTO,NOARCPROTO,NOVARIABLE,0,NOCOMCOMP,NOCLUSTER,		/* info */
 	N_("n-channel MOS (from Mead & Conway)"),										/* description */
 	0, nmos_layers, 0, nmos_arcprotos, 0, nmos_nodeprotos, nmos_variables,			/* tables */
 	nmos_initprocess, 0, 0, 0,														/* control routines */
@@ -159,7 +171,7 @@ TECHNOLOGY el_technologylist[] =
 	NOTECHNOLOGY, NONEGATEDARCS|STATICTECHNOLOGY, 0, 0},							/* miscellaneous */
 
 	/* CMOS */
-	{"cmos", 0, 4000, NONODEPROTO,NOARCPROTO,NOVARIABLE,0,NOCOMCOMP,NOCLUSTER,		/* info */
+	{x_("cmos"), 0, 4000, NONODEPROTO,NOARCPROTO,NOVARIABLE,0,NOCOMCOMP,NOCLUSTER,		/* info */
 	N_("Complementary MOS (old, N-Well, from Griswold)"),							/* description */
 	0, cmos_layers, 0, cmos_arcprotos, 0, cmos_nodeprotos, cmos_variables,			/* tables */
 	cmos_initprocess, 0, 0, 0,														/* control routines */
@@ -169,7 +181,7 @@ TECHNOLOGY el_technologylist[] =
 	NOTECHNOLOGY, NONEGATEDARCS|STATICTECHNOLOGY, 0, 0},							/* miscellaneous */
 
 	/* MOSIS CMOS */
-	{"mocmos", 0, 400,NONODEPROTO,NOARCPROTO,NOVARIABLE,0,&mocmos_parse,NOCLUSTER,	/* info */
+	{x_("mocmos"), 0, 400,NONODEPROTO,NOARCPROTO,NOVARIABLE,0,&mocmos_parse,NOCLUSTER,	/* info */
 	N_("Complementary MOS (from MOSIS, 2-6 metals [4], 1-2 polys [2], flex rules [submicron])"),	/* description */
 	0, mocmos_layers, 0, mocmos_arcprotos, 0, mocmos_nodeprotos, mocmos_variables,	/* tables */
 	mocmos_initprocess, 0, mocmos_setmode, mocmos_request,							/* control routines */
@@ -179,7 +191,7 @@ TECHNOLOGY el_technologylist[] =
 	NOTECHNOLOGY, NONEGATEDARCS|STATICTECHNOLOGY, 0, 0},							/* miscellaneous */
 
 	/* Old MOSIS CMOS */
-	{"mocmosold", 0, 2000,NONODEPROTO,NOARCPROTO,NOVARIABLE,0,&mocmosold_parse,NOCLUSTER,	/* info */
+	{x_("mocmosold"), 0, 2000,NONODEPROTO,NOARCPROTO,NOVARIABLE,0,&mocmosold_parse,NOCLUSTER,	/* info */
 	N_("Complementary MOS (old, from MOSIS, P-Well, double metal)"),				/* description */
 	0, mocmosold_layers, 0, mocmosold_arcprotos, 0, mocmosold_nodeprotos, mocmosold_variables,	/* tables */
 	mocmosold_initprocess, 0, mocmosold_setmode, 0,									/* control routines */
@@ -189,7 +201,7 @@ TECHNOLOGY el_technologylist[] =
 	NOTECHNOLOGY, NONEGATEDARCS|STATICTECHNOLOGY, 0, 0},							/* miscellaneous */
 
 	/* MOSIS CMOS Submicron */
-	{"mocmossub", 0, 400,NONODEPROTO,NOARCPROTO,NOVARIABLE,0,&mocmossub_parse,NOCLUSTER,/* info */
+	{x_("mocmossub"), 0, 400,NONODEPROTO,NOARCPROTO,NOVARIABLE,0,&mocmossub_parse,NOCLUSTER,/* info */
 	N_("Complementary MOS (old, from MOSIS, Submicron, 2-6 metals [4], double poly)"),	/* description */
 	0, mocmossub_layers, 0, mocmossub_arcprotos, 0, mocmossub_nodeprotos, mocmossub_variables,	/* tables */
 	mocmossub_initprocess, 0, mocmossub_setmode, mocmossub_request,					/* control routines */
@@ -199,7 +211,7 @@ TECHNOLOGY el_technologylist[] =
 	NOTECHNOLOGY, NONEGATEDARCS|STATICTECHNOLOGY, 0, 0},							/* miscellaneous */
 
 	/* MOSIS BiCMOS */
-	{"bicmos", 0, 2000, NONODEPROTO,NOARCPROTO,NOVARIABLE,0,NOCOMCOMP,NOCLUSTER,	/* info */
+	{x_("bicmos"), 0, 2000, NONODEPROTO,NOARCPROTO,NOVARIABLE,0,NOCOMCOMP,NOCLUSTER,	/* info */
 	N_("Bipolar/CMOS (from MOSIS, N-Well, SCE Rules)"),								/* description */
 	0, bicmos_layers, 0, bicmos_arcprotos, 0, bicmos_nodeprotos, bicmos_variables,	/* tables */
 	bicmos_initprocess, 0, 0, 0,													/* control routines */
@@ -209,7 +221,7 @@ TECHNOLOGY el_technologylist[] =
 	NOTECHNOLOGY, NONEGATEDARCS|STATICTECHNOLOGY, 0, 0},							/* miscellaneous */
 
 	/* Round MOSIS CMOS */
-	{"rcmos", 0, 2000, NONODEPROTO,NOARCPROTO,NOVARIABLE,0,NOCOMCOMP,NOCLUSTER,		/* info */
+	{x_("rcmos"), 0, 2000, NONODEPROTO,NOARCPROTO,NOVARIABLE,0,NOCOMCOMP,NOCLUSTER,		/* info */
 	N_("Complementary MOS (round, from MOSIS, P-Well, double metal)"),				/* description */
 	0, rcmos_layers, 0, rcmos_arcprotos, 0, rcmos_nodeprotos, rcmos_variables,		/* tables */
 	rcmos_initprocess, 0, 0, 0,														/* control routines */
@@ -219,7 +231,7 @@ TECHNOLOGY el_technologylist[] =
 	NOTECHNOLOGY, NONSTANDARD|NONEGATEDARCS|STATICTECHNOLOGY, 0, 0},				/* miscellaneous */
 
 	/* DOD CMOS (from Gary Lambert) */
-	{"cmosdodn", 0, 2000, NONODEPROTO,NOARCPROTO,NOVARIABLE,0,NOCOMCOMP,NOCLUSTER,	/* info */
+	{x_("cmosdodn"), 0, 2000, NONODEPROTO,NOARCPROTO,NOVARIABLE,0,NOCOMCOMP,NOCLUSTER,	/* info */
 	N_("Complementary MOS (from DOD, P-Well, double metal"),						/* description */
 	0, dodcmosn_layers, 0, dodcmosn_arcprotos, 0, dodcmosn_nodeprotos, dodcmosn_variables,	/* tables */
  	dodcmosn_initprocess, 0, 0, 0,													/* control routines */
@@ -229,7 +241,7 @@ TECHNOLOGY el_technologylist[] =
 	NOTECHNOLOGY, NONEGATEDARCS|STATICTECHNOLOGY, 0, 0},							/* miscellaneous */
 
 	/* bipolar */
-	{"bipolar", 0, 4000, NONODEPROTO,NOARCPROTO,NOVARIABLE,0,NOCOMCOMP,NOCLUSTER,	/* info */
+	{x_("bipolar"), 0, 4000, NONODEPROTO,NOARCPROTO,NOVARIABLE,0,NOCOMCOMP,NOCLUSTER,	/* info */
 	N_("Bipolar (self-aligned, single poly)"),										/* description */
 	0, bipolar_layers, 0, bipolar_arcprotos, 0, bipolar_nodeprotos, bipolar_variables,	/* tables */
 	bipolar_initprocess, 0, 0, 0,													/* control routines */
@@ -239,7 +251,7 @@ TECHNOLOGY el_technologylist[] =
 	NOTECHNOLOGY, NONEGATEDARCS|STATICTECHNOLOGY, 0, 0},							/* miscellaneous */
 
 	/* Schematic capture */
-	{"schematic", 0, 4000, NONODEPROTO,NOARCPROTO,NOVARIABLE,0,&sch_parse,NOCLUSTER,/* info */
+	{x_("schematic"), 0, 4000, NONODEPROTO,NOARCPROTO,NOVARIABLE,0,&sch_parse,NOCLUSTER,/* info */
 	N_("Schematic Capture"),														/* description */
 	0, sch_layers, 0, sch_arcprotos, 0, sch_nodeprotos, sch_variables,				/* tables */
 	sch_initprocess, sch_termprocess, sch_setmode, sch_request,						/* control routines */
@@ -249,7 +261,7 @@ TECHNOLOGY el_technologylist[] =
 	NOTECHNOLOGY, NONSTANDARD|STATICTECHNOLOGY, 0, 0},								/* miscellaneous */
 
 	/* FPGA */
-	{"fpga", 0, 2000, NONODEPROTO,NOARCPROTO,NOVARIABLE,0,&fpga_parse,NOCLUSTER,	/* info */
+	{x_("fpga"), 0, 2000, NONODEPROTO,NOARCPROTO,NOVARIABLE,0,&fpga_parse,NOCLUSTER,	/* info */
 	N_("FPGA Building-Blocks"),														/* description */
 	0, fpga_layers, 0, fpga_arcprotos, 0, fpga_nodeprotos, fpga_variables,			/* tables */
 	fpga_initprocess, fpga_termprocess, fpga_setmode, 0,							/* control routines */
@@ -259,7 +271,7 @@ TECHNOLOGY el_technologylist[] =
 	NOTECHNOLOGY, NONSTANDARD|STATICTECHNOLOGY|NOPRIMTECHNOLOGY, 0, 0},				/* miscellaneous */
 
 	/* Printed Circuit Board */
-	{"pcb", 0, 2540000, NONODEPROTO,NOARCPROTO,NOVARIABLE,0,NOCOMCOMP,NOCLUSTER,	/* info */
+	{x_("pcb"), 0, 2540000, NONODEPROTO,NOARCPROTO,NOVARIABLE,0,NOCOMCOMP,NOCLUSTER,	/* info */
 	N_("Printed Circuit Board (eight-layer)"),										/* description */
 	0, pcb_layers, 0, pcb_arcprotos, 0, pcb_nodeprotos, pcb_variables,				/* tables */
 	pcb_initprocess, 0, 0, 0,														/* control routines */
@@ -269,7 +281,7 @@ TECHNOLOGY el_technologylist[] =
 	NOTECHNOLOGY, NONEGATEDARCS|STATICTECHNOLOGY, 0, 0},							/* miscellaneous */
 
 	/* Artwork */
-	{"artwork", 0, 4000, NONODEPROTO,NOARCPROTO,NOVARIABLE,0,&art_parse,NOCLUSTER,	/* info */
+	{x_("artwork"), 0, 4000, NONODEPROTO,NOARCPROTO,NOVARIABLE,0,&art_parse,NOCLUSTER,	/* info */
 	N_("General Purpose Sketchpad Facility"),										/* description */
 	0, art_layers, 0, art_arcprotos, 0, art_nodeprotos, art_variables,				/* tables */
 	art_initprocess, 0, art_setmode, art_request,									/* control routines */
@@ -279,7 +291,7 @@ TECHNOLOGY el_technologylist[] =
 	NOTECHNOLOGY, NONSTANDARD|NONELECTRICAL|NONEGATEDARCS|STATICTECHNOLOGY, 0, 0},	/* miscellaneous */
 
 	/* Gem Planning */
-	{"gem", 0, 2000, NONODEPROTO,NOARCPROTO,NOVARIABLE,0,NOCOMCOMP,NOCLUSTER,		/* info */
+	{x_("gem"), 0, 2000, NONODEPROTO,NOARCPROTO,NOVARIABLE,0,NOCOMCOMP,NOCLUSTER,		/* info */
 	N_("Temporal Specification Facility (from Lansky)"),							/* description */
 	0, gem_layers, 0, gem_arcprotos, 0, gem_nodeprotos, gem_variables,				/* tables */
 	gem_initprocess, 0, 0, 0,														/* control routines */
@@ -289,7 +301,7 @@ TECHNOLOGY el_technologylist[] =
 	NOTECHNOLOGY, NONSTANDARD|NONELECTRICAL|NODIRECTIONALARCS|NONEGATEDARCS|STATICTECHNOLOGY, 0, 0},/* miscellaneous */
 
 	/* Digital Filter */
-	{"efido", 0, 20000, NONODEPROTO,NOARCPROTO,NOVARIABLE,0,NOCOMCOMP,NOCLUSTER,	/* info */
+	{x_("efido"), 0, 20000, NONODEPROTO,NOARCPROTO,NOVARIABLE,0,NOCOMCOMP,NOCLUSTER,	/* info */
 	N_("Digital Filter Facility (from Kroeker)"),									/* description */
 	0, efido_layers, 0, efido_arcprotos, 0, efido_nodeprotos, efido_variables,		/* tables */
 	efido_initprocess, 0, 0, 0,														/* control routines */
@@ -298,6 +310,26 @@ TECHNOLOGY el_technologylist[] =
 	0, 0, 0, 0,																		/* arc routines */
 	NOTECHNOLOGY, NONEGATEDARCS|STATICTECHNOLOGY, 0, 0},							/* miscellaneous */
 
+#ifdef FORCESUNTOOLS
+	{x_("ziptronics"), 0, 2000, NONODEPROTO,NOARCPROTO,NOVARIABLE,0,NOCOMCOMP,NOCLUSTER,	/* info */
+	N_("Ziptronics Metal Layers with Micron SRAM Wafer"),							/* description */
+	0, ziptronics_layers, 0, ziptronics_arcprotos, 0, ziptronics_nodeprotos, ziptronics_variables,	/* tables */
+	0, 0, 0, 0,																		/* control routines */
+	0, 0, 0, 0, 0, 0, 0,															/* node routines */
+	0,																				/* port routine */
+	0, 0, 0, 0,																		/* arc routines */
+	NOTECHNOLOGY, NONEGATEDARCS|STATICTECHNOLOGY, 0, 0},							/* miscellaneous */
+
+	{x_("epic7s"), 0, 40, NONODEPROTO,NOARCPROTO,NOVARIABLE,0,NOCOMCOMP,NOCLUSTER,	/* info */
+	N_("Epic7S from Texas Instruments (90nm, 9 metal, 1 poly)"),					/* description */
+	0, epic7s_layers, 0, epic7s_arcprotos, 0, epic7s_nodeprotos, epic7s_variables,	/* tables */
+	0, 0, 0, 0,																		/* control routines */
+	0, 0, 0, 0, 0, 0, 0,															/* node routines */
+	0,																				/* port routine */
+	0, 0, 0, 0,																		/* arc routines */
+	NOTECHNOLOGY, NONEGATEDARCS|STATICTECHNOLOGY, 0, 0},							/* miscellaneous */
+#endif
+
 	/* termination */
 	{NULL, 0, 0, NULL, NULL, NULL, 0, NULL, NULL,									/* info */
 	NULL,																			/* description */
