@@ -84,7 +84,7 @@ ARCINST *aconnect(GEOM *fromgeom, PORTPROTO *frompp, GEOM *togeom, PORTPROTO *to
 	REGISTER INTBIG j, t, ans, gent;
 	REGISTER INTBIG i, bestdist, bestx, besty, usecontact;
 	INTBIG x, y;
-	char *result[2];
+	CHAR *result[2];
 	extern COMCOMP us_noyesp;
 	REGISTER void *infstr;
 
@@ -101,32 +101,35 @@ ARCINST *aconnect(GEOM *fromgeom, PORTPROTO *frompp, GEOM *togeom, PORTPROTO *to
 		if (!fromgeom->entryisnode) ai = fromgeom->entryaddr.ai; else
 			ai = togeom->entryaddr.ai;
 		ni = NONODEINST;
-		if (fromgeom->entryisnode) ni = fromgeom->entryaddr.ni;
-		if (togeom->entryisnode) ni = togeom->entryaddr.ni;
+		if (fromgeom->entryisnode) { ni = fromgeom->entryaddr.ni;   pp = frompp; }
+		if (togeom->entryisnode) { ni = togeom->entryaddr.ni;   pp = topp; }
 
 		if (ni != NONODEINST && ni->proto->primindex == 0)
 		{
 			/* found facet connected to arcinst: search for closest portinst */
-			bestdist = MAXINTBIG;
-			for(fpt = ni->proto->firstportproto; fpt != NOPORTPROTO; fpt = fpt->nextportproto)
+			if (pp == NOPORTPROTO)
 			{
-				/* see if the arcinst can connect at this portinst */
-				for(i=0; fpt->connects[i] != NOARCPROTO; i++)
-					if (fpt->connects[i] == ai->proto) break;
-				if (fpt->connects[i] == NOARCPROTO) continue;
+				bestdist = MAXINTBIG;
+				for(fpt = ni->proto->firstportproto; fpt != NOPORTPROTO; fpt = fpt->nextportproto)
+				{
+					/* see if the arcinst can connect at this portinst */
+					for(i=0; fpt->connects[i] != NOARCPROTO; i++)
+						if (fpt->connects[i] == ai->proto) break;
+					if (fpt->connects[i] == NOARCPROTO) continue;
 
-				/* compute position for closest applicable portinst */
-				i = us_portdistance(ni, fpt, prefx, prefy, &x, &y,
-					defaultarcwidth(typ) - arcprotowidthoffset(typ), FALSE);
-				if (i > bestdist) continue;
-				bestdist = i;   bestx = x;   besty = y;
-			}
+					/* compute position for closest applicable portinst */
+					i = us_portdistance(ni, fpt, prefx, prefy, &x, &y,
+						defaultarcwidth(typ) - arcprotowidthoffset(typ), FALSE);
+					if (i > bestdist) continue;
+					bestdist = i;   bestx = x;   besty = y;
+				}
 
-			/* adjust prefered position to closest port (manhattan only!!!) */
-			if (bestdist < MAXINTBIG)
-			{
-				if (ai->end[0].xpos == ai->end[1].xpos) prefy = besty;
-				if (ai->end[0].ypos == ai->end[1].ypos) prefx = bestx;
+				/* adjust prefered position to closest port (manhattan only!!!) */
+				if (bestdist < MAXINTBIG)
+				{
+					if (ai->end[0].xpos == ai->end[1].xpos) prefy = besty;
+					if (ai->end[0].ypos == ai->end[1].ypos) prefx = bestx;
+				}
 			}
 		}
 	}
@@ -813,7 +816,7 @@ ARCINST *us_directarcinst(NODEINST *fromnodeinst, PORTPROTO *fromppt, ARCPROTO *
 					tonodeinst, toportproto, besttx, bestty, fromarcproto, wid);
 				if (ai == NOARCINST) return(NOARCINST);
 				if (report)
-					us_reportarcscreated(0, 1, fromarcproto->protoname, 0, "");
+					us_reportarcscreated(0, 1, fromarcproto->protoname, 0, x_(""));
 			}
 			return(ai);
 		} else
@@ -836,28 +839,28 @@ ARCINST *us_directarcinst(NODEINST *fromnodeinst, PORTPROTO *fromppt, ARCPROTO *
  * ignore that part of the message.  If "type1" is zero, ignore that part of the message.
  * Also plays a sound appropriate to the number of arcs created.
  */
-void us_reportarcscreated(char *who, INTBIG numarcs1, char *type1, INTBIG numarcs2, char *type2)
+void us_reportarcscreated(CHAR *who, INTBIG numarcs1, CHAR *type1, INTBIG numarcs2, CHAR *type2)
 {
 	REGISTER void *infstr;
 	REGISTER INTBIG totalcreated;
 
 	infstr = initinfstr();
-	if (who != 0) formatinfstr(infstr, "%s: ", who);
+	if (who != 0) formatinfstr(infstr, x_("%s: "), who);
 	if (numarcs2 > 0)
 	{
 		formatinfstr(infstr, _("Created %ld %s and %ld %s %s"), numarcs1, type1, numarcs2, type2,
-			makeplural("arc", numarcs2));
+			makeplural(x_("arc"), numarcs2));
 	} else
 	{
 		if (type1 == 0)
 		{
-			formatinfstr(infstr, _("Created %ld %s"), numarcs1, makeplural("arc", numarcs1));
+			formatinfstr(infstr, _("Created %ld %s"), numarcs1, makeplural(x_("arc"), numarcs1));
 		} else
 		{
-			formatinfstr(infstr, _("Created %ld %s %s"), numarcs1, type1, makeplural("arc", numarcs1));
+			formatinfstr(infstr, _("Created %ld %s %s"), numarcs1, type1, makeplural(x_("arc"), numarcs1));
 		}
 	}
-	ttyputmsg("%s", returninfstr(infstr));
+	ttyputmsg(x_("%s"), returninfstr(infstr));
 	totalcreated = numarcs1 + numarcs2;
 	if (totalcreated == 1)
 	{
@@ -1072,7 +1075,7 @@ ARCINST *us_onebend(NODEINST *fromnodeinst, PORTPROTO *fromppt, ARCPROTO *fromar
 			{
 				if (fromarcproto == toarcproto)
 				{
-					us_reportarcscreated(0, 2, fromarcproto->protoname, 0, "");
+					us_reportarcscreated(0, 2, fromarcproto->protoname, 0, x_(""));
 				} else
 				{
 					us_reportarcscreated(0, 1, fromarcproto->protoname, 1, toarcproto->protoname);
@@ -1207,7 +1210,7 @@ ARCINST *us_twobend(NODEINST *fromnodeinst, PORTPROTO *fromppt, ARCPROTO *fromar
 		if (abs(bestfx-besttx) > abs(bestfy-bestty)) i = 0; else i = 900;
 	}
 	i = (i+450) % 1800;   if (i < 0) i += 1800;
-	gridalign(&prefx, &prefx, 1);
+	gridalign(&prefx, &prefx, 1, fromnodeinst->parent);
 	if (i < 900)
 	{
 		if (bestty == bestfy) horizontaljog = TRUE; else
@@ -1273,7 +1276,7 @@ ARCINST *us_twobend(NODEINST *fromnodeinst, PORTPROTO *fromppt, ARCPROTO *fromar
 		{
 			if (fromarcproto == toarcproto)
 			{
-				us_reportarcscreated(0, 3, fromarcproto->protoname, 0, "");
+				us_reportarcscreated(0, 3, fromarcproto->protoname, 0, x_(""));
 			} else
 			{
 				us_reportarcscreated(0, 2, fromarcproto->protoname, 1, toarcproto->protoname);
@@ -1494,7 +1497,7 @@ NODEINST *us_getnodeonarcinst(GEOM **ipos, PORTPROTO **ipp, GEOM *othergeom,
 	REGISTER NODEPROTO *np;
 	REGISTER GEOM *geom;
 	static NODEINST node;
-	REGISTER INTBIG w, wid, owid, lx, hx, ly, hy, delta;
+	REGISTER INTBIG w, wid, owid, lx, hx, ly, hy, delta, fun;
 	INTBIG pxs, pys;
 	static POLYGON *poly = NOPOLYGON;
 
@@ -1508,21 +1511,24 @@ NODEINST *us_getnodeonarcinst(GEOM **ipos, PORTPROTO **ipp, GEOM *othergeom,
 	if (othergeom->entryisnode)
 	{
 		ni = othergeom->entryaddr.ni;
-		if (otherport != NOPORTPROTO)
+		if (ni->proto->primindex != 0)
 		{
-			/* make sure there is a polygon */
-			(void)needstaticpolygon(&poly, 1, us_tool->cluster);
+			if (otherport != NOPORTPROTO)
+			{
+				/* make sure there is a polygon */
+				(void)needstaticpolygon(&poly, 1, us_tool->cluster);
 
-			/* get the polygon describing the port */
-			poly->xv[0] = prefx;   poly->yv[0] = prefy;   poly->count = 1;
-			shapeportpoly(ni, otherport, poly, TRUE);
+				/* get the polygon describing the port */
+				poly->xv[0] = prefx;   poly->yv[0] = prefy;   poly->count = 1;
+				shapeportpoly(ni, otherport, poly, TRUE);
 
-			/* determine the center of the polygon */
-			getcenter(poly, &prefx, &prefy);
-		} else if (ni->proto->primindex != 0)
-		{
-			prefx = (ni->lowx + ni->highx) / 2;
-			prefy = (ni->lowy + ni->highy) / 2;
+				/* determine the center of the polygon */
+				getcenter(poly, &prefx, &prefy);
+			} else if (ni->proto->primindex != 0)
+			{
+				prefx = (ni->lowx + ni->highx) / 2;
+				prefy = (ni->lowy + ni->highy) / 2;
+			}
 		}
 	}
 
@@ -1574,27 +1580,31 @@ NODEINST *us_getnodeonarcinst(GEOM **ipos, PORTPROTO **ipp, GEOM *othergeom,
 	us_getproperconsize(np, ap, wid, ap, wid, &pxs, &pys);
 
 	/* make contact asymmetric if other arc is wider */
-	owid = wid;
-	if (othergeom->entryisnode)
+	fun = (np->userbits&NFUNCTION) >> NFUNCTIONSH;
+	if (fun != NPPIN)
 	{
-		w = us_widestarcinst(ap, othergeom->entryaddr.ni, otherport);
-		if (w > owid) owid = w;
-	} else
-	{
-		if (othergeom->entryaddr.ai->width > owid)
-			owid = othergeom->entryaddr.ai->width;
-	}
-	if (owid > ai->width)
-	{
-		delta = owid - ai->width;
-		if (ai->end[0].xpos == ai->end[1].xpos)
+		owid = wid;
+		if (othergeom->entryisnode)
 		{
-			/* vertical arc, make contact larger in Y */
-			pys += delta;
-		} else if (ai->end[0].ypos == ai->end[1].ypos)
+			w = us_widestarcinst(ap, othergeom->entryaddr.ni, otherport);
+			if (w > owid) owid = w;
+		} else
 		{
-			/* horizontal arc, make contact larger in x */
-			pxs += delta;
+			if (othergeom->entryaddr.ai->width > owid)
+				owid = othergeom->entryaddr.ai->width;
+		}
+		if (owid > ai->width)
+		{
+			delta = owid - ai->width;
+			if (ai->end[0].xpos == ai->end[1].xpos)
+			{
+				/* vertical arc, make contact larger in Y */
+				pys += delta;
+			} else if (ai->end[0].ypos == ai->end[1].ypos)
+			{
+				/* horizontal arc, make contact larger in x */
+				pxs += delta;
+			}
 		}
 	}
 
@@ -1903,12 +1913,12 @@ void us_getproperconsize(NODEPROTO *con, ARCPROTO *fromap, INTBIG fwid,
 	tolayer = poly->layer;
 	truetwid = twid - arcprotowidthoffset(toap);
 
-	fromdiff = todiff = 0;
 	ni = &node;   initdummynode(ni);
 	ni->proto = con;
 	ni->lowx = con->lowx;   ni->highx = con->highx;
 	ni->lowy = con->lowy;   ni->highy = con->highy;
 	tot = nodepolys(ni, 0, NOWINDOWPART);
+	fromdiff = todiff = 0;
 	for(i=0; i<tot; i++)
 	{
 		shapenodepoly(ni, i, poly);
@@ -1947,7 +1957,7 @@ void us_portposition(NODEINST *ni, PORTPROTO *pp, INTBIG *x, INTBIG *y)
 	(void)needstaticpolygon(&poly, 4, us_tool->cluster);
 	portposition(ni, pp, x, y);
 	ax = *x;   ay = *y;
-	gridalign(&ax, &ay, 1);
+	gridalign(&ax, &ay, 1, ni->parent);
 	if (ax != *x || ay != *y)
 	{
 		shapeportpoly(ni, pp, poly, FALSE);
@@ -2001,10 +2011,9 @@ BOOLEAN us_figuredrawpath(GEOM *fromgeom, PORTPROTO *fromport, GEOM *togeom, POR
 {
 	static POLYGON *poly = NOPOLYGON, *poly2 = NOPOLYGON;
 	REGISTER NODEINST *tonode, *fromnode;
-	INTBIG flx, fhx, fly, fhy, tlx, tly, thx, thy, lx, hx, ly, hy, overx[2], overy[2],
-		cornerx[4], cornery[4];
+	INTBIG flx, fhx, fly, fhy, tlx, tly, thx, thy, lx, hx, ly, hy, overx[2], overy[2];
 	REGISTER INTBIG k, overcount, fx, fy, tx, ty, c1x, c1y, c2x, c2y,
-		c1dist, c2dist, pxs, pys, dist, ox, oy, i, bestdist, j, x, y;
+		c1dist, c2dist, pxs, pys, dist, ox, oy, x, y;
 
 	/* get polygon */
 	(void)needstaticpolygon(&poly, 4, us_tool->cluster);
@@ -2019,7 +2028,7 @@ BOOLEAN us_figuredrawpath(GEOM *fromgeom, PORTPROTO *fromport, GEOM *togeom, POR
 	fromnode = fromgeom->entryaddr.ni;
 
 	ox = *xcur;   oy = *ycur;
-	gridalign(xcur, ycur, 1);
+	gridalign(xcur, ycur, 1, fromnode->parent);
 
 	/* user dragged over another object: connect them */
 	tonode = us_getnodeonarcinst(&togeom, &toport, fromgeom,
@@ -2095,6 +2104,8 @@ BOOLEAN us_figuredrawpath(GEOM *fromgeom, PORTPROTO *fromport, GEOM *togeom, POR
 				pxs = c2x;   pys = c2y;
 			}
 		}
+
+#if 0		/* exaggerate corner by pushing it away from the center */
 		cornerx[0] = lx-1;   cornery[0] = ly-1;
 		cornerx[1] = lx-1;   cornery[1] = hy+1;
 		cornerx[2] = hx+1;   cornery[2] = hy+1;
@@ -2112,7 +2123,7 @@ BOOLEAN us_figuredrawpath(GEOM *fromgeom, PORTPROTO *fromport, GEOM *togeom, POR
 		}
 		pxs = cornerx[j]*2 - (lx+hx)/2;
 		pys = cornery[j]*2 - (ly+hy)/2;
-
+#endif
 		/* set coordinate in the center if the ports overlap in either axis */
 		if (fromport != NOPORTPROTO)
 		{
