@@ -45,69 +45,70 @@ typedef struct
 {
 	INTBIG  type;
 	INTBIG  addr;
-	char   *name;
+	CHAR   *name;
 } VARLIST;
 
 /* these variables should not exist */
 VARLIST us_deprecatedvariables[] =
 {
-	{VNODEPROTO, 0,                 "NET_last_good_ncc"},
-	{VNODEPROTO, 0,                 "NET_last_good_ncc_facet"},
-	{VNODEPROTO, 0,                 "SIM_window_signal_order"},
-	{VTOOL,      (INTBIG)&net_tool, "NET_auto_name"},
-	{VTOOL,      (INTBIG)&net_tool, "NET_use_port_names"},
-	{VTOOL,      (INTBIG)&net_tool, "NET_compare_hierarchy"},
-	{VTOOL,      (INTBIG)&net_tool, "D"},
-	{VTOOL,      (INTBIG)&net_tool, "<"},
-	{VTOOL,      (INTBIG)&net_tool, "\001"},
-	{VTOOL,      (INTBIG)&us_tool,  "USER_alignment_obj"},
-	{VTOOL,      (INTBIG)&us_tool,  "USER_alignment_edge"},
-	{VTOOL,      (INTBIG)&sim_tool, "SIM_fasthenry_defthickness"},
-	{0, 0}
+	{VNODEPROTO, 0,                 x_("NET_last_good_ncc")},
+	{VNODEPROTO, 0,                 x_("NET_last_good_ncc_facet")},
+	{VNODEPROTO, 0,                 x_("SIM_window_signal_order")},
+	{VTOOL,      (INTBIG)&net_tool, x_("NET_auto_name")},
+	{VTOOL,      (INTBIG)&net_tool, x_("NET_use_port_names")},
+	{VTOOL,      (INTBIG)&net_tool, x_("NET_compare_hierarchy")},
+	{VTOOL,      (INTBIG)&net_tool, x_("D")},
+	{VTOOL,      (INTBIG)&net_tool, x_("<")},
+	{VTOOL,      (INTBIG)&net_tool, x_("\001")},
+	{VTOOL,      (INTBIG)&us_tool,  x_("USER_alignment_obj")},
+	{VTOOL,      (INTBIG)&us_tool,  x_("USER_alignment_edge")},
+	{VTOOL,      (INTBIG)&sim_tool, x_("SIM_fasthenry_defthickness")},
+	{VTOOL,      (INTBIG)&dr_tool,  x_("DRC_pointout")},
+	{0, 0, 0}
 };
 
 /* these variables should always have VDONTSAVE set on them */
 VARLIST us_temporaryvariables[] =
 {
-	{VTECHNOLOGY,0,                 "DRC_max_distances"},
-	{VTECHNOLOGY,0,                 "TECH_arc_width_offset"},
-	{VTECHNOLOGY,0,                 "TECH_node_width_offset"},
-	{VTECHNOLOGY,0,                 "TECH_layer_names"},
-	{VTECHNOLOGY,0,                 "TECH_layer_function"},
-	{VTECHNOLOGY,0,                 "USER_layer_letters"},
-	{VLIBRARY,   0,                 "LIB_former_version"},
-	{VNODEINST,  0,                 "NODE_original_name"},
-	{VNODEPROTO, 0,                 "USER_descent_path"},
-	{VNODEPROTO, 0,                 "USER_descent_view"},
-	{VTOOL,      (INTBIG)&dr_tool, "DRC_pointout"},
-	{VTOOL,      (INTBIG)&dr_tool, "DRC_ignore_list"},
-	{VTOOL,      (INTBIG)&us_tool,  "USER_current_constraint"},
-	{VTOOL,      (INTBIG)&us_tool,  "USER_have_lisp"},
-	{VTOOL,      (INTBIG)&us_tool,  "USER_have_tcl"},
-	{VTOOL,      (INTBIG)&us_tool,  "USER_have_java"},
-	{VTOOL,      (INTBIG)&us_tool,  "USER_have_cadence"},
-	{VTOOL,      (INTBIG)&us_tool,  "USER_have_suntools"},
-	{VTOOL,      (INTBIG)&us_tool,  "USER_macro_*"},
-	{VTOOL,      (INTBIG)&us_tool,  "USER_highlight_*"},
-	{VTOOL,      (INTBIG)&us_tool,  "USER_binding_popup_*"},
-	{VTOOL,      (INTBIG)&us_tool,  "USER_windowview_*"},
-	{VTOOL,      (INTBIG)&us_tool,  "USER_machine"},
-	{VTOOL,      (INTBIG)&us_tool,  "USER_color_map"},
-	{VTOOL,      (INTBIG)&us_tool,  "USER_binding_keys"},
-	{VTOOL,      (INTBIG)&us_tool,  "USER_binding_buttons"},
-	{VTOOL,      (INTBIG)&us_tool,  "USER_binding_buttons"},
-	{VTOOL,      (INTBIG)&us_tool,  "USER_current_window"},
-	{VTOOL,      (INTBIG)&us_tool,  "USER_current_technology"},
-	{VTOOL,      (INTBIG)&us_tool,  "USER_current_node"},
-	{VTOOL,      (INTBIG)&us_tool,  "USER_highlighted"},
-	{VTOOL,      (INTBIG)&us_tool,  "USER_highlightstack"},
-	{VTOOL,      (INTBIG)&us_tool,  "USER_ignore_option_changes"},
-	{VTOOL,      (INTBIG)&us_tool,  "USER_interactive_angle"},
-	{VTOOL,      (INTBIG)&us_tool,  "USER_macrobuilding"},
-	{VTOOL,      (INTBIG)&us_tool,  "USER_macrorunning"},
-	{VTOOL,      (INTBIG)&us_tool,  "USER_menu_x"},
-	{VTOOL,      (INTBIG)&us_tool,  "USER_menu_y"},
-	{VTOOL,      (INTBIG)&us_tool,  "USER_menu_position"},
+	{VTECHNOLOGY,0,                 x_("DRC_max_distances")},
+	{VTECHNOLOGY,0,                 x_("TECH_arc_width_offset")},
+	{VTECHNOLOGY,0,                 x_("TECH_node_width_offset")},
+	{VTECHNOLOGY,0,                 x_("TECH_layer_names")},
+	{VTECHNOLOGY,0,                 x_("TECH_layer_function")},
+	{VTECHNOLOGY,0,                 x_("USER_layer_letters")},
+	{VLIBRARY,   0,                 x_("LIB_former_version")},
+	{VNODEINST,  0,                 x_("NODE_original_name")},
+	{VNODEPROTO, 0,                 x_("USER_descent_path")},
+	{VNODEPROTO, 0,                 x_("USER_descent_view")},
+	{VTOOL,      (INTBIG)&dr_tool, x_("DRC_pointout")},
+	{VTOOL,      (INTBIG)&dr_tool, x_("DRC_ignore_list")},
+	{VTOOL,      (INTBIG)&us_tool,  x_("USER_current_constraint")},
+	{VTOOL,      (INTBIG)&us_tool,  x_("USER_have_lisp")},
+	{VTOOL,      (INTBIG)&us_tool,  x_("USER_have_tcl")},
+	{VTOOL,      (INTBIG)&us_tool,  x_("USER_have_java")},
+	{VTOOL,      (INTBIG)&us_tool,  x_("USER_have_cadence")},
+	{VTOOL,      (INTBIG)&us_tool,  x_("USER_have_suntools")},
+	{VTOOL,      (INTBIG)&us_tool,  x_("USER_macro_*")},
+	{VTOOL,      (INTBIG)&us_tool,  x_("USER_highlight_*")},
+	{VTOOL,      (INTBIG)&us_tool,  x_("USER_binding_popup_*")},
+	{VTOOL,      (INTBIG)&us_tool,  x_("USER_windowview_*")},
+	{VTOOL,      (INTBIG)&us_tool,  x_("USER_machine")},
+	{VTOOL,      (INTBIG)&us_tool,  x_("USER_color_map")},
+	{VTOOL,      (INTBIG)&us_tool,  x_("USER_binding_keys")},
+	{VTOOL,      (INTBIG)&us_tool,  x_("USER_binding_buttons")},
+	{VTOOL,      (INTBIG)&us_tool,  x_("USER_binding_buttons")},
+	{VTOOL,      (INTBIG)&us_tool,  x_("USER_current_window")},
+	{VTOOL,      (INTBIG)&us_tool,  x_("USER_current_technology")},
+	{VTOOL,      (INTBIG)&us_tool,  x_("USER_current_node")},
+	{VTOOL,      (INTBIG)&us_tool,  x_("USER_highlighted")},
+	{VTOOL,      (INTBIG)&us_tool,  x_("USER_highlightstack")},
+	{VTOOL,      (INTBIG)&us_tool,  x_("USER_ignore_option_changes")},
+	{VTOOL,      (INTBIG)&us_tool,  x_("USER_interactive_angle")},
+	{VTOOL,      (INTBIG)&us_tool,  x_("USER_macrobuilding")},
+	{VTOOL,      (INTBIG)&us_tool,  x_("USER_macrorunning")},
+	{VTOOL,      (INTBIG)&us_tool,  x_("USER_menu_x")},
+	{VTOOL,      (INTBIG)&us_tool,  x_("USER_menu_y")},
+	{VTOOL,      (INTBIG)&us_tool,  x_("USER_menu_position")},
 };
 
 /* prototypes for local routines */
@@ -115,7 +116,7 @@ static void    us_checklibrary(LIBRARY*, BOOLEAN, INTBIG*, INTBIG*);
 static BOOLEAN us_checkvariables(INTBIG, INTBIG, INTSML*, VARIABLE*, LIBRARY*);
 static INTBIG  us_checkrtree(RTNODE*, RTNODE*, NODEPROTO*, INTBIG*, INTBIG*);
 static BOOLEAN us_checktextdescript(INTBIG, INTBIG, UINTBIG *descript);
-static char   *us_describeobject(INTBIG addr, INTBIG type);
+static CHAR   *us_describeobject(INTBIG addr, INTBIG type);
 static BOOLEAN us_checkforuniquenodenames(NODEPROTO *np);
 
 void us_checkdatabase(BOOLEAN verbose)
@@ -130,8 +131,8 @@ void us_checkdatabase(BOOLEAN verbose)
 	REGISTER TOOL *tool;
 	REGISTER ARCPROTO *ap;
 	REGISTER VIEW *v;
-	REGISTER char *ch;
-	char *cellname;
+	REGISTER CHAR *ch;
+	CHAR *cellname;
 	REGISTER void *infstr;
 
 	us_clearhighlightcount();
@@ -255,7 +256,7 @@ void us_checkdatabase(BOOLEAN verbose)
 			warnings++;
 		if ((v->viewstate&MULTIPAGEVIEW) != 0)
 		{
-			if (namesamen(v->viewname, "schematic-page-", 15) != 0)
+			if (namesamen(v->viewname, x_("schematic-page-"), 15) != 0)
 			{
 				ttyputmsg(_("    View %s should not be multipage"), v->viewname);
 				v->viewstate &= ~MULTIPAGEVIEW;
@@ -263,7 +264,7 @@ void us_checkdatabase(BOOLEAN verbose)
 			}
 		} else
 		{
-			if (namesamen(v->viewname, "schematic-page-", 15) == 0)
+			if (namesamen(v->viewname, x_("schematic-page-"), 15) == 0)
 			{
 				ttyputmsg(_("    View %s should be multipage"), v->viewname);
 				v->viewstate |= MULTIPAGEVIEW;
@@ -282,7 +283,7 @@ void us_checkdatabase(BOOLEAN verbose)
 		if (*c->cellname == 0)
 		{
 			ttyputmsg(_("Library %s: null cell name; renamed to 'NULL'"), lib->libname);
-			(void)setval((INTBIG)c, VCELL, "cellname", (INTBIG)"NULL", VSTRING);
+			(void)setval((INTBIG)c, VCELL, x_("cellname"), (INTBIG)x_("NULL"), VSTRING);
 			warnings++;
 			lib->userbits |= LIBCHANGEDMAJOR;
 		}
@@ -313,16 +314,16 @@ void us_checkdatabase(BOOLEAN verbose)
 		for(;;)
 		{
 			cellname = c->cellname;
-			c->cellname = "";
+			c->cellname = x_("");
 			oc = db_findcellname(cellname, lib);
 			c->cellname = cellname;
 			if (oc == NOCELL) break;
 			ttyputmsg(_("Library %s, cell %s: duplicate name"), lib->libname, c->cellname);
 			infstr = initinfstr();
 			addstringtoinfstr(infstr, c->cellname);
-			addstringtoinfstr(infstr, ".0");
+			addstringtoinfstr(infstr, x_(".0"));
 			nextchangequiet();
-			(void)setval((INTBIG)c, VCELL, "cellname", (INTBIG)returninfstr(infstr), VSTRING);
+			(void)setval((INTBIG)c, VCELL, x_("cellname"), (INTBIG)returninfstr(infstr), VSTRING);
 			warnings++;
 			lib->userbits |= LIBCHANGEDMAJOR;
 		}
@@ -551,13 +552,13 @@ void us_checkdatabase(BOOLEAN verbose)
 
 void us_checklibrary(LIBRARY *curlib, BOOLEAN verbose, INTBIG *warnings, INTBIG *errors)
 {
-	REGISTER NODEPROTO *np, *onp;
+	REGISTER NODEPROTO *np, *onp, *cnp;
 	REGISTER PORTPROTO *pp, *opp, *subpp, *lpp;
 	REGISTER PORTARCINST *pi, *lpi;
 	REGISTER PORTEXPINST *pe, *lpe;
 	REGISTER NODEINST *ni, *subni;
 	REGISTER ARCINST *ai, *oai, *lastai;
-	REGISTER VARIABLE *var;
+	REGISTER VARIABLE *var, *ovar;
 	REGISTER TECHNOLOGY *tech;
 	REGISTER NETWORK *net;
 	REGISTER VIEW *v;
@@ -569,8 +570,8 @@ void us_checklibrary(LIBRARY *curlib, BOOLEAN verbose, INTBIG *warnings, INTBIG
 	INTBIG lx, hx, ly, hy, position[2], growx, growy, shiftx, shifty;
 	BOOLEAN canscalefonts;
 	XARRAY trans;
-	char newframeinfo[10];
-	REGISTER char *ch, *ch2;
+	CHAR newframeinfo[10];
+	REGISTER CHAR *ch, *ch2;
 	REGISTER void *infstr1, *infstr2;
 	static POLYGON *poly = NOPOLYGON;
 
@@ -609,7 +610,7 @@ void us_checklibrary(LIBRARY *curlib, BOOLEAN verbose, INTBIG *warnings, INTBIG
 		var = getvalkey((INTBIG)np, VNODEPROTO, VSTRING, el_schematic_page_size_key);
 		if (var != NOVARIABLE)
 		{
-			strncpy(newframeinfo, (char *)var->addr, 9);
+			estrncpy(newframeinfo, (CHAR *)var->addr, 9);
 			i = 0;
 			if ((newframeinfo[0] < 'a' || newframeinfo[0] > 'e') && newframeinfo[0] != 'h')
 			{
@@ -629,7 +630,7 @@ void us_checklibrary(LIBRARY *curlib, BOOLEAN verbose, INTBIG *warnings, INTBIG
 			if (i != 0)
 			{
 				ttyputmsg(_("Facet %s: bad frame size info (was '%s', now '%s')"),
-					describenodeproto(np), (char *)var->addr, newframeinfo);
+					describenodeproto(np), (CHAR *)var->addr, newframeinfo);
 				setvalkey((INTBIG)np, VNODEPROTO, el_schematic_page_size_key,
 					(INTBIG)newframeinfo, VSTRING);
 				(*warnings)++;
@@ -721,7 +722,7 @@ void us_checklibrary(LIBRARY *curlib, BOOLEAN verbose, INTBIG *warnings, INTBIG
 			if (*pp->protoname == 0)
 			{
 				ttyputmsg(_("Facet %s: null port name, renamed to 'NULL'"), describenodeproto(np));
-				(void)allocstring(&pp->protoname, "NULL", np->cell->cluster);
+				(void)allocstring(&pp->protoname, x_("NULL"), np->cell->cluster);
 				(*warnings)++;
 				curlib->userbits |= LIBCHANGEDMAJOR;
 			}
@@ -843,20 +844,20 @@ void us_checklibrary(LIBRARY *curlib, BOOLEAN verbose, INTBIG *warnings, INTBIG
 			if (pp->connects != pp->subportproto->connects)
 			{
 				infstr1 = initinfstr();
-				if (pp->connects == &gen_upconn[1]) addstringtoinfstr(infstr1, "ALL-PORTS"); else
+				if (pp->connects == &gen_upconn[1]) addstringtoinfstr(infstr1, x_("ALL-PORTS")); else
 				{
 					for(i=0; pp->connects[i] != NOARCPROTO; i++)
 					{
-						if (i != 0) addstringtoinfstr(infstr1, ",");
+						if (i != 0) addstringtoinfstr(infstr1, x_(","));
 						addstringtoinfstr(infstr1, pp->connects[i]->protoname);
 					}
 				}
 				infstr2 = initinfstr();
-				if (pp->subportproto->connects == &gen_upconn[1]) addstringtoinfstr(infstr2, "ALL-PORTS"); else
+				if (pp->subportproto->connects == &gen_upconn[1]) addstringtoinfstr(infstr2, x_("ALL-PORTS")); else
 				{
 					for(i=0; pp->subportproto->connects[i] != NOARCPROTO; i++)
 					{
-						if (i != 0) addstringtoinfstr(infstr2, ",");
+						if (i != 0) addstringtoinfstr(infstr2, x_(","));
 						addstringtoinfstr(infstr2, pp->subportproto->connects[i]->protoname);
 					}
 				}
@@ -1525,11 +1526,43 @@ void us_checklibrary(LIBRARY *curlib, BOOLEAN verbose, INTBIG *warnings, INTBIG
 				curlib->userbits |= LIBCHANGEDMAJOR;
 			}
 
+			/* make sure parameters on the node also exist on the facet */
+			for(i=0; i<ni->numvar; i++)
+			{
+				var = &ni->firstvar[i];
+				if (TDGETISPARAM(var->textdescript) != 0) break;
+			}
+			if (i < ni->numvar)
+			{
+				/* found parameter on the node: check against prototype */
+				onp = ni->proto;
+				cnp = contentsview(onp);
+				if (cnp != NONODEPROTO) onp = cnp;
+				for(i=0; i<ni->numvar; i++)
+				{
+					var = &ni->firstvar[i];
+					if (TDGETISPARAM(var->textdescript) == 0) continue;
+					for(j=0; j<onp->numvar; j++)
+					{
+						ovar = &onp->firstvar[j];
+						if (TDGETISPARAM(ovar->textdescript) == 0) continue;
+						if (ovar->key == var->key) break;
+					}
+					if (j >= onp->numvar)
+					{
+						ttyputmsg(_("Facet %s, node %s, variable %s: not a parameter"),
+							describenodeproto(np), describenodeinst(ni), makename(var->key));
+						(*warnings)++;
+						TDSETISPARAM(var->textdescript, 0);
+					}
+				}
+			}
+
 			/* check for null names on nodes */
 			var = getvalkey((INTBIG)ni, VNODEINST, VSTRING, el_node_name_key);
 			if (var != NOVARIABLE)
 			{
-				ch = (char *)var->addr;
+				ch = (CHAR *)var->addr;
 				while (*ch == ' ' || *ch == '\t') ch++;
 				if (*ch == 0)
 				{
@@ -1961,9 +1994,20 @@ void us_checklibrary(LIBRARY *curlib, BOOLEAN verbose, INTBIG *warnings, INTBIG
 		if (stopping(STOPREASONCHECK)) return;
 		if (verbose) ttyputmsg(_("Checking networks in %s"), describenodeproto(np));
 
-		/* initialize for port count and arc reference count */
+		/* initialize for port count and arc reference count, check buswidth */
 		for(net = np->firstnetwork; net != NONETWORK; net = net->nextnetwork)
+		{
+			if(net->buswidth < 1 || (net->globalnet >= 0 && net->buswidth != 1))
+			{
+				ttyputmsg(_("Facet %s, %s network %s: buswidth %d is wrong"),
+					(net->globalnet >= 0 ? "global" : ""), describenodeproto(np),
+					describenetwork(net), net->buswidth);
+				neterrors++;
+				(*warnings)++;
+				curlib->userbits |= LIBCHANGEDMAJOR;
+			}
 			net->temp1 = net->temp2 = 0;
+		}
 
 		/* check network information on ports */
 		for(pp = np->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
@@ -2036,12 +2080,40 @@ void us_checklibrary(LIBRARY *curlib, BOOLEAN verbose, INTBIG *warnings, INTBIG
 			}
 		}
 
+		/* consider global nets in refcount */
+		for(ni = np->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
+		{
+			/* ignore primitives and recursive references (showing icon in contents) */
+			if (ni->proto->primindex != 0 || ni->proto->cell == np->cell) continue;
+			onp = contentsview(ni->proto);
+			if (onp == NONODEPROTO) onp = ni->proto;
+			for(i=0; i<onp->globalnetcount; i++)
+			{
+				if(onp->globalnetworks[i] == NONETWORK) continue;
+				if(i<2)
+					j = (i<np->globalnetcount && np->globalnetworks[i] != NONETWORK ? i : -1);
+				else
+					j = net_findglobalnet(np,onp->globalnetnames[i]);
+				if(j>=0 && j<np->globalnetcount && np->globalnetworks[j] != NONETWORK)
+					np->globalnetworks[j]->temp1++; else
+				{
+					ttyputmsg(_("Facet %s, global %s of subfacet %s not found"), describenodeproto(np),
+						onp->globalnetnames[i], describenodeproto(onp));
+					neterrors++;
+					(*warnings)++;
+					curlib->userbits |= LIBCHANGEDMAJOR;
+				}
+			}
+		}
+
 		/* check port and arc reference counts, prepare for arc counts */
 		for(net = np->firstnetwork; net != NONETWORK; net = net->nextnetwork)
 		{
-			if (net->arccount == 1) ((ARCINST *)net->arcaddr)->temp1++; else
-				for(i=0; i<net->arccount; i++)
+			for(i=0; i<net->arccount; i++)
+			{
+				if (net->arctotal == 0) ((ARCINST *)net->arcaddr)->temp1++; else
 					((ARCINST **)net->arcaddr)[i]->temp1++;
+			}
 			if (net->refcount != net->temp1)
 			{
 				ttyputmsg(_("Facet %s, network %s: reference count wrong"), describenodeproto(np),
@@ -2138,9 +2210,12 @@ void us_checklibrary(LIBRARY *curlib, BOOLEAN verbose, INTBIG *warnings, INTBIG
 				}
 			}
 		}
+
+		/* check name hash */
+		net_checknetprivate(np);
 	}
 
-	if (neterrors != 0) (void)asktool(net_tool, "total-re-number");
+	if (neterrors != 0) (void)asktool(net_tool, x_("total-re-number"));
 }
 
 BOOLEAN us_checkvariables(INTBIG addr, INTBIG type, INTSML *numvar, VARIABLE *firstvar, LIBRARY *olib)
@@ -2148,7 +2223,7 @@ BOOLEAN us_checkvariables(INTBIG addr, INTBIG type, INTSML *numvar, VARIABLE *fi
 	REGISTER INTBIG i, j, errors, ty, len;
 	REGISTER LIBRARY *lib;
 	REGISTER NODEPROTO *np, *vnp;
-	REGISTER char *varname, *matchname;
+	REGISTER CHAR *varname, *matchname;
 	REGISTER TECHNOLOGY *tech;
 	REGISTER VARIABLE *var;
 
@@ -2168,7 +2243,7 @@ BOOLEAN us_checkvariables(INTBIG addr, INTBIG type, INTSML *numvar, VARIABLE *fi
 	{
 		var = &firstvar[i];
 		ty = var->type;
-		varname = (char *)var->key;
+		varname = (CHAR *)var->key;
 
 		/* see if this variable has been deprecated */
 		for(j=0; us_deprecatedvariables[j].type != 0; j++)
@@ -2209,7 +2284,7 @@ BOOLEAN us_checkvariables(INTBIG addr, INTBIG type, INTSML *numvar, VARIABLE *fi
 				}
 				matchname = us_temporaryvariables[j].name;
 				if (namesame(matchname, varname) == 0) break;
-				len = strlen(matchname) - 1;
+				len = estrlen(matchname) - 1;
 				if (matchname[len] == '*')
 				{
 					if (namesamen(matchname, varname, len) == 0) break;
@@ -2225,6 +2300,18 @@ BOOLEAN us_checkvariables(INTBIG addr, INTBIG type, INTSML *numvar, VARIABLE *fi
 			}
 		}
 
+		/* see if this variable can't be code */
+		if ((var->type&(VCODE1|VCODE2)) != 0 &&
+			((type == VNODEINST && var->key == sch_globalnamekey) ||
+			 (type == VNODEINST && var->key == el_node_name_key) ||
+			 (type == VARCINST && var->key == el_arc_name_key)))
+		{
+			ttyputmsg(_("%s: variable '%s' cannot be interpreted code"),
+				us_describeobject(addr, type), varname);
+			var->type = VSTRING | (var->type&(VDISPLAY|VDONTSAVE|VCANTSET));
+			errors++;
+		}
+
 		/* make sure the variable is in the main namespace */
 		for(j=0; j<el_numnames; j++)
 			if (varname == el_namespace[j]) break;
@@ -2275,6 +2362,7 @@ BOOLEAN us_checkvariables(INTBIG addr, INTBIG type, INTSML *numvar, VARIABLE *fi
 			vnp = (NODEPROTO *)firstvar[i].addr;
 			if (vnp != NONODEPROTO)
 			{
+				np = NONODEPROTO;
 				if (olib == NOLIBRARY)
 				{
 					for(lib = el_curlib; lib != NOLIBRARY; lib = lib->nextlibrary)
@@ -2341,19 +2429,19 @@ BOOLEAN us_checkforuniquenodenames(NODEPROTO *np)
 {
 	REGISTER INTBIG i, count;
 	REGISTER BOOLEAN retval;
-	REGISTER char *lastname, *thisname, *warnedname;
-	char **namelist;
+	REGISTER CHAR *lastname, *thisname, *warnedname;
+	CHAR **namelist;
 
 	count = net_gathernodenames(np, &namelist);
 	if (count <= 1) return(FALSE);
-	esort(namelist, count, sizeof (char *), sort_stringascending);
+	esort(namelist, count, sizeof (CHAR *), sort_stringascending);
 
 	retval = FALSE;
 	lastname = namelist[0];
 	warnedname = 0;
 	for(i=1; i<count; i++)
 	{
-		thisname = (char *)namelist[i];
+		thisname = (CHAR *)namelist[i];
 		if (lastname != 0 && thisname != 0)
 		{
 			if (namesame(lastname, thisname) == 0)
@@ -2375,7 +2463,7 @@ BOOLEAN us_checkforuniquenodenames(NODEPROTO *np)
 /*
  * Routine to describe object "addr" of type "type".
  */
-char *us_describeobject(INTBIG addr, INTBIG type)
+CHAR *us_describeobject(INTBIG addr, INTBIG type)
 {
 	REGISTER NODEPROTO *np;
 	REGISTER PORTARCINST *pi;
@@ -2399,16 +2487,16 @@ char *us_describeobject(INTBIG addr, INTBIG type)
 	{
 		case VNODEINST:
 			ni = (NODEINST *)addr;
-			formatinfstr(infstr, "Facet %s, node %s", describenodeproto(ni->parent), describenodeinst(ni));
+			formatinfstr(infstr, x_("Facet %s, node %s"), describenodeproto(ni->parent), describenodeinst(ni));
 			break;
 		case VNODEPROTO:
 			np = (NODEPROTO *)addr;
 			if (np->primindex != 0)
 			{
-				formatinfstr(infstr, "Technology %s, node %s", np->tech->techname, np->primname);
+				formatinfstr(infstr, x_("Technology %s, node %s"), np->tech->techname, np->primname);
 			} else
 			{
-				formatinfstr(infstr, "Facet %s", describenodeproto(np));
+				formatinfstr(infstr, x_("Facet %s"), describenodeproto(np));
 			}
 			break;
 		case VPORTARCINST:
@@ -2417,62 +2505,62 @@ char *us_describeobject(INTBIG addr, INTBIG type)
 			if (ai->end[0].portarcinst == pi) thisend = 0; else
 				thisend = 1;
 			ni = ai->end[thisend].nodeinst;
-			formatinfstr(infstr, "Facet %s, node %s, port %s",
+			formatinfstr(infstr, x_("Facet %s, node %s, port %s"),
 				describenodeproto(ai->parent), describenodeinst(ni), pi->proto->protoname);
 			break;
 		case VPORTEXPINST:
 			pe = (PORTEXPINST *)addr;
 			pp = pe->exportproto;
-			formatinfstr(infstr, "Facet %s, node %s, export %s",
+			formatinfstr(infstr, x_("Facet %s, node %s, export %s"),
 				describenodeproto(pp->parent), describenodeinst(pp->subnodeinst), pp->protoname);
 			break;
 		case VPORTPROTO:
 			pp = (PORTPROTO *)addr;
-			formatinfstr(infstr, "Facet %s, export %s", describenodeproto(pp->parent), pp->protoname);
+			formatinfstr(infstr, x_("Facet %s, export %s"), describenodeproto(pp->parent), pp->protoname);
 			break;
 		case VARCINST:
 			ai = (ARCINST *)addr;
-			formatinfstr(infstr, "Facet %s, arc %s", describenodeproto(ai->parent), describearcinst(ai));
+			formatinfstr(infstr, x_("Facet %s, arc %s"), describenodeproto(ai->parent), describearcinst(ai));
 			break;
 		case VARCPROTO:
 			ap = (ARCPROTO *)addr;
-			formatinfstr(infstr, "Arc %s", describearcproto(ap));
+			formatinfstr(infstr, x_("Arc %s"), describearcproto(ap));
 			break;
 		case VGEOM:
 			geom = (GEOM *)addr;
 			if (!geom->entryisnode)
 			{
 				ai = geom->entryaddr.ai;
-				formatinfstr(infstr, "Facet %s, arc geom %s", describenodeproto(ai->parent), describearcinst(ai));
+				formatinfstr(infstr, x_("Facet %s, arc geom %s"), describenodeproto(ai->parent), describearcinst(ai));
 			} else
 			{
 				ni = geom->entryaddr.ni;
-				formatinfstr(infstr, "Facet %s, node geom %s", describenodeproto(ni->parent), describenodeinst(ni));
+				formatinfstr(infstr, x_("Facet %s, node geom %s"), describenodeproto(ni->parent), describenodeinst(ni));
 			}
 			break;
 		case VLIBRARY:
 			lib = (LIBRARY *)addr;
-			formatinfstr(infstr, "Library %s", lib->libname);
+			formatinfstr(infstr, x_("Library %s"), lib->libname);
 			break;
 		case VTECHNOLOGY:
 			tech = (TECHNOLOGY *)addr;
-			formatinfstr(infstr, "Technology %s", tech->techname);
+			formatinfstr(infstr, x_("Technology %s"), tech->techname);
 			break;
 		case VTOOL:
 			tool = (TOOL *)addr;
-			formatinfstr(infstr, "Tool %s", tool->toolname);
+			formatinfstr(infstr, x_("Tool %s"), tool->toolname);
 			break;
 		case VNETWORK:
 			net = (NETWORK *)addr;
-			formatinfstr(infstr, "Facet %s, network %s", describenodeproto(net->parent), describenetwork(net));
+			formatinfstr(infstr, x_("Facet %s, network %s"), describenodeproto(net->parent), describenetwork(net));
 			break;
 		case VCELL:
 			c = (CELL *)addr;
-			formatinfstr(infstr, "Library %s, cell %s", c->lib->libname, c->cellname);
+			formatinfstr(infstr, x_("Library %s, cell %s"), c->lib->libname, c->cellname);
 			break;
 		case VVIEW:
 			v = (VIEW *)addr;
-			formatinfstr(infstr, "View %s", v->viewname);
+			formatinfstr(infstr, x_("View %s"), v->viewname);
 			break;
 	}
 	return(returninfstr(infstr));
@@ -2485,7 +2573,7 @@ char *us_describeobject(INTBIG addr, INTBIG type)
 BOOLEAN us_checktextdescript(INTBIG addr, INTBIG type, UINTBIG *descript)
 {
 	INTBIG face, maxfaces, disppart;
-	char **facelist;
+	CHAR **facelist;
 
 	if ((type&VTYPE) != VNODEPROTO)
 	{
