@@ -35,13 +35,13 @@
 #include "drc.h"
 #include "usrtrack.h"
 
-void us_arc(INTBIG count, char *par[])
+void us_arc(INTBIG count, CHAR *par[])
 {
 	REGISTER INTBIG negate, toggle, r, j, i, l, interactive, lambda, wid;
 	INTBIG ix, iy, xcur, ycur, dx[2], dy[2];
 	REGISTER ARCINST *ai;
 	REGISTER NODEPROTO *np;
-	REGISTER char *pp;
+	REGISTER CHAR *pp;
 	REGISTER NETWORK *net;
 	extern COMCOMP us_arcp, us_arcnotp, us_arcnamep, us_arctogp;
 	REGISTER VARIABLE *var;
@@ -57,10 +57,10 @@ void us_arc(INTBIG count, char *par[])
 			return;
 		}
 	}
-	l = strlen(pp = par[0]);
+	l = estrlen(pp = par[0]);
 	negate = toggle = 0;
 
-	if (namesamen(pp, "not", l) == 0 && l >= 2)
+	if (namesamen(pp, x_("not"), l) == 0 && l >= 2)
 	{
 		if (count == 1)
 		{
@@ -73,9 +73,9 @@ void us_arc(INTBIG count, char *par[])
 		}
 		count--;
 		par++;
-		l = strlen(pp = par[0]);
+		l = estrlen(pp = par[0]);
 		negate = 1;
-	} else if (namesamen(pp, "toggle", l) == 0 && l >= 2)
+	} else if (namesamen(pp, x_("toggle"), l) == 0 && l >= 2)
 	{
 		if (count == 1)
 		{
@@ -88,7 +88,7 @@ void us_arc(INTBIG count, char *par[])
 		}
 		count--;
 		par++;
-		l = strlen(pp = par[0]);
+		l = estrlen(pp = par[0]);
 		toggle = 1;
 	}
 
@@ -108,90 +108,90 @@ void us_arc(INTBIG count, char *par[])
 	us_pushhighlight();
 	us_clearhighlightcount();
 
-	if (namesamen(pp, "rigid", l) == 0 && l >= 2)
+	if (namesamen(pp, x_("rigid"), l) == 0 && l >= 2)
 	{
-		if (namesame(el_curconstraint->conname, "layout") != 0)
+		if (namesame(el_curconstraint->conname, x_("layout")) != 0)
 		{
 			us_abortcommand(_("Use the layout constraint system for rigid arcs"));
 			us_pophighlight(FALSE);
 			return;
 		}
-		i = us_modarcbits((toggle != 0 ? 23 : (negate != 0 ? 1 : 0)), FALSE, "", list);
-		if (i >= 0) ttyputverbose("%ld %s %s", i, makeplural(_("arc"), i),
+		i = us_modarcbits((toggle != 0 ? 23 : (negate != 0 ? 1 : 0)), FALSE, x_(""), list);
+		if (i >= 0) ttyputverbose(x_("%ld %s %s"), i, makeplural(_("arc"), i),
 			(toggle != 0 ? _("toggle rigidity") : (negate != 0 ? _("made un-rigid") : _("made rigid"))));
-	} else if ((namesamen(pp, "manhattan", l) == 0 ||
-		namesamen(pp, "fixed-angle", l) == 0) && l >= 1)
+	} else if ((namesamen(pp, x_("manhattan"), l) == 0 ||
+		namesamen(pp, x_("fixed-angle"), l) == 0) && l >= 1)
 	{
-		if (namesame(el_curconstraint->conname, "layout") != 0)
+		if (namesame(el_curconstraint->conname, x_("layout")) != 0)
 		{
 			us_abortcommand(_("Use the layout constraint system for fixed-angle arcs"));
 			us_pophighlight(FALSE);
 			return;
 		}
-		if (namesamen(pp, "manhattan", l) == 0)
+		if (namesamen(pp, x_("manhattan"), l) == 0)
 			ttyputmsg(_("It is now proper to use 'arc fixed-angle' instead of 'arc manhattan'"));
-		i = us_modarcbits((toggle != 0 ? 24 : (negate != 0 ? 3 : 2)), FALSE, "", list);
+		i = us_modarcbits((toggle != 0 ? 24 : (negate != 0 ? 3 : 2)), FALSE, x_(""), list);
 		if (i >= 0)
-			ttyputverbose("%ld %s %s", i, makeplural(_("arc"), i), (toggle != 0 ? _("toggle fixed-angle") :
+			ttyputverbose(x_("%ld %s %s"), i, makeplural(_("arc"), i), (toggle != 0 ? _("toggle fixed-angle") :
 				(negate != 0 ? _("made not fixed-angle") : _("made fixed-angle"))));
-	} else if (namesamen(pp, "slide", l) == 0 && l >= 2)
+	} else if (namesamen(pp, x_("slide"), l) == 0 && l >= 2)
 	{
-		if (namesame(el_curconstraint->conname, "layout") != 0)
+		if (namesame(el_curconstraint->conname, x_("layout")) != 0)
 		{
 			us_abortcommand(_("Use the layout constraint system for slidable arcs"));
 			us_pophighlight(FALSE);
 			return;
 		}
-		i = us_modarcbits((toggle != 0 ? 25 : (negate != 0 ? 5 : 4)), FALSE, "", list);
+		i = us_modarcbits((toggle != 0 ? 25 : (negate != 0 ? 5 : 4)), FALSE, x_(""), list);
 		if (i >= 0)
-			ttyputverbose("%ld %s %s", i, makeplural(_("arc"), i), (toggle != 0 ? _("toggle slidability") :
+			ttyputverbose(x_("%ld %s %s"), i, makeplural(_("arc"), i), (toggle != 0 ? _("toggle slidability") :
 				(negate != 0 ? _("can not slide in ports") : _("can slide in ports"))));
-	} else if (namesamen(pp, "temp-rigid", l) == 0 && l >= 1)
+	} else if (namesamen(pp, x_("temp-rigid"), l) == 0 && l >= 1)
 	{
-		if (namesame(el_curconstraint->conname, "layout") != 0)
+		if (namesame(el_curconstraint->conname, x_("layout")) != 0)
 		{
 			us_abortcommand(_("Use the layout constraint system for rigid arcs"));
 			us_pophighlight(FALSE);
 			return;
 		}
-		i = us_modarcbits((negate != 0 ? 7 : 6), FALSE, "", list);
+		i = us_modarcbits((negate != 0 ? 7 : 6), FALSE, x_(""), list);
 		if (i >= 0) ttyputverbose(M_("%ld %s made temporarily %srigid"), i, makeplural(_("arc"), i),
-			(negate!=0 ? _("un-") : ""));
-	} else if (namesamen(pp, "ends-extend", l) == 0 && l >= 1)
+			(negate!=0 ? _("un-") : x_("")));
+	} else if (namesamen(pp, x_("ends-extend"), l) == 0 && l >= 1)
 	{
-		i = us_modarcbits((toggle != 0 ? 26 : (negate != 0 ? 9 : 8)), TRUE, "", list);
-		if (i >= 0) ttyputverbose("%ld %s %s", i, makeplural(_("arc"), i),
+		i = us_modarcbits((toggle != 0 ? 26 : (negate != 0 ? 9 : 8)), TRUE, x_(""), list);
+		if (i >= 0) ttyputverbose(x_("%ld %s %s"), i, makeplural(_("arc"), i),
 			(toggle != 0 ? _("toggle end extension") :
 				(negate != 0 ? _("given no end extension") : _("given full end extension"))));
-	} else if (namesamen(pp, "directional", l) == 0 && l >= 1)
+	} else if (namesamen(pp, x_("directional"), l) == 0 && l >= 1)
 	{
-		i = us_modarcbits((toggle != 0 ? 27 : (negate != 0 ? 11: 10)), TRUE, "", list);
-		if (i >= 0) ttyputverbose("%ld %s %s", i, makeplural(_("arc"), i),
+		i = us_modarcbits((toggle != 0 ? 27 : (negate != 0 ? 11: 10)), TRUE, x_(""), list);
+		if (i >= 0) ttyputverbose(x_("%ld %s %s"), i, makeplural(_("arc"), i),
 			(toggle != 0 ? _("toggle directionality") :
 				(negate != 0 ? _("given no direction") : _("given direction"))));
-	} else if (namesamen(pp, "negated", l) == 0 && l >= 2)
+	} else if (namesamen(pp, x_("negated"), l) == 0 && l >= 2)
 	{
-		i = us_modarcbits((toggle != 0 ? 28 : (negate != 0 ? 13 : 12)), TRUE, "", list);
-		if (i >= 0) ttyputverbose("%ld %s %s", i, makeplural(_("arc"), i),
+		i = us_modarcbits((toggle != 0 ? 28 : (negate != 0 ? 13 : 12)), TRUE, x_(""), list);
+		if (i >= 0) ttyputverbose(x_("%ld %s %s"), i, makeplural(_("arc"), i),
 			(toggle != 0 ? _("toggle negation") : (negate != 0 ? _("not negated") : _("negated"))));
-	} else if (namesamen(pp, "skip-tail", l) == 0 && l >= 6)
+	} else if (namesamen(pp, x_("skip-tail"), l) == 0 && l >= 6)
 	{
-		i = us_modarcbits((toggle != 0 ? 29 : (negate != 0 ? 15 : 14)), TRUE, "", list);
-		if (i >= 0) ttyputverbose("%ld %s %s", i, makeplural(_("arc"), i),
+		i = us_modarcbits((toggle != 0 ? 29 : (negate != 0 ? 15 : 14)), TRUE, x_(""), list);
+		if (i >= 0) ttyputverbose(x_("%ld %s %s"), i, makeplural(_("arc"), i),
 			(toggle != 0 ? _("toggle tail use") : (negate!=0 ? _("use tail") : _("do not use tail"))));
-	} else if (namesamen(pp, "skip-head", l) == 0 && l >= 6)
+	} else if (namesamen(pp, x_("skip-head"), l) == 0 && l >= 6)
 	{
-		i = us_modarcbits((toggle != 0 ? 30 : (negate != 0 ? 17 : 16)), TRUE, "", list);
-		if (i >= 0) ttyputverbose("%ld %s %s", i, makeplural(_("arc"), i),
+		i = us_modarcbits((toggle != 0 ? 30 : (negate != 0 ? 17 : 16)), TRUE, x_(""), list);
+		if (i >= 0) ttyputverbose(x_("%ld %s %s"), i, makeplural(_("arc"), i),
 			(toggle != 0 ? _("toggle head use") : (negate!=0 ? _("use head") : _("do not use head"))));
-	} else if (namesamen(pp, "reverse", l) == 0 && l >= 2)
+	} else if (namesamen(pp, x_("reverse"), l) == 0 && l >= 2)
 	{
 		if (negate != 0) ttyputerr(_("'arc reverse' is a relative notion, 'not' ignored"));
-		i = us_modarcbits(18, TRUE, "", list);
+		i = us_modarcbits(18, TRUE, x_(""), list);
 		if (i >= 0) ttyputverbose(M_("%ld %s direction reversed"), i, makeplural(_("arc"), i));
-	} else if (namesamen(pp, "constraint", l) == 0 && l >= 2)
+	} else if (namesamen(pp, x_("constraint"), l) == 0 && l >= 2)
 	{
-		if (namesame(el_curconstraint->conname, "linear") != 0)
+		if (namesame(el_curconstraint->conname, x_("linear")) != 0)
 		{
 			us_abortcommand(_("First switch to the linear inequalities constraint system"));
 			us_pophighlight(FALSE);
@@ -199,15 +199,15 @@ void us_arc(INTBIG count, char *par[])
 		}
 		if (count <= 1)
 		{
-			if (negate != 0) (void)us_modarcbits(19, TRUE, "", list); else
-				(void)us_modarcbits(20, FALSE, "", list);
+			if (negate != 0) (void)us_modarcbits(19, TRUE, x_(""), list); else
+				(void)us_modarcbits(20, FALSE, x_(""), list);
 		} else
 		{
-			if (count > 2 && namesamen(par[2], "add", strlen(par[2])) == 0)
+			if (count > 2 && namesamen(par[2], x_("add"), estrlen(par[2])) == 0)
 				i = us_modarcbits(22, TRUE, par[1], list); else
 					i = us_modarcbits(21, TRUE, par[1], list);
 		}
-	} else if (namesamen(pp, "name", l) == 0 && l >= 2)
+	} else if (namesamen(pp, x_("name"), l) == 0 && l >= 2)
 	{
 		if (list[0]->entryisnode || list[1] != NOGEOM)
 		{
@@ -248,10 +248,10 @@ void us_arc(INTBIG count, char *par[])
 				us_pophighlight(FALSE);
 				return;
 			}
-			if (var != NOVARIABLE) us_setarcname(ai, (char *)0);
+			if (var != NOVARIABLE) us_setarcname(ai, (CHAR *)0);
 			ttyputverbose(M_("Arc name removed"));
 		}
-	} else if (namesamen(pp, "center", l) == 0 && l >= 2)
+	} else if (namesamen(pp, x_("center"), l) == 0 && l >= 2)
 	{
 		if (list[0]->entryisnode || list[1] != NOGEOM)
 		{
@@ -271,7 +271,7 @@ void us_arc(INTBIG count, char *par[])
 
 		/* see if curvature should be set interactively */
 		interactive = 0;
-		if (count >= 2 && namesamen(par[1], "interactive", strlen(par[1])) == 0)
+		if (count >= 2 && namesamen(par[1], x_("interactive"), estrlen(par[1])) == 0)
 			interactive = 1;
 
 		/* change the arc center information */
@@ -305,7 +305,7 @@ void us_arc(INTBIG count, char *par[])
 			(void)modifyarcinst(ai, 0, 0, 0, 0, 0);
 			endobjectchange((INTBIG)ai, VARCINST);
 		}
-	} else if (namesamen(pp, "shorten", l) == 0 && l >= 2)
+	} else if (namesamen(pp, x_("shorten"), l) == 0 && l >= 2)
 	{
 		/* get the necessary polygon */
 		(void)needstaticpolygon(&poly, 4, us_tool->cluster);
@@ -340,8 +340,8 @@ void us_arc(INTBIG count, char *par[])
 				l++;
 			}
 		}
-		ttyputmsg("Shortened %ld %s", l, makeplural(_("arc"), l));
-	} else if (namesamen(pp, "curve", l) == 0 && l >= 2)
+		ttyputmsg(x_("Shortened %ld %s"), l, makeplural(_("arc"), l));
+	} else if (namesamen(pp, x_("curve"), l) == 0 && l >= 2)
 	{
 		if (list[0]->entryisnode || list[1] != NOGEOM)
 		{
@@ -361,7 +361,7 @@ void us_arc(INTBIG count, char *par[])
 
 		/* see if curvature should be set interactively */
 		interactive = 0;
-		if (count >= 2 && namesamen(par[1], "interactive", strlen(par[1])) == 0)
+		if (count >= 2 && namesamen(par[1], x_("interactive"), estrlen(par[1])) == 0)
 			interactive = 1;
 
 		/* change the arc center information */
@@ -396,13 +396,13 @@ void us_arc(INTBIG count, char *par[])
 			(void)modifyarcinst(ai, 0, 0, 0, 0, 0);
 			endobjectchange((INTBIG)ai, VARCINST);
 		}
-	} else ttyputbadusage("arc");
+	} else ttyputbadusage(x_("arc"));
 
 	/* clean-up */
 	us_pophighlight(TRUE);
 }
 
-void us_array(INTBIG count, char *par[])
+void us_array(INTBIG count, CHAR *par[])
 {
 	REGISTER BOOLEAN flipx, flipy, first, staggerx, staggery, centerx, centery,
 		noname, diagonal, onlydrcvalid, *validity;
@@ -412,8 +412,8 @@ void us_array(INTBIG count, char *par[])
 		xsize, ysize, yindex, originalx, originaly, lambda, checknodecount;
 	REGISTER GEOM **list, *geom;
 	INTBIG xoverlap, yoverlap, plx, ply, phx, phy;
-	REGISTER char *pt1, *pt2;
-	char totalname[200], *objname;
+	REGISTER CHAR *pt1, *pt2;
+	CHAR totalname[200], *objname;
 	REGISTER NODEINST *ni, *newno, **nodelist, *ni0, *ni1, **nodestocheck;
 	REGISTER ARCINST *ai, **arclist, *newai;
 	REGISTER NODEPROTO *np;
@@ -421,7 +421,7 @@ void us_array(INTBIG count, char *par[])
 	REGISTER VARIABLE *var;
 
 	/* special case for the "array file" command */
-	if (count > 0 && namesamen(par[0], "file", strlen(par[0])) == 0)
+	if (count > 0 && namesamen(par[0], x_("file"), estrlen(par[0])) == 0)
 	{
 		us_arrayfromfile(par[1]);
 		return;
@@ -453,16 +453,16 @@ void us_array(INTBIG count, char *par[])
 	noname = diagonal = onlydrcvalid = FALSE;
 	while (count > 0)
 	{
-		l = strlen(pt1 = par[count-1]);
-		if (namesamen(pt1, "no-names", l) == 0)
+		l = estrlen(pt1 = par[count-1]);
+		if (namesamen(pt1, x_("no-names"), l) == 0)
 		{
 			noname = TRUE;
 			count--;
-		} else if (namesamen(pt1, "diagonal", l) == 0)
+		} else if (namesamen(pt1, x_("diagonal"), l) == 0)
 		{
 			diagonal = TRUE;
 			count--;
-		} else if (namesamen(pt1, "only-drc-valid", l) == 0)
+		} else if (namesamen(pt1, x_("only-drc-valid"), l) == 0)
 		{
 			onlydrcvalid = TRUE;
 			count--;
@@ -472,13 +472,13 @@ void us_array(INTBIG count, char *par[])
 	/* get the X extent of the array */
 	if (count == 0)
 	{
-		ttyputusage("array XREP[f][s][c] [YREP[f][s][c] [XOVRLP [YOVRLP [no-names][diagonal][only-drc-valid]]]]");
+		ttyputusage(x_("array XREP[f][s][c] [YREP[f][s][c] [XOVRLP [YOVRLP [no-names][diagonal][only-drc-valid]]]]"));
 		return;
 	}
 	pt1 = par[0];
 	xsize = myatoi(pt1);
 	flipx = staggerx = centerx = FALSE;
-	for(i = strlen(pt1)-1; i > 0; i--)
+	for(i = estrlen(pt1)-1; i > 0; i--)
 	{
 		if (pt1[i] == 'f') flipx = TRUE; else
 			if (pt1[i] == 's') staggerx = TRUE; else
@@ -487,10 +487,10 @@ void us_array(INTBIG count, char *par[])
 	}
 
 	/* get the Y extent of the array */
-	if (count == 1) pt2 = "1"; else pt2 = par[1];
-	ysize = atoi(pt2);
+	if (count == 1) pt2 = x_("1"); else pt2 = par[1];
+	ysize = eatoi(pt2);
 	flipy = staggery = centery = FALSE;
-	for(i = strlen(pt2)-1; i > 0; i--)
+	for(i = estrlen(pt2)-1; i > 0; i--)
 	{
 		if (pt2[i] == 'f') flipy = TRUE; else
 			if (pt2[i] == 's') staggery = TRUE; else
@@ -551,7 +551,7 @@ void us_array(INTBIG count, char *par[])
 		arclist = (ARCINST **)emalloc(arccount * (sizeof (ARCINST *)), el_tempcluster);
 		if (arclist == 0)
 		{
-			if (nodecount > 0) efree((char *)nodelist);
+			if (nodecount > 0) efree((CHAR *)nodelist);
 			return;
 		}
 		for(ai = np->firstarcinst, i=0; ai != NOARCINST; ai = ai->nextarcinst)
@@ -622,8 +622,8 @@ void us_array(INTBIG count, char *par[])
 		if (x < xsize)
 		{
 			us_abortcommand(_("Array is too wide...place elements closer or use fewer"));
-			if (nodecount > 0) efree((char *)nodelist);
-			if (arccount > 0) efree((char *)arclist);
+			if (nodecount > 0) efree((CHAR *)nodelist);
+			if (arccount > 0) efree((CHAR *)arclist);
 			return;
 		}
 	}
@@ -645,8 +645,8 @@ void us_array(INTBIG count, char *par[])
 		if (y < ysize)
 		{
 			us_abortcommand(_("Array is too tall...place elements closer or use fewer"));
-			if (nodecount > 0) efree((char *)nodelist);
-			if (arccount > 0) efree((char *)arclist);
+			if (nodecount > 0) efree((CHAR *)nodelist);
+			if (arccount > 0) efree((CHAR *)arclist);
 			return;
 		}
 	}
@@ -719,8 +719,8 @@ void us_array(INTBIG count, char *par[])
 			if (newno == NONODEINST)
 			{
 				ttyputerr(_("Problem creating array nodes"));
-				if (nodecount > 0) efree((char *)nodelist);
-				if (arccount > 0) efree((char *)arclist);
+				if (nodecount > 0) efree((CHAR *)nodelist);
+				if (arccount > 0) efree((CHAR *)arclist);
 				us_pophighlight(FALSE);
 				return;
 			}
@@ -729,16 +729,16 @@ void us_array(INTBIG count, char *par[])
 			(void)copyvars((INTBIG)ni, VNODEINST, (INTBIG)newno, VNODEINST, TRUE);
 			if (!noname)
 			{
-				objname = "";
+				objname = x_("");
 				var = getvalkey((INTBIG)ni, VNODEINST, VSTRING, el_node_name_key);
 				if (var != NOVARIABLE)
 				{
-					if (strcmp((char *)var->addr, "0") != 0 && strcmp((char *)var->addr, "0-0") != 0)
-						objname = (char *)var->addr;
+					if (estrcmp((CHAR *)var->addr, x_("0")) != 0 && estrcmp((CHAR *)var->addr, x_("0-0")) != 0)
+						objname = (CHAR *)var->addr;
 				}
 				if (xsize <= 1 || ysize <= 1)
-					(void)sprintf(totalname, "%s%ld", objname, x+y); else
-						(void)sprintf(totalname, "%s%ld-%ld", objname, x, y);
+					(void)esnprintf(totalname, 200, x_("%s%ld"), objname, x+y); else
+						(void)esnprintf(totalname, 200, x_("%s%ld-%ld"), objname, x, y);
 				var = setvalkey((INTBIG)newno, VNODEINST, el_node_name_key,
 					(INTBIG)totalname, VSTRING|VDISPLAY);
 				if (var != NOVARIABLE)
@@ -807,24 +807,24 @@ void us_array(INTBIG count, char *par[])
 			if (newai == NOARCINST)
 			{
 				ttyputerr(_("Problem creating array arcs"));
-				if (nodecount > 0) efree((char *)nodelist);
-				if (arccount > 0) efree((char *)arclist);
+				if (nodecount > 0) efree((CHAR *)nodelist);
+				if (arccount > 0) efree((CHAR *)arclist);
 				us_pophighlight(FALSE);
 				return;
 			}
 			(void)copyvars((INTBIG)ai, VARCINST, (INTBIG)newai, VARCINST, TRUE);
 			if (!noname)
 			{
-				objname = "";
+				objname = x_("");
 				var = getvalkey((INTBIG)ai, VARCINST, VSTRING, el_arc_name_key);
 				if (var != NOVARIABLE)
 				{
-					if (strcmp((char *)var->addr, "0") != 0 && strcmp((char *)var->addr, "0-0") != 0)
-						objname = (char *)var->addr;
+					if (estrcmp((CHAR *)var->addr, x_("0")) != 0 && estrcmp((CHAR *)var->addr, x_("0-0")) != 0)
+						objname = (CHAR *)var->addr;
 				}
 				if (xsize <= 1 || ysize <= 1)
-					(void)sprintf(totalname, "%s%ld", objname, x+y); else
-						(void)sprintf(totalname, "%s%ld-%ld", objname, x, y);
+					(void)esnprintf(totalname, 200, x_("%s%ld"), objname, x+y); else
+						(void)esnprintf(totalname, 200, x_("%s%ld-%ld"), objname, x, y);
 				var = setvalkey((INTBIG)newai, VARCINST, el_arc_name_key,
 					(INTBIG)totalname, VSTRING|VDISPLAY);
 				if (var != NOVARIABLE)
@@ -844,14 +844,19 @@ void us_array(INTBIG count, char *par[])
 
 			/* get former name of node */
 			var = getvalkey((INTBIG)ni, VNODEINST, VSTRING, el_node_name_key);
-			objname = "";
+			objname = x_("");
 			if (var != NOVARIABLE)
 			{
-				if (strcmp((char *)var->addr, "0") != 0 && strcmp((char *)var->addr, "0-0") != 0)
-					objname = (char *)var->addr;
+				if (estrcmp((CHAR *)var->addr, x_("0")) != 0 && estrcmp((CHAR *)var->addr, x_("0-0")) != 0)
+					objname = (CHAR *)var->addr;
+			}
+			if (xsize <= 1 || ysize <= 1)
+			{
+				(void)esnprintf(totalname, 200, x_("%s%ld"), objname, originalx+originaly);
+			} else
+			{
+				(void)esnprintf(totalname, 200, x_("%s%ld-%ld"), objname, originalx, originaly);
 			}
-			if (xsize <= 1 || ysize <= 1) (void)sprintf(totalname, "%s%ld", objname, originalx+originaly); else
-				(void)sprintf(totalname, "%s%ld-%ld", objname, originalx, originaly);
 			var = setvalkey((INTBIG)ni, VNODEINST, el_node_name_key, (INTBIG)totalname, VSTRING|VDISPLAY);
 			if (var != NOVARIABLE)
 			{
@@ -873,14 +878,19 @@ void us_array(INTBIG count, char *par[])
 
 			/* get former name of arc */
 			var = getvalkey((INTBIG)ai, VARCINST, VSTRING, el_arc_name_key);
-			objname = "";
+			objname = x_("");
 			if (var != NOVARIABLE)
 			{
-				if (strcmp((char *)var->addr, "0") != 0 && strcmp((char *)var->addr, "0-0") != 0)
-					objname = (char *)var->addr;
+				if (estrcmp((CHAR *)var->addr, x_("0")) != 0 && estrcmp((CHAR *)var->addr, x_("0-0")) != 0)
+					objname = (CHAR *)var->addr;
+			}
+			if (xsize <= 1 || ysize <= 1)
+			{
+				(void)esnprintf(totalname, 200, x_("%s%ld"), objname, originalx+originaly);
+			} else
+			{
+				(void)esnprintf(totalname, 200, x_("%s%ld-%ld"), objname, originalx, originaly);
 			}
-			if (xsize <= 1 || ysize <= 1) (void)sprintf(totalname, "%s%ld", objname, originalx+originaly); else
-				(void)sprintf(totalname, "%s%ld-%ld", objname, originalx, originaly);
 			var = setvalkey((INTBIG)ai, VARCINST, el_arc_name_key, (INTBIG)totalname, VSTRING|VDISPLAY);
 			if (var != NOVARIABLE)
 				defaulttextsize(4, var->textdescript);
@@ -891,7 +901,7 @@ void us_array(INTBIG count, char *par[])
 	/* if only arraying where DRC valid, check them now and delete what is not valid */
 	if (onlydrcvalid)
 	{
-		(void)asktool(dr_tool, "check-instances", (INTBIG)np, checknodecount, (INTBIG)nodestocheck,
+		(void)asktool(dr_tool, x_("check-instances"), (INTBIG)np, checknodecount, (INTBIG)nodestocheck,
 			(INTBIG)validity);
 		for(i=1; i<checknodecount; i++)
 		{
@@ -901,17 +911,17 @@ void us_array(INTBIG count, char *par[])
 				killnodeinst(nodestocheck[i]);
 			}
 		}
-		efree((char *)nodestocheck);
-		efree((char *)validity);
+		efree((CHAR *)nodestocheck);
+		efree((CHAR *)validity);
 	}
 
 	/* restore highlighting */
 	us_pophighlight(FALSE);
-	if (nodecount > 0) efree((char *)nodelist);
-	if (arccount > 0) efree((char *)arclist);
+	if (nodecount > 0) efree((CHAR *)nodelist);
+	if (arccount > 0) efree((CHAR *)arclist);
 }
 
-void us_bind(INTBIG count, char *par[])
+void us_bind(INTBIG count, CHAR *par[])
 {
 	REGISTER INTBIG i, j, l, negated, bindex, newcount, menu, popup,
 		x, y, backgroundcolor, swap, lastchar, varkey, formerquickkey, len;
@@ -920,13 +930,13 @@ void us_bind(INTBIG count, char *par[])
 	REGISTER INTBIG but;
 	INTBIG important, menumessagesize;
 	REGISTER USERCOM *rb;
-	REGISTER char *pp, *letter, *popname, *str;
+	REGISTER CHAR *pp, *letter, *popname, *str;
 	NODEPROTO *nodeglyph;
 	ARCPROTO *arcglyph;
 	POPUPMENU *pm;
 	REGISTER VARIABLE *var;
 	COMMANDBINDING commandbinding, oldcommandbinding;
-	char partial[80], *a[MAXPARS+1], *menumessage, *pt;
+	CHAR partial[80], *a[MAXPARS+1], *menumessage, *pt;
 	extern COMCOMP us_bindp, us_bindsetp, us_bindbuttonp, us_bindkeyp,
 		us_bindmenuryp, us_bindmenuxp, us_userp, us_bindpopnp, us_bindpoprep;
 	REGISTER void *infstr;
@@ -940,21 +950,21 @@ void us_bind(INTBIG count, char *par[])
 			return;
 		}
 	}
-	l = strlen(pp = par[0]);
+	l = estrlen(pp = par[0]);
 	negated = 0;
 
-	if (namesamen(pp, "not", l) == 0 && l >= 1)
+	if (namesamen(pp, x_("not"), l) == 0 && l >= 1)
 	{
 		negated = 1;
 		if (count <= 1)
 		{
-			ttyputusage("bind not verbose");
+			ttyputusage(x_("bind not verbose"));
 			return;
 		}
-		l = strlen(pp = par[1]);
+		l = estrlen(pp = par[1]);
 	}
 
-	if (namesamen(pp, "verbose", l) == 0 && l >= 1)
+	if (namesamen(pp, x_("verbose"), l) == 0 && l >= 1)
 	{
 		if (negated == 0)
 		{
@@ -968,11 +978,11 @@ void us_bind(INTBIG count, char *par[])
 		return;
 	}
 
-	if (namesamen(pp, "get", l) == 0 && l >= 1)
+	if (namesamen(pp, x_("get"), l) == 0 && l >= 1)
 	{
 		if (count < 2)
 		{
-			ttyputusage("bind get LETTER OBJECT");
+			ttyputusage(x_("bind get LETTER OBJECT"));
 			return;
 		}
 		letter = par[1];
@@ -982,18 +992,18 @@ void us_bind(INTBIG count, char *par[])
 			return;
 		}
 
-		l = strlen(pp = par[2]);
-		if (namesamen(pp, "button", l) == 0 && l >= 1)
+		l = estrlen(pp = par[2]);
+		if (namesamen(pp, x_("button"), l) == 0 && l >= 1)
 		{
 			if (count < 4)
 			{
-				ttyputusage("bind get LETTER button BUTTON");
+				ttyputusage(x_("bind get LETTER button BUTTON"));
 				return;
 			}
 			pp = par[3];
 			for(but=0; but<buttoncount(); but++)
 			{
-				(void)strcpy(partial, buttonname(but, &important));
+				(void)estrcpy(partial, buttonname(but, &important));
 				for(j=0; j<important; j++)
 				{
 					if (isupper(pp[j])) pp[j] = tolower(pp[j]);
@@ -1009,18 +1019,18 @@ void us_bind(INTBIG count, char *par[])
 			}
 			var = getvalkey((INTBIG)us_tool, VTOOL, VSTRING|VISARRAY, us_binding_buttons_key);
 			if (var == NOVARIABLE) return;
-			us_parsebinding(((char **)var->addr)[but], &commandbinding);
-			if (*commandbinding.command == 0) commandbinding.command = "-";
+			us_parsebinding(((CHAR **)var->addr)[but], &commandbinding);
+			if (*commandbinding.command == 0) commandbinding.command = x_("-");
 			(void)setval((INTBIG)us_tool, VTOOL, us_commandvarname(*letter),
 				(INTBIG)commandbinding.command, VSTRING|VDONTSAVE);
 			us_freebindingparse(&commandbinding);
 			return;
 		}
-		if (namesamen(pp, "key", l) == 0 && l >= 1)
+		if (namesamen(pp, x_("key"), l) == 0 && l >= 1)
 		{
 			if (count < 4)
 			{
-				ttyputusage("bind get LETTER key KEY");
+				ttyputusage(x_("bind get LETTER key KEY"));
 				return;
 			}
 			pp = par[3];
@@ -1028,17 +1038,17 @@ void us_bind(INTBIG count, char *par[])
 			i = us_findboundkey(key, 0, &pt);
 			if (i < 0) return;
 			us_parsebinding(pt, &commandbinding);
-			if (*commandbinding.command == 0) commandbinding.command = "-";
+			if (*commandbinding.command == 0) commandbinding.command = x_("-");
 			(void)setval((INTBIG)us_tool, VTOOL, us_commandvarname(*letter),
 				(INTBIG)commandbinding.command, VSTRING|VDONTSAVE);
 			us_freebindingparse(&commandbinding);
 			return;
 		}
-		if (namesamen(pp, "menu", l) == 0 && l >= 1)
+		if (namesamen(pp, x_("menu"), l) == 0 && l >= 1)
 		{
 			if (count < 5)
 			{
-				ttyputusage("bind get LETTER menu ROW COLUMN");
+				ttyputusage(x_("bind get LETTER menu ROW COLUMN"));
 				return;
 			}
 			y = myatoi(pp = par[3]);
@@ -1051,20 +1061,20 @@ void us_bind(INTBIG count, char *par[])
 			var = getvalkey((INTBIG)us_tool, VTOOL, VSTRING|VISARRAY, us_binding_menu_key);
 			if (var == NOVARIABLE) return;
 			if (us_menupos <= 1)
-				str = ((char **)var->addr)[y * us_menux + x]; else
-					str = ((char **)var->addr)[x * us_menuy + y];
+				str = ((CHAR **)var->addr)[y * us_menux + x]; else
+					str = ((CHAR **)var->addr)[x * us_menuy + y];
 			us_parsebinding(str, &commandbinding);
-			if (*commandbinding.command == 0) commandbinding.command = "-";
+			if (*commandbinding.command == 0) commandbinding.command = x_("-");
 			(void)setval((INTBIG)us_tool, VTOOL, us_commandvarname(*letter),
 				(INTBIG)commandbinding.command, VSTRING|VDONTSAVE);
 			us_freebindingparse(&commandbinding);
 			return;
 		}
-		if (namesamen(pp, "popup", l) == 0 && l >= 1)
+		if (namesamen(pp, x_("popup"), l) == 0 && l >= 1)
 		{
 			if (count < 5)
 			{
-				ttyputusage("bind get LETTER popup MENU ENTRY");
+				ttyputusage(x_("bind get LETTER popup MENU ENTRY"));
 				return;
 			}
 			pm = us_getpopupmenu(par[3]);
@@ -1082,7 +1092,7 @@ void us_bind(INTBIG count, char *par[])
 			rb = pm->list[popup-1].response;
 
 			/* make sure there is a command there */
-			if (rb == NOUSERCOM || rb->active < 0) pp = "-"; else
+			if (rb == NOUSERCOM || rb->active < 0) pp = x_("-"); else
 			{
 				infstr = initinfstr();
 				addstringtoinfstr(infstr, rb->comname);
@@ -1093,11 +1103,11 @@ void us_bind(INTBIG count, char *par[])
 				(INTBIG)pp, VSTRING|VDONTSAVE);
 			return;
 		}
-		ttyputusage("bind get LETTER key|button|menu|popup ENTRY");
+		ttyputusage(x_("bind get LETTER key|button|menu|popup ENTRY"));
 		return;
 	}
 
-	if (namesamen(pp, "set", l) == 0 && l >= 1)
+	if (namesamen(pp, x_("set"), l) == 0 && l >= 1)
 	{
 		if (count < 2)
 		{
@@ -1108,7 +1118,7 @@ void us_bind(INTBIG count, char *par[])
 				return;
 			}
 		}
-		l = strlen(pp = par[1]);
+		l = estrlen(pp = par[1]);
 		important = 0;
 		popup = menu = key = 0;
 		special = 0;
@@ -1118,7 +1128,7 @@ void us_bind(INTBIG count, char *par[])
 		menumessage = 0;
 		menumessagesize = TXTSETPOINTS(20);
 
-		if (namesamen(pp, "button", l) == 0 && l >= 1)
+		if (namesamen(pp, x_("button"), l) == 0 && l >= 1)
 		{
 			if (count < 3)
 			{
@@ -1132,7 +1142,7 @@ void us_bind(INTBIG count, char *par[])
 			pp = par[2];
 			for(but=0; but<buttoncount(); but++)
 			{
-				(void)strcpy(partial, buttonname(but, &important));
+				(void)estrcpy(partial, buttonname(but, &important));
 				for(j=0; j<important; j++)
 				{
 					if (isupper(pp[j])) pp[j] = tolower(pp[j]);
@@ -1149,7 +1159,7 @@ void us_bind(INTBIG count, char *par[])
 			important = 3;
 			varkey = us_binding_buttons_key;
 			bindex = but;
-		} else if (namesamen(pp, "key", l) == 0 && l >= 1)
+		} else if (namesamen(pp, x_("key"), l) == 0 && l >= 1)
 		{
 			if (count < 3)
 			{
@@ -1164,8 +1174,8 @@ void us_bind(INTBIG count, char *par[])
 			(void)us_getboundkey(pp, &key, &special);
 			varkey = us_binding_keys_key;
 			important = 3;
-		} else if ((namesamen(pp, "popup", l) == 0 ||
-			namesamen(pp, "input-popup", l) == 0) && l >= 1)
+		} else if ((namesamen(pp, x_("popup"), l) == 0 ||
+			namesamen(pp, x_("input-popup"), l) == 0) && l >= 1)
 		{
 			if (count < 3)
 			{
@@ -1184,12 +1194,12 @@ void us_bind(INTBIG count, char *par[])
 				return;
 			}
 			infstr = initinfstr();
-			addstringtoinfstr(infstr, "USER_binding_popup_");
+			addstringtoinfstr(infstr, x_("USER_binding_popup_"));
 			addstringtoinfstr(infstr, popname);
 			varkey = makekey(returninfstr(infstr));
 
 			/* look for possible message indication */
-			if (count >= 5 && namesamen(par[3], "message", strlen(par[3])) == 0)
+			if (count >= 5 && namesamen(par[3], x_("message"), estrlen(par[3])) == 0)
 			{
 				menumessage = par[4];
 				count -= 2;
@@ -1214,13 +1224,13 @@ void us_bind(INTBIG count, char *par[])
 			if (pp[0] == 'i') popup = -popup;
 			important = 4;
 			bindex = abs(popup);
-		} else if (namesamen(pp, "menu", l) == 0 && l >= 1)
+		} else if (namesamen(pp, x_("menu"), l) == 0 && l >= 1)
 		{
 			/* look for possible glyph/message/background indication */
 			while (count >= 4)
 			{
-				l = strlen(pp = par[2]);
-				if (namesamen(pp, "glyph", l) == 0)
+				l = estrlen(pp = par[2]);
+				if (namesamen(pp, x_("glyph"), l) == 0)
 				{
 					nodeglyph = getnodeproto(par[3]);
 					if (nodeglyph == NONODEPROTO)
@@ -1232,21 +1242,21 @@ void us_bind(INTBIG count, char *par[])
 					par += 2;
 					continue;
 				}
-				if (namesamen(pp, "message", l) == 0)
+				if (namesamen(pp, x_("message"), l) == 0)
 				{
 					menumessage = par[3];
 					count -= 2;
 					par += 2;
 					continue;
 				}
-				if (namesamen(pp, "textsize", l) == 0)
+				if (namesamen(pp, x_("textsize"), l) == 0)
 				{
 					menumessagesize = us_gettextsize(par[3], TXTSETQLAMBDA(12));
 					count -= 2;
 					par += 2;
 					continue;
 				}
-				if (namesamen(pp, "background", l) == 0)
+				if (namesamen(pp, x_("background"), l) == 0)
 				{
 					backgroundcolor = getecolor(par[3]);
 					count -= 2;
@@ -1279,13 +1289,13 @@ void us_bind(INTBIG count, char *par[])
 			x = myatoi(pp = par[3]);
 
 			/* reorder the meaning if the optional "w" character is appended */
-			lastchar = par[2][ strlen(par[2])-1 ];
+			lastchar = par[2][ estrlen(par[2])-1 ];
 			if (lastchar == 'w' && us_menuy > us_menux)
 			{
 				swap = x;   x = y;   y = swap;
 			} else
 			{
-				lastchar = par[3][ strlen(par[3])-1 ];
+				lastchar = par[3][ estrlen(par[3])-1 ];
 				if (lastchar == 'w' && us_menux > us_menuy)
 				{
 					swap = x;   x = y;   y = swap;
@@ -1307,7 +1317,7 @@ void us_bind(INTBIG count, char *par[])
 
 		if (important == 0)
 		{
-			ttyputusage("bind set key|button|menu|[input-]popup COMMAND");
+			ttyputusage(x_("bind set key|button|menu|[input-]popup COMMAND"));
 			return;
 		}
 
@@ -1329,7 +1339,7 @@ void us_bind(INTBIG count, char *par[])
 		}
 
 		/* handle un-binding */
-		if (strcmp(par[important], "-") == 0)
+		if (estrcmp(par[important], x_("-")) == 0)
 		{
 			if (key != 0 && us_islasteval(key, special))
 			{
@@ -1338,25 +1348,25 @@ void us_bind(INTBIG count, char *par[])
 			}
 			infstr = initinfstr();
 			if (key != 0)
-				formatinfstr(infstr, "%c%c", key, (special == 0 ? '\\' : '/'));
+				formatinfstr(infstr, x_("%c%c"), key, (special == 0 ? '\\' : '/'));
 			if (popup != 0)
 			{
-				if (popup < 0) addstringtoinfstr(infstr, "inputpopup="); else
-					addstringtoinfstr(infstr, "popup=");
+				if (popup < 0) addstringtoinfstr(infstr, x_("inputpopup=")); else
+					addstringtoinfstr(infstr, x_("popup="));
 				addstringtoinfstr(infstr, popname);
 				addtoinfstr(infstr, ' ');
 			}
 			if (menumessage != 0)
 			{
-				addstringtoinfstr(infstr, "message=\"");
+				addstringtoinfstr(infstr, x_("message=\""));
 				for(pt = menumessage; *pt != 0; pt++)
 				{
 					if (*pt == '"') addtoinfstr(infstr, '^');
 					addtoinfstr(infstr, *pt);
 				}
-				addstringtoinfstr(infstr, "\" ");
+				addstringtoinfstr(infstr, x_("\" "));
 			}
-			addstringtoinfstr(infstr, "command=");
+			addstringtoinfstr(infstr, x_("command="));
 			if (key != 0)
 			{
 				bindex = us_findboundkey(key, special, &pt);
@@ -1376,8 +1386,8 @@ void us_bind(INTBIG count, char *par[])
 		}
 
 		/* special case: cannot rebind the last "telltool user" */
-		if (i >= us_longcount || strcmp(us_lcommand[i].name, "telltool") != 0 ||
-			newcount != 1 || strcmp(a[1], "user") != 0)
+		if (i >= us_longcount || estrcmp(us_lcommand[i].name, x_("telltool")) != 0 ||
+			newcount != 1 || estrcmp(a[1], x_("user")) != 0)
 		{
 			if (key != 0 && us_islasteval(key, special))
 			{
@@ -1387,10 +1397,10 @@ void us_bind(INTBIG count, char *par[])
 		}
 
 		/* special case for menu binds of "getproto" command */
-		if (menu != 0 && namesame(par[important], "getproto") == 0)
+		if (menu != 0 && namesame(par[important], x_("getproto")) == 0)
 		{
-			if (newcount > 2 && namesame(a[1], "node") == 0) nodeglyph = getnodeproto(a[2]); else
-				if (newcount > 2 && namesame(a[1], "arc") == 0) arcglyph = getarcproto(a[2]); else
+			if (newcount > 2 && namesame(a[1], x_("node")) == 0) nodeglyph = getnodeproto(a[2]); else
+				if (newcount > 2 && namesame(a[1], x_("arc")) == 0) arcglyph = getarcproto(a[2]); else
 					if (newcount >= 2) nodeglyph = getnodeproto(a[1]);
 		}
 
@@ -1400,7 +1410,7 @@ void us_bind(INTBIG count, char *par[])
 			addstringtoinfstr(infstr, us_describeboundkey(key, special, 0));
 		if (nodeglyph != NONODEPROTO)
 		{
-			addstringtoinfstr(infstr, "node=");
+			addstringtoinfstr(infstr, x_("node="));
 			if (nodeglyph->primindex != 0)
 			{
 				addstringtoinfstr(infstr, nodeglyph->tech->techname);
@@ -1411,7 +1421,7 @@ void us_bind(INTBIG count, char *par[])
 		}
 		if (arcglyph != NOARCPROTO)
 		{
-			addstringtoinfstr(infstr, "arc=");
+			addstringtoinfstr(infstr, x_("arc="));
 			addstringtoinfstr(infstr, arcglyph->tech->techname);
 			addtoinfstr(infstr, ':');
 			addstringtoinfstr(infstr, arcglyph->protoname);
@@ -1419,17 +1429,17 @@ void us_bind(INTBIG count, char *par[])
 		}
 		if (backgroundcolor != 0)
 		{
-			(void)sprintf(partial, "background=%ld ", backgroundcolor);
+			(void)esnprintf(partial, 80, x_("background=%ld "), backgroundcolor);
 			addstringtoinfstr(infstr, partial);
 		}
 		if (menumessage != 0)
 		{
-			addstringtoinfstr(infstr, "message=\"");
+			addstringtoinfstr(infstr, x_("message=\""));
 			formerquickkey = 0;
 			if (popup != 0)
 			{
 				/* check for defaulted quick-key in popup assignment */
-				len = strlen(menumessage) - 1;
+				len = estrlen(menumessage) - 1;
 				if (menumessage[len] == '<') len--;
 				if (menumessage[len] == '/' || menumessage[len] == '\\')
 				{
@@ -1437,8 +1447,8 @@ void us_bind(INTBIG count, char *par[])
 					var = getvalkey((INTBIG)us_tool, VTOOL, VSTRING|VISARRAY, varkey);
 					if (var != NOVARIABLE)
 					{
-						us_parsebinding(((char **)var->addr)[bindex], &oldcommandbinding);
-						len = strlen(oldcommandbinding.menumessage) - 1;
+						us_parsebinding(((CHAR **)var->addr)[bindex], &oldcommandbinding);
+						len = estrlen(oldcommandbinding.menumessage) - 1;
 						if (oldcommandbinding.menumessage[len] == '<') len--;
 						if (oldcommandbinding.menumessage[len-1] == '/' ||
 							oldcommandbinding.menumessage[len-1] == '\\')
@@ -1453,25 +1463,25 @@ void us_bind(INTBIG count, char *par[])
 				addtoinfstr(infstr, *pt);
 				if (formerquickkey != 0 && (*pt == '/' || *pt == '\\'))
 				{
-					addtoinfstr(infstr, (char)formerquickkey);
+					addtoinfstr(infstr, (CHAR)formerquickkey);
 					formerquickkey = 0;
 				}
 			}
-			addstringtoinfstr(infstr, "\" ");
+			addstringtoinfstr(infstr, x_("\" "));
 			if (menumessagesize != 0)
 			{
-				(void)sprintf(partial, "messagesize=%ld ", menumessagesize);
+				(void)esnprintf(partial, 80, x_("messagesize=%ld "), menumessagesize);
 				addstringtoinfstr(infstr, partial);
 			}
 		}
 		if (popup != 0)
 		{
-			if (popup < 0) addstringtoinfstr(infstr, "inputpopup="); else
-				addstringtoinfstr(infstr, "popup=");
+			if (popup < 0) addstringtoinfstr(infstr, x_("inputpopup=")); else
+				addstringtoinfstr(infstr, x_("popup="));
 			addstringtoinfstr(infstr, popname);
 			addtoinfstr(infstr, ' ');
 		}
-		addstringtoinfstr(infstr, "command=");
+		addstringtoinfstr(infstr, x_("command="));
 		for(j=important; j<count; j++)
 		{
 			if (j != important) addtoinfstr(infstr, ' ');
@@ -1488,5 +1498,5 @@ void us_bind(INTBIG count, char *par[])
 		return;
 	}
 
-	ttyputbadusage("bind");
+	ttyputbadusage(x_("bind"));
 }
