@@ -32,12 +32,13 @@
 #include "global.h"
 #include "usr.h"
 #include "egraphics.h"
+#include "sim.h"
 
-void us_offtool(INTBIG count, char *par[])
+void us_offtool(INTBIG count, CHAR *par[])
 {
 	REGISTER INTBIG permanently;
 
-	if (count == 2 && namesamen(par[1], "permanently", strlen(par[1])) == 0)
+	if (count == 2 && namesamen(par[1], x_("permanently"), estrlen(par[1])) == 0)
 	{
 		count--;
 		permanently = 1;
@@ -45,21 +46,21 @@ void us_offtool(INTBIG count, char *par[])
 	us_settool(count, par, permanently);
 }
 
-void us_ontool(INTBIG count, char *par[])
+void us_ontool(INTBIG count, CHAR *par[])
 {
 	us_settool(count, par, 2);
 }
 
-void us_outhier(INTBIG count, char *par[])
+void us_outhier(INTBIG count, CHAR *par[])
 {
-	REGISTER INTBIG len, total, i, haveview, vlx, vhx, vly, vhy, value;
-	INTBIG lx, hx, ly, hy, index;
+	REGISTER INTBIG len, total, i, j, haveview, vlx, vhx, vly, vhy;
+	INTBIG lx, hx, ly, hy, index, viewinfo[22];
 	REGISTER NODEPROTO *curnp, *hinp, *np;
-	REGISTER char *pt;
 	REGISTER BOOLEAN newwindow, found;
 	REGISTER NODEINST *ni, *hini, *iconinst;
 	REGISTER PORTPROTO *pp, *curpp, *hipp;
 	REGISTER PORTEXPINST *pe;
+	REGISTER WINDOWPART *w;
 	REGISTER VARIABLE *var;
 	XARRAY into, outof;
 	HIGHLIGHT high;
@@ -67,7 +68,7 @@ void us_outhier(INTBIG count, char *par[])
 	/* make sure repeat count is valid */
 	if (count == 0) total = 1; else
 	{
-		total = atoi(par[0]);
+		total = eatoi(par[0]);
 		if (total <= 0)
 		{
 			us_abortcommand(_("Specify a positive number"));
@@ -79,6 +80,20 @@ void us_outhier(INTBIG count, char *par[])
 	curnp = us_needfacet();
 	if (curnp == NONODEPROTO) return;
 
+	/* if in waveform window, switch to associated circuit window */
+	if ((el_curwindowpart->state&WINDOWTYPE) == WAVEFORMWINDOW)
+	{
+		for(w = el_topwindowpart; w != NOWINDOWPART; w = w->nextwindowpart)
+			if (w != el_curwindowpart && w->curnodeproto == curnp) break;
+		if (w == NOWINDOWPART)
+		{
+			us_abortcommand(_("Cannot go up the hierarchy from this waveform window"));
+			return;
+		}
+		(void)setvalkey((INTBIG)us_tool, VTOOL, us_current_window_key, (INTBIG)w,
+			VWINDOWPART|VDONTSAVE);
+	}
+
 	/* initialize desired window extent */
 	lx = el_curwindowpart->screenlx;   hx = el_curwindowpart->screenhx;
 	ly = el_curwindowpart->screenly;   hy = el_curwindowpart->screenhy;
@@ -92,7 +107,7 @@ void us_outhier(INTBIG count, char *par[])
 		if (len == 1)
 		{
 			/* get the highlighted object */
-			if (!us_makehighlight(((char **)var->addr)[0], &high))
+			if (!us_makehighlight(((CHAR **)var->addr)[0], &high))
 			{
 				pp = NOPORTPROTO;
 				if ((high.status&HIGHTYPE) == HIGHTEXT)
@@ -131,46 +146,36 @@ void us_outhier(INTBIG count, char *par[])
 	{
 		hinp = NONODEPROTO;
 
-		hini = descentparent(curnp, &index);
+		hini = descentparent(curnp, &index, el_curwindowpart, viewinfo);
 		if (hini != NONODEINST)
 		{
 			hinp = hini->parent;
-			var = getvalkey((INTBIG)curnp, VNODEPROTO, VSTRING, us_descent_view_key);
-			if (var != NOVARIABLE)
+			for(j=0; j<22; j++) if (viewinfo[j] != 0) break;
+			if (j >= 22) haveview = 0; else
 			{
-				pt = (char *)var->addr;
-				for(i=0; i<22; i++)
-				{
-					while (*pt == ' ') pt++;
-					value = atoi(pt);
-					while (*pt != 0 && *pt != ' ') pt++;
-					switch (i)
-					{
-						case 0:  vlx         = value;   break;
-						case 1:  vhx         = value;   break;
-						case 2:  vly         = value;   break;
-						case 3:  vhy         = value;   break;
-						case 4:  into[0][0]  = value;   break;
-						case 5:  into[0][1]  = value;   break;
-						case 6:  into[0][2]  = value;   break;
-						case 7:  into[1][0]  = value;   break;
-						case 8:  into[1][1]  = value;   break;
-						case 9:  into[1][2]  = value;   break;
-						case 10: into[2][0]  = value;   break;
-						case 11: into[2][1]  = value;   break;
-						case 12: into[2][2]  = value;   break;
-						case 13: outof[0][0] = value;   break;
-						case 14: outof[0][1] = value;   break;
-						case 15: outof[0][2] = value;   break;
-						case 16: outof[1][0] = value;   break;
-						case 17: outof[1][1] = value;   break;
-						case 18: outof[1][2] = value;   break;
-						case 19: outof[2][0] = value;   break;
-						case 20: outof[2][1] = value;   break;
-						case 21: outof[2][2] = value;   break;
-					}
-				}
 				haveview = 1;
+				vlx         = viewinfo[0];
+				vhx         = viewinfo[1];
+				vly         = viewinfo[2];
+				vhy         = viewinfo[3];
+				into[0][0]  = viewinfo[4];
+				into[0][1]  = viewinfo[5];
+				into[0][2]  = viewinfo[6];
+				into[1][0]  = viewinfo[7];
+				into[1][1]  = viewinfo[8];
+				into[1][2]  = viewinfo[9];
+				into[2][0]  = viewinfo[10];
+				into[2][1]  = viewinfo[11];
+				into[2][2]  = viewinfo[12];
+				outof[0][0] = viewinfo[13];
+				outof[0][1] = viewinfo[14];
+				outof[0][2] = viewinfo[15];
+				outof[1][0] = viewinfo[16];
+				outof[1][1] = viewinfo[17];
+				outof[1][2] = viewinfo[18];
+				outof[2][0] = viewinfo[19];
+				outof[2][1] = viewinfo[20];
+				outof[2][2] = viewinfo[21];
 			}
 		}
 
@@ -262,24 +267,31 @@ void us_outhier(INTBIG count, char *par[])
 	/* display the final location */
 	if (haveview != 0)
 	{
-		us_setxarray((INTBIG)el_curwindowpart, VWINDOWPART, "intofacet", into);
-		us_setxarray((INTBIG)el_curwindowpart, VWINDOWPART, "outoffacet", outof);
+		us_setxarray((INTBIG)el_curwindowpart, VWINDOWPART, x_("intofacet"), into);
+		us_setxarray((INTBIG)el_curwindowpart, VWINDOWPART, x_("outoffacet"), outof);
 		if (outof[2][0] == 0 && outof[2][1] == 0 && outof[2][2] == 0)
 		{
-			(void)setval((INTBIG)el_curwindowpart, VWINDOWPART, "state",
+			(void)setval((INTBIG)el_curwindowpart, VWINDOWPART, x_("state"),
 				el_curwindowpart->state & ~INPLACEEDIT, VINTEGER);
 		} else
 		{
-			(void)setval((INTBIG)el_curwindowpart, VWINDOWPART, "state",
+			(void)setval((INTBIG)el_curwindowpart, VWINDOWPART, x_("state"),
 				el_curwindowpart->state | INPLACEEDIT, VINTEGER);
-			(void)setval((INTBIG)el_curwindowpart, VWINDOWPART, "inplacedepth",
+			(void)setval((INTBIG)el_curwindowpart, VWINDOWPART, x_("inplacedepth"),
 				el_curwindowpart->inplacedepth-1, VINTEGER);
 		}
 	}
-	us_switchtofacet(hinp, lx, hx, ly, hy, hini, hipp, newwindow, 1);
+	us_switchtofacet(hinp, lx, hx, ly, hy, hini, hipp, newwindow, TRUE, TRUE);
+
+	/* if simulating, coordinate this hierarchy traversal with the waveform */
+	if (el_curwindowpart != NOWINDOWPART &&
+		(el_curwindowpart->state&WINDOWMODE) == WINDOWSIMMODE)
+	{
+		asktool(sim_tool, "traverse-up", (INTBIG)hinp);
+	}
 }
 
-void us_package(INTBIG count, char *par[])
+void us_package(INTBIG count, CHAR *par[])
 {
 	INTBIG lx, hx, ly, hy;
 	REGISTER INTBIG search;
@@ -289,7 +301,7 @@ void us_package(INTBIG count, char *par[])
 	REGISTER NODEINST *ni, *newni;
 	REGISTER ARCINST *ai, *newar;
 	REGISTER LIBRARY *lib;
-	REGISTER char *pt;
+	REGISTER CHAR *pt;
 	extern COMCOMP us_packagep;
 
 	/* get the specified area */
@@ -425,7 +437,7 @@ void us_package(INTBIG count, char *par[])
 	ttyputmsg(_("Facet %s created"), describenodeproto(np));
 }
 
-void us_port(INTBIG count, char *par[])
+void us_port(INTBIG count, CHAR *par[])
 {
 	REGISTER INTBIG i, l, labels, total, reducehighlighting;
 	INTBIG lx, hx, ly, hy, mlx, mly, mhx, mhy, bits, mask, newbits, x, y, deleted;
@@ -438,8 +450,8 @@ void us_port(INTBIG count, char *par[])
 	REGISTER LIBRARY *olib;
 	GEOM *fromgeom, *togeom;
 	PORTPROTO *fromport, *toport;
-	REGISTER char *pt;
-	char *portname;
+	REGISTER CHAR *pt;
+	CHAR *portname, *refname;
 	NODEINST **nilist;
 	REGISTER HIGHLIGHT *high;
 	HIGHLIGHT newhigh;
@@ -458,18 +470,18 @@ void us_port(INTBIG count, char *par[])
 			return;
 		}
 	}
-	l = strlen(pt = par[0]);
+	l = estrlen(pt = par[0]);
 
-	if (namesamen(pt, "labels", l) == 0 && l >= 1)
+	if (namesamen(pt, x_("labels"), l) == 0 && l >= 1)
 	{
 		if (count > 1)
 		{
-			l = strlen(pt = par[1]);
-			if (namesamen(pt, "crosses", l) == 0 && l >= 1) labels = PORTSCROSS; else
-			if (namesamen(pt, "short", l) == 0 && l >= 2) labels = PORTSSHORT; else
-			if (namesamen(pt, "long", l) == 0 && l >= 1) labels = PORTSFULL; else
+			l = estrlen(pt = par[1]);
+			if (namesamen(pt, x_("crosses"), l) == 0 && l >= 1) labels = PORTSCROSS; else
+			if (namesamen(pt, x_("short"), l) == 0 && l >= 2) labels = PORTSSHORT; else
+			if (namesamen(pt, x_("long"), l) == 0 && l >= 1) labels = PORTSFULL; else
 			{
-				ttyputusage("port labels short|long|crosses");
+				ttyputusage(x_("port labels short|long|crosses"));
 				return;
 			}
 			startobjectchange((INTBIG)us_tool, VTOOL);
@@ -486,16 +498,16 @@ void us_port(INTBIG count, char *par[])
 		return;
 	}
 
-	if (namesamen(pt, "export-labels", l) == 0 && l >= 8)
+	if (namesamen(pt, x_("export-labels"), l) == 0 && l >= 8)
 	{
 		if (count > 1)
 		{
-			l = strlen(pt = par[1]);
-			if (namesamen(pt, "crosses", l) == 0 && l >= 1) labels = EXPORTSCROSS; else
-			if (namesamen(pt, "short", l) == 0 && l >= 2) labels = EXPORTSSHORT; else
-			if (namesamen(pt, "long", l) == 0 && l >= 1) labels = EXPORTSFULL; else
+			l = estrlen(pt = par[1]);
+			if (namesamen(pt, x_("crosses"), l) == 0 && l >= 1) labels = EXPORTSCROSS; else
+			if (namesamen(pt, x_("short"), l) == 0 && l >= 2) labels = EXPORTSSHORT; else
+			if (namesamen(pt, x_("long"), l) == 0 && l >= 1) labels = EXPORTSFULL; else
 			{
-				ttyputusage("port export-labels short|long|crosses");
+				ttyputusage(x_("port export-labels short|long|crosses"));
 				return;
 			}
 			startobjectchange((INTBIG)us_tool, VTOOL);
@@ -512,11 +524,11 @@ void us_port(INTBIG count, char *par[])
 		return;
 	}
 
-	if (namesamen(pt, "synchronize-library", l) == 0 && l >= 1)
+	if (namesamen(pt, x_("synchronize-library"), l) == 0 && l >= 1)
 	{
 		if (count <= 1)
 		{
-			ttyputusage("port synchronize-library LIBRARY");
+			ttyputusage(x_("port synchronize-library LIBRARY"));
 			return;
 		}
 		olib = getlibrary(par[1]);
@@ -534,7 +546,7 @@ void us_port(INTBIG count, char *par[])
 		return;
 	}
 
-	if (namesamen(pt, "identify-facet", l) == 0 && l >= 10)
+	if (namesamen(pt, x_("identify-facet"), l) == 0 && l >= 10)
 	{
 		/* make sure there is a current facet */
 		np = us_needfacet();
@@ -548,7 +560,7 @@ void us_port(INTBIG count, char *par[])
 		return;
 	}
 
-	if (namesamen(pt, "identify-node", l) == 0 && l >= 10)
+	if (namesamen(pt, x_("identify-node"), l) == 0 && l >= 10)
 	{
 		/* make sure there is a current node */
 		if ((el_curwindowpart->state&WINDOWTYPE) == DISP3DWINDOW)
@@ -568,11 +580,11 @@ void us_port(INTBIG count, char *par[])
 		for(i=0; g[i] != NOGEOM; i++)
 			nilist[i] = g[i]->entryaddr.ni;
 		us_identifyports(i, nilist, nilist[0]->proto, LAYERA, FALSE);
-		efree((char *)nilist);
+		efree((CHAR *)nilist);
 		return;
 	}
 
-	if (namesamen(pt, "move", l) == 0 && l >= 1)
+	if (namesamen(pt, x_("move"), l) == 0 && l >= 1)
 	{
 		if (us_gettwoobjects(&fromgeom, &fromport, &togeom, &toport))
 		{
@@ -599,8 +611,8 @@ void us_port(INTBIG count, char *par[])
 		reducehighlighting = 1;
 		if (count > 1)
 		{
-			l = strlen(pt = par[1]);
-			if (namesamen(pt, "remain-highlighted", l) == 0) reducehighlighting = 0;
+			l = estrlen(pt = par[1]);
+			if (namesamen(pt, x_("remain-highlighted"), l) == 0) reducehighlighting = 0;
 		}
 
 		/* get the "source" node and export */
@@ -650,7 +662,7 @@ void us_port(INTBIG count, char *par[])
 		return;
 	}
 
-	if (namesamen(pt, "re-export-all", l) == 0 && l >= 1)
+	if (namesamen(pt, x_("re-export-all"), l) == 0 && l >= 1)
 	{
 		/* make sure there is a current facet */
 		np = us_needfacet();
@@ -718,7 +730,7 @@ void us_port(INTBIG count, char *par[])
 		return;
 	}
 
-	if (namesamen(pt, "highlighted-re-export", l) == 0 && l >= 1)
+	if (namesamen(pt, x_("highlighted-re-export"), l) == 0 && l >= 1)
 	{
 		/* get the necessary polygon */
 		(void)needstaticpolygon(&poly, 4, us_tool->cluster);
@@ -811,7 +823,7 @@ void us_port(INTBIG count, char *par[])
 		return;
 	}
 
-	if (namesamen(pt, "power-ground-re-export", l) == 0 && l >= 1)
+	if (namesamen(pt, x_("power-ground-re-export"), l) == 0 && l >= 1)
 	{
 		/* make sure there is a current facet */
 		np = us_needfacet();
@@ -866,14 +878,14 @@ void us_port(INTBIG count, char *par[])
 		return;
 	}
 
-	if (namesamen(pt, "not", l) == 0 && l >= 1)
+	if (namesamen(pt, x_("not"), l) == 0 && l >= 1)
 	{
-		if (count <= 1 || namesamen(par[1], "export", strlen(par[1])) != 0)
+		if (count <= 1 || namesamen(par[1], x_("export"), estrlen(par[1])) != 0)
 		{
-			ttyputusage("port not export [OPTIONS]");
+			ttyputusage(x_("port not export [OPTIONS]"));
 			return;
 		}
-		if (count == 3 && namesame(par[2], "geometry") == 0)
+		if (count == 3 && namesame(par[2], x_("geometry")) == 0)
 		{
 			/* delete ports in selected area */
 			np = us_getareabounds(&lx, &hx, &ly, &hy);
@@ -915,7 +927,7 @@ void us_port(INTBIG count, char *par[])
 			if (deleted == 0) ttyputmsg(_("No exports are in the selected area"));
 			return;
 		}
-		if (count == 3 && namesame(par[2], "all") == 0)
+		if (count == 3 && namesame(par[2], x_("all")) == 0)
 		{
 			g = us_gethighlighted(WANTNODEINST, 0, 0);
 			if (g[0] == NOGEOM)
@@ -984,7 +996,7 @@ void us_port(INTBIG count, char *par[])
 		if (us_cantedit(ni->parent, NONODEINST, TRUE)) return;
 
 		/* get the specification details */
-		pp = us_portdetails(ppt, count-2, &par[2], ni, &bits, &mask, TRUE, "");
+		pp = us_portdetails(ppt, count-2, &par[2], ni, &bits, &mask, TRUE, x_(""), &refname);
 		if (pp == NOPORTPROTO) return;
 
 		/* remove highlighting */
@@ -1003,7 +1015,7 @@ void us_port(INTBIG count, char *par[])
 		return;
 	}
 
-	if (namesamen(pt, "export", l) == 0 && l >= 1)
+	if (namesamen(pt, x_("export"), l) == 0 && l >= 1)
 	{
 		ni = (NODEINST *)us_getobject(VNODEINST, FALSE);
 		if (ni == NONODEINST) return;
@@ -1036,7 +1048,7 @@ void us_port(INTBIG count, char *par[])
 			ttyputmsg(_("Already a port called %s, calling this %s"), pt, portname);
 
 		/* get the specification details */
-		pp = us_portdetails(NOPORTPROTO, count-2, &par[2], ni, &bits, &mask, FALSE, pt);
+		pp = us_portdetails(NOPORTPROTO, count-2, &par[2], ni, &bits, &mask, FALSE, pt, &refname);
 		if (pp == NOPORTPROTO) return;
 
 		/* save highlighting */
@@ -1044,7 +1056,9 @@ void us_port(INTBIG count, char *par[])
 		us_clearhighlightcount();
 
 		/* make the port */
-		(void)us_makenewportproto(ni->parent, ni, pp, portname, mask, bits, pp->textdescript);
+		pp = us_makenewportproto(ni->parent, ni, pp, portname, mask, bits, pp->textdescript);
+		if (*refname != 0)
+			setval((INTBIG)pp, VPORTPROTO, x_("EXPORT_reference_name"), (INTBIG)refname, VSTRING);
 
 		/* restore highlighting */
 		us_pophighlight(FALSE);
@@ -1053,7 +1067,7 @@ void us_port(INTBIG count, char *par[])
 		return;
 	}
 
-	if (namesamen(pt, "change", l) == 0 && l >= 1)
+	if (namesamen(pt, x_("change"), l) == 0 && l >= 1)
 	{
 		high = us_getonehighlight();
 		if (high == NOHIGHLIGHT) return;
@@ -1077,7 +1091,7 @@ void us_port(INTBIG count, char *par[])
 		if (us_cantedit(ni->parent, NONODEINST, TRUE)) return;
 
 		/* get the specification details */
-		pp = us_portdetails(ppt, count-1, &par[1], ni, &bits, &mask, TRUE, "");
+		pp = us_portdetails(ppt, count-1, &par[1], ni, &bits, &mask, TRUE, x_(""), &refname);
 		if (pp == NOPORTPROTO) return;
 
 		/* change the port characteristics */
@@ -1088,7 +1102,7 @@ void us_port(INTBIG count, char *par[])
 			newbits = (newbits & ~PORTDRAWN) | (bits & PORTDRAWN);
 		if ((mask&BODYONLY) != 0)
 			newbits = (newbits & ~BODYONLY) | (bits & BODYONLY);
-		setval((INTBIG)pp, VPORTPROTO, "userbits", newbits, VINTEGER);
+		setval((INTBIG)pp, VPORTPROTO, x_("userbits"), newbits, VINTEGER);
 
 		/* propagate the change information up the hierarchy */
 		changeallports(pp);
@@ -1098,20 +1112,20 @@ void us_port(INTBIG count, char *par[])
 		if ((pp->userbits&STATEBITS) == 0)
 			addstringtoinfstr(infstr, _(" has no characteristics")); else
 		{
-			formatinfstr(infstr, _(" is %s"), describeportbits(pp));
+			formatinfstr(infstr, _(" is %s"), describeportbits(pp->userbits));
 		}
 		formatinfstr(infstr, _(" (label %s"), us_describetextdescript(pp->textdescript));
 		if ((pp->userbits&PORTDRAWN) != 0) addstringtoinfstr(infstr, _(",always-drawn"));
 		if ((pp->userbits&BODYONLY) != 0) addstringtoinfstr(infstr, _(",only-on-body"));
-		addstringtoinfstr(infstr, ") ");
-		ttyputmsg("%s", returninfstr(infstr));
+		addstringtoinfstr(infstr, x_(") "));
+		ttyputmsg(x_("%s"), returninfstr(infstr));
 		return;
 	}
 
-	ttyputbadusage("port");
+	ttyputbadusage(x_("port"));
 }
 
-void us_quit(INTBIG count, char *par[])
+void us_quit(INTBIG count, CHAR *par[])
 {
 	if (us_preventloss(NOLIBRARY, 0, TRUE)) return;
 	bringdown();
