@@ -46,18 +46,18 @@
 
 /* prototypes for local routines */
 static PORTPROTO *us_convport(NODEINST*, NODEINST*, PORTPROTO*);
-static void       us_dumpfields(char***, INTBIG, INTBIG, FILE*, char*);
+static void       us_dumpfields(CHAR***, INTBIG, INTBIG, FILE*, CHAR*);
 static ARCPROTO  *us_figurenewaproto(ARCPROTO*, TECHNOLOGY*);
 static NODEPROTO *us_figurenewnproto(NODEINST*, TECHNOLOGY*);
 static PORTPROTO *us_tranconvpp(NODEINST*, PORTPROTO*);
 static PORTPROTO *us_trangetproto(NODEINST*, INTBIG);
 static INTBIG     us_tranismos(NODEINST*);
 static void       us_tranplacenode(NODEINST*, NODEPROTO*, NODEPROTO*, TECHNOLOGY*, TECHNOLOGY*);
-static NODEPROTO *us_tran_linkage(char*, VIEW*, NODEPROTO*);
+static NODEPROTO *us_tran_linkage(CHAR*, VIEW*, NODEPROTO*);
 static void       us_tran_logmakearcs(NODEPROTO*, NODEPROTO*);
 static NODEINST  *us_tran_logmakenode(NODEPROTO*, NODEINST*, INTSML, INTSML, NODEPROTO*, TECHNOLOGY*);
 static void       us_tran_logmakenodes(NODEPROTO*, NODEPROTO*, TECHNOLOGY*);
-static NODEPROTO *us_tran_makelayoutfacets(NODEPROTO*, char*, TECHNOLOGY*, TECHNOLOGY*, VIEW*);
+static NODEPROTO *us_tran_makelayoutfacets(NODEPROTO*, CHAR*, TECHNOLOGY*, TECHNOLOGY*, VIEW*);
 static BOOLEAN    us_tran_makelayoutparts(NODEPROTO*, NODEPROTO*, TECHNOLOGY*, TECHNOLOGY*, VIEW*);
 static void       us_tran_makemanhattan(NODEPROTO*);
 
@@ -87,7 +87,7 @@ NODEPROTO *us_convertfacet(NODEPROTO *oldfacet, TECHNOLOGY *newtech)
 		 * Look to see if the technology has its own routine.
 		 * Note that it may call some of the functions in this file!
 		 */
-		var = getval((INTBIG)el_curtech, VTECHNOLOGY, VADDRESS, "TECH_schematic_conversion");
+		var = getval((INTBIG)el_curtech, VTECHNOLOGY, VADDRESS, x_("TECH_schematic_conversion"));
 		if (var != NOVARIABLE)
 		{
 			localconversion = (NODEPROTO *(*)(NODEPROTO*, TECHNOLOGY*))var->addr;
@@ -138,10 +138,10 @@ NODEPROTO *us_convertfacet(NODEPROTO *oldfacet, TECHNOLOGY *newtech)
  * equivalent to an old facet in "facet".  The view type of the new facet is
  * in "newfacetview" and the view type of the old facet is in "facetview"
  */
-NODEPROTO *us_tran_linkage(char *newfacetname, VIEW *newfacetview, NODEPROTO *facet)
+NODEPROTO *us_tran_linkage(CHAR *newfacetname, VIEW *newfacetview, NODEPROTO *facet)
 {
 	NODEPROTO *newfacet;
-	REGISTER char *facetname;
+	REGISTER CHAR *facetname;
 	REGISTER void *infstr;
 
 	/* create the new facet */
@@ -498,14 +498,14 @@ PORTPROTO *us_trangetproto(NODEINST *ni, INTBIG port)
  * is "oldtech" and the technology to use for the new facet is "newtech".  The
  * old view type is "oldview" and the new view type is "nview".
  */
-NODEPROTO *us_tran_makelayoutfacets(NODEPROTO *oldfacet, char *newfacetname,
+NODEPROTO *us_tran_makelayoutfacets(NODEPROTO *oldfacet, CHAR *newfacetname,
 	TECHNOLOGY *oldtech, TECHNOLOGY *newtech, VIEW *nview)
 {
 	REGISTER NODEPROTO *newfacet, *rnp;
 	REGISTER INTBIG bits;
 	REGISTER NODEINST *ni;
 	REGISTER ARCINST *ai;
-	char *str;
+	CHAR *str;
 
 	/* first convert the sub-facets */
 	for(ni = oldfacet->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
@@ -563,7 +563,7 @@ BOOLEAN us_tran_makelayoutparts(NODEPROTO *oldfacet, NODEPROTO *newfacet,
 	ARCINST *ai;
 	REGISTER PORTPROTO *mospp1, *mospp2, *schempp1, *schempp2;
 	INTBIG x1, y1, x2, y2, lx1, hx1, ly1, hy1, lx2, hx2, ly2, hy2, tx1, ty1, tx2, ty2;
-	REGISTER INTBIG newwid, newbits, oldlambda, newlambda;
+	REGISTER INTBIG newwid, newbits, oldlambda, newlambda, defwid, curwid;
 	REGISTER INTBIG badarcs, i, j;
 	REGISTER BOOLEAN univarcs;
 	static POLYGON *poly1 = NOPOLYGON, *poly2 = NOPOLYGON;
@@ -596,6 +596,7 @@ BOOLEAN us_tran_makelayoutparts(NODEPROTO *oldfacet, NODEPROTO *newfacet,
 		}
 
 		/* handle primitives */
+		if (ni->proto == gen_facetcenterprim) continue;
 		newnp = us_figurenewnproto(ni, newtech);
 		us_tranplacenode(ni, newnp, newfacet, oldtech, newtech);
 	}
@@ -651,8 +652,10 @@ BOOLEAN us_tran_makelayoutparts(NODEPROTO *oldfacet, NODEPROTO *newfacet,
 			newbits &= ~(FIXED | FIXANG);
 		} else
 		{
-			newwid = ai->width - arcwidthoffset(ai);
-			newwid = muldiv(newwid, newlambda, oldlambda) + arcprotowidthoffset(newap);
+			defwid = ai->proto->nominalwidth - arcprotowidthoffset(ai->proto);
+			curwid = ai->width - arcwidthoffset(ai);
+			newwid = muldiv(newap->nominalwidth - arcprotowidthoffset(newap), curwid, defwid) +
+				arcprotowidthoffset(newap);
 			if (newwid <= 0) newwid = defaultarcwidth(newap);
 		}
 
@@ -709,7 +712,7 @@ void us_tranplacenode(NODEINST *ni, NODEPROTO *newnp, NODEPROTO *newfacet,
 {
 	INTBIG lx, ly, hx, hy, nlx, nly, nhx, nhy, bx, by, length, width;
 	REGISTER INTBIG i, len, newsx, newsy, x1, y1, newlx, newhx, newly, newhy, *newtrace,
-		oldlambda, newlambda;
+		oldlambda, newlambda, thissizex, thissizey, defsizex, defsizey;
 	XARRAY trans;
 	REGISTER INTSML trn;
 	REGISTER PORTEXPINST *pexp;
@@ -725,7 +728,7 @@ void us_tranplacenode(NODEINST *ni, NODEPROTO *newnp, NODEPROTO *newfacet,
 	if (ni->proto->primindex != 0)
 	{
 		/* get offsets for new node type */
-		nodeprotosizeoffset(newnp, &nlx, &nly, &nhx, &nhy);
+		nodeprotosizeoffset(newnp, &nlx, &nly, &nhx, &nhy, NONODEPROTO);
 
 		/* special case for schematic transistors: get size from description */
 		if (((ni->proto->userbits&NFUNCTION) >> NFUNCTIONSH) == NPTRANS)
@@ -744,14 +747,22 @@ void us_tranplacenode(NODEINST *ni, NODEPROTO *newnp, NODEPROTO *newfacet,
 			newsy = muldiv(hy - ly, newlambda, oldlambda);
 		} else
 		{
-			/* compute true bounds of old node */
+			/* determine this node's percentage of the default node's size */
+			nodeprotosizeoffset(ni->proto, &lx, &ly, &hx, &hy, NONODEPROTO);
+			defsizex = (ni->proto->highx - hx) - (ni->proto->lowx + lx);
+			defsizey = (ni->proto->highy - hy) - (ni->proto->lowy + ly);
+
 			nodesizeoffset(ni, &lx, &ly, &hx, &hy);
+			thissizex = (ni->highx - hx) - (ni->lowx + lx);
+			thissizey = (ni->highy - hy) - (ni->lowy + ly);
+
+			/* compute size of new node that is the same percentage of its default */
+			newsx = muldiv((newnp->highx - nhx) - (newnp->lowx + nlx), thissizex, defsizex);
+			newsy = muldiv((newnp->highy - nhy) - (newnp->lowy + nly), thissizey, defsizey);
+
+			/* determine location of new node */
 			lx = ni->lowx + lx;   hx = ni->highx - hx;
 			ly = ni->lowy + ly;   hy = ni->highy - hy;
-
-			/* compute scaled size for new node */
-			newsx = muldiv(hx - lx, newlambda, oldlambda);
-			newsy = muldiv(hy - ly, newlambda, oldlambda);
 		}
 
 		/* compute center of old node */
@@ -780,6 +791,7 @@ void us_tranplacenode(NODEINST *ni, NODEPROTO *newnp, NODEPROTO *newfacet,
 	if (newni == NONODEINST) return;
 	newni->userbits |= (ni->userbits & (NEXPAND | WIPED | NSHORT));
 	ni->temp1 = (INTBIG)newni;
+	(void)copyvars((INTBIG)ni, VNODEINST, (INTBIG)newni, VNODEINST, FALSE);
 
 	/* copy "trace" information if there is any */
 	var = gettrace(ni);
@@ -792,8 +804,9 @@ void us_tranplacenode(NODEINST *ni, NODEPROTO *newnp, NODEPROTO *newfacet,
 			newtrace[i] = muldiv(((INTBIG *)var->addr)[i], newlambda, oldlambda);
 		(void)setvalkey((INTBIG)newni, VNODEINST, el_trace_key, (INTBIG)newtrace,
 			VINTEGER|VISARRAY|(len<<VLENGTHSH));
-		efree((char *)newtrace);
+		efree((CHAR *)newtrace);
 	}
+	endobjectchange((INTBIG)newni, VNODEINST);
 
 	/* re-export any ports on the node */
 	for(pexp = ni->firstportexpinst; pexp != NOPORTEXPINST; pexp = pexp->nextportexpinst)
@@ -986,8 +999,8 @@ extern LIST us_tecarc_functions[];
 void us_printtechnology(TECHNOLOGY *tech)
 {
 	FILE *f;
-	char *name, *fieldname, *colorsymbol, thefield[50], *truename, **fields[MAXCOLS];
-	REGISTER char **names, **colors, **styles, **cifs, **gdss,
+	CHAR *name, *fieldname, *colorsymbol, thefield[50], *truename, **fields[MAXCOLS];
+	REGISTER CHAR **names, **colors, **styles, **cifs, **gdss,
 		**funcs, **layers, **layersizes, **extensions, **angles, **wipes, **ports,
 		**portsizes, **portangles, **connections;
 	REGISTER INTBIG i, j, k, l, m, tot, base;
@@ -1014,7 +1027,7 @@ void us_printtechnology(TECHNOLOGY *tech)
 
 	infstr = initinfstr();
 	addstringtoinfstr(infstr, tech->techname);
-	addstringtoinfstr(infstr, ".doc");
+	addstringtoinfstr(infstr, x_(".doc"));
 	name = returninfstr(infstr);
 	f = xcreate(name, el_filetypetext, _("Technology Documentation File"), &truename);
 	if (f == NULL)
@@ -1027,27 +1040,27 @@ void us_printtechnology(TECHNOLOGY *tech)
 	/****************************** dump layers ******************************/
 
 	/* get layer variables */
-	cifvar = getval((INTBIG)tech, VTECHNOLOGY, VSTRING|VISARRAY, "IO_cif_layer_names");
-	gdsvar = getval((INTBIG)tech, VTECHNOLOGY, VINTEGER|VISARRAY, "IO_gds_layer_numbers");
-	funcvar = getval((INTBIG)tech, VTECHNOLOGY, VINTEGER|VISARRAY, "TECH_layer_function");
+	cifvar = getval((INTBIG)tech, VTECHNOLOGY, VSTRING|VISARRAY, x_("IO_cif_layer_names"));
+	gdsvar = getval((INTBIG)tech, VTECHNOLOGY, VSTRING|VISARRAY, x_("IO_gds_layer_numbers"));
+	funcvar = getval((INTBIG)tech, VTECHNOLOGY, VINTEGER|VISARRAY, x_("TECH_layer_function"));
 
 	/* allocate space for all layer fields */
-	names = (char **)emalloc((tech->layercount+1) * (sizeof (char *)), el_tempcluster);
-	colors = (char **)emalloc((tech->layercount+1) * (sizeof (char *)), el_tempcluster);
-	styles = (char **)emalloc((tech->layercount+1) * (sizeof (char *)), el_tempcluster);
-	cifs = (char **)emalloc((tech->layercount+1) * (sizeof (char *)), el_tempcluster);
-	gdss = (char **)emalloc((tech->layercount+1) * (sizeof (char *)), el_tempcluster);
-	funcs = (char **)emalloc((tech->layercount+1) * (sizeof (char *)), el_tempcluster);
+	names = (CHAR **)emalloc((tech->layercount+1) * (sizeof (CHAR *)), el_tempcluster);
+	colors = (CHAR **)emalloc((tech->layercount+1) * (sizeof (CHAR *)), el_tempcluster);
+	styles = (CHAR **)emalloc((tech->layercount+1) * (sizeof (CHAR *)), el_tempcluster);
+	cifs = (CHAR **)emalloc((tech->layercount+1) * (sizeof (CHAR *)), el_tempcluster);
+	gdss = (CHAR **)emalloc((tech->layercount+1) * (sizeof (CHAR *)), el_tempcluster);
+	funcs = (CHAR **)emalloc((tech->layercount+1) * (sizeof (CHAR *)), el_tempcluster);
 	if (names == 0 || colors == 0 || styles == 0 || cifs == 0 || gdss == 0 || funcs == 0)
 		return;
 
 	/* load the header */
-	(void)allocstring(&names[0], "Layer", el_tempcluster);
-	(void)allocstring(&colors[0], "Color", el_tempcluster);
-	(void)allocstring(&styles[0], "Style", el_tempcluster);
-	(void)allocstring(&cifs[0], "CIF", el_tempcluster);
-	(void)allocstring(&gdss[0], "GDS", el_tempcluster);
-	(void)allocstring(&funcs[0], "Function", el_tempcluster);
+	(void)allocstring(&names[0], x_("Layer"), el_tempcluster);
+	(void)allocstring(&colors[0], x_("Color"), el_tempcluster);
+	(void)allocstring(&styles[0], x_("Style"), el_tempcluster);
+	(void)allocstring(&cifs[0], x_("CIF"), el_tempcluster);
+	(void)allocstring(&gdss[0], x_("GDS"), el_tempcluster);
+	(void)allocstring(&funcs[0], x_("Function"), el_tempcluster);
 
 	/* compute each layer */
 	for(i=0; i<tech->layercount; i++)
@@ -1055,33 +1068,30 @@ void us_printtechnology(TECHNOLOGY *tech)
 		(void)allocstring(&names[i+1], layername(tech, i), el_tempcluster);
 
 		gra = tech->layers[i];
-		if (ecolorname(gra->col, &fieldname, &colorsymbol)) fieldname = "?";
+		if (ecolorname(gra->col, &fieldname, &colorsymbol)) fieldname = x_("?");
 		(void)allocstring(&colors[i+1], fieldname, el_tempcluster);
 
-		if (el_curwindowpart == NOWINDOWPART) fieldname = "unkwn."; else
+		if (el_curwindowpart == NOWINDOWPART) fieldname = x_("unkwn."); else
 		{
 			switch (gra->colstyle&(NATURE|INVISIBLE))
 			{
-				case SOLIDC:              fieldname = "solid";    break;
-				case PATTERNED:           fieldname = "pat.";     break;
-				case INVISIBLE|SOLIDC:    fieldname = "INVsol";   break;
-				case INVISIBLE|PATTERNED: fieldname = "INVpat";   break;
+				case SOLIDC:              fieldname = x_("solid");    break;
+				case PATTERNED:           fieldname = x_("pat.");     break;
+				case INVISIBLE|SOLIDC:    fieldname = x_("INVsol");   break;
+				case INVISIBLE|PATTERNED: fieldname = x_("INVpat");   break;
 			}
 		}
 		(void)allocstring(&styles[i+1], fieldname, el_tempcluster);
 
-		if (cifvar == NOVARIABLE) fieldname = "---"; else
-			fieldname = ((char **)cifvar->addr)[i];
+		if (cifvar == NOVARIABLE) fieldname = x_("---"); else
+			fieldname = ((CHAR **)cifvar->addr)[i];
 		(void)allocstring(&cifs[i+1], fieldname, el_tempcluster);
 
-		if (gdsvar == NOVARIABLE) fieldname = "---"; else
-		{
-			(void)sprintf(thefield, "%ld", ((INTBIG *)gdsvar->addr)[i]);
-			fieldname = thefield;
-		}
+		if (gdsvar == NOVARIABLE) fieldname = x_("---"); else
+			fieldname = ((CHAR **)gdsvar->addr)[i];
 		(void)allocstring(&gdss[i+1], fieldname, el_tempcluster);
 
-		if (funcvar == NOVARIABLE) fieldname = "---"; else
+		if (funcvar == NOVARIABLE) fieldname = x_("---"); else
 		{
 			func = ((INTBIG *)funcvar->addr)[i];
 			infstr = initinfstr();
@@ -1094,7 +1104,7 @@ void us_printtechnology(TECHNOLOGY *tech)
 	/* write the layer information */
 	fields[0] = names;   fields[1] = colors;   fields[2] = styles;
 	fields[3] = cifs;    fields[4] = gdss;     fields[5] = funcs;
-	us_dumpfields(fields, 6, tech->layercount+1, f, "LAYERS");
+	us_dumpfields(fields, 6, tech->layercount+1, f, x_("LAYERS"));
 	for(i=0; i<=tech->layercount; i++)
 	{
 		efree(names[i]);
@@ -1104,12 +1114,12 @@ void us_printtechnology(TECHNOLOGY *tech)
 		efree(gdss[i]);
 		efree(funcs[i]);
 	}
-	efree((char *)names);
-	efree((char *)colors);
-	efree((char *)styles);
-	efree((char *)cifs);
-	efree((char *)gdss);
-	efree((char *)funcs);
+	efree((CHAR *)names);
+	efree((CHAR *)colors);
+	efree((CHAR *)styles);
+	efree((CHAR *)cifs);
+	efree((CHAR *)gdss);
+	efree((CHAR *)funcs);
 
 	/****************************** dump arcs ******************************/
 
@@ -1127,24 +1137,24 @@ void us_printtechnology(TECHNOLOGY *tech)
 			j = tech->arcprotos[ap->arcindex]->laycount;
 		tot += j;
 	}
-	names = (char **)emalloc(tot * (sizeof (char *)), el_tempcluster);
-	layers = (char **)emalloc(tot * (sizeof (char *)), el_tempcluster);
-	layersizes = (char **)emalloc(tot * (sizeof (char *)), el_tempcluster);
-	extensions = (char **)emalloc(tot * (sizeof (char *)), el_tempcluster);
-	angles = (char **)emalloc(tot * (sizeof (char *)), el_tempcluster);
-	wipes = (char **)emalloc(tot * (sizeof (char *)), el_tempcluster);
-	funcs = (char **)emalloc(tot * (sizeof (char *)), el_tempcluster);
+	names = (CHAR **)emalloc(tot * (sizeof (CHAR *)), el_tempcluster);
+	layers = (CHAR **)emalloc(tot * (sizeof (CHAR *)), el_tempcluster);
+	layersizes = (CHAR **)emalloc(tot * (sizeof (CHAR *)), el_tempcluster);
+	extensions = (CHAR **)emalloc(tot * (sizeof (CHAR *)), el_tempcluster);
+	angles = (CHAR **)emalloc(tot * (sizeof (CHAR *)), el_tempcluster);
+	wipes = (CHAR **)emalloc(tot * (sizeof (CHAR *)), el_tempcluster);
+	funcs = (CHAR **)emalloc(tot * (sizeof (CHAR *)), el_tempcluster);
 	if (names == 0 || layers == 0 || layersizes == 0 || extensions == 0 || angles == 0 ||
 		wipes == 0 || funcs == 0) return;
 
 	/* load the header */
-	(void)allocstring(&names[0], "Arc", el_tempcluster);
-	(void)allocstring(&layers[0], "Layer", el_tempcluster);
-	(void)allocstring(&layersizes[0], "Size", el_tempcluster);
-	(void)allocstring(&extensions[0], "Extend", el_tempcluster);
-	(void)allocstring(&angles[0], "Angle", el_tempcluster);
-	(void)allocstring(&wipes[0], "Wipes", el_tempcluster);
-	(void)allocstring(&funcs[0], "Function", el_tempcluster);
+	(void)allocstring(&names[0], x_("Arc"), el_tempcluster);
+	(void)allocstring(&layers[0], x_("Layer"), el_tempcluster);
+	(void)allocstring(&layersizes[0], x_("Size"), el_tempcluster);
+	(void)allocstring(&extensions[0], x_("Extend"), el_tempcluster);
+	(void)allocstring(&angles[0], x_("Angle"), el_tempcluster);
+	(void)allocstring(&wipes[0], x_("Wipes"), el_tempcluster);
+	(void)allocstring(&funcs[0], x_("Function"), el_tempcluster);
 
 	tot = 1;
 	for(ap = tech->firstarcproto; ap != NOARCPROTO; ap = ap->nextarcproto)
@@ -1154,11 +1164,11 @@ void us_printtechnology(TECHNOLOGY *tech)
 		var = getvalkey((INTBIG)ap, VARCPROTO, VINTEGER, us_arcstylekey);
 		if (var != NOVARIABLE) bits = var->addr; else
 			bits = ap->userbits;
-		if ((bits&WANTNOEXTEND) == 0) fieldname = "yes"; else fieldname = "no";
+		if ((bits&WANTNOEXTEND) == 0) fieldname = x_("yes"); else fieldname = x_("no");
 		(void)allocstring(&extensions[tot], fieldname, el_tempcluster);
-		(void)sprintf(thefield, "%ld", (ap->userbits&AANGLEINC) >> AANGLEINCSH);
+		(void)esnprintf(thefield, 50, x_("%ld"), (ap->userbits&AANGLEINC) >> AANGLEINCSH);
 		(void)allocstring(&angles[tot], thefield, el_tempcluster);
-		if ((ap->userbits&CANWIPE) == 0) fieldname = "no"; else fieldname = "yes";
+		if ((ap->userbits&CANWIPE) == 0) fieldname = x_("no"); else fieldname = x_("yes");
 		(void)allocstring(&wipes[tot], fieldname, el_tempcluster);
 		func = (ap->userbits&AFUNCTION) >> AFUNCTIONSH;
 		(void)allocstring(&funcs[tot], us_tecarc_functions[func].name, el_tempcluster);
@@ -1184,11 +1194,11 @@ void us_printtechnology(TECHNOLOGY *tech)
 			el_units = (el_units & ~DISPLAYUNITS) | saveunit;
 			if (k > 0)
 			{
-				(void)allocstring(&names[tot], "", el_tempcluster);
-				(void)allocstring(&extensions[tot], "", el_tempcluster);
-				(void)allocstring(&angles[tot], "", el_tempcluster);
-				(void)allocstring(&wipes[tot], "", el_tempcluster);
-				(void)allocstring(&funcs[tot], "", el_tempcluster);
+				(void)allocstring(&names[tot], x_(""), el_tempcluster);
+				(void)allocstring(&extensions[tot], x_(""), el_tempcluster);
+				(void)allocstring(&angles[tot], x_(""), el_tempcluster);
+				(void)allocstring(&wipes[tot], x_(""), el_tempcluster);
+				(void)allocstring(&funcs[tot], x_(""), el_tempcluster);
 			}
 			tot++;
 		}
@@ -1198,7 +1208,7 @@ void us_printtechnology(TECHNOLOGY *tech)
 	fields[0] = names;        fields[1] = layers;   fields[2] = layersizes;
 	fields[3] = extensions;   fields[4] = angles;   fields[5] = wipes;
 	fields[6] = funcs;
-	us_dumpfields(fields, 7, tot, f, "ARCS");
+	us_dumpfields(fields, 7, tot, f, x_("ARCS"));
 	for(i=0; i<tot; i++)
 	{
 		efree(names[i]);
@@ -1209,13 +1219,13 @@ void us_printtechnology(TECHNOLOGY *tech)
 		efree(wipes[i]);
 		efree(funcs[i]);
 	}
-	efree((char *)names);
-	efree((char *)layers);
-	efree((char *)layersizes);
-	efree((char *)extensions);
-	efree((char *)angles);
-	efree((char *)wipes);
-	efree((char *)funcs);
+	efree((CHAR *)names);
+	efree((CHAR *)layers);
+	efree((CHAR *)layersizes);
+	efree((CHAR *)extensions);
+	efree((CHAR *)angles);
+	efree((CHAR *)wipes);
+	efree((CHAR *)funcs);
 
 	/****************************** dump nodes ******************************/
 
@@ -1238,26 +1248,26 @@ void us_printtechnology(TECHNOLOGY *tech)
 		}
 		tot += maxi(j, l);
 	}
-	names = (char **)emalloc(tot * (sizeof (char *)), el_tempcluster);
-	funcs = (char **)emalloc(tot * (sizeof (char *)), el_tempcluster);
-	layers = (char **)emalloc(tot * (sizeof (char *)), el_tempcluster);
-	layersizes = (char **)emalloc(tot * (sizeof (char *)), el_tempcluster);
-	ports = (char **)emalloc(tot * (sizeof (char *)), el_tempcluster);
-	portsizes = (char **)emalloc(tot * (sizeof (char *)), el_tempcluster);
-	portangles = (char **)emalloc(tot * (sizeof (char *)), el_tempcluster);
-	connections = (char **)emalloc(tot * (sizeof (char *)), el_tempcluster);
+	names = (CHAR **)emalloc(tot * (sizeof (CHAR *)), el_tempcluster);
+	funcs = (CHAR **)emalloc(tot * (sizeof (CHAR *)), el_tempcluster);
+	layers = (CHAR **)emalloc(tot * (sizeof (CHAR *)), el_tempcluster);
+	layersizes = (CHAR **)emalloc(tot * (sizeof (CHAR *)), el_tempcluster);
+	ports = (CHAR **)emalloc(tot * (sizeof (CHAR *)), el_tempcluster);
+	portsizes = (CHAR **)emalloc(tot * (sizeof (CHAR *)), el_tempcluster);
+	portangles = (CHAR **)emalloc(tot * (sizeof (CHAR *)), el_tempcluster);
+	connections = (CHAR **)emalloc(tot * (sizeof (CHAR *)), el_tempcluster);
 	if (names == 0 || funcs == 0 || layers == 0 || layersizes == 0 || ports == 0 ||
 		portsizes == 0 || portangles == 0 || connections == 0) return;
 
 	/* load the header */
-	(void)allocstring(&names[0], "Node", el_tempcluster);
-	(void)allocstring(&funcs[0], "Function", el_tempcluster);
-	(void)allocstring(&layers[0], "Layers", el_tempcluster);
-	(void)allocstring(&layersizes[0], "Size", el_tempcluster);
-	(void)allocstring(&ports[0], "Ports", el_tempcluster);
-	(void)allocstring(&portsizes[0], "Size", el_tempcluster);
-	(void)allocstring(&portangles[0], "Angle", el_tempcluster);
-	(void)allocstring(&connections[0], "Connections", el_tempcluster);
+	(void)allocstring(&names[0], x_("Node"), el_tempcluster);
+	(void)allocstring(&funcs[0], x_("Function"), el_tempcluster);
+	(void)allocstring(&layers[0], x_("Layers"), el_tempcluster);
+	(void)allocstring(&layersizes[0], x_("Size"), el_tempcluster);
+	(void)allocstring(&ports[0], x_("Ports"), el_tempcluster);
+	(void)allocstring(&portsizes[0], x_("Size"), el_tempcluster);
+	(void)allocstring(&portangles[0], x_("Angle"), el_tempcluster);
+	(void)allocstring(&connections[0], x_("Connections"), el_tempcluster);
 
 	tot = 1;
 	for(np = tech->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
@@ -1293,13 +1303,13 @@ void us_printtechnology(TECHNOLOGY *tech)
 			getbbox(poly, &lx, &hx, &ly, &hy);
 			saveunit = el_units & DISPLAYUNITS;
 			el_units = (el_units & ~DISPLAYUNITS) | DISPUNITMIC;
-			(void)sprintf(thefield, "%s x %s", latoa(hx-lx, 0), latoa(hy-ly, 0));
+			(void)esnprintf(thefield, 50, x_("%s x %s"), latoa(hx-lx, 0), latoa(hy-ly, 0));
 			(void)allocstring(&layersizes[tot], thefield, el_tempcluster);
 			el_units = (el_units & ~DISPLAYUNITS) | saveunit;
 			if (k > 0)
 			{
-				(void)allocstring(&names[tot], "", el_tempcluster);
-				(void)allocstring(&funcs[tot], "", el_tempcluster);
+				(void)allocstring(&names[tot], x_(""), el_tempcluster);
+				(void)allocstring(&funcs[tot], x_(""), el_tempcluster);
 			}
 			tot++;
 		}
@@ -1310,11 +1320,11 @@ void us_printtechnology(TECHNOLOGY *tech)
 			getbbox(poly, &lx, &hx, &ly, &hy);
 			saveunit = el_curtech->userbits & DISPLAYUNITS;
 			el_units = (el_units & ~DISPLAYUNITS) | DISPUNITMIC;
-			(void)sprintf(thefield, "%s x %s", latoa(hx-lx, 0), latoa(hy-ly, 0));
+			(void)esnprintf(thefield, 50, x_("%s x %s"), latoa(hx-lx, 0), latoa(hy-ly, 0));
 			(void)allocstring(&portsizes[base], thefield, el_tempcluster);
 			el_units = (el_units & ~DISPLAYUNITS) | saveunit;
-			if (((pp->userbits&PORTARANGE) >> PORTARANGESH) == 180) (void)strcpy(thefield, ""); else
-				(void)sprintf(thefield, "%ld", (pp->userbits&PORTANGLE) >> PORTANGLESH);
+			if (((pp->userbits&PORTARANGE) >> PORTARANGESH) == 180) (void)estrcpy(thefield, x_("")); else
+				(void)esnprintf(thefield, 50, x_("%ld"), (pp->userbits&PORTANGLE) >> PORTANGLESH);
 			(void)allocstring(&portangles[base], thefield, el_tempcluster);
 			m = 0;
 			for(k=0; pp->connects[k] != NOARCPROTO; k++)
@@ -1323,28 +1333,28 @@ void us_printtechnology(TECHNOLOGY *tech)
 				(void)allocstring(&connections[base], pp->connects[k]->protoname, el_tempcluster);
 				if (m != 0)
 				{
-					(void)allocstring(&ports[base], "", el_tempcluster);
-					(void)allocstring(&portsizes[base], "", el_tempcluster);
-					(void)allocstring(&portangles[base], "", el_tempcluster);
+					(void)allocstring(&ports[base], x_(""), el_tempcluster);
+					(void)allocstring(&portsizes[base], x_(""), el_tempcluster);
+					(void)allocstring(&portangles[base], x_(""), el_tempcluster);
 				}
 				m++;
 				base++;
 			}
-			if (m == 0) (void)allocstring(&connections[base++], "<NONE>", el_tempcluster);
+			if (m == 0) (void)allocstring(&connections[base++], x_("<NONE>"), el_tempcluster);
 		}
 		for( ; base < tot; base++)
 		{
-			(void)allocstring(&ports[base], "", el_tempcluster);
-			(void)allocstring(&portsizes[base], "", el_tempcluster);
-			(void)allocstring(&portangles[base], "", el_tempcluster);
-			(void)allocstring(&connections[base], "", el_tempcluster);
+			(void)allocstring(&ports[base], x_(""), el_tempcluster);
+			(void)allocstring(&portsizes[base], x_(""), el_tempcluster);
+			(void)allocstring(&portangles[base], x_(""), el_tempcluster);
+			(void)allocstring(&connections[base], x_(""), el_tempcluster);
 		}
 		for( ; tot < base; tot++)
 		{
-			(void)allocstring(&names[tot], "", el_tempcluster);
-			(void)allocstring(&funcs[tot], "", el_tempcluster);
-			(void)allocstring(&layers[tot], "", el_tempcluster);
-			(void)allocstring(&layersizes[tot], "", el_tempcluster);
+			(void)allocstring(&names[tot], x_(""), el_tempcluster);
+			(void)allocstring(&funcs[tot], x_(""), el_tempcluster);
+			(void)allocstring(&layers[tot], x_(""), el_tempcluster);
+			(void)allocstring(&layersizes[tot], x_(""), el_tempcluster);
 		}
 	}
 
@@ -1352,7 +1362,7 @@ void us_printtechnology(TECHNOLOGY *tech)
 	fields[0] = names;        fields[1] = funcs;    fields[2] = layers;
 	fields[3] = layersizes;   fields[4] = ports;    fields[5] = portsizes;
 	fields[6] = portangles;   fields[7] = connections;
-	us_dumpfields(fields, 8, tot, f, "NODES");
+	us_dumpfields(fields, 8, tot, f, x_("NODES"));
 	for(i=0; i<tot; i++)
 	{
 		efree(names[i]);
@@ -1364,19 +1374,19 @@ void us_printtechnology(TECHNOLOGY *tech)
 		efree(portangles[i]);
 		efree(connections[i]);
 	}
-	efree((char *)names);
-	efree((char *)funcs);
-	efree((char *)layers);
-	efree((char *)layersizes);
-	efree((char *)ports);
-	efree((char *)portsizes);
-	efree((char *)portangles);
-	efree((char *)connections);
+	efree((CHAR *)names);
+	efree((CHAR *)funcs);
+	efree((CHAR *)layers);
+	efree((CHAR *)layersizes);
+	efree((CHAR *)ports);
+	efree((CHAR *)portsizes);
+	efree((CHAR *)portangles);
+	efree((CHAR *)connections);
 
 	xclose(f);
 }
 
-void us_dumpfields(char ***fields, INTBIG count, INTBIG length, FILE *f, char *title)
+void us_dumpfields(CHAR ***fields, INTBIG count, INTBIG length, FILE *f, CHAR *title)
 {
 	INTBIG widths[MAXCOLS];
 	REGISTER INTBIG len, i, j, k, totwid, stars;
@@ -1387,28 +1397,28 @@ void us_dumpfields(char ***fields, INTBIG count, INTBIG length, FILE *f, char *t
 		widths[i] = 8;
 		for(j=0; j<length; j++)
 		{
-			len = strlen(fields[i][j]);
+			len = estrlen(fields[i][j]);
 			if (len > widths[i]) widths[i] = len;
 		}
 		widths[i]++;
 		totwid += widths[i];
 	}
 
-	stars = (totwid - strlen(title) - 2) / 2;
-	for(i=0; i<stars; i++) xprintf(f, "*");
-	xprintf(f, " %s ", title);
-	for(i=0; i<stars; i++) xprintf(f, "*");
-	xprintf(f, "\n");
+	stars = (totwid - estrlen(title) - 2) / 2;
+	for(i=0; i<stars; i++) xprintf(f, x_("*"));
+	xprintf(f, x_(" %s "), title);
+	for(i=0; i<stars; i++) xprintf(f, x_("*"));
+	xprintf(f, x_("\n"));
 
 	for(j=0; j<length; j++)
 	{
 		for(i=0; i<count; i++)
 		{
-			xprintf(f, "%s", fields[i][j]);
+			xprintf(f, x_("%s"), fields[i][j]);
 			if (i == count-1) continue;
-			for(k=strlen(fields[i][j]); k<widths[i]; k++) xprintf(f, " ");
+			for(k=estrlen(fields[i][j]); k<widths[i]; k++) xprintf(f, x_(" "));
 		}
-		xprintf(f, "\n");
+		xprintf(f, x_("\n"));
 	}
-	xprintf(f, "\n");
+	xprintf(f, x_("\n"));
 }
