@@ -78,6 +78,14 @@ static GRAPHICS us_graybox = {LAYERO, GRAY, PATTERNED, PATTERNED,
 					0x0000,  /*                  */
 					0x3030,  /*   XX      XX     */
 					0x8484,  /* X    X  X    X   */
+					0x3030,  /*   XX      XX     */
+					0x0000,  /*                  */
+					0x0303,  /*       XX      XX */
+					0x4848,  /*  X  X    X  X    */
+					0x0303,  /*       XX      XX */
+					0x0000,  /*                  */
+					0x3030,  /*   XX      XX     */
+					0x8484,  /* X    X  X    X   */
 					0x3030}, /*   XX      XX     */
 					NOVARIABLE, 0};
 
@@ -90,6 +98,14 @@ static GRAPHICS us_dimbox = {LAYERH, HIGHLIT, PATTERNED, PATTERNED,
 					0x0404,  /*      X       X   */
 					0x0000,  /*                  */
 					0x4040,  /*  X       X       */
+					0x0000,  /*                  */
+					0x0404,  /*      X       X   */
+					0x0000,  /*                  */
+					0x4040,  /*  X       X       */
+					0x0000,  /*                  */
+					0x0404,  /*      X       X   */
+					0x0000,  /*                  */
+					0x4040,  /*  X       X       */
 					0x0000}, /*                  */
 					NOVARIABLE, 0};
 
@@ -122,7 +138,7 @@ void us_drawwindow(WINDOWPART *w, INTBIG color)
 	(void)needstaticpolygon(&poly, 5, us_tool->cluster);
 
 	/* don't draw window border if it is a whole-screen window */
-	if (strcmp(w->location, "entire") == 0) return;
+	if (estrcmp(w->location, x_("entire")) == 0) return;
 
 	/* don't draw window border around popup text editors */
 	if ((w->state & WINDOWTYPE) == POPTEXTWINDOW) return;
@@ -153,10 +169,10 @@ void us_gettruewindowbounds(WINDOWPART *w, INTBIG *lx, INTBIG *hx, INTBIG *ly, I
 {
 	*lx = w->uselx;   *hx = w->usehx;
 	*ly = w->usely;   *hy = w->usehy;
-	if ((w->state&WINDOWSIMULATING) != 0)
+	if ((w->state&WINDOWMODE) != 0)
 	{
-		*lx -= SIMULATINGBORDERSIZE;   *hx += SIMULATINGBORDERSIZE;
-		*ly -= SIMULATINGBORDERSIZE;   *hy += SIMULATINGBORDERSIZE;
+		*lx -= WINDOWMODEBORDERSIZE;   *hx += WINDOWMODEBORDERSIZE;
+		*ly -= WINDOWMODEBORDERSIZE;   *hy += WINDOWMODEBORDERSIZE;
 	}
 	if ((w->state&WINDOWTYPE) == DISPWINDOW)
 	{
@@ -176,22 +192,23 @@ void us_gettruewindowbounds(WINDOWPART *w, INTBIG *lx, INTBIG *hx, INTBIG *ly, I
 void us_fullview(NODEPROTO *np, INTBIG *screenlx, INTBIG *screenhx, INTBIG *screenly,
 	INTBIG *screenhy)
 {
-	INTBIG x, y, nlx, nhx, nly, nhy, xc, yc;
-	INTBIG tsx, tsy;
-	REGISTER INTBIG lambda, first, oldlx, oldhx, oldly, oldhy, i, xw, yw;
+	INTBIG fsx, fsy, nlx, nhx, nly, nhy, xc, yc, tsx, tsy;
+	REGISTER INTBIG lambda, first, oldlx, oldhx, oldly, oldhy, i, xw, yw, frameinfo;
 	REGISTER NODEINST *ni;
 	REGISTER ARCINST *ai;
 	REGISTER VARIABLE *var;
-	REGISTER char *str;
+	REGISTER WINDOWPART *oldwin;
+	REGISTER CHAR *str;
 	static POLYGON *poly = NOPOLYGON;
 
 	/* only one size allowed in windows with frames */
-	if (!framesize(&x, &y, np))
+	frameinfo = framesize(&fsx, &fsy, np);
+	if (frameinfo == 0)
 	{
-		*screenlx = -x/2;
-		*screenly = -y/2;
-		*screenhx = x/2;
-		*screenhy = y/2;
+		*screenlx = -fsx/2;
+		*screenly = -fsy/2;
+		*screenhx = fsx/2;
+		*screenhy = fsy/2;
 		return;
 	}
 
@@ -255,6 +272,7 @@ void us_fullview(NODEPROTO *np, INTBIG *screenlx, INTBIG *screenhx, INTBIG *scre
 	}
 
 	/* include all displayed facet variables */
+	oldwin = setvariablewindow(el_curwindowpart);
 	for(i = 0; i < np->numvar; i++)
 	{
 		var = &np->firstvar[i];
@@ -292,6 +310,7 @@ void us_fullview(NODEPROTO *np, INTBIG *screenlx, INTBIG *screenhx, INTBIG *scre
 			*screenhy = maxi(*screenhy, nhy);
 		}
 	}
+	(void)setvariablewindow(oldwin);
 
 	/* set default size if nothing is there */
 	if (first != 0)
@@ -302,6 +321,15 @@ void us_fullview(NODEPROTO *np, INTBIG *screenlx, INTBIG *screenhx, INTBIG *scre
 		*screenhy = np->highy;
 	}
 
+	/* if there is frame information, include it */
+	if (frameinfo == 1)
+	{
+		*screenlx = mini(*screenlx, -fsx/2);
+		*screenhx = maxi(*screenhx, fsx/2);
+		*screenly = mini(*screenly, -fsy/2);
+		*screenhy = maxi(*screenhy, fsy/2);
+	}
+
 	if (*screenlx >= *screenhx && *screenly >= *screenhy)
 	{
 		*screenlx -= 25 * lambda;
@@ -585,6 +613,51 @@ WINDOWPART *us_subwindow(INTBIG lx, INTBIG hx, INTBIG ly, INTBIG hy, WINDOWPART
 	return(&ww);
 }
 
+void us_showwindowmode(WINDOWPART *w)
+{
+	REGISTER INTBIG x, y, numcolors, colorindex, high;
+	INTBIG lx, hx, ly, hy, colors[5];
+
+	us_gettruewindowbounds(w, &lx, &hx, &ly, &hy);
+	numcolors = 0;
+	if ((w->state&WINDOWSIMMODE) != 0) colors[numcolors++] = RED;
+	if ((w->state&WINDOWTECEDMODE) != 0) colors[numcolors++] = YELLOW;
+	if ((w->state&WINDOWOUTLINEEDMODE) != 0) colors[numcolors++] = BLUE;
+	if (numcolors == 0) return;
+	if (numcolors == 1)
+	{
+		/* just 1 border color: draw it simply */
+		us_box.col = colors[0];
+		screendrawbox(w, lx, hx, ly, ly+WINDOWMODEBORDERSIZE-1, &us_box);
+		screendrawbox(w, lx, hx, hy-WINDOWMODEBORDERSIZE+1, hy, &us_box);
+		screendrawbox(w, lx, lx+WINDOWMODEBORDERSIZE-1, ly, hy, &us_box);
+		screendrawbox(w, hx-WINDOWMODEBORDERSIZE+1, hx, ly, hy, &us_box);
+		return;
+	}
+
+	/* multiple border colors: interleave them */
+	colorindex = 0;
+	for(x = lx; x<hx; x += 30)
+	{
+		us_box.col = colors[colorindex++];
+		if (colorindex >= numcolors) colorindex = 0;
+		high = x + 30;
+		if (high > hx) high = hx;
+		screendrawbox(w, x, high, ly, ly+WINDOWMODEBORDERSIZE-1, &us_box);
+		screendrawbox(w, x, high, hy-WINDOWMODEBORDERSIZE+1, hy, &us_box);
+	}
+	colorindex = 0;
+	for(y=ly; y<hy; y += 30)
+	{
+		us_box.col = colors[colorindex++];
+		if (colorindex >= numcolors) colorindex = 0;
+		high = y + 30;
+		if (high > hy) high = hy;
+		screendrawbox(w, lx, lx+WINDOWMODEBORDERSIZE-1, y, high, &us_box);
+		screendrawbox(w, hx-WINDOWMODEBORDERSIZE+1, hx, y, high, &us_box);
+	}
+}
+
 /*
  * routine to erase window "w" and draw everything that should be in it.
  */
@@ -592,13 +665,14 @@ void us_redisplay(WINDOWPART *w)
 {
 	WINDOWPART ww;
 	static POLYGON *poly = NOPOLYGON;
-	INTBIG lx, hx, ly, hy;
+	INTBIG lx, hx, ly, hy, numicons;
+	REGISTER BOOLEAN drawexplorericon;
 
 	/* get polygon */
 	(void)needstaticpolygon(&poly, 7, us_tool->cluster);
 
-	/* draw fat red border if simulating */
-	if ((w->state&WINDOWSIMULATING) != 0)
+	/* draw fat colored border if in a mode */
+	if ((w->state&WINDOWMODE) != 0)
 	{
 		us_gettruewindowbounds(w, &lx, &hx, &ly, &hy);
 		ww.screenlx = ww.uselx = lx;
@@ -612,14 +686,7 @@ void us_redisplay(WINDOWPART *w)
 		us_box.col = RED;
 		poly->style = FILLEDRECT;
 
-		maketruerectpoly(lx, hx, ly, ly+SIMULATINGBORDERSIZE, poly);
-		us_showpoly(poly, &ww);
-		maketruerectpoly(lx, hx, hy-SIMULATINGBORDERSIZE, hy, poly);
-		us_showpoly(poly, &ww);
-		maketruerectpoly(lx, lx+SIMULATINGBORDERSIZE, ly, hy, poly);
-		us_showpoly(poly, &ww);
-		maketruerectpoly(hx-SIMULATINGBORDERSIZE, hx, ly, hy, poly);
-		us_showpoly(poly, &ww);
+		us_showwindowmode(w);
 	}
 
 	/* draw sliders if a display window */
@@ -629,10 +696,13 @@ void us_redisplay(WINDOWPART *w)
 		ly = w->usely;   hy = w->usehy;
 
 		/* the slider on the bottom and right */
+		numicons = 0;
+		drawexplorericon = us_windowgetsexploericon(w);
+		if (drawexplorericon) numicons++;
 		w->usehx += DISPLAYSLIDERSIZE;
 		w->usely -= DISPLAYSLIDERSIZE;
 		us_drawverticalslider(w, hx, ly, hy, FALSE);
-		us_drawhorizontalslider(w, ly, lx, hx);
+		us_drawhorizontalslider(w, ly, lx, hx, numicons);
 		w->usehx -= DISPLAYSLIDERSIZE;
 		w->usely += DISPLAYSLIDERSIZE;
 
@@ -647,6 +717,23 @@ void us_redisplay(WINDOWPART *w)
 		us_redisplaynow(w, FALSE);
 }
 
+/*
+ * Routine to return TRUE if an "explorer icon" should be drawn in this window.
+ */
+BOOLEAN us_windowgetsexploericon(WINDOWPART *w)
+{
+	REGISTER WINDOWPART *ow;
+
+	if ((w->state&WINDOWTYPE) == EXPLORERWINDOW) return(TRUE);
+	if ((w->state&WINDOWTYPE) != DISPWINDOW) return(FALSE);
+	for(ow = el_topwindowpart; ow != NOWINDOWPART; ow = ow->nextwindowpart)
+	{
+		if (ow->frame != w->frame) continue;
+		if ((ow->state&WINDOWTYPE) == EXPLORERWINDOW) return(FALSE);
+	}
+	return(TRUE);
+}
+
 /*
  * Routine to draw a grey box in the corner where two sliders meet.
  */
@@ -678,7 +765,7 @@ void us_drawslidercorner(WINDOWPART *win, INTBIG lx, INTBIG hx, INTBIG ly, INTBI
  */
 void us_drawdispwindowsliders(WINDOWPART *w)
 {
-	REGISTER INTBIG lx, hx, ly, hy;
+	REGISTER INTBIG lx, hx, ly, hy, numicons;
 	REGISTER NODEPROTO *np;
 	INTBIG facetsizex, facetsizey;
 	REGISTER INTBIG screensizex, screensizey,
@@ -690,9 +777,15 @@ void us_drawdispwindowsliders(WINDOWPART *w)
 	w->thumblx = 0;  w->thumbhx = -1;
 	w->thumbly = 0;  w->thumbhy = -1;
 
+	/* see how many icons appear on the left side of the horizontal slider */
+	numicons = 0;
+	if (us_windowgetsexploericon(w)) numicons++;
+
 	np = w->curnodeproto;
-	lx = w->uselx;   hx = w->usehx;
-	ly = w->usely;   hy = w->usehy;
+	lx = w->uselx + numicons*DISPLAYSLIDERSIZE;
+	hx = w->usehx;
+	ly = w->usely;
+	hy = w->usehy;
 	if (np != NONODEPROTO)
 	{
 		/* determine amount of the facet that is shown */
@@ -750,7 +843,9 @@ void us_drawdispwindowsliders(WINDOWPART *w)
 	w->usehx += DISPLAYSLIDERSIZE;
 	w->usely -= DISPLAYSLIDERSIZE;
 	us_drawverticalsliderthumb(w, hx, ly, hy, w->thumbly, w->thumbhy);
-	us_drawhorizontalsliderthumb(w, ly, lx, hx, w->thumblx, w->thumbhx);
+	us_drawhorizontalsliderthumb(w, ly, lx, hx, w->thumblx, w->thumbhx, numicons);
+	if (numicons > 0)
+		us_drawexplorericon(w, lx, w->usely);
 	w->usehx -= DISPLAYSLIDERSIZE;
 	w->usely += DISPLAYSLIDERSIZE;
 }
@@ -837,7 +932,7 @@ void us_drawverticalslider(WINDOWPART *w, INTBIG lx, INTBIG ly, INTBIG hy, BOOLE
  * Routine to draw a horizontal slider in window "w" whose top edge is "hy" and which
  * runs horizontally from "lx" to "hx".  The slider has arrows and borders, but no thumb.
  */
-void us_drawhorizontalslider(WINDOWPART *w, INTBIG hy, INTBIG lx, INTBIG hx)
+void us_drawhorizontalslider(WINDOWPART *w, INTBIG hy, INTBIG lx, INTBIG hx, INTBIG numicons)
 {
 	static POLYGON *poly = NOPOLYGON;
 	REGISTER INTBIG i;
@@ -855,6 +950,7 @@ void us_drawhorizontalslider(WINDOWPART *w, INTBIG hy, INTBIG lx, INTBIG hx)
 	computewindowscale(&ww);
 
 	/* erase the area */
+	lx += numicons * DISPLAYSLIDERSIZE;
 	poly->desc = &us_box;
 	us_box.col = WHITE;
 	poly->style = FILLEDRECT;
@@ -948,8 +1044,9 @@ void us_drawverticalsliderthumb(WINDOWPART *w, INTBIG hx, INTBIG ly, INTBIG hy,
  * Routine to draw the thumb in the horizontal slider of window "w".  The slider has
  * its top edge at "ly" and runs from "lx" to "hx".  The thumb runs from
  * "lt" to "ht" (if "lt" is greater than "ht", don't draw a thumb).
+ * "numicons" is the number of icons on the left that will be drawn.
  */
-void us_drawhorizontalsliderthumb(WINDOWPART *w, INTBIG ly, INTBIG lx, INTBIG hx, INTBIG lt, INTBIG ht)
+void us_drawhorizontalsliderthumb(WINDOWPART *w, INTBIG ly, INTBIG lx, INTBIG hx, INTBIG lt, INTBIG ht, INTBIG numicons)
 {
 	static POLYGON *poly = NOPOLYGON;
 	WINDOWPART ww;
@@ -966,8 +1063,9 @@ void us_drawhorizontalsliderthumb(WINDOWPART *w, INTBIG ly, INTBIG lx, INTBIG hx
 	computewindowscale(&ww);
 
 	poly->desc = &us_box;
+	lx += numicons * DISPLAYSLIDERSIZE;
 
-	/* erase the vertical slider on the right */
+	/* erase the horizontal slider on the bottom */
 	us_box.col = LGRAY;
 	poly->style = FILLEDRECT;
 	maketruerectpoly(lx+DISPLAYSLIDERSIZE+2, hx-DISPLAYSLIDERSIZE-2, ly-DISPLAYSLIDERSIZE, ly-2, poly);
@@ -995,7 +1093,7 @@ void us_drawhorizontalsliderthumb(WINDOWPART *w, INTBIG ly, INTBIG lx, INTBIG hx
 /*
  * routine to erase window "w" and draw everything that should be in it.
  * If "now" is true, draw everything immediately.  Otherwise, draw
- * overlapping layers first and queue nonoverlapping layers for later.
+ * overlapping layers first and queue opaque layers for later.
  */
 void us_redisplaynow(WINDOWPART *w, BOOLEAN now)
 {
@@ -1018,6 +1116,9 @@ void us_redisplaynow(WINDOWPART *w, BOOLEAN now)
 		return;
 	}
 
+	/* set the environment window for hierarchy traversal */
+	(void)setvariablewindow(w);
+
 	/* show the background if editing in place */
 	if ((w->state&INPLACEEDIT) != 0 && w->topnodeproto != NONODEPROTO)
 	{
@@ -1074,7 +1175,7 @@ void us_redisplaynow(WINDOWPART *w, BOOLEAN now)
 		(void)needstaticpolygon(&poly, 6, us_tool->cluster);
 
 		/* grid spacing */
-		lambda = facet->cell->lib->lambda[facet->tech->techindex];
+		lambda = lambdaoffacet(facet);
 		poly->xv[0] = muldiv(w->gridx, lambda, WHOLE);
 		poly->yv[0] = muldiv(w->gridy, lambda, WHOLE);
 
@@ -1110,6 +1211,9 @@ void us_redisplaynow(WINDOWPART *w, BOOLEAN now)
 		flushscreen();
 	}
 
+	/* reset environment window for hierarchy traversal */
+	(void)setvariablewindow(NOWINDOWPART);
+
 	/* end accumulation of polygons if doing 3D drawing */
 	if ((w->state&WINDOWTYPE) == DISP3DWINDOW) us_3denddrawing();
 }
@@ -1221,13 +1325,13 @@ void us_gridset(WINDOWPART *w, INTBIG state)
 
 	if ((state&GRIDON) == 0)
 	{
-		(void)setval((INTBIG)w, VWINDOWPART, "state", w->state & ~GRIDON, VINTEGER);
+		(void)setval((INTBIG)w, VWINDOWPART, x_("state"), w->state & ~GRIDON, VINTEGER);
 		return;
 	}
 
 	if ((w->state&WINDOWTYPE) == WAVEFORMWINDOW)
 	{
-		(void)setval((INTBIG)w, VWINDOWPART, "state", (w->state & ~GRIDTOOSMALL) | GRIDON, VINTEGER);
+		(void)setval((INTBIG)w, VWINDOWPART, x_("state"), (w->state & ~GRIDTOOSMALL) | GRIDON, VINTEGER);
 		return;
 	}
 
@@ -1249,14 +1353,14 @@ void us_gridset(WINDOWPART *w, INTBIG state)
 			if ((w->state&GRIDTOOSMALL) == 0)
 			{
 				ttyputverbose(M_("Grid too small, turned off"));
-				(void)setval((INTBIG)w, VWINDOWPART, "state", w->state | GRIDTOOSMALL | GRIDON, VINTEGER);
+				(void)setval((INTBIG)w, VWINDOWPART, x_("state"), w->state | GRIDTOOSMALL | GRIDON, VINTEGER);
 			}
 			return;
 		}
 	}
 
 	if ((w->state&GRIDTOOSMALL) != 0) ttyputverbose(M_("Grid turned back on"));
-	(void)setval((INTBIG)w, VWINDOWPART, "state", (w->state & ~GRIDTOOSMALL) | GRIDON, VINTEGER);
+	(void)setval((INTBIG)w, VWINDOWPART, x_("state"), (w->state & ~GRIDTOOSMALL) | GRIDON, VINTEGER);
 }
 
 /******************** PORT SELECTION ******************/
@@ -1283,7 +1387,7 @@ void us_identifyports(INTBIG count, NODEINST **nilist, NODEPROTO *np, INTBIG on,
 		leftsidecount, topsidecount, rightsidecount, botsidecount, bestoff,
 		i, j, dist, bestdist, ignored, halfsizex, halfsizey;
 	INTBIG x, y, xout, yout, tsx, tsy, sidex[4], sidey[4];
-	char line[80];
+	CHAR line[80];
 	REGISTER WINDOWPART *w;
 	REGISTER SHOWNPORTS *portlist;
 	static POLYGON *poly = NOPOLYGON;
@@ -1472,7 +1576,7 @@ void us_identifyports(INTBIG count, NODEINST **nilist, NODEPROTO *np, INTBIG on,
 	{
 		if (usenumbers)
 		{
-			(void)sprintf(line, "%ld", i);
+			(void)esnprintf(line, 80, x_("%ld"), i);
 			poly->string = line;
 		} else
 		{
@@ -1488,7 +1592,7 @@ void us_identifyports(INTBIG count, NODEINST **nilist, NODEPROTO *np, INTBIG on,
 		poly->tech = el_curtech;
 		us_hbox.col = HIGHLIT&on;
 		us_showpoly(poly, w);
-		(void)strcpy(line, "");
+		(void)estrcpy(line, x_(""));
 
 		/* draw the line from the port to the index number */
 		poly->xv[0] = portlist[(bestoff+i)%total].portx;
@@ -1515,9 +1619,9 @@ void us_identifyports(INTBIG count, NODEINST **nilist, NODEPROTO *np, INTBIG on,
 		us_showpoly(poly, w);
 	}
 	flushscreen();
-	efree((char *)portx);
-	efree((char *)porty);
-	efree((char *)portlist);
+	efree((CHAR *)portx);
+	efree((CHAR *)porty);
+	efree((CHAR *)portlist);
 	if (ignored > 0)
 		ttyputmsg(_("Could not display %ld %s (outside of the window)"), ignored,
 			makeplural(_("port"), ignored));
@@ -1680,7 +1784,6 @@ INTBIG us_drawnodeinst(NODEINST *ni, INTBIG on, XARRAY prevtrans, INTBIG layers,
 			/* save the color information and update it */
 			i = gra->col;
 			gra->col &= on;
-
 			/* draw the nodeinst and restore the color */
 			if ((w->state&WINDOWTYPE) == DISP3DWINDOW) us_3dshowpoly(poly, w); else
 				(*us_displayroutine)(poly, w);
@@ -1708,7 +1811,11 @@ INTBIG us_drawnodeinst(NODEINST *ni, INTBIG on, XARRAY prevtrans, INTBIG layers,
 
 			/* facet is off, so simply blank the area */
 			us_getnodebounds(ni, &bx, &ux, &by, &uy);
-			maketruerectpoly(bx, ux, by, uy, poly);
+
+			/* extend the bounds by 1 pixel */
+			i = roundfloat(1.0f / w->scalex);
+			if (i <= 0) i = 1;
+			maketruerectpoly(bx-i, ux+i, by-i, uy+i, poly);
 			xformpoly(poly, prevtrans);
 
 			/* because "us_getnodebounds()" returns rotated area, "prevtrans" over-rotates */
@@ -1727,7 +1834,7 @@ INTBIG us_drawnodeinst(NODEINST *ni, INTBIG on, XARRAY prevtrans, INTBIG layers,
 		{
 			NODEINST **nilist;
 			INTBIG *indexlist, depth, inplacedepth;
-			gettraversalpath(ni->parent, &nilist, &indexlist, &depth, 0);
+			gettraversalpath(ni->parent, w, &nilist, &indexlist, &depth, 0);
 			inplacedepth = w->inplacedepth-1;
 			if (ni == w->inplacestack[inplacedepth])
 			{
@@ -1911,19 +2018,6 @@ INTBIG us_drawnodeinst(NODEINST *ni, INTBIG on, XARRAY prevtrans, INTBIG layers,
 						us_drawportprotovariables(pp, LAYERA, *xptr, w, TRUE);
 					}
 				}
-
-				/* see if there are displayable variables on the facet instance */
-				displaytotal = tech_displayablenvars(ni, w, &tech_oneprocpolyloop);
-				for(i = 0; i < displaytotal; i++)
-				{
-					(void)tech_filldisplayablenvar(ni, poly, w, 0, &tech_oneprocpolyloop);
-					xformpoly(poly, prevtrans);
-					if ((w->state&WINDOWTYPE) == DISP3DWINDOW) us_3dshowpoly(poly, w); else
-						(*us_displayroutine)(poly, w);
-				}
-
-				/* draw facet variables on expanded facets */
-				us_drawnodeprotovariables(ni->proto, subrot, w, TRUE);
 			}
 
 			/* descend hierarchy to this node */
@@ -1944,6 +2038,23 @@ INTBIG us_drawnodeinst(NODEINST *ni, INTBIG on, XARRAY prevtrans, INTBIG layers,
 				moretodo |= res;
 			}
 			uphierarchy();
+
+			/* draw text */
+			if ((layers&2) != 0)
+			{
+				/* see if there are displayable variables on the facet instance */
+				displaytotal = tech_displayablenvars(ni, w, &tech_oneprocpolyloop);
+				for(i = 0; i < displaytotal; i++)
+				{
+					(void)tech_filldisplayablenvar(ni, poly, w, 0, &tech_oneprocpolyloop);
+					xformpoly(poly, prevtrans);
+					if ((w->state&WINDOWTYPE) == DISP3DWINDOW) us_3dshowpoly(poly, w); else
+						(*us_displayroutine)(poly, w);
+				}
+
+				/* draw facet variables on expanded facets */
+				us_drawnodeprotovariables(ni->proto, subrot, w, TRUE);
+			}
 		}
 	}
 
@@ -1952,14 +2063,17 @@ INTBIG us_drawnodeinst(NODEINST *ni, INTBIG on, XARRAY prevtrans, INTBIG layers,
 	{
 		if (ni->firstportexpinst != NOPORTEXPINST && ni->parent == w->curnodeproto)
 		{
-			if ((layers&2) == 0) moretodo |= 2; else
+			for(pe = ni->firstportexpinst; pe != NOPORTEXPINST; pe = pe->nextportexpinst)
 			{
-				for(pe = ni->firstportexpinst; pe != NOPORTEXPINST; pe = pe->nextportexpinst)
+				if (on == 0)
 				{
 					us_writeprotoname(pe->exportproto, on, prevtrans, LAYERO,
 						el_colfacettxt&on, w, 0, 0, 0, 0,
 							(us_useroptions&EXPORTLABELS)>>EXPORTLABELSSH);
 					us_drawportprotovariables(pe->exportproto, on, prevtrans, w, FALSE);
+				} else
+				{
+					us_queueexport(pe->exportproto);
 				}
 			}
 		}
@@ -2355,9 +2469,9 @@ void us_writeprotoname(PORTPROTO *pp, INTBIG on, XARRAY prevtrans, INTBIG bits,
  * routine to return the displayed port name for port "pp", given a style of "dispstyle"
  * (0: full, 1: crosses, 2: nothing, 3: short)
  */
-char *us_displayedportname(PORTPROTO *pp, INTBIG dispstyle)
+CHAR *us_displayedportname(PORTPROTO *pp, INTBIG dispstyle)
 {
-	REGISTER char *pt;
+	REGISTER CHAR *pt;
 	REGISTER void *infstr;
 
 	if (dispstyle == 3)
