@@ -108,9 +108,9 @@ extern GRAPHICS us_ebox, us_menutext, us_menufigs;
 INTBIG          us_lastemacschar;		/* state of last character typed */
 static INTBIG   us_twid, us_thei;		/* size of a single letter */
 static INTBIG   us_editemacsfont;		/* font size for editor */
-static char    *us_killbuf;				/* saved line when ^K is done */
+static CHAR    *us_killbuf;				/* saved line when ^K is done */
 static INTBIG   us_killbufchars = 0;	/* characters in kill buffer */
-static char    *us_searchbuf = 0;		/* search string for ^S and ^R */
+static CHAR    *us_searchbuf = 0;		/* search string for ^S and ^R */
 
 /* prototypes for local routines */
 static void us_editemacsgotbutton(WINDOWPART*, INTBIG, INTBIG, INTBIG);
@@ -124,7 +124,7 @@ static void us_editemacsshiftscreendown(WINDOWPART*);
 static void us_editemacsensuretextshown(WINDOWPART*, INTBIG);
 static void us_editemacsredrawscreen(WINDOWPART*);
 static void us_editemacsredrawline(WINDOWPART*, INTBIG);
-static void us_editemacssetheader(WINDOWPART*, char*);
+static void us_editemacssetheader(WINDOWPART*, CHAR*);
 static void us_editemacsflashcursor(WINDOWPART*);
 static void us_editemacsoffhighlight(WINDOWPART*);
 static void us_editemacscleanupline(WINDOWPART*, INTBIG);
@@ -135,10 +135,10 @@ static void us_editemacsgetbuffers(EDITOR*);
 static void us_editemacsmovebox(WINDOWPART*, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG);
 static void us_editemacsclearbox(WINDOWPART*, INTBIG, INTBIG, INTBIG, INTBIG);
 static void us_editemacsinvertbox(WINDOWPART*, INTBIG, INTBIG, INTBIG, INTBIG);
-static void us_editemacstext(WINDOWPART*, char*, INTBIG, INTBIG);
-static void us_editemacsdosearch(WINDOWPART *win, char *str, BOOLEAN reverse,
+static void us_editemacstext(WINDOWPART*, CHAR*, INTBIG, INTBIG);
+static void us_editemacsdosearch(WINDOWPART *win, CHAR *str, BOOLEAN reverse,
 			BOOLEAN fromtop, BOOLEAN casesensitive, BOOLEAN fromuser);
-static char us_editemacsnextvalidcharacter(EDITOR *e);
+static CHAR us_editemacsnextvalidcharacter(EDITOR *e);
 
 /******************** INTERFACE FOR TEXT WINDOW ********************/
 
@@ -148,7 +148,7 @@ static char us_editemacsnextvalidcharacter(EDITOR *e);
  * "header".  The number of characters and lines are placed in "chars" and
  * "lines".  Returns the window (NOWINDOWPART if the editor cannot be started).
  */
-WINDOWPART *us_editemacsmakeeditor(WINDOWPART *oriwin, char *header, INTBIG *chars, INTBIG *lines)
+WINDOWPART *us_editemacsmakeeditor(WINDOWPART *oriwin, CHAR *header, INTBIG *chars, INTBIG *lines)
 {
 	INTBIG i, x, y;
 	UINTBIG descript[TEXTDESCRIPTSIZE];
@@ -177,7 +177,7 @@ WINDOWPART *us_editemacsmakeeditor(WINDOWPART *oriwin, char *header, INTBIG *cha
 
 		/* create a window that covers the popup */
 		startobjectchange((INTBIG)us_tool, VTOOL);
-		win = newwindowpart("popup", el_curwindowpart);
+		win = newwindowpart(x_("popup"), el_curwindowpart);
 		win->uselx = maxi(x-200, 0);
 		win->usely = maxi(y-us_thei-1, 0);
 		win->usehx = mini(win->uselx+400, swid-1);
@@ -195,7 +195,7 @@ WINDOWPART *us_editemacsmakeeditor(WINDOWPART *oriwin, char *header, INTBIG *cha
 			win->usehx += DISPLAYSLIDERSIZE;
 			win->usely -= DISPLAYSLIDERSIZE;
 		}
-		win->state = (win->state & ~(WINDOWTYPE|WINDOWSIMULATING)) | TEXTWINDOW;
+		win->state = (win->state & ~(WINDOWTYPE|WINDOWMODE)) | TEXTWINDOW;
 	}
 
 	win->curnodeproto = NONODEPROTO;
@@ -216,13 +216,13 @@ WINDOWPART *us_editemacsmakeeditor(WINDOWPART *oriwin, char *header, INTBIG *cha
 	 *     -var set tool:user.USER_textedit_font 5
 	 */
 	us_editemacsfont = TXTEDITOR;
-	var = getval((INTBIG)us_tool, VTOOL, VINTEGER, "USER_textedit_font");
+	var = getval((INTBIG)us_tool, VTOOL, VINTEGER, x_("USER_textedit_font"));
 	if (var != NOVARIABLE && var->addr >= 4)
 		us_editemacsfont = var->addr;
 	TDCLEAR(descript);
 	TDSETSIZE(descript, us_editemacsfont);
 	screensettextinfo(win, NOTECHNOLOGY, descript);
-	screengettextsize(win, "X", &us_twid, &us_thei);
+	screengettextsize(win, x_("X"), &us_twid, &us_thei);
 
 	/* create a new editor object */
 	e = us_alloceditor();
@@ -248,7 +248,7 @@ WINDOWPART *us_editemacsmakeeditor(WINDOWPART *oriwin, char *header, INTBIG *cha
 		e->state |= EDITORINITED;
 		e->maxlines = e->screenlines;
 		e->mostchars = e->screenchars;
-		e->textarray = (char **)emalloc((e->maxlines * (sizeof (char *))),
+		e->textarray = (CHAR **)emalloc((e->maxlines * (sizeof (CHAR *))),
 			us_tool->cluster);
 		if (e->textarray == 0) ttyputnomemory();
 		e->maxchars = (INTBIG *)emalloc((e->maxlines * SIZEOFINTBIG), us_tool->cluster);
@@ -256,7 +256,7 @@ WINDOWPART *us_editemacsmakeeditor(WINDOWPART *oriwin, char *header, INTBIG *cha
 		us_editemacsgetbuffers(e);
 		for(i=0; i<e->maxlines; i++)
 		{
-			e->textarray[i] = (char *)emalloc((e->screenchars+1), us_tool->cluster);
+			e->textarray[i] = (CHAR *)emalloc((e->screenchars+1) * SIZEOFCHAR, us_tool->cluster);
 			if (e->textarray[i] == 0) ttyputnomemory();
 			e->textarray[i][0] = 0;
 			e->maxchars[i] = e->screenchars;
@@ -306,11 +306,11 @@ void us_editemacsterminate(EDITOR *e)
 	REGISTER INTBIG i;
 
 	for(i=0; i<e->maxlines; i++)
-		efree((char *)e->textarray[i]);
-	efree((char *)e->textarray);
-	efree((char *)e->maxchars);
-	efree((char *)e->formerline);
-	efree((char *)us_killbuf);
+		efree((CHAR *)e->textarray[i]);
+	efree((CHAR *)e->textarray);
+	efree((CHAR *)e->maxchars);
+	efree((CHAR *)e->formerline);
+	efree((CHAR *)us_killbuf);
 	us_killbufchars = 0;
 }
 
@@ -332,12 +332,12 @@ INTBIG us_editemacstotallines(WINDOWPART *win)
  * routine to get the string on line "lindex" (0 based).  A negative line
  * returns the current line.  Returns -1 if the index is beyond the file limit
  */
-char *us_editemacsgetline(WINDOWPART *win, INTBIG lindex)
+CHAR *us_editemacsgetline(WINDOWPART *win, INTBIG lindex)
 {
 	REGISTER EDITOR *e;
 
 	e = win->editor;
-	if (e == NOEDITOR) return("");
+	if (e == NOEDITOR) return(x_(""));
 	if (lindex < 0) lindex = e->curline;
 	if (lindex >= e->maxlines) return(NOSTRING);
 	return(e->textarray[lindex]);
@@ -346,9 +346,9 @@ char *us_editemacsgetline(WINDOWPART *win, INTBIG lindex)
 /*
  * routine to add line "str" to the text facet to become line "lindex"
  */
-void us_editemacsaddline(WINDOWPART *win, INTBIG lindex, char *str)
+void us_editemacsaddline(WINDOWPART *win, INTBIG lindex, CHAR *str)
 {
-	REGISTER char *pt;
+	REGISTER CHAR *pt;
 	REGISTER INTBIG savedline, savedchar;
 	REGISTER EDITOR *e;
 
@@ -368,9 +368,9 @@ void us_editemacsaddline(WINDOWPART *win, INTBIG lindex, char *str)
 /*
  * routine to replace the line number "lindex" with the string "str".
  */
-void us_editemacsreplaceline(WINDOWPART *win, INTBIG lindex, char *str)
+void us_editemacsreplaceline(WINDOWPART *win, INTBIG lindex, CHAR *str)
 {
-	REGISTER char *pt;
+	REGISTER CHAR *pt;
 	REGISTER INTBIG savedline, savedchar;
 	REGISTER EDITOR *e;
 
@@ -459,12 +459,12 @@ void us_editemacsresumegraphics(WINDOWPART *win)
 /*
  * routine to write the text file to "file"
  */
-void us_editemacswritetextfile(WINDOWPART *win, char *file)
+void us_editemacswritetextfile(WINDOWPART *win, CHAR *file)
 {
 	REGISTER EDITOR *e;
 	REGISTER INTBIG i, j;
 	REGISTER FILE *f;
-	char *truename;
+	CHAR *truename;
 
 	e = win->editor;
 	if (e == NOEDITOR) return;
@@ -485,7 +485,7 @@ void us_editemacswritetextfile(WINDOWPART *win, char *file)
 		return;
 	}
 
-	for(i=0; i<=j; i++) xprintf(f, "%s\n", e->textarray[i]);
+	for(i=0; i<=j; i++) xprintf(f, x_("%s\n"), e->textarray[i]);
 	xclose(f);
 	ttyputmsg(_("%s written"), truename);
 }
@@ -493,18 +493,18 @@ void us_editemacswritetextfile(WINDOWPART *win, char *file)
 /*
  * routine to read the text file "file"
  */
-void us_editemacsreadtextfile(WINDOWPART *win, char *file)
+void us_editemacsreadtextfile(WINDOWPART *win, CHAR *file)
 {
 	REGISTER EDITOR *e;
 	REGISTER INTBIG linecount, i, c;
 	REGISTER FILE *f;
-	char *filename;
+	CHAR *filename;
 
 	e = win->editor;
 	if (e == NOEDITOR) return;
 
 	/* get the file */
-	f = xopen(file, el_filetypetext, "", &filename);
+	f = xopen(file, el_filetypetext, x_(""), &filename);
 	if (f == NULL)
 	{
 		ttyputerr(_("Cannot read %s"), file);
@@ -532,7 +532,7 @@ void us_editemacsreadtextfile(WINDOWPART *win, char *file)
 	{
 		linecount = e->curline;
 		if (e->curchar != 0) linecount++;
-		(*win->changehandler)(win, REPLACEALLTEXT, "", (char *)e->textarray,
+		(*win->changehandler)(win, REPLACEALLTEXT, x_(""), (CHAR *)e->textarray,
 			linecount);
 	}
 
@@ -577,7 +577,7 @@ void us_editemacsgotbutton(WINDOWPART *win, INTBIG but, INTBIG x, INTBIG y)
 	yc = (e->revy-y) / us_thei + e->firstline;
 	if (yc < e->firstline) yc = e->firstline;
 	if (yc >= e->maxlines) yc = e->maxlines-1;
-	len = strlen(e->textarray[yc]);
+	len = estrlen(e->textarray[yc]);
 	if (xc > len) xc = len;
 	us_editemacsflashcursor(win);
 	e->curchar = xc;
@@ -669,7 +669,7 @@ void us_editemacsundo(WINDOWPART *w) { ttybeep(SOUNDBEEP, TRUE); }
  *   4   case sensitive
  *   8   search upwards
  */
-void us_editemacssearch(WINDOWPART *w, char *str, char *replace, INTBIG bits)
+void us_editemacssearch(WINDOWPART *w, CHAR *str, CHAR *replace, INTBIG bits)
 {
 	REGISTER BOOLEAN fromtop, reverse, casesensitive;
 
@@ -720,7 +720,7 @@ BOOLEAN us_editemacsimplementchar(WINDOWPART *win, INTBIG i, BOOLEAN m, BOOLEAN
 {
 	REGISTER EDITOR *e;
 	INTBIG j, k, savecur, len, nextlineno, nextcharno;
-	char s[2], *pt, *nextline, ch;
+	CHAR s[2], *pt, *nextline, ch;
 	REGISTER void *infstr;
 
 	e = win->editor;
@@ -745,7 +745,7 @@ BOOLEAN us_editemacsimplementchar(WINDOWPART *win, INTBIG i, BOOLEAN m, BOOLEAN
 		if (i == CTLW && !m)
 		{
 			if (fromuser) us_editemacsshipchanges(win);
-			us_editemacswritetextfile(win, "EMACSbuffer");
+			us_editemacswritetextfile(win, x_("EMACSbuffer"));
 			return(FALSE);
 		}
 
@@ -753,7 +753,7 @@ BOOLEAN us_editemacsimplementchar(WINDOWPART *win, INTBIG i, BOOLEAN m, BOOLEAN
 		if (i == CTLV && !m)
 		{
 			if (fromuser) us_editemacsshipchanges(win);
-			pt = (char *)fileselect(_("File name: "), el_filetypetext, "");
+			pt = (CHAR *)fileselect(_("File name: "), el_filetypetext, x_(""));
 			if (pt == 0 || *pt == 0)
 			{
 				us_abortedmsg();
@@ -789,7 +789,7 @@ BOOLEAN us_editemacsimplementchar(WINDOWPART *win, INTBIG i, BOOLEAN m, BOOLEAN
 		if (fromuser) us_editemacsworkingoncurline(e);
 
 		/* see if line needs to be extended */
-		if ((INTBIG)strlen(e->textarray[e->curline]) >= e->maxchars[e->curline])
+		if ((INTBIG)estrlen(e->textarray[e->curline]) >= e->maxchars[e->curline])
 			us_editemacsaddmorechars(e, e->curline);
 
 		/* see if new character is at end of line */
@@ -816,11 +816,11 @@ BOOLEAN us_editemacsimplementchar(WINDOWPART *win, INTBIG i, BOOLEAN m, BOOLEAN
 		{
 			us_editemacsclearbox(win, e->curchar, e->curline-e->firstline,
 				us_twid, us_thei);
-			s[0] = (char)i;   s[1] = 0;
+			s[0] = (CHAR)i;   s[1] = 0;
 			us_editemacstext(win, s, e->curchar, e->curline-e->firstline);
 			us_editemacscleanupline(win, e->curline);
 		}
-		e->textarray[e->curline][e->curchar] = (char)i;
+		e->textarray[e->curline][e->curchar] = (CHAR)i;
 
 		/* advance the character pointer */
 		e->curchar++;
@@ -926,7 +926,7 @@ BOOLEAN us_editemacsimplementchar(WINDOWPART *win, INTBIG i, BOOLEAN m, BOOLEAN
 		{
 			if (e->curline <= 0) { e->curchar++;   return(FALSE); }
 			e->curline--;
-			e->curchar = strlen(e->textarray[e->curline]);
+			e->curchar = estrlen(e->textarray[e->curline]);
 		}
 		us_editemacsdeletechar(win, fromuser);
 		return(FALSE);
@@ -945,7 +945,7 @@ BOOLEAN us_editemacsimplementchar(WINDOWPART *win, INTBIG i, BOOLEAN m, BOOLEAN
 			{
 				if (e->curline <= 0) { e->curchar++;   return(FALSE); }
 				e->curline--;
-				e->curchar = strlen(e->textarray[e->curline]);
+				e->curchar = estrlen(e->textarray[e->curline]);
 			}
 			if (isalnum(e->textarray[e->curline][e->curchar])) break;
 			us_editemacsdeletechar(win, fromuser);
@@ -961,7 +961,7 @@ BOOLEAN us_editemacsimplementchar(WINDOWPART *win, INTBIG i, BOOLEAN m, BOOLEAN
 			{
 				if (nextlineno <= 0) return(FALSE);
 				nextlineno--;
-				nextcharno = strlen(e->textarray[nextlineno]);
+				nextcharno = estrlen(e->textarray[nextlineno]);
 			}
 			if (!isalnum(e->textarray[nextlineno][nextcharno])) break;
 			e->curchar = nextcharno;
@@ -994,14 +994,14 @@ BOOLEAN us_editemacsimplementchar(WINDOWPART *win, INTBIG i, BOOLEAN m, BOOLEAN
 			savecur = e->curline;
 			for(; e->curline < e->maxlines; e->curline++)
 			{
-				if (e->curline == e->maxlines-1) nextline = ""; else
+				if (e->curline == e->maxlines-1) nextline = x_(""); else
 					nextline = e->textarray[e->curline+1];
-				if (strcmp(e->textarray[e->curline], nextline) == 0) continue;
+				if (estrcmp(e->textarray[e->curline], nextline) == 0) continue;
 				if (fromuser) us_editemacsworkingoncurline(e);
-				len = strlen(nextline);
+				len = estrlen(nextline);
 				while (len > e->maxchars[e->curline])
 					us_editemacsaddmorechars(e, e->curline);
-				(void)strcpy(e->textarray[e->curline], nextline);
+				(void)estrcpy(e->textarray[e->curline], nextline);
 				if (fromuser) us_editemacsshipchanges(win);
 			}
 			e->curline = savecur;
@@ -1029,7 +1029,7 @@ BOOLEAN us_editemacsimplementchar(WINDOWPART *win, INTBIG i, BOOLEAN m, BOOLEAN
 
 			/* kill to end of line */
 			if (fromuser) us_editemacsworkingoncurline(e);
-			(void)strcpy(us_killbuf, &e->textarray[e->curline][e->curchar]);
+			(void)estrcpy(us_killbuf, &e->textarray[e->curline][e->curchar]);
 			if (e->curline-e->firstline < e->screenlines &&
 				e->curline >= e->firstline && (e->state&EGRAPHICSOFF) == 0)
 					us_editemacsclearbox(win, e->curchar, e->curline-e->firstline,
@@ -1323,10 +1323,10 @@ BOOLEAN us_editemacsimplementchar(WINDOWPART *win, INTBIG i, BOOLEAN m, BOOLEAN
 		{
 			if (j == e->curline+1) nextline = &e->textarray[e->curline][e->curchar]; else
 				nextline = e->textarray[j-1];
-			len = strlen(nextline) + 1;
+			len = estrlen(nextline) + 1;
 			while (len > e->maxchars[j])
 				us_editemacsaddmorechars(e, j);
-			(void)strcpy(e->textarray[j], nextline);
+			(void)estrcpy(e->textarray[j], nextline);
 		}
 		e->textarray[e->curline][e->curchar] = 0;
 		if ((e->state&EGRAPHICSOFF) == 0 && e->curline-e->firstline < e->screenlines &&
@@ -1341,7 +1341,7 @@ BOOLEAN us_editemacsimplementchar(WINDOWPART *win, INTBIG i, BOOLEAN m, BOOLEAN
 		{
 			us_editemacsshipchanges(win);
 			if (win->changehandler != 0)
-				(*win->changehandler)(win, INSERTTEXTLINE, "", e->textarray[e->curline+1], e->curline+1);
+				(*win->changehandler)(win, INSERTTEXTLINE, x_(""), e->textarray[e->curline+1], e->curline+1);
 			us_editemacsworkingoncurline(e);
 		}
 
@@ -1389,10 +1389,10 @@ BOOLEAN us_editemacsimplementchar(WINDOWPART *win, INTBIG i, BOOLEAN m, BOOLEAN
 		{
 			if (j == e->curline+1) nextline = &e->textarray[e->curline][e->curchar]; else
 				nextline = e->textarray[j-1];
-			len = strlen(nextline) + 1;
+			len = estrlen(nextline) + 1;
 			while (len > e->maxchars[j])
 				us_editemacsaddmorechars(e, j);
-			(void)strcpy(e->textarray[j], nextline);
+			(void)estrcpy(e->textarray[j], nextline);
 		}
 		e->textarray[e->curline][e->curchar] = 0;
 		if ((e->state&EGRAPHICSOFF) == 0 && e->curline-e->firstline < e->screenlines &&
@@ -1408,7 +1408,7 @@ BOOLEAN us_editemacsimplementchar(WINDOWPART *win, INTBIG i, BOOLEAN m, BOOLEAN
 		if (fromuser)
 		{
 			if (win->changehandler != 0)
-				(*win->changehandler)(win, INSERTTEXTLINE, "", e->textarray[e->curline], e->curline);
+				(*win->changehandler)(win, INSERTTEXTLINE, x_(""), e->textarray[e->curline], e->curline);
 			if (e->curline == e->firstline+e->screenlines-1)
 				us_editemacsshiftscreenup(win);
 			us_editemacsworkingoncurline(e);
@@ -1513,8 +1513,8 @@ BOOLEAN us_editemacsadvancechar(WINDOWPART *win, BOOLEAN fromuser)
 void us_editemacsdeletechar(WINDOWPART *win, BOOLEAN fromuser)
 {
 	REGISTER INTBIG j, curl, len;
-	REGISTER char *nextline;
-	char s[2];
+	REGISTER CHAR *nextline;
+	CHAR s[2];
 	REGISTER EDITOR *e;
 
 	e = win->editor;
@@ -1529,28 +1529,28 @@ void us_editemacsdeletechar(WINDOWPART *win, BOOLEAN fromuser)
 			/* start by appending the next line to this */
 			if (fromuser) us_editemacsworkingoncurline(e);
 			nextline = e->textarray[e->curline+1];
-			len = strlen(e->textarray[e->curline]) + strlen(nextline);
+			len = estrlen(e->textarray[e->curline]) + estrlen(nextline);
 			while (len > e->maxchars[e->curline])
 				us_editemacsaddmorechars(e, e->curline);
-			(void)strcat(e->textarray[e->curline], nextline);
+			(void)estrcat(e->textarray[e->curline], nextline);
 			us_editemacsshipchanges(win);
 			us_editemacsredrawline(win, e->curline);
 
 			/* now report deletion of following line */
 			if (win->changehandler != 0)
-				(*win->changehandler)(win, DELETETEXTLINE, "", e->textarray[e->curline+1], e->curline+1);
+				(*win->changehandler)(win, DELETETEXTLINE, x_(""), e->textarray[e->curline+1], e->curline+1);
 			us_editemacsworkingoncurline(e);
 
 			/* shift up lines in memory */
 			for(curl = e->curline+1; curl < e->maxlines; curl++)
 			{
-				if (curl == e->maxlines-1) nextline = ""; else
+				if (curl == e->maxlines-1) nextline = x_(""); else
 					nextline = e->textarray[curl+1];
-				if (strcmp(e->textarray[curl], nextline) == 0) continue;
-				len = strlen(nextline);
+				if (estrcmp(e->textarray[curl], nextline) == 0) continue;
+				len = estrlen(nextline);
 				while (len > e->maxchars[curl])
 					us_editemacsaddmorechars(e, curl);
-				(void)strcpy(e->textarray[curl], nextline);
+				(void)estrcpy(e->textarray[curl], nextline);
 			}
 
 			/* delete line on the screen */
@@ -1580,7 +1580,7 @@ void us_editemacsdeletechar(WINDOWPART *win, BOOLEAN fromuser)
 		us_editemacsmovebox(win, e->curchar, e->curline-e->firstline,
 			e->swid-e->curchar*us_twid-us_twid, us_thei,
 				e->curchar+1, e->curline-e->firstline);
-		if ((INTBIG)strlen(e->textarray[e->curline]) >= e->screenchars)
+		if ((INTBIG)estrlen(e->textarray[e->curline]) >= e->screenchars)
 		{
 			us_editemacsclearbox(win, e->screenchars-1, e->curline-e->firstline,
 				us_twid, us_thei);
@@ -1596,7 +1596,7 @@ void us_editemacsdeletechar(WINDOWPART *win, BOOLEAN fromuser)
  * Start search from the top if "fromtop" is true.  Issue proper calls if this was
  * made by the user ("fromuser" true).
  */
-void us_editemacsdosearch(WINDOWPART *win, char *str, BOOLEAN reverse,
+void us_editemacsdosearch(WINDOWPART *win, CHAR *str, BOOLEAN reverse,
 	BOOLEAN fromtop, BOOLEAN casesensitive, BOOLEAN fromuser)
 {
 	REGISTER EDITOR *e;
@@ -1604,7 +1604,7 @@ void us_editemacsdosearch(WINDOWPART *win, char *str, BOOLEAN reverse,
 
 	/* search for the string */
 	e = win->editor;
-	i = strlen(str);
+	i = estrlen(str);
 	if (fromtop)
 	{
 		/* search from the top of the buffer */
@@ -1626,7 +1626,7 @@ void us_editemacsdosearch(WINDOWPART *win, char *str, BOOLEAN reverse,
 			{
 				j--;
 				if (j < 0) j = e->maxlines - 1;
-				k = strlen(e->textarray[j]);
+				k = estrlen(e->textarray[j]);
 			}
 		} else
 		{
@@ -1650,7 +1650,7 @@ void us_editemacsdosearch(WINDOWPART *win, char *str, BOOLEAN reverse,
 		/* if string matches, set cursor pointers */
 		if (casesensitive)
 		{
-			match = strncmp(str, &e->textarray[j][k], i);
+			match = estrncmp(str, &e->textarray[j][k], i);
 		} else
 		{
 			match = namesamen(str, &e->textarray[j][k], i);
@@ -1752,19 +1752,19 @@ void us_editemacsredrawline(WINDOWPART *win, INTBIG j)
 	e = win->editor;
 	if (e == NOEDITOR) return;
 
-	if ((INTBIG)strlen(e->textarray[j+e->firstline]) > e->screenchars)
+	if ((INTBIG)estrlen(e->textarray[j+e->firstline]) > e->screenchars)
 	{
 		save = e->textarray[j+e->firstline][e->screenchars];
 		e->textarray[j+e->firstline][e->screenchars] = 0;
 	} else save = 0;
 	us_editemacstext(win, e->textarray[j+e->firstline], 0, j);
-	if (save != 0) e->textarray[j+e->firstline][e->screenchars] = (char)save;
+	if (save != 0) e->textarray[j+e->firstline][e->screenchars] = (CHAR)save;
 }
 
 /*
  * routine to write the header string
  */
-void us_editemacssetheader(WINDOWPART *win, char *header)
+void us_editemacssetheader(WINDOWPART *win, CHAR *header)
 {
 	REGISTER INTBIG save;
 	REGISTER EDITOR *e;
@@ -1772,7 +1772,7 @@ void us_editemacssetheader(WINDOWPART *win, char *header)
 	e = win->editor;
 	if (e == NOEDITOR) return;
 	screendrawbox(win, win->uselx, win->usehx, win->usely, win->usehy, &us_ebox);
-	if ((INTBIG)strlen(header) > e->screenchars)
+	if ((INTBIG)estrlen(header) > e->screenchars)
 	{
 		save = header[e->screenchars];
 		header[e->screenchars] = 0;
@@ -1781,7 +1781,7 @@ void us_editemacssetheader(WINDOWPART *win, char *header)
 	if ((win->state&WINDOWTYPE) == POPTEXTWINDOW)
 		us_editemacstext(win, _("EMACS editor: type RETURN when done"), 0, -1); else
 	{
-		if (strcmp(win->location, "entire") != 0)
+		if (estrcmp(win->location, x_("entire")) != 0)
 			us_editemacstext(win, _("EMACS editor: type ^Xd when done"), 0, -1); else
 		{
 			if (graphicshas(CANUSEFRAMES))
@@ -1789,7 +1789,7 @@ void us_editemacssetheader(WINDOWPART *win, char *header)
 					us_editemacstext(win, _("EMACS editor: text-only facet"), 0, -1);
 		}
 	}
-	if (save != 0) header[e->screenchars] = (char)save;
+	if (save != 0) header[e->screenchars] = (CHAR)save;
 	screeninvertbox(win, e->offx-1, e->offx+e->swid,
 		e->revy+1, e->revy+us_thei*HEADERLINES);
 	us_menufigs.col = el_colmengly;
@@ -1804,7 +1804,7 @@ void us_editemacssetheader(WINDOWPART *win, char *header)
 /*
  * Routine to return the next valid character (ignoring end-of-lines).
  */
-char us_editemacsnextvalidcharacter(EDITOR *e)
+CHAR us_editemacsnextvalidcharacter(EDITOR *e)
 {
 	INTBIG line, chr;
 
@@ -1876,7 +1876,7 @@ void us_editemacsworkingoncurline(EDITOR *e)
 	if (e->working == -1)
 	{
 		/* first time: save the line */
-		(void)strcpy(e->formerline, e->textarray[e->curline]);
+		(void)estrcpy(e->formerline, e->textarray[e->curline]);
 		e->working = e->curline;
 	}
 }
@@ -1909,7 +1909,7 @@ void us_editemacsaddmorelines(EDITOR *e)
 {
 	REGISTER INTBIG oldlines, i;
 	REGISTER INTBIG *maxchars;
-	REGISTER char **textarray;
+	REGISTER CHAR **textarray;
 
 	/* save former buffer size, double it */
 	oldlines = e->maxlines;
@@ -1918,7 +1918,7 @@ void us_editemacsaddmorelines(EDITOR *e)
 	/* allocate new arrays */
 	maxchars = (INTBIG *)emalloc((e->maxlines * SIZEOFINTBIG), us_tool->cluster);
 	if (maxchars == 0) ttyputnomemory();
-	textarray = (char **)emalloc((e->maxlines * (sizeof (char *))), us_tool->cluster);
+	textarray = (CHAR **)emalloc((e->maxlines * (sizeof (CHAR *))), us_tool->cluster);
 	if (textarray == 0) ttyputnomemory();
 
 	/* copy old information */
@@ -1926,23 +1926,23 @@ void us_editemacsaddmorelines(EDITOR *e)
 	{
 		if (i >= oldlines)
 		{
-			textarray[i] = (char *)emalloc((e->screenchars+1), us_tool->cluster);
+			textarray[i] = (CHAR *)emalloc((e->screenchars+1) * SIZEOFCHAR, us_tool->cluster);
 			if (textarray[i] == 0) ttyputnomemory();
 			textarray[i][0] = 0;
 			maxchars[i] = e->screenchars;
 		} else
 		{
-			textarray[i] = (char *)emalloc((e->maxchars[i]+1), us_tool->cluster);
+			textarray[i] = (CHAR *)emalloc((e->maxchars[i]+1) * SIZEOFCHAR, us_tool->cluster);
 			if (textarray[i] == 0) ttyputnomemory();
-			(void)strcpy(textarray[i], e->textarray[i]);
+			(void)estrcpy(textarray[i], e->textarray[i]);
 			maxchars[i] = e->maxchars[i];
 		}
 	}
 
 	/* free old arrays */
 	for(i=0; i<oldlines; i++) efree(e->textarray[i]);
-	efree((char *)e->textarray);
-	efree((char *)e->maxchars);
+	efree((CHAR *)e->textarray);
+	efree((CHAR *)e->maxchars);
 
 	/* setup pointers correctly */
 	e->textarray = textarray;
@@ -1954,12 +1954,12 @@ void us_editemacsaddmorelines(EDITOR *e)
  */
 void us_editemacsaddmorechars(EDITOR *e, INTBIG line)
 {
-	REGISTER char *oldline;
+	REGISTER CHAR *oldline;
 
 	oldline = e->textarray[line];
 	e->maxchars[line] *= 2;
-	e->textarray[line] = (char *)emalloc((e->maxchars[line]+1), us_tool->cluster);
-	(void)strcpy(e->textarray[line], oldline);
+	e->textarray[line] = (CHAR *)emalloc((e->maxchars[line]+1) * SIZEOFCHAR, us_tool->cluster);
+	(void)estrcpy(e->textarray[line], oldline);
 	if (e->maxchars[line] > e->mostchars)
 	{
 		e->mostchars = e->maxchars[line];
@@ -1973,12 +1973,12 @@ void us_editemacsaddmorechars(EDITOR *e, INTBIG line)
  */
 void us_editemacsgetbuffers(EDITOR *e)
 {
-	e->formerline = (char *)emalloc((e->mostchars+1), us_tool->cluster);
+	e->formerline = (CHAR *)emalloc((e->mostchars+1) * SIZEOFCHAR, us_tool->cluster);
 	if (e->formerline == 0) ttyputnomemory();
 	if (e->mostchars > us_killbufchars)
 	{
 		if (us_killbufchars != 0) efree(us_killbuf);
-		us_killbuf = (char *)emalloc(e->mostchars, us_tool->cluster);
+		us_killbuf = (CHAR *)emalloc(e->mostchars * SIZEOFCHAR, us_tool->cluster);
 		if (us_killbuf == 0) ttyputnomemory();
 		us_killbufchars = e->mostchars;
 	}
@@ -2034,7 +2034,7 @@ void us_editemacsinvertbox(WINDOWPART *win, INTBIG dx, INTBIG dy, INTBIG wid, IN
 /*
  * write text "str" starting at character position (x,y)
  */
-void us_editemacstext(WINDOWPART *win, char *str, INTBIG x, INTBIG y)
+void us_editemacstext(WINDOWPART *win, CHAR *str, INTBIG x, INTBIG y)
 {
 	REGISTER EDITOR *e;
 	UINTBIG descript[TEXTDESCRIPTSIZE];
