@@ -66,7 +66,7 @@ void us_graphfacets(NODEPROTO *top)
 	pinpp = gen_invispinprim->firstportproto;
 
 	/* create the graph facet */
-	graphnp = newnodeproto("FacetStructure", el_curlib);
+	graphnp = newnodeproto(x_("FacetStructure"), el_curlib);
 	if (graphnp == NONODEPROTO) return;
 	if (graphnp->prevversion != NONODEPROTO)
 		ttyputverbose(M_("Creating new version of facet: FacetStructure")); else
@@ -161,7 +161,7 @@ void us_graphfacets(NODEPROTO *top)
 		nd->main = NONODEDESCR;
 
 		nd->x = xval[np->temp1];
-		xval[np->temp1] += strlen(describenodeproto(np));
+		xval[np->temp1] += estrlen(describenodeproto(np));
 		if (xval[np->temp1] > maxwidth) maxwidth = xval[np->temp1];
 		nd->y = np->temp1;
 		nd->yoff = 0;
@@ -336,10 +336,10 @@ void us_graphfacets(NODEPROTO *top)
 		for(np = lib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
 	{
 		if (np->temp1 == -1) continue;
-		efree((char *)np->temp1);
+		efree((CHAR *)np->temp1);
 	}
-	efree((char *)xval);
-	efree((char *)yoff);
+	efree((CHAR *)xval);
+	efree((CHAR *)yoff);
 }
 
 /*
@@ -387,7 +387,7 @@ NODEPROTO *us_graphmainview(NODEPROTO *np)
 
 typedef struct Icomill
 {
-	char *name;
+	CHAR *name;
 	INTBIG  x, y;
 	INTBIG  realx;
 	INTBIG  children;
@@ -405,13 +405,13 @@ static INTBIG us_illustrateXpos[MAXILLUSTRATEDEPTH];		/* current build-out X pos
 static COMCOMP *us_illustrateparam[MAXILLUSTRATEDEPTH];	/* current parameter type */
 
 /* prototypes for local routines */
-static COMILL *us_illustratecommand(char*, INTBIG, COMILL*);
+static COMILL *us_illustratecommand(CHAR*, INTBIG, COMILL*);
 
 void us_illustratecommandset(void)
 {
 	REGISTER INTBIG i;
 	REGISTER INTBIG j;
-	char *newmessage[1];
+	CHAR *newmessage[1];
 	REGISTER NODEPROTO *graphnp;
 	REGISTER NODEINST *ni;
 	REGISTER COMILL *ci, *nextci;
@@ -420,7 +420,7 @@ void us_illustratecommandset(void)
 	REGISTER VARIABLE *var;
 
 	/* create the graph facet */
-	graphnp = newnodeproto("CommandStructure", el_curlib);
+	graphnp = newnodeproto(x_("CommandStructure"), el_curlib);
 	if (graphnp == NONODEPROTO) return;
 	if (graphnp->prevversion != NONODEPROTO)
 		ttyputmsg(_("Creating new version of facet: CommandStructure")); else
@@ -510,22 +510,22 @@ void us_illustratecommandset(void)
 	for(ci = us_allcomill; ci != NOCOMILL; ci = nextci)
 	{
 		nextci = ci->nextcomill;
-		efree((char *)ci);
+		efree((CHAR *)ci);
 	}
 
 	/* have the facet displayed on the screen */
-	newmessage[0] = "CommandStructure";
+	newmessage[0] = x_("CommandStructure");
 	us_editfacet(1, newmessage);
 }
 
-COMILL *us_illustratecommand(char *name, INTBIG depth, COMILL *thisci)
+COMILL *us_illustratecommand(CHAR *name, INTBIG depth, COMILL *thisci)
 {
 	static COMCOMP us_recursioncomcomp = {
-		NOKEYWORD, NOTOPLIST, NONEXTLIST, NOPARAMS, 0, "", ""};
+		NOKEYWORD, NOTOPLIST, NONEXTLIST, NOPARAMS, 0, x_(""), x_("")};
 	REGISTER COMCOMP *cc;
 	REGISTER COMILL *ci, *subci;
 	REGISTER INTBIG i, j, k;
-	REGISTER char *arg;
+	REGISTER CHAR *arg;
 
 	/* put this name at the appropriate depth */
 	if (depth >= MAXILLUSTRATEDEPTH) return(NOCOMILL);
@@ -548,44 +548,44 @@ COMILL *us_illustratecommand(char *name, INTBIG depth, COMILL *thisci)
 	{
 		/* force extension of the tree to a specified depth */
 		if (depth < FORCEDDEPTH)
-			(void)us_illustratecommand((char *)0, depth+1, ci);
+			(void)us_illustratecommand((CHAR *)0, depth+1, ci);
 		return(ci);
 	}
 
 	cc = us_illustrateparam[depth];
 	if (cc->ifmatch == NOKEYWORD)
 	{
-		if (cc->toplist == topoffile) arg = "FILE"; else
-		if (cc->toplist == topoflibfile) arg = "LIBRARY"; else
-		if (cc->toplist == topoftechs) arg = "TECH"; else
-		if (cc->toplist == topoflibs) arg = "LIB"; else
-		if (cc->toplist == topoftools) arg = "TOOL"; else
-		if (cc->toplist == topofcells) arg = "CELL"; else
-		if (cc->toplist == topofviews) arg = "VIEW"; else
-		if (cc->toplist == topofnets) arg = "NET"; else
-		if (cc->toplist == topofarcs) arg = "ARC"; else
-		if (cc->toplist == topoffacets) arg = "FACET"; else
-		if (cc->toplist == us_topofcommands) arg = "COM"; else
-		if (cc->toplist == us_topofmacros) arg = "MACRO"; else
-		if (cc->toplist == us_topofpopupmenu) arg = "POPUP"; else
-		if (cc->toplist == us_topofports) arg = "PORT"; else
-		if (cc->toplist == us_topofcports) arg = "FACETPORT"; else
-		if (cc->toplist == us_topofexpports) arg = "EXPORT"; else
-		if (cc->toplist == us_topofwindows) arg = "WINDOWPART"; else
-		if (cc->toplist == us_topoflayers) arg = "LAYER"; else
-		if (cc->toplist == us_topofhighlight) arg = "HIGH"; else
-		if (cc->toplist == us_topofarcnodes) arg = "ARC/NODE"; else
-		if (cc->toplist == us_topofnodes) arg = "NODE"; else
-		if (cc->toplist == us_topofcellfacets) arg = "FACET/CELL"; else
-		if (cc->toplist == us_topofprims) arg = "PRIM"; else
-		if (cc->toplist == us_topofconstraints) arg = "CONSTR"; else
-		if (cc->toplist == us_topofmbuttons) arg = "BUTTON"; else
-		if (cc->toplist == us_topofedteclay) arg = "LAYER"; else
-		if (cc->toplist == us_topofedtecarc) arg = "ARC"; else
-		if (cc->toplist == us_topofedtecnode) arg = "NODE"; else
-		if (cc->toplist == us_topofallthings) arg = "ANY"; else
-		if (cc->toplist == us_topofvars) arg = "VAR"; else
-		if (cc == &us_recursioncomcomp) arg = "***"; else arg = "ARG";
+		if (cc->toplist == topoffile) arg = x_("FILE"); else
+		if (cc->toplist == topoflibfile) arg = x_("LIBRARY"); else
+		if (cc->toplist == topoftechs) arg = x_("TECH"); else
+		if (cc->toplist == topoflibs) arg = x_("LIB"); else
+		if (cc->toplist == topoftools) arg = x_("TOOL"); else
+		if (cc->toplist == topofcells) arg = x_("CELL"); else
+		if (cc->toplist == topofviews) arg = x_("VIEW"); else
+		if (cc->toplist == topofnets) arg = x_("NET"); else
+		if (cc->toplist == topofarcs) arg = x_("ARC"); else
+		if (cc->toplist == topoffacets) arg = x_("FACET"); else
+		if (cc->toplist == us_topofcommands) arg = x_("COM"); else
+		if (cc->toplist == us_topofmacros) arg = x_("MACRO"); else
+		if (cc->toplist == us_topofpopupmenu) arg = x_("POPUP"); else
+		if (cc->toplist == us_topofports) arg = x_("PORT"); else
+		if (cc->toplist == us_topofcports) arg = x_("FACETPORT"); else
+		if (cc->toplist == us_topofexpports) arg = x_("EXPORT"); else
+		if (cc->toplist == us_topofwindows) arg = x_("WINDOWPART"); else
+		if (cc->toplist == us_topoflayers) arg = x_("LAYER"); else
+		if (cc->toplist == us_topofhighlight) arg = x_("HIGH"); else
+		if (cc->toplist == us_topofarcnodes) arg = x_("ARC/NODE"); else
+		if (cc->toplist == us_topofnodes) arg = x_("NODE"); else
+		if (cc->toplist == us_topofcellfacets) arg = x_("FACET/CELL"); else
+		if (cc->toplist == us_topofprims) arg = x_("PRIM"); else
+		if (cc->toplist == us_topofconstraints) arg = x_("CONSTR"); else
+		if (cc->toplist == us_topofmbuttons) arg = x_("BUTTON"); else
+		if (cc->toplist == us_topofedteclay) arg = x_("LAYER"); else
+		if (cc->toplist == us_topofedtecarc) arg = x_("ARC"); else
+		if (cc->toplist == us_topofedtecnode) arg = x_("NODE"); else
+		if (cc->toplist == us_topofallthings) arg = x_("ANY"); else
+		if (cc->toplist == us_topofvars) arg = x_("VAR"); else
+		if (cc == &us_recursioncomcomp) arg = x_("***"); else arg = x_("ARG");
 		subci = us_illustratecommand(arg, depth+1, ci);
 		if (subci == NOCOMILL) return(NOCOMILL);
 		return(ci);
@@ -617,7 +617,7 @@ COMILL *us_illustratecommand(char *name, INTBIG depth, COMILL *thisci)
 /****************************** PULLDOWN MENU DUMPING ******************************/
 
 /* prototypes for local routines */
-static void us_dumppulldownmenu(FILE *io, POPUPMENU *pm, char *name, char *prefix);
+static void us_dumppulldownmenu(FILE *io, POPUPMENU *pm, CHAR *name, CHAR *prefix);
 
 /*
  * Routine to dump the pulldown menus to an indented text file.
@@ -625,11 +625,11 @@ static void us_dumppulldownmenu(FILE *io, POPUPMENU *pm, char *name, char *prefi
 void us_dumppulldownmenus(void)
 {
 	FILE *io;
-	char *truename;
+	CHAR *truename;
 	REGISTER INTBIG i;
 	REGISTER POPUPMENU *pm;
 
-	io = xcreate("pulldowns.txt", el_filetypetext, M_("Menu dump file"), &truename);
+	io = xcreate(x_("pulldowns.txt"), el_filetypetext, M_("Menu dump file"), &truename);
 	if (io == NULL) return;
 
 	xprintf(io, M_("Pulldown menus in Electric as of %s\n"),
@@ -637,33 +637,33 @@ void us_dumppulldownmenus(void)
 	for(i=0; i<us_pulldownmenucount; i++)
 	{
 		pm = us_pulldowns[i];
-		xprintf(io, "\n");
-		us_dumppulldownmenu(io, pm, pm->header, "");
+		xprintf(io, x_("\n"));
+		us_dumppulldownmenu(io, pm, pm->header, x_(""));
 	}
 
 	xclose(io);
 	ttyputmsg(M_("Pulldown menus dumped to %s"), truename);
 }
 
-void us_dumppulldownmenu(FILE *io, POPUPMENU *pm, char *name, char *prefix)
+void us_dumppulldownmenu(FILE *io, POPUPMENU *pm, CHAR *name, CHAR *prefix)
 {
 	REGISTER POPUPMENUITEM *mi;
 	REGISTER USERCOM *uc;
 	REGISTER INTBIG i, j, k;
-	char comname[300], subprefix[50];
+	CHAR comname[300], subprefix[50];
 
 	for(k=j=0; name[k] != 0; k++)
 		if (name[k] != '&') comname[j++] = name[k];
 	comname[j] = 0;
 
-	xprintf(io, "%s%s:\n", prefix, comname);
+	xprintf(io, x_("%s%s:\n"), prefix, comname);
 	for(i=0; i<pm->total; i++)
 	{
 		mi = &pm->list[i];
 		uc = mi->response;
 		if (uc->active < 0)
 		{
-			xprintf(io, "%s    ----------\n", prefix);
+			xprintf(io, x_("%s    ----------\n"), prefix);
 			continue;
 		}
 
@@ -677,11 +677,11 @@ void us_dumppulldownmenu(FILE *io, POPUPMENU *pm, char *name, char *prefix)
 
 		if (uc->menu != NOPOPUPMENU)
 		{
-			strcpy(subprefix, prefix);
-			strcat(subprefix, "    ");
+			estrcpy(subprefix, prefix);
+			estrcat(subprefix, x_("    "));
 			us_dumppulldownmenu(io, uc->menu, comname, subprefix);
 			continue;
 		}
-		xprintf(io, "%s    %s\n", prefix, comname);
+		xprintf(io, x_("%s    %s\n"), prefix, comname);
 	}
 }
