@@ -29,7 +29,7 @@
  * info@staticfreesoft.com
  */
 
- /*
+/*
  * the code in this module makes me quiver with trepidation whenever it
  * breaks ... smr
  */
@@ -47,7 +47,8 @@
 static INTBIG us_tracelist;
 static INTBIG us_tracedata[MAXTRACE];
 static GRAPHICS us_highl = {LAYERH, 0, SOLIDC, SOLIDC,
-	{0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF}, NOVARIABLE, 0};
+	{0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,
+	0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF}, NOVARIABLE, 0};
 
 static INTBIG us_dragx, us_dragy, us_dragox, us_dragoy, us_dragoffx,
 	us_dragoffy, us_lastcurx, us_lastcury, us_dragpoint,
@@ -74,12 +75,12 @@ static INTBIG      us_dragstartx, us_dragstarty;
 static INTBIG      us_dragwirepathcount;
 static INTBIG      us_dragwirepath[8];
 static HIGHLIGHT   us_draghigh;
-static char        us_dragmessage[100];
+static CHAR        us_dragmessage[100];
 static UINTBIG     us_beforepantime = 0;
 static INTBIG      us_initthumbcoord;
 static WINDOWPART  us_trackww;
 static INTBIG      us_dragtextcount;
-static char      **us_dragtexts;
+static CHAR      **us_dragtexts;
 static void      (*us_trackingcallback)(INTBIG);
 
 /* prototypes for local routines */
@@ -89,6 +90,7 @@ static void us_invertstretch(void);
 static void us_wanttoinvert(INTBIG fx, INTBIG fy, INTBIG tx, INTBIG ty, WINDOWPART *w);
 static void us_drawdistance(void);
 static void us_panatscreenedge(INTBIG *x, INTBIG *y);
+static void us_wanttoinvert(INTBIG fx, INTBIG fy, INTBIG tx, INTBIG ty, WINDOWPART *w);
 
 /************************* NODE TRACE *************************/
 
@@ -130,7 +132,7 @@ void us_traceup(void)
 
 	if (us_tracelist == 0)
 	{
-		(void)setval((INTBIG)us_tool, VTOOL, us_commandvarname('T'), (INTBIG)"nothing",
+		(void)setval((INTBIG)us_tool, VTOOL, us_commandvarname('T'), (INTBIG)x_("nothing"),
 			VSTRING|VDONTSAVE);
 		return;
 	}
@@ -184,14 +186,14 @@ void us_findpointbegin(void)
 
 	us_dragshown = 0;
 	if (getxy(&us_dragx, &us_dragy)) return;
-	gridalign(&us_dragx, &us_dragy, 1);
+	gridalign(&us_dragx, &us_dragy, 1, el_curlib->curnodeproto);
 	us_setcursorpos(NOWINDOWFRAME, us_dragx, us_dragy);
 	us_dragwindow = el_curwindowpart;
 
 	/* select the current point on the node */
 	highvar = getvalkey((INTBIG)us_tool, VTOOL, VSTRING|VISARRAY, us_highlightedkey);
 	if (highvar == NOVARIABLE) return;
-	(void)us_makehighlight(((char **)highvar->addr)[0], &newhigh);
+	(void)us_makehighlight(((CHAR **)highvar->addr)[0], &newhigh);
 	newhigh.fromport = NOPORTPROTO;
 	newhigh.facet = getcurfacet();
 	us_setfind(&newhigh, 1, 0, 0, 0);
@@ -199,7 +201,7 @@ void us_findpointbegin(void)
 	/* get the point to be moved */
 	highvar = getvalkey((INTBIG)us_tool, VTOOL, VSTRING|VISARRAY, us_highlightedkey);
 	if (highvar == NOVARIABLE) return;
-	(void)us_makehighlight(((char **)highvar->addr)[0], &newhigh);
+	(void)us_makehighlight(((CHAR **)highvar->addr)[0], &newhigh);
 	us_dragpoint = newhigh.frompoint;
 }
 
@@ -221,7 +223,7 @@ BOOLEAN us_addpdown(INTBIG x, INTBIG y)
 		return(FALSE);
 	}
 	(void)getxy(&us_lastcurx, &us_lastcury);
-	gridalign(&us_lastcurx, &us_lastcury, 1);
+	gridalign(&us_lastcurx, &us_lastcury, 1, el_curlib->curnodeproto);
 	us_setcursorpos(NOWINDOWFRAME, us_lastcurx, us_lastcury);
 
 	/* if the lines are already being shown, erase them */
@@ -249,7 +251,7 @@ BOOLEAN us_addpdown(INTBIG x, INTBIG y)
 		cx = (us_dragnodeinst->lowx + us_dragnodeinst->highx) / 2;
 		cy = (us_dragnodeinst->lowy + us_dragnodeinst->highy) / 2;
 		p = 0;
-		if (us_dragpoint <= size)
+		if (us_dragpoint > 0 && us_dragpoint <= size)
 		{
 			xform(((INTBIG *)var->addr)[(us_dragpoint-1)*2] + cx,
 				((INTBIG *)var->addr)[(us_dragpoint-1)*2+1] + cy,
@@ -298,7 +300,7 @@ BOOLEAN us_movepdown(INTBIG x, INTBIG y)
 		return(FALSE);
 	}
 	(void)getxy(&us_lastcurx, &us_lastcury);
-	gridalign(&us_lastcurx, &us_lastcury, 1);
+	gridalign(&us_lastcurx, &us_lastcury, 1, el_curlib->curnodeproto);
 	us_setcursorpos(NOWINDOWFRAME, us_lastcurx, us_lastcury);
 
 	/* if the lines are already being shown, erase them */
@@ -624,7 +626,7 @@ BOOLEAN us_sizeadown(INTBIG x, INTBIG y)
 		return(FALSE);
 	}
 	(void)getxy(&us_lastcurx, &us_lastcury);
-	gridalign(&us_lastcurx, &us_lastcury, 2);
+	gridalign(&us_lastcurx, &us_lastcury, 2, el_curlib->curnodeproto);
 	us_setcursorpos(NOWINDOWFRAME, us_lastcurx, us_lastcury);
 
 	/* if the box is already being shown, erase it */
@@ -671,7 +673,7 @@ BOOLEAN us_sizedown(INTBIG x, INTBIG y)
 		return(FALSE);
 	}
 	(void)getxy(&us_lastcurx, &us_lastcury);
-	gridalign(&us_lastcurx, &us_lastcury, 1);
+	gridalign(&us_lastcurx, &us_lastcury, 1, el_curlib->curnodeproto);
 	us_setcursorpos(NOWINDOWFRAME, us_lastcurx, us_lastcury);
 
 	/* if the box is already being shown, erase it */
@@ -784,7 +786,7 @@ BOOLEAN us_sizecdown(INTBIG x, INTBIG y)
 		return(FALSE);
 	}
 	(void)getxy(&us_lastcurx, &us_lastcury);
-	gridalign(&us_lastcurx, &us_lastcury, 2);
+	gridalign(&us_lastcurx, &us_lastcury, 2, el_curlib->curnodeproto);
 	us_setcursorpos(NOWINDOWFRAME, us_lastcurx, us_lastcury);
 
 	/* if the box is already being shown, erase it */
@@ -917,11 +919,10 @@ void us_finddoibegin(BOOLEAN complement)
 {
 	REGISTER VARIABLE *highvar;
 	REGISTER NODEINST *ni;
-	REGISTER ARCINST *ai;
 	REGISTER PORTPROTO *pp;
 	REGISTER INTBIG len, another;
 	HIGHLIGHT newhigh, oldhigh;
-	INTBIG i, j;
+	INTBIG i;
 	INTBIG xcur, ycur, dist, bestdist;
 
 	/* remember initial time of this action */
@@ -947,7 +948,7 @@ void us_finddoibegin(BOOLEAN complement)
 	if (highvar != NOVARIABLE)
 	{
 		len = getlength(highvar);
-		(void)us_makehighlight(((char **)highvar->addr)[0], &newhigh);
+		(void)us_makehighlight(((CHAR **)highvar->addr)[0], &newhigh);
 	} else
 	{
 		len = 0;
@@ -965,13 +966,13 @@ void us_finddoibegin(BOOLEAN complement)
 		/* see if the cursor is over something highlighted */
 		for(i=0; i<len; i++)
 		{
-			(void)us_makehighlight(((char **)highvar->addr)[i], &oldhigh);
+			(void)us_makehighlight(((CHAR **)highvar->addr)[i], &oldhigh);
 			if (us_cursoroverhigh(&oldhigh, xcur, ycur, el_curwindowpart)) break;
 		}
 		if (i < len)
 		{
 			/* re-find the closest port when one node is selected */
-			(void)us_makehighlight(((char **)highvar->addr)[i], &newhigh);
+			(void)us_makehighlight(((CHAR **)highvar->addr)[i], &newhigh);
 			if (len == 1 && (newhigh.status&HIGHFROM) != 0 &&
 				newhigh.fromgeom->entryisnode)
 			{
@@ -1009,7 +1010,7 @@ void us_finddoibegin(BOOLEAN complement)
 			{
 				for(i=0; i<len; i++)
 				{
-					(void)us_makehighlight(((char **)highvar->addr)[i], &newhigh);
+					(void)us_makehighlight(((CHAR **)highvar->addr)[i], &newhigh);
 					if (us_cursoroverhigh(&newhigh, xcur, ycur, el_curwindowpart)) break;
 				}
 				if (i < len)
@@ -1041,7 +1042,7 @@ void us_finddoibegin(BOOLEAN complement)
 	}
 
 	/* grid the cursor coordinates when over something */
-	gridalign(&us_dragx, &us_dragy, 1);
+	gridalign(&us_dragx, &us_dragy, 1, us_dragnodeproto);
 	us_setcursorpos(NOWINDOWFRAME, us_dragx, us_dragy);
 	us_dragox = us_dragx;   us_dragoy = us_dragy;
 
@@ -1054,13 +1055,15 @@ void us_finddoibegin(BOOLEAN complement)
 	/* see if object under cursor is already highlighted */
 	for(i=0; i<len; i++)
 	{
-		if (us_makehighlight(((char **)highvar->addr)[i], &oldhigh)) continue;
+		if (us_makehighlight(((CHAR **)highvar->addr)[i], &oldhigh)) continue;
 		if (oldhigh.facet != newhigh.facet) continue;
 		if ((oldhigh.status&HIGHTYPE) != (newhigh.status&HIGHTYPE)) continue;
 		if (oldhigh.fromgeom != newhigh.fromgeom) continue;
 		if ((oldhigh.status&HIGHTYPE) == HIGHTEXT)
 		{
 			if (oldhigh.fromvar != newhigh.fromvar) continue;
+			if (oldhigh.fromport != NOPORTPROTO && newhigh.fromport != NOPORTPROTO &&
+				oldhigh.fromport != newhigh.fromport) continue;
 		}
 		break;
 	}
@@ -1098,6 +1101,7 @@ void us_finddoibegin(BOOLEAN complement)
 	}
 
 	/* can only drag if in "Mac" mode */
+	us_cantdrag = 1;
 	if (us_dragstayonhigh == 0) return;
 
 	/* do no motion if stillness requested */
@@ -1117,38 +1121,16 @@ void us_finddoibegin(BOOLEAN complement)
 
 	/* stop if nothing selected */
 	if (us_dragobjectlist[0] == NOGEOM && us_dragtextcount == 0) return;
+	us_cantdrag = 0;
 
 	/* stop if from different facets */
 	for(i=0; us_dragobjectlist[i] != NOGEOM; i++)
 		if (us_dragnodeproto != geomparent(us_dragobjectlist[i])) return;
 
-	/* count the number of nodes, excluding locked ones */
+	/* count the number of nodes */
 	us_dragnodetotal = 0;
 	for(ni = us_dragnodeproto->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
-	{
-		if (ni->temp1 == 0) continue;
-		if (us_cantedit(us_dragnodeproto, ni, FALSE))
-		{
-			ni->temp1 = 0;
-			continue;
-		}
-		us_dragnodetotal++;
-	}
-	if (us_dragnodetotal == 0 && us_dragtextcount == 0) us_cantdrag = 1; else
-		us_cantdrag = 0;
-
-	/* remove from list all arcs touching locked nodes */
-	for(i=j=0; us_dragobjectlist[i] != NOGEOM; i++)
-	{
-		if (!us_dragobjectlist[i]->entryisnode)
-		{
-			ai = us_dragobjectlist[i]->entryaddr.ai;
-			if (us_cantedit(us_dragnodeproto, ai->end[0].nodeinst, FALSE) ||
-				us_cantedit(us_dragnodeproto, ai->end[1].nodeinst, FALSE)) continue;
-		}
-		us_dragobjectlist[j++] = us_dragobjectlist[i];
-	}
-	us_dragobjectlist[j] = NOGEOM;
+		if (ni->temp1 != 0) us_dragnodetotal++;
 
 	/* build a list that includes all nodes touching selected arcs */
 	if (us_dragnodetotal != 0)
@@ -1158,8 +1140,8 @@ void us_finddoibegin(BOOLEAN complement)
 		if (us_dragnodelist == 0) return;
 		for(i=0, ni = us_dragnodeproto->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
 		{
-			if (ni->temp1 == 0) continue;
-			us_dragnodelist[i++] = ni;
+			if (ni->temp1 != 0)
+				us_dragnodelist[i++] = ni;
 		}
 	}
 
@@ -1200,8 +1182,11 @@ BOOLEAN us_findidown(INTBIG x, INTBIG y)
 void us_findiup(void)
 {
 	INTBIG xcur, ycur;
-	char **list;
+	CHAR **list;
 	REGISTER INTBIG i, len, k, slx, shx, sly, shy, bits, angle, total;
+	REGISTER NODEINST *ni;
+	REGISTER ARCINST *ai;
+	REGISTER BOOLEAN domove;
 	REGISTER UINTBIG now;
 	HIGHLIGHT newhigh, oldhigh;
 	REGISTER VARIABLE *highvar;
@@ -1216,20 +1201,50 @@ void us_findiup(void)
 			us_cantdrag == 0 && el_pleasestop == 0)
 		{
 			if (getxy(&xcur, &ycur)) return;
-			gridalign(&xcur, &ycur, 1);
+			gridalign(&xcur, &ycur, 1, us_dragnodeproto);
 			us_setcursorpos(NOWINDOWFRAME, xcur, ycur);
 			bits = getbuckybits();
 			if ((bits&CONTROLDOWN) != 0) angle = us_dragangle; else angle = 0;
 			us_getslide(angle, us_dragox, us_dragoy, xcur, ycur, &us_dragx, &us_dragy);
 			if (us_dragx != us_dragox || us_dragy != us_dragoy)
 			{
-				us_manymove(us_dragobjectlist, us_dragnodelist, us_dragnodetotal,
-					us_dragx-us_dragox, us_dragy-us_dragoy);
-				us_moveselectedtext(us_dragtextcount, us_dragtexts,
-					us_dragobjectlist, us_dragx - us_dragox, us_dragy - us_dragoy);
+				/* eliminate locked nodes */
+				domove = TRUE;
+				for(i=0; i<us_dragnodetotal; i++)
+				{
+					ni = us_dragnodelist[i];
+					if (us_cantedit(ni->parent, ni, TRUE)) { domove = FALSE;   break; }
+				}
+
+				/* also check for locked nodes at the end of selected arcs */
+				if (domove)
+				{
+					for(i=0; us_dragobjectlist[i] != NOGEOM; i++)
+					{
+						if (!us_dragobjectlist[i]->entryisnode)
+						{
+							ai = us_dragobjectlist[i]->entryaddr.ai;
+							if (us_cantedit(us_dragnodeproto, ai->end[0].nodeinst, TRUE) ||
+								us_cantedit(us_dragnodeproto, ai->end[1].nodeinst, TRUE))
+							{
+								domove = FALSE;
+								break;
+							}
+						}
+					}
+				}
+
+				/* do the move */
+				if (domove)
+				{
+					us_manymove(us_dragobjectlist, us_dragnodelist, us_dragnodetotal,
+						us_dragx-us_dragox, us_dragy-us_dragoy);
+					us_moveselectedtext(us_dragtextcount, us_dragtexts,
+						us_dragobjectlist, us_dragx - us_dragox, us_dragy - us_dragoy);
+				}
 			}
 		}
-		if (us_dragnodetotal > 0) efree((char *)us_dragnodelist);
+		if (us_dragnodetotal > 0) efree((CHAR *)us_dragnodelist);
 		us_pophighlight(TRUE);
 	} else if (us_dragstate == 1)
 	{
@@ -1244,8 +1259,6 @@ void us_findiup(void)
 		if (total > 0)
 			(void)setvalkey((INTBIG)us_tool, VTOOL, us_highlightedkey, (INTBIG)list,
 				VSTRING|VISARRAY|(total<<VLENGTHSH)|VDONTSAVE);
-		for(i=0; i<total; i++) efree(list[i]);
-		if (total > 0) efree((char *)list);
 	} else if (us_dragstate == 2)
 	{
 		/* special case when complementing highlight */
@@ -1265,7 +1278,7 @@ void us_findiup(void)
 			/* see if this object is already highlighted */
 			for(k=0; k<len; k++)
 			{
-				if (us_makehighlight(((char **)highvar->addr)[k], &oldhigh)) continue;
+				if (us_makehighlight(((CHAR **)highvar->addr)[k], &oldhigh)) continue;
 				if (oldhigh.facet != newhigh.facet) continue;
 				if ((oldhigh.status&HIGHTYPE) != (newhigh.status&HIGHTYPE)) continue;
 				if ((oldhigh.status&HIGHTYPE) == HIGHFROM)
@@ -1289,9 +1302,6 @@ void us_findiup(void)
 			highvar = getvalkey((INTBIG)us_tool, VTOOL, VSTRING|VISARRAY, us_highlightedkey);
 			if (highvar != NOVARIABLE) len = getlength(highvar); else len = 0;
 		}
-
-		for(i=0; i<total; i++) efree(list[i]);
-		if (total > 0) efree((char *)list);
 	}
 }
 
@@ -1389,7 +1399,7 @@ void us_createinsbegin(void)
 	ni->lowx = xcur;   ni->highx = xcur + pxs;
 	ni->lowy = ycur;   ni->highy = ycur + pys;
 	makerot(ni, trans);
-	nodeprotosizeoffset(us_dragnodeproto, &lx, &ly, &hx, &hy);
+	nodeprotosizeoffset(us_dragnodeproto, &lx, &ly, &hx, &hy, el_curwindowpart->curnodeproto);
 	maketruerectpoly(ni->lowx+lx, ni->highx-hx, ni->lowy+ly, ni->highy-hy, us_dragpoly);
 	us_dragpoly->style = CLOSEDRECT;
 	xformpoly(us_dragpoly, trans);
@@ -1418,7 +1428,7 @@ BOOLEAN us_createinsdown(INTBIG x, INTBIG y)
 		return(FALSE);
 	}
 	(void)getxy(&us_lastcurx, &us_lastcury);
-	gridalign(&us_lastcurx, &us_lastcury, 1);
+	gridalign(&us_lastcurx, &us_lastcury, 1, el_curlib->curnodeproto);
 	us_setcursorpos(NOWINDOWFRAME, us_lastcurx, us_lastcury);
 
 	/* find closest point along arc */
@@ -1503,17 +1513,21 @@ void us_createbegin(void)
 	ni->rotation = (INTSML)(us_dragangle%3600);
 	ni->transpose = (INTSML)(us_dragangle/3600);
 	defaultnodesize(us_dragnodeproto, &pxs, &pys);
-	ni->lowx = xcur;   ni->highx = xcur + pxs;
-	ni->lowy = ycur;   ni->highy = ycur + pys;
-	makerot(ni, trans);
-	nodeprotosizeoffset(us_dragnodeproto, &lx, &ly, &hx, &hy);
-	maketruerectpoly(ni->lowx+lx, ni->highx-hx, ni->lowy+ly, ni->highy-hy, us_dragpoly);
-	us_dragpoly->style = CLOSEDRECT;
-	xformpoly(us_dragpoly, trans);
 	if ((us_useroptions&CENTEREDPRIMITIVES) != 0) centeredprimitives = TRUE; else
 		centeredprimitives = FALSE;
 	corneroffset(NONODEINST, us_dragnodeproto, us_dragangle%3600,
 		us_dragangle/3600, &cx, &cy, centeredprimitives);
+
+	/* adjust size if technologies differ */
+	us_adjustfornodeinfacet(us_dragnodeproto, el_curwindowpart->curnodeproto, &cx, &cy);
+	us_adjustfornodeinfacet(us_dragnodeproto, el_curwindowpart->curnodeproto, &pxs, &pys);
+	ni->lowx = xcur;   ni->highx = xcur + pxs;
+	ni->lowy = ycur;   ni->highy = ycur + pys;
+	makerot(ni, trans);
+	nodeprotosizeoffset(us_dragnodeproto, &lx, &ly, &hx, &hy, el_curwindowpart->curnodeproto);
+	maketruerectpoly(ni->lowx+lx, ni->highx-hx, ni->lowy+ly, ni->highy-hy, us_dragpoly);
+	us_dragpoly->style = CLOSEDRECT;
+	xformpoly(us_dragpoly, trans);
 	us_dragx = xcur + cx;   us_dragy = ycur + cy;
 	us_dragwindow = el_curwindowpart;
 	us_dragwirepathcount = 0;
@@ -1554,16 +1568,22 @@ void us_createabegin(void)
 	ni->rotation = 0;
 	ni->transpose = 0;
 	defaultnodesize(us_dragnodeproto, &pxs, &pys);
-	ni->lowx = xcur;   ni->highx = xcur + pxs;
-	ni->lowy = ycur;   ni->highy = ycur + pys;
-	makerot(ni, trans);
-	nodeprotosizeoffset(us_dragnodeproto, &lx, &ly, &hx, &hy);
-	maketruerectpoly(ni->lowx+lx, ni->highx-hx, ni->lowy+ly, ni->highy-hy, us_dragpoly);
-	us_dragpoly->style = CLOSEDRECT;
-	xformpoly(us_dragpoly, trans);
 	if ((us_useroptions&CENTEREDPRIMITIVES) != 0) centeredprimitives = TRUE; else
 		centeredprimitives = FALSE;
 	corneroffset(NONODEINST, us_dragnodeproto, 0, 0, &cx, &cy, centeredprimitives);
+
+	/* adjust size if technologies differ */
+	us_adjustfornodeinfacet(us_dragnodeproto, us_dragwindow->curnodeproto, &cx, &cy);
+	us_adjustfornodeinfacet(us_dragnodeproto, us_dragwindow->curnodeproto, &pxs, &pys);
+
+	ni->lowx = xcur;   ni->highx = xcur + pxs;
+	ni->lowy = ycur;   ni->highy = ycur + pys;
+	makerot(ni, trans);
+	nodeprotosizeoffset(us_dragnodeproto, &lx, &ly, &hx, &hy, el_curwindowpart->curnodeproto);
+	maketruerectpoly(ni->lowx+lx, ni->highx-hx, ni->lowy+ly, ni->highy-hy, us_dragpoly);
+	us_dragpoly->style = CLOSEDRECT;
+	xformpoly(us_dragpoly, trans);
+
 	us_dragoffx = cx;
 	us_dragoffy = cy;
 	us_dragx = xcur;   us_dragy = ycur;
@@ -1579,9 +1599,11 @@ BOOLEAN us_createadown(INTBIG x, INTBIG y)
 	REGISTER INTBIG i;
 	INTBIG pxs, pys, unalx, unaly, fakecoords[8];
 	REGISTER PORTPROTO *pp, *foundpp;
-	REGISTER NODEINST *ni;
+	REGISTER NODEINST *ni, *fakefromnode, *faketonode;
 	ARCINST *ai1, *ai2, *ai3;
 	NODEINST *con1, *con2;
+	GEOM *fakefromgeom, *faketogeom;
+	PORTPROTO *fakefromport, *faketoport;
 	REGISTER GEOM *foundgeom;
 	static POLYGON *poly = NOPOLYGON;
 
@@ -1599,7 +1621,7 @@ BOOLEAN us_createadown(INTBIG x, INTBIG y)
 	}
 	(void)getxy(&us_lastcurx, &us_lastcury);
 	unalx = us_lastcurx;   unaly = us_lastcury;
-	gridalign(&us_lastcurx, &us_lastcury, 1);
+	gridalign(&us_lastcurx, &us_lastcury, 1, us_dragwindow->curnodeproto);
 	us_setcursorpos(NOWINDOWFRAME, us_lastcurx, us_lastcury);
 
 	us_getslide(us_dragangle, us_dragox, us_dragoy, us_lastcurx, us_lastcury, &pxs, &pys);
@@ -1615,6 +1637,8 @@ BOOLEAN us_createadown(INTBIG x, INTBIG y)
 		alignment = muldiv(us_alignment_ratio, el_curlib->lambda[el_curtech->techindex], WHOLE);
 		foundgeom = us_getclosest(us_lastcurx-us_dragoffx+pxs/2, us_lastcury-us_dragoffy+pys/2,
 			alignment/2, us_dragwindow->curnodeproto);
+if (foundgeom != NOGEOM)
+	dist = 7;
 
 		/* determine closest port if a node was found */
 		if (foundgeom != NOGEOM && foundgeom->entryisnode)
@@ -1641,14 +1665,21 @@ BOOLEAN us_createadown(INTBIG x, INTBIG y)
 
 	/* determine what is being connected */
 	count = 0;
-	if (foundgeom != NOGEOM && foundgeom->entryisnode &&
-		us_dragfromgeom != NOGEOM && us_dragfromgeom->entryisnode)
+	fakefromgeom = us_dragfromgeom;   fakefromport = us_dragfromport;
+	faketogeom = foundgeom;           faketoport = foundpp;
+	if (fakefromgeom == NOGEOM) fakefromnode = NONODEINST; else
+		fakefromnode = us_getnodeonarcinst(&fakefromgeom, &fakefromport, faketogeom,
+			faketoport, pxs, pys, 1);
+	if (faketogeom == NOGEOM) faketonode = NONODEINST; else
+		faketonode = us_getnodeonarcinst(&faketogeom, &faketoport, fakefromgeom,
+			fakefromport, pxs, pys, 1);
+	if (fakefromnode != NONODEINST && faketonode != NONODEINST)
 	{
 		if (!us_figuredrawpath(us_dragfromgeom, us_dragfromport,
 			foundgeom, foundpp, &unalx, &unaly))
 		{
-			ai1 = us_makeconnection(us_dragfromgeom->entryaddr.ni, us_dragfromport,
-				gen_universalarc, foundgeom->entryaddr.ni, foundpp, gen_universalarc,
+			ai1 = us_makeconnection(fakefromnode, fakefromport,
+				gen_universalarc, faketonode, faketoport, gen_universalarc,
 				gen_univpinprim, unalx, unaly, &ai2, &ai3, &con1, &con2,
 				us_dragangle, FALSE, fakecoords, TRUE);
 			if (ai1 != NOARCINST) count = 4;
@@ -1694,7 +1725,8 @@ BOOLEAN us_createadown(INTBIG x, INTBIG y)
 		if (us_dragshown != 0)
 		{
 			/* if it didn't actually move, go no further */
-			if (us_dragx == dx && us_dragy == dy && samepath != 0) return(FALSE);
+			if (us_dragx == dx && us_dragy == dy && samepath != 0 &&
+				us_dragobject == foundgeom) return(FALSE);
 
 			/* undraw the box */
 			us_highl.col = 0;
@@ -1833,7 +1865,7 @@ void us_multidragbegin(void)
 	us_dragpoly->desc = &us_highl;
 
 	(void)getxy(&us_dragx, &us_dragy);
-	gridalign(&us_dragx, &us_dragy, 1);
+	gridalign(&us_dragx, &us_dragy, 1, el_curlib->curnodeproto);
 	us_setcursorpos(NOWINDOWFRAME, us_dragx, us_dragy);
 	us_dragwindow = el_curwindowpart;
 
@@ -1884,7 +1916,7 @@ BOOLEAN us_multidragdown(INTBIG x, INTBIG y)
 		return(FALSE);
 	}
 	(void)getxy(&us_lastcurx, &us_lastcury);
-	gridalign(&us_lastcurx, &us_lastcury, 1);
+	gridalign(&us_lastcurx, &us_lastcury, 1, el_curlib->curnodeproto);
 	us_setcursorpos(NOWINDOWFRAME, us_lastcurx, us_lastcury);
 	bits = getbuckybits();
 	if ((bits&CONTROLDOWN) != 0) angle = us_dragangle; else angle = 0;
@@ -1932,8 +1964,9 @@ void us_multidragdraw(INTBIG col, INTBIG dx, INTBIG dy)
 {
 	REGISTER INTBIG i, thisend, portcount, endfixed, wid, xzeros, yzeros, savestate;
 	INTBIG lx, ly, hx, hy, xc, yc, xw, yw, j;
-	char coords[100], xcoord[50], ycoord[50], *pt;
+	CHAR coords[100], xcoord[50], ycoord[50], *pt;
 	XARRAY trans;
+	REGISTER BOOLEAN moveotherx, moveothery;
 	REGISTER NODEINST *ni;
 	REGISTER ARCINST *ai;
 	REGISTER PORTARCINST *pi;
@@ -1992,7 +2025,6 @@ void us_multidragdraw(INTBIG col, INTBIG dx, INTBIG dy)
 				{
 					/* compute the port bounds */
 					shapeportpoly(ni, pp, us_dragpoly, FALSE);
-					us_dragpoly->desc = &us_highl;
 
 					/* see if the polygon is a single point */
 					for(j=1; j<us_dragpoly->count; j++)
@@ -2001,9 +2033,16 @@ void us_multidragdraw(INTBIG col, INTBIG dx, INTBIG dy)
 					if (j < us_dragpoly->count)
 					{
 						/* not a single point, draw its outline */
-						if (us_dragpoly->style == FILLEDRECT) us_dragpoly->style = CLOSEDRECT;
-						if (us_dragpoly->style == FILLED) us_dragpoly->style = CLOSED;
-						if (us_dragpoly->style == DISC) us_dragpoly->style = CIRCLE;
+						switch (us_dragpoly->style)
+						{
+							case FILLEDRECT: us_dragpoly->style = CLOSEDRECT;  break;
+							case FILLED:     us_dragpoly->style = CLOSED;      break;
+							case DISC:       us_dragpoly->style = CIRCLE;      break;
+							case OPENEDT1:
+							case OPENEDT2:
+							case OPENEDT3:
+							case OPENEDO1:   us_dragpoly->style = OPENED;      break;
+						}
 					} else
 					{
 						/* single point port: make it a cross */
@@ -2054,15 +2093,23 @@ void us_multidragdraw(INTBIG col, INTBIG dx, INTBIG dy)
 				endfixed = 0;
 				if (ai->temp1 >= 2 || (ai->userbits&FIXED) != 0) endfixed = 1;
 
+				moveotherx = moveothery = FALSE;
 				if (endfixed != 0)
 				{
-					us_dragpoly->xv[1-thisend] += dx;
-					us_dragpoly->yv[1-thisend] += dy;
+					 moveotherx = moveothery = TRUE;
 				} else if ((ai->userbits&FIXANG) != 0)
 				{
-					if (ai->end[0].xpos == ai->end[1].xpos) us_dragpoly->xv[1-thisend] += dx;
-					if (ai->end[0].ypos == ai->end[1].ypos) us_dragpoly->yv[1-thisend] += dy;
+					if (ai->end[0].xpos != ai->end[1].xpos && ai->end[0].ypos != ai->end[1].ypos)
+					{
+						moveotherx = moveothery = TRUE;
+					} else
+					{
+						if (ai->end[0].xpos == ai->end[1].xpos) moveotherx = TRUE;
+						if (ai->end[0].ypos == ai->end[1].ypos) moveothery = TRUE;
+					}
 				}
+				if (moveotherx) us_dragpoly->xv[1-thisend] += dx;
+				if (moveothery) us_dragpoly->yv[1-thisend] += dy;
 
 				/* draw line */
 				us_showpoly(us_dragpoly, us_dragwindow);
@@ -2099,8 +2146,7 @@ void us_multidragdraw(INTBIG col, INTBIG dx, INTBIG dy)
 		us_gethightextcenter(&us_draghigh, &xc, &yc, &j);
 		us_dragpoly->style = j;
 
-#if 0
-		/* clip range of text descriptor */
+#if 0		/* clip range of text descriptor */
 		lambda = el_curlib->lambda[tech->techindex];
 		xcur = (us_lastcurx - us_dragx) * 4 / lambda;
 		us_lastcurx = us_lastcurx - us_dragx + us_dragoffx;
@@ -2127,26 +2173,26 @@ void us_multidragdraw(INTBIG col, INTBIG dx, INTBIG dy)
 	/* show the distance moved */
 	if (us_multidragshowoffset)
 	{
-		strcpy(xcoord, latoa(dx, 0));
+		estrcpy(xcoord, latoa(dx, 0));
 		for(pt = xcoord; *pt != 0; pt++) if (*pt == '.') break;
-		if (*pt == 0) xzeros = -1; else xzeros = strlen(pt) - 1;
-		strcpy(ycoord, latoa(dy, 0));
+		if (*pt == 0) xzeros = -1; else xzeros = estrlen(pt) - 1;
+		estrcpy(ycoord, latoa(dy, 0));
 		for(pt = ycoord; *pt != 0; pt++) if (*pt == '.') break;
-		if (*pt == 0) yzeros = -1; else yzeros = strlen(pt) - 1;
+		if (*pt == 0) yzeros = -1; else yzeros = estrlen(pt) - 1;
 		if (xzeros > us_multidragmostzeros) us_multidragmostzeros = xzeros;
 		if (yzeros > us_multidragmostzeros) us_multidragmostzeros = yzeros;
 		if (xzeros < us_multidragmostzeros)
 		{
-			if (xzeros < 0) { strcat(xcoord, "."); xzeros++; }
-			for(i=xzeros; i<us_multidragmostzeros; i++) strcat(xcoord, "0");
+			if (xzeros < 0) { estrcat(xcoord, x_(".")); xzeros++; }
+			for(i=xzeros; i<us_multidragmostzeros; i++) estrcat(xcoord, x_("0"));
 		}
 		if (yzeros < us_multidragmostzeros)
 		{
-			if (yzeros < 0) { strcat(ycoord, "."); yzeros++; }
-			for(i=yzeros; i<us_multidragmostzeros; i++) strcat(ycoord, "0");
+			if (yzeros < 0) { estrcat(ycoord, x_(".")); yzeros++; }
+			for(i=yzeros; i<us_multidragmostzeros; i++) estrcat(ycoord, x_("0"));
 		}
 
-		sprintf(coords, "(%s,%s)", xcoord, ycoord);
+		esnprintf(coords, 100, x_("(%s,%s)"), xcoord, ycoord);
 		TDCLEAR(us_dragpoly->textdescript);
 		TDSETSIZE(us_dragpoly->textdescript, TXTSETPOINTS(20));
 		us_dragpoly->style = TEXTCENT;
@@ -2193,7 +2239,7 @@ BOOLEAN us_distancedown(INTBIG x, INTBIG y)
 		us_dragwindow->curnodeproto == NONODEPROTO) return(FALSE);
 	us_dragnodeproto = us_dragwindow->curnodeproto;
 	(void)getxy(&us_dragx, &us_dragy);
-	gridalign(&us_dragx, &us_dragy, 1);
+	gridalign(&us_dragx, &us_dragy, 1, us_dragnodeproto);
 	us_setcursorpos(NOWINDOWFRAME, us_dragx, us_dragy);
 
 	if (us_measureshown == 0)
@@ -2221,13 +2267,13 @@ BOOLEAN us_distancedown(INTBIG x, INTBIG y)
 	TDSETSIZE(us_dragpoly->textdescript, TXTSETPOINTS(12));
 	us_dragpoly->tech = el_curtech;
 	dist = computedistance(us_firstmeasurex, us_firstmeasurey, us_dragx, us_dragy);
-	(void)strcpy(us_dragmessage, _("Distance: "));
-	(void)strcat(us_dragmessage, latoa(dist, 0));
-	(void)strcat(us_dragmessage, " (dX=");
-	(void)strcat(us_dragmessage, latoa(us_dragx - us_firstmeasurex, 0));
-	(void)strcat(us_dragmessage, " dY=");
-	(void)strcat(us_dragmessage, latoa(us_dragy - us_firstmeasurey, 0));
-	(void)strcat(us_dragmessage, ")");
+	(void)estrcpy(us_dragmessage, _("Distance: "));
+	(void)estrcat(us_dragmessage, latoa(dist, 0));
+	(void)estrcat(us_dragmessage, x_(" (dX="));
+	(void)estrcat(us_dragmessage, latoa(us_dragx - us_firstmeasurex, 0));
+	(void)estrcat(us_dragmessage, x_(" dY="));
+	(void)estrcat(us_dragmessage, latoa(us_dragy - us_firstmeasurey, 0));
+	(void)estrcat(us_dragmessage, x_(")"));
 	us_dragpoly->string = us_dragmessage;
 	us_drawdistance();
 	us_measureshown = 1;
@@ -2280,7 +2326,7 @@ void us_distanceup(void)
 	if (us_measureshown != 0)
 	{
 		/* leave the results in the messages window */
-		ttyputmsg("%s", us_dragpoly->string);
+		ttyputmsg(x_("%s"), us_dragpoly->string);
 	}
 }
 
@@ -2636,7 +2682,7 @@ void us_vpartdividerdone(void)
 		for(w = el_topwindowpart; w != NOWINDOWPART; w = w->nextwindowpart)
 		{
 			if (w->frame != us_trackww.frame) continue;
-			if (strcmp(w->location, "entire") == 0) continue;
+			if (estrcmp(w->location, x_("entire")) == 0) continue;
 
 			us_gettruewindowbounds(w, &lx, &hx, &ly, &hy);
 			lx--;   hx++;
@@ -2766,7 +2812,7 @@ void us_hpartdividerdone(void)
 		for(w = el_topwindowpart; w != NOWINDOWPART; w = w->nextwindowpart)
 		{
 			if (w->frame != us_trackww.frame) continue;
-			if (strcmp(w->location, "entire") == 0) continue;
+			if (estrcmp(w->location, x_("entire")) == 0) continue;
 
 			us_gettruewindowbounds(w, &lx, &hx, &ly, &hy);
 			lx--;   hx++;
@@ -2857,6 +2903,10 @@ void us_invertstretch(void)
 	us_wanttoinvert(us_dragx,  us_dragoy, us_dragox, us_dragoy, us_dragwindow);
 }
 
+/*
+ * routine to clip and possibly draw a line from (fx,fy) to (tx,ty) in
+ * window "w" with description "desc", texture "texture"
+ */
 void us_wanttoinvert(INTBIG fx, INTBIG fy, INTBIG tx, INTBIG ty, WINDOWPART *w)
 {
 	if ((w->state&INPLACEEDIT) != 0)
@@ -2889,7 +2939,7 @@ BOOLEAN us_dragdown(INTBIG x, INTBIG y)
 		return(FALSE);
 	}
 	(void)getxy(&us_lastcurx, &us_lastcury);
-	gridalign(&us_lastcurx, &us_lastcury, 1);
+	gridalign(&us_lastcurx, &us_lastcury, 1, us_dragwindow->curnodeproto);
 	us_setcursorpos(NOWINDOWFRAME, us_lastcurx, us_lastcury);
 
 	/* if the box is already being shown, erase it */
@@ -3009,7 +3059,7 @@ BOOLEAN us_nullchar(INTBIG x, INTBIG y, INTSML ch) { return(FALSE); }
  */
 BOOLEAN us_ignoreup(INTBIG x, INTBIG y)
 {
-	gridalign(&x, &y, 1);
+	gridalign(&x, &y, 1, el_curlib->curnodeproto);
 	us_setcursorpos(NOWINDOWFRAME, x, y);
 	return(FALSE);
 }
