@@ -41,34 +41,34 @@ static DIALOGITEM us_transdialogitems[] =
 {
  /*  1 */ {0, {336,132,360,212}, BUTTON, N_("Next")},
  /*  2 */ {0, {148,8,164,96}, MESSAGE, N_("Translation:")},
- /*  3 */ {0, {148,100,196,528}, EDITTEXT, ""},
+ /*  3 */ {0, {148,100,196,528}, EDITTEXT, x_("")},
  /*  4 */ {0, {8,324,24,472}, MESSAGE, N_("Total strings:")},
- /*  5 */ {0, {8,473,24,529}, MESSAGE, ""},
+ /*  5 */ {0, {8,473,24,529}, MESSAGE, x_("")},
  /*  6 */ {0, {28,324,44,472}, MESSAGE, N_("Untranslated strings:")},
- /*  7 */ {0, {28,472,44,528}, MESSAGE, ""},
+ /*  7 */ {0, {28,472,44,528}, MESSAGE, x_("")},
  /*  8 */ {0, {48,324,64,472}, MESSAGE, N_("Fuzzy strings:")},
- /*  9 */ {0, {48,472,64,528}, MESSAGE, ""},
+ /*  9 */ {0, {48,472,64,528}, MESSAGE, x_("")},
  /* 10 */ {0, {92,8,108,96}, MESSAGE, N_("English:")},
- /* 11 */ {0, {92,100,140,528}, EDITTEXT, ""},
+ /* 11 */ {0, {92,100,140,528}, EDITTEXT, x_("")},
  /* 12 */ {0, {320,440,344,520}, BUTTON, N_("DONE")},
  /* 13 */ {0, {172,8,188,96}, CHECK, N_("Fuzzy")},
  /* 14 */ {0, {336,220,360,300}, BUTTON, N_("Prev")},
  /* 15 */ {0, {336,12,360,92}, BUTTON, N_("First")},
- /* 16 */ {0, {48,8,80,316}, MESSAGE, ""},
+ /* 16 */ {0, {48,8,80,316}, MESSAGE, x_("")},
  /* 17 */ {0, {288,441,312,521}, BUTTON, N_("Save")},
  /* 18 */ {0, {8,8,24,132}, MESSAGE, N_("Language:")},
- /* 19 */ {0, {8,132,24,188}, POPUP, ""},
- /* 20 */ {0, {204,100,264,528}, SCROLL, ""},
+ /* 19 */ {0, {8,132,24,188}, POPUP, x_("")},
+ /* 20 */ {0, {204,100,264,528}, SCROLL, x_("")},
  /* 21 */ {0, {204,8,220,96}, MESSAGE, N_("Comments:")},
  /* 22 */ {0, {272,12,288,100}, MESSAGE, N_("Choose:")},
- /* 23 */ {0, {272,100,288,300}, POPUP, ""},
- /* 24 */ {0, {8,192,24,304}, POPUP, ""},
+ /* 23 */ {0, {272,100,288,300}, POPUP, x_("")},
+ /* 24 */ {0, {8,192,24,304}, POPUP, x_("")},
  /* 25 */ {0, {272,328,296,408}, BUTTON, N_("Unix-to-Mac")},
  /* 26 */ {0, {305,328,329,408}, BUTTON, N_("Mac-to-UNIX")},
- /* 27 */ {0, {292,100,308,300}, EDITTEXT, ""},
+ /* 27 */ {0, {292,100,308,300}, EDITTEXT, x_("")},
  /* 28 */ {0, {292,24,308,84}, BUTTON, N_("Find:")},
  /* 29 */ {0, {68,324,84,472}, MESSAGE, N_("Found strings:")},
- /* 30 */ {0, {68,472,84,528}, MESSAGE, ""},
+ /* 30 */ {0, {68,472,84,528}, MESSAGE, x_("")},
  /* 31 */ {0, {312,24,328,152}, CHECK, N_("Find in English")},
  /* 32 */ {0, {312,156,328,300}, CHECK, N_("Find in translation")},
  /* 33 */ {0, {337,328,361,408}, BUTTON, N_("Validate")}
@@ -120,9 +120,9 @@ static DIALOG us_transdialog = {{75,75,444,613}, N_("Translate Electric Strings"
 typedef struct Istringentry
 {
 	INTBIG   headerlinecount;
-	char   **headerlines;
-	char    *english;
-	char    *translated;
+	CHAR   **headerlines;
+	CHAR    *english;
+	CHAR    *translated;
 	INTBIG   index;
 	INTBIG   flags;
 	struct Istringentry *nextstringentry;
@@ -132,29 +132,29 @@ typedef struct Istringentry
 STRINGENTRY *us_transfirststringentry;
 
 static INTBIG    us_transheaderlinecount;
-static char    **us_transheaderlines;
+static CHAR    **us_transheaderlines;
 
 static INTBIG    us_transgatherlinecount;
 static INTBIG    us_transgatherlinetotal = 0;
-static char    **us_transgatherlines;
+static CHAR    **us_transgatherlines;
 static INTBIG    us_filetypetrans = 0;
-static char     *us_translation;
+static CHAR     *us_translation;
 static INTBIG    us_translationsize = 0;
 
 /* prototypes for local routines */
-static BOOLEAN      us_transloadmessages(char *file, INTBIG *entrycount, INTBIG *untranslatedcount,
+static BOOLEAN      us_transloadmessages(CHAR *file, INTBIG *entrycount, INTBIG *untranslatedcount,
 						INTBIG *fuzzycount, void *dia);
-static BOOLEAN      us_transgathermessage(char *line);
+static BOOLEAN      us_transgathermessage(CHAR *line);
 static STRINGENTRY *us_transfirst(INTBIG choose);
 static void         us_transhowentry(STRINGENTRY *se, void *dia);
-static void         us_transave(char *language, INTBIG platform);
-static char        *us_transgetfiles(char *language, INTBIG platform);
-static char        *us_transquoteit(char *message);
+static void         us_transave(CHAR *language, INTBIG platform);
+static CHAR        *us_transgetfiles(CHAR *language, INTBIG platform);
+static CHAR        *us_transquoteit(CHAR *message);
 static STRINGENTRY *us_translast(INTBIG choose);
 static BOOLEAN      us_transmeetscriteria(STRINGENTRY *se, INTBIG choose);
-static void         us_transmactounix(char *language);
-static void         us_transdumpline(FILE *io, char *line, char *prefix);
-static INTBIG       us_namesamennoamp(char *pt1, char *pt2, INTBIG count);
+static void         us_transmactounix(CHAR *language);
+static void         us_transdumpline(FILE *io, CHAR *line, CHAR *prefix);
+static INTBIG       us_namesamennoamp(CHAR *pt1, CHAR *pt2, INTBIG count);
 static void         us_transvalidate(void);
 
 /*
@@ -162,7 +162,7 @@ static void         us_transvalidate(void);
  */
 void us_freetranslatememory(void)
 {
-	if (us_translationsize > 0) efree((char *)us_translation);
+	if (us_translationsize > 0) efree((CHAR *)us_translation);
 }
 
 /*
@@ -173,29 +173,29 @@ void us_translationdlog(void)
 	INTBIG itemno, total, untranslatedcount, fuzzycount,  i, j, langcount, len, choose,
 		platform, ptlen, selen, tests, foundcount;
 	BOOLEAN dirty, findenglish, findtranslation;
-	char *language, num[20], *pt, *sept, *par[6], **filelist, intlpath[300], **langlist;
+	CHAR *language, num[20], *pt, *sept, *par[6], **filelist, intlpath[300], **langlist;
 	REGISTER STRINGENTRY *se, *curse;
 	REGISTER void *dia;
 
 	if (us_filetypetrans == 0)
-		us_filetypetrans = setupfiletype("", "*.*", MACFSTAG('TEXT'), FALSE, "transfile", _("Translation File"));
+		us_filetypetrans = setupfiletype(x_(""), x_("*.*"), MACFSTAG('TEXT'), FALSE, x_("transfile"), _("Translation File"));
 
 	/* examine the translation area */
-	sprintf(intlpath, "%sinternational%s", el_libdir, DIRSEPSTR);
-	len = strlen(intlpath);
+	esnprintf(intlpath, 300, x_("%sinternational%s"), el_libdir, DIRSEPSTR);
+	len = estrlen(intlpath);
 	j = filesindirectory(intlpath, &filelist);
 	if (j <= 0)
 	{
 		ttyputerr(_("No folders in '%s' to translate"), intlpath);
 		return;
 	}
-	langlist = (char **)emalloc(j * (sizeof (char *)), el_tempcluster);
+	langlist = (CHAR **)emalloc(j * (sizeof (CHAR *)), el_tempcluster);
 	if (langlist == 0) return;
 	langcount = 0;
 	for(i=0; i<j; i++)
 	{
-		if (filelist[i][0] == '.' || namesame (filelist[i], "CVS") == 0) continue;
-		strcpy(&intlpath[len], filelist[i]);
+		if (filelist[i][0] == '.' || namesame (filelist[i], x_("CVS")) == 0) continue;
+		estrcpy(&intlpath[len], filelist[i]);
 		if (fileexistence(intlpath) != 2) continue;
 		langlist[langcount++] = filelist[i];
 	}
@@ -254,7 +254,7 @@ void us_translationdlog(void)
 			{
 				i = us_noyesdlog(_("Translations have changed.  Quit without saving?"), par);
 				if (i == 0) break;
-				if (namesame(par[0], "no") == 0) continue;
+				if (namesame(par[0], x_("no")) == 0) continue;
 			}
 			break;
 		}
@@ -285,7 +285,7 @@ void us_translationdlog(void)
 				if (DiaGetControl(dia, DTRN_FINDTRN) != 0) findtranslation = TRUE; else
 					findtranslation = FALSE;
 				pt = DiaGetText(dia, DTRN_FINDSTR);
-				ptlen = strlen(pt);
+				ptlen = estrlen(pt);
 				foundcount = 0;
 				for(se = us_transfirststringentry; se != NOSTRINGENTRY; se = se->nextstringentry)
 				{
@@ -293,7 +293,7 @@ void us_translationdlog(void)
 					if (findenglish && se->english != 0)
 					{
 						sept = se->english;
-						selen = strlen(sept);
+						selen = estrlen(sept);
 						tests = selen - ptlen + 1;
 						for(i=0; i<tests; i++)
 							if (us_namesamennoamp(pt, sept++, ptlen) == 0) break;
@@ -307,7 +307,7 @@ void us_translationdlog(void)
 					if (findtranslation && se->translated != 0)
 					{
 						sept = se->translated;
-						selen = strlen(sept);
+						selen = estrlen(sept);
 						tests = selen - ptlen + 1;
 						for(i=0; i<tests; i++)
 							if (namesamen(pt, sept++, ptlen) == 0) break;
@@ -318,9 +318,9 @@ void us_translationdlog(void)
 						}
 					}
 				}
-				sprintf(num, "%ld", foundcount);
+				esnprintf(num, 20, x_("%ld"), foundcount);
 				DiaSetText(dia, DTRN_FOUNDSTR, num);
-			} else DiaSetText(dia, DTRN_FOUNDSTR, "");
+			} else DiaSetText(dia, DTRN_FOUNDSTR, x_(""));
 			curse = us_transfirst(choose);
 			us_transhowentry(curse, dia);
 			continue;
@@ -333,7 +333,7 @@ void us_translationdlog(void)
 			{
 				i = us_noyesdlog(_("Translations have changed.  Change languages without saving?"), par);
 				if (i == 0) break;
-				if (namesame(par[0], "no") == 0) continue;
+				if (namesame(par[0], x_("no")) == 0) continue;
 			}
 
 			pt = us_transgetfiles(language, i);
@@ -349,12 +349,12 @@ void us_translationdlog(void)
 		if (itemno == DTRN_LANGUAGE)
 		{
 			i = DiaGetPopupEntry(dia, DTRN_LANGUAGE);
-			if (strcmp(langlist[i], language) == 0) continue;
+			if (estrcmp(langlist[i], language) == 0) continue;
 			if (dirty)
 			{
 				i = us_noyesdlog(_("Translations have changed.  Change languages without saving?"), par);
 				if (i == 0) break;
-				if (namesame(par[0], "no") == 0) continue;
+				if (namesame(par[0], x_("no")) == 0) continue;
 			}
 
 			pt = us_transgetfiles(langlist[i], platform);
@@ -390,7 +390,7 @@ void us_translationdlog(void)
 				DiaMessageInDialog(_("Must save before translating files"));
 				continue;
 			}
-			DiaMessageInDialog("Can't yet");
+			DiaMessageInDialog(x_("Can't yet"));
 			continue;
 		}
 		if (itemno == DTRN_NEXT)
@@ -439,7 +439,7 @@ void us_translationdlog(void)
 				curse->flags &= ~WASFUZZY;
 				fuzzycount++;
 			}
-			sprintf(num, "%ld", fuzzycount);
+			esnprintf(num, 20, x_("%ld"), fuzzycount);
 			DiaSetText(dia, DTRN_FUZSTR, num);
 			dirty = TRUE;
 			continue;
@@ -453,24 +453,24 @@ void us_translationdlog(void)
 				if (*pt == 0) continue;
 			} else
 			{
-				if (strcmp(pt, curse->translated) == 0) continue;
+				if (estrcmp(pt, curse->translated) == 0) continue;
 			}
 
 			if (curse->translated == 0)
 			{
 				untranslatedcount--;
-				sprintf(num, "%ld", untranslatedcount);
+				esnprintf(num, 20, x_("%ld"), untranslatedcount);
 				DiaSetText(dia, DTRN_UNTSTR, num);
 			}
 			if ((curse->flags & FUZZY) != 0)
 			{
 				fuzzycount--;
-				sprintf(num, "%ld", fuzzycount);
+				esnprintf(num, 20, x_("%ld"), fuzzycount);
 				DiaSetText(dia, DTRN_FUZSTR, num);
 				DiaSetControl(dia, DTRN_ISFUZZY, 0);
 				if ((curse->flags&FUZZY) != 0) curse->flags |= WASFUZZY;
 			}
-			if (curse->translated != 0) efree((char *)curse->translated);
+			if (curse->translated != 0) efree((CHAR *)curse->translated);
 			(void)allocstring(&curse->translated, pt, us_tool->cluster);
 			dirty = TRUE;
 			continue;
@@ -481,7 +481,7 @@ void us_translationdlog(void)
 
 void us_transhowentry(STRINGENTRY *se, void *dia)
 {
-	char line[100];
+	CHAR line[100];
 	REGISTER INTBIG whichone, i;
 	BOOLEAN matching;
 	REGISTER STRINGENTRY *ose;
@@ -490,8 +490,8 @@ void us_transhowentry(STRINGENTRY *se, void *dia)
 	DiaSetControl(dia, DTRN_ISFUZZY, 0);
 	if (se == NOSTRINGENTRY)
 	{
-		DiaSetText(dia, DTRN_ENGLISH, "");
-		DiaSetText(dia, DTRN_FOREIGN, "");
+		DiaSetText(dia, DTRN_ENGLISH, x_(""));
+		DiaSetText(dia, DTRN_FOREIGN, x_(""));
 		DiaSetText(dia, DTRN_MSGID, _("No strings left"));
 		return;
 	}
@@ -518,29 +518,29 @@ void us_transhowentry(STRINGENTRY *se, void *dia)
 	}
 	if (matching)
 	{
-		sprintf(line, _("String %ld (matched string %ld)"), se->index, whichone);
+		esnprintf(line, 100, _("String %ld (matched string %ld)"), se->index, whichone);
 	} else
 	{
 		if ((se->flags&FUZZY) != 0)
 		{
 			if ((se->flags&WASFUZZY) != 0)
-				sprintf(line, _("String %ld (was fuzzy)"), se->index); else
-					sprintf(line, _("String %ld (fuzzy string %ld)"), se->index, whichone);
+				esnprintf(line, 100, _("String %ld (was fuzzy)"), se->index); else
+					esnprintf(line, 100, _("String %ld (fuzzy string %ld)"), se->index, whichone);
 		} else if (se->translated == 0)
 		{
-			sprintf(line, _("String %ld (untranslated string %ld)"), se->index, whichone);
+			esnprintf(line, 100, _("String %ld (untranslated string %ld)"), se->index, whichone);
 		} else if ((se->flags&THISTIME) != 0)
 		{
-			sprintf(line, _("String %ld (just translated)"), se->index);
+			esnprintf(line, 100, _("String %ld (just translated)"), se->index);
 		} else
 		{
-			sprintf(line, _("String %ld (already translated)"), se->index);
+			esnprintf(line, 100, _("String %ld (already translated)"), se->index);
 		}
 	}
 	DiaSetText(dia, DTRN_MSGID, line);
-	if (se->english == 0) DiaSetText(dia, DTRN_ENGLISH, ""); else
+	if (se->english == 0) DiaSetText(dia, DTRN_ENGLISH, x_("")); else
 		DiaSetText(dia, DTRN_ENGLISH, se->english);
-	if (se->translated == 0) DiaSetText(dia, -DTRN_FOREIGN, ""); else
+	if (se->translated == 0) DiaSetText(dia, -DTRN_FOREIGN, x_("")); else
 		DiaSetText(dia, -DTRN_FOREIGN, se->translated);
 	if ((se->flags&(FUZZY|WASFUZZY)) == FUZZY) DiaSetControl(dia, DTRN_ISFUZZY, 1);
 	for(i=0; i<se->headerlinecount; i++)
@@ -599,13 +599,13 @@ BOOLEAN us_transmeetscriteria(STRINGENTRY *se, INTBIG choose)
 	return(FALSE);
 }
 
-BOOLEAN us_transloadmessages(char *file, INTBIG *entrycount, INTBIG *untranslatedcount,
+BOOLEAN us_transloadmessages(CHAR *file, INTBIG *entrycount, INTBIG *untranslatedcount,
 	INTBIG *fuzzycount, void *dia)
 {
 	REGISTER FILE *io;
 	REGISTER INTBIG i, j, eof, inenglish, endchr, haveline, index, lineno;
-	REGISTER char *pt, *ptr;
-	char line[500], build[700], *truename;
+	REGISTER CHAR *pt, *ptr;
+	CHAR line[500], build[700], *truename;
 	REGISTER STRINGENTRY *se, *lastse;
 
 	io = xopen(file, us_filetypetrans, 0, &truename);
@@ -626,7 +626,7 @@ BOOLEAN us_transloadmessages(char *file, INTBIG *entrycount, INTBIG *untranslate
 		if (us_transgathermessage(line)) return(TRUE);
 	}
 	us_transheaderlinecount = us_transgatherlinecount;
-	us_transheaderlines = (char **)emalloc(us_transheaderlinecount * (sizeof (char *)), us_tool->cluster);
+	us_transheaderlines = (CHAR **)emalloc(us_transheaderlinecount * (sizeof (CHAR *)), us_tool->cluster);
 	if (us_transheaderlines == 0) return(TRUE);
 	for(i=0; i<us_transheaderlinecount; i++)
 	{
@@ -665,13 +665,13 @@ BOOLEAN us_transloadmessages(char *file, INTBIG *entrycount, INTBIG *untranslate
 				pt = &us_transgatherlines[i][1];
 				while (*pt != 0)
 				{
-					if (strncmp(pt, ", c-format", 10) == 0)
+					if (estrncmp(pt, x_(", c-format"), 10) == 0)
 					{
 						se->flags |= CFORMAT;
 						pt += 10;
 						continue;
 					}
-					if (strncmp(pt, ", fuzzy", 7) == 0)
+					if (estrncmp(pt, x_(", fuzzy"), 7) == 0)
 					{
 						se->flags |= FUZZY;
 						pt += 7;
@@ -689,7 +689,7 @@ BOOLEAN us_transloadmessages(char *file, INTBIG *entrycount, INTBIG *untranslate
 
 		/* store the comment lines */
 		se->headerlinecount = us_transgatherlinecount;
-		se->headerlines = (char **)emalloc(se->headerlinecount * (sizeof (char *)), us_tool->cluster);
+		se->headerlines = (CHAR **)emalloc(se->headerlinecount * (sizeof (CHAR *)), us_tool->cluster);
 		if (se->headerlines == 0) return(TRUE);
 		for(i=0; i<us_transgatherlinecount; i++)
 		{
@@ -722,17 +722,17 @@ BOOLEAN us_transloadmessages(char *file, INTBIG *entrycount, INTBIG *untranslate
 			} else haveline = 0;
 			if (line[0] == 0) break;
 			pt = line;
-			if (strncmp(pt, "msgid ", 6) == 0)
+			if (estrncmp(pt, x_("msgid "), 6) == 0)
 			{
 				inenglish = 1;
 				pt += 6;
-			} else if (strncmp(pt, "msgstr ", 7) == 0)
+			} else if (estrncmp(pt, x_("msgstr "), 7) == 0)
 			{
 				inenglish = 0;
 				pt += 7;
 			}
 			if (*pt == '"') pt++;
-			endchr = strlen(pt) - 1;
+			endchr = estrlen(pt) - 1;
 			if (pt[endchr] == '"') pt[endchr] = 0;
 			if (*pt == 0) continue;
 
@@ -741,7 +741,7 @@ BOOLEAN us_transloadmessages(char *file, INTBIG *entrycount, INTBIG *untranslate
 			{
 				if (*ptr != '\\') continue;
 				if (ptr[1] != '"') continue;
-				strcpy(ptr, &ptr[1]);
+				estrcpy(ptr, &ptr[1]);
 			}
 
 			if (inenglish != 0)
@@ -749,20 +749,20 @@ BOOLEAN us_transloadmessages(char *file, INTBIG *entrycount, INTBIG *untranslate
 				build[0] = 0;
 				if (se->english != 0)
 				{
-					strcpy(build, se->english);
-					efree((char *)se->english);
+					estrcpy(build, se->english);
+					efree((CHAR *)se->english);
 				}
-				strcat(build, pt);
+				estrcat(build, pt);
 				(void)allocstring(&se->english, build, us_tool->cluster);
 			} else
 			{
 				build[0] = 0;
 				if (se->translated != 0)
 				{
-					strcpy(build, se->translated);
-					efree((char *)se->translated);
+					estrcpy(build, se->translated);
+					efree((CHAR *)se->translated);
 				}
-				strcat(build, pt);
+				estrcat(build, pt);
 				(void)allocstring(&se->translated, build, us_tool->cluster);
 			}
 		}
@@ -785,64 +785,64 @@ BOOLEAN us_transloadmessages(char *file, INTBIG *entrycount, INTBIG *untranslate
 			se->flags |= THISTIME;
 		}
 	}
-	sprintf(line, "%ld", *entrycount);
+	esnprintf(line, 500, x_("%ld"), *entrycount);
 	DiaSetText(dia, DTRN_TOTSTR, line);
-	sprintf(line, "%ld", *untranslatedcount);
+	esnprintf(line, 500, x_("%ld"), *untranslatedcount);
 	DiaSetText(dia, DTRN_UNTSTR, line);
-	sprintf(line, "%ld", *fuzzycount);
+	esnprintf(line, 500, x_("%ld"), *fuzzycount);
 	DiaSetText(dia, DTRN_FUZSTR, line);
 	return(FALSE);
 }
 
-BOOLEAN us_transgathermessage(char *line)
+BOOLEAN us_transgathermessage(CHAR *line)
 {
 	REGISTER INTBIG newtotal, i;
-	REGISTER char **newlines;
+	REGISTER CHAR **newlines;
 
 	if (us_transgatherlinecount >= us_transgatherlinetotal)
 	{
 		newtotal = us_transgatherlinetotal * 2;
 		if (us_transgatherlinecount >= newtotal)
 			newtotal = us_transgatherlinecount + 30;
-		newlines = (char **)emalloc(newtotal * (sizeof (char *)), us_tool->cluster);
+		newlines = (CHAR **)emalloc(newtotal * (sizeof (CHAR *)), us_tool->cluster);
 		if (newlines == 0) return(TRUE);
 		for(i=0; i<us_transgatherlinecount; i++)
 			newlines[i] = us_transgatherlines[i];
 		for(i=us_transgatherlinecount; i<newtotal; i++)
 			newlines[i] = 0;
 		if (us_transgatherlinetotal > 0)
-			efree((char *)us_transgatherlines);
+			efree((CHAR *)us_transgatherlines);
 		us_transgatherlines = newlines;
 		us_transgatherlinetotal = newtotal;
 	}
 	if (us_transgatherlines[us_transgatherlinecount] != 0)
-		efree((char *)us_transgatherlines[us_transgatherlinecount]);
+		efree((CHAR *)us_transgatherlines[us_transgatherlinecount]);
 	if (allocstring(&us_transgatherlines[us_transgatherlinecount], line,
 		us_tool->cluster)) return(TRUE);
 	us_transgatherlinecount++;
 	return(FALSE);
 }
 
-void us_transave(char *language, INTBIG platform)
+void us_transave(CHAR *language, INTBIG platform)
 {
 	REGISTER STRINGENTRY *se;
 	REGISTER INTBIG i;
 	INTBIG year, month, mday, hour, minute, second;
 	REGISTER time_t olddate;
-	char filename[300], rename[300], datesuffix[100], *truename;
+	CHAR filename[300], rename[300], datesuffix[100], *truename;
 	FILE *io;
 	REGISTER void *infstr;
 
 	/* rename the old file */
-	strcpy(filename, us_transgetfiles(language, platform));
+	estrcpy(filename, us_transgetfiles(language, platform));
 	olddate = filedate(filename);
 	parsetime(olddate, &year, &month, &mday, &hour, &minute, &second);
 	for(i=0; i<1000; i++)
 	{
-		if (i == 0) sprintf(datesuffix, "-%ld-%ld-%ld", year, month+1, mday); else
-			sprintf(datesuffix, "-%ld-%ld-%ld--%ld", year, month+1, mday, i);
-		(void)strcpy(rename, filename);
-		(void)strcat(rename, datesuffix);
+		if (i == 0) esnprintf(datesuffix, 100, x_("-%ld-%ld-%ld"), year, month+1, mday); else
+			esnprintf(datesuffix, 100, x_("-%ld-%ld-%ld--%ld"), year, month+1, mday, i);
+		(void)estrcpy(rename, filename);
+		(void)estrcat(rename, datesuffix);
 		if (fileexistence(rename) == 0) break;
 	}
 	if (erename(filename, rename) != 0)
@@ -858,46 +858,46 @@ void us_transave(char *language, INTBIG platform)
 
 	/* write the header lines */
 	for(i=0; i<us_transheaderlinecount; i++)
-		fprintf(io, "%s\n", us_transheaderlines[i]);
+		efprintf(io, x_("%s\n"), us_transheaderlines[i]);
 
 	/* write the translations */
 	for(se = us_transfirststringentry; se != NOSTRINGENTRY; se = se->nextstringentry)
 	{
-		fprintf(io, "\n");
+		efprintf(io, x_("\n"));
 		for(i=0; i<se->headerlinecount; i++)
-			fprintf(io, "%s\n", se->headerlines[i]);
+			efprintf(io, x_("%s\n"), se->headerlines[i]);
 		if ((se->flags&(FUZZY|WASFUZZY)) == FUZZY ||
 			(se->flags&CFORMAT) != 0)
 		{
 			infstr = initinfstr();
-			addstringtoinfstr(infstr, "#");
-			if ((se->flags&(FUZZY|WASFUZZY)) == FUZZY) addstringtoinfstr(infstr, ", fuzzy");
-			if ((se->flags&CFORMAT) != 0) addstringtoinfstr(infstr, ", c-format");
-			fprintf(io, "%s\n", returninfstr(infstr));
+			addstringtoinfstr(infstr, x_("#"));
+			if ((se->flags&(FUZZY|WASFUZZY)) == FUZZY) addstringtoinfstr(infstr, x_(", fuzzy"));
+			if ((se->flags&CFORMAT) != 0) addstringtoinfstr(infstr, x_(", c-format"));
+			efprintf(io, x_("%s\n"), returninfstr(infstr));
 		}
 		if (se->english != 0)
-			us_transdumpline(io, us_transquoteit(se->english), "msgid");
+			us_transdumpline(io, us_transquoteit(se->english), x_("msgid"));
 		if (se->translated != 0)
-			us_transdumpline(io, us_transquoteit(se->translated), "msgstr");
+			us_transdumpline(io, us_transquoteit(se->translated), x_("msgstr"));
 	}
 	xclose(io);
 }
 
 #define MAXLEN 80
 
-void us_transdumpline(FILE *io, char *line, char *prefix)
+void us_transdumpline(FILE *io, CHAR *line, CHAR *prefix)
 {
 	REGISTER INTBIG len, preflen, i;
-	char save;
+	CHAR save;
 
-	preflen = strlen(prefix) + 3;
-	len = strlen(line);
+	preflen = estrlen(prefix) + 3;
+	len = estrlen(line);
 	if (len+preflen <= MAXLEN)
 	{
-		fprintf(io, "%s \"%s\"\n", prefix, line);
+		efprintf(io, x_("%s \"%s\"\n"), prefix, line);
 		return;
 	}
-	fprintf(io, "%s \"\"\n", prefix);
+	efprintf(io, x_("%s \"\"\n"), prefix);
 	while (len > MAXLEN-4)
 	{
 		i = MAXLEN-4;
@@ -906,20 +906,20 @@ void us_transdumpline(FILE *io, char *line, char *prefix)
 		i++;
 		save = line[i];
 		line[i] = 0;
-		fprintf(io, "\"%s\"\n", line);
+		efprintf(io, x_("\"%s\"\n"), line);
 		line[i] = save;
 		line = &line[i];
-		len = strlen(line);
+		len = estrlen(line);
 	}
 	if (len > 0)
-		fprintf(io, "\"%s\"\n", line);
+		efprintf(io, x_("\"%s\"\n"), line);
 }
 
 /*
  * Routine to do a string comparison between "pt1" and "pt2" up to "count" characters.
  * Ignores "&" characters.
  */
-INTBIG us_namesamennoamp(char *pt1, char *pt2, INTBIG count)
+INTBIG us_namesamennoamp(CHAR *pt1, CHAR *pt2, INTBIG count)
 {
 	REGISTER INTBIG c1, c2, i;
 
@@ -935,11 +935,11 @@ INTBIG us_namesamennoamp(char *pt1, char *pt2, INTBIG count)
 	return(0);
 }
 
-char *us_transquoteit(char *message)
+CHAR *us_transquoteit(CHAR *message)
 {
-	REGISTER char *pt;
+	REGISTER CHAR *pt;
 	REGISTER INTBIG j;
-	static char result[500];
+	static CHAR result[500];
 
 	j = 0;
 	for(pt = message; *pt != 0; pt++)
@@ -951,16 +951,16 @@ char *us_transquoteit(char *message)
 	return(result);
 }
 
-char *us_transgetfiles(char *language, INTBIG platform)
+CHAR *us_transgetfiles(CHAR *language, INTBIG platform)
 {
-	REGISTER char *onmac;
+	REGISTER CHAR *onmac;
 	REGISTER void *infstr;
 
-	if (platform == 0) onmac = "mac"; else
-		onmac = "";
+	if (platform == 0) onmac = x_("mac"); else
+		onmac = x_("");
 	infstr = initinfstr();
 	addstringtoinfstr(infstr, el_libdir);
-	formatinfstr(infstr, "international%s%s%sLC_MESSAGES%s%selectric.%s",
+	formatinfstr(infstr, x_("international%s%s%sLC_MESSAGES%s%selectric.%s"),
 		DIRSEPSTR, language, DIRSEPSTR, DIRSEPSTR, onmac, language);
 	return(returninfstr(infstr));
 }
@@ -969,29 +969,29 @@ void us_transvalidate(void)
 {
 	REGISTER STRINGENTRY *se;
 	REGISTER INTBIG i;
-	REGISTER char *pt;
+	REGISTER CHAR *pt;
 
 	for(se = us_transfirststringentry; se != NOSTRINGENTRY; se = se->nextstringentry)
 	{
 		if (se->translated == 0) continue;
 
 		/* see if the use of elipses at the end matches */
-		i = strlen(se->translated);
-		if (i > 3 && strcmp(&se->translated[i-3], "...") == 0)
+		i = estrlen(se->translated);
+		if (i > 3 && estrcmp(&se->translated[i-3], x_("...")) == 0)
 		{
 			/* translation has ellipses: make sure original does, too */
-			i = strlen(se->english);
-			if (i < 3 || strcmp(&se->english[i-3], "...") != 0)
+			i = estrlen(se->english);
+			if (i < 3 || estrcmp(&se->english[i-3], x_("...")) != 0)
 			{
-				ttyputmsg("'%s' should not have '...' in translation", se->english);
+				ttyputmsg(x_("'%s' should not have '...' in translation"), se->english);
 			}
 		} else
 		{
 			/* translation does not have ellipses: make sure original doesn't either */
-			i = strlen(se->english);
-			if (i > 3 && strcmp(&se->english[i-3], "...") == 0)
+			i = estrlen(se->english);
+			if (i > 3 && estrcmp(&se->english[i-3], x_("...")) == 0)
 			{
-				ttyputmsg("'%s' must have '...' in translation", se->english);
+				ttyputmsg(x_("'%s' must have '...' in translation"), se->english);
 			}
 		}
 
@@ -1005,67 +1005,65 @@ void us_transvalidate(void)
 			{
 				pt = se->headerlines[i];
 				while (*pt == '#' || *pt == ' ') pt++;
-				if (strncmp(pt, "lib", 3) == 0) break;
+				if (estrncmp(pt, x_("lib"), 3) == 0) break;
 			}
 			if (i < se->headerlinecount)
 			{
 				/* this should not have "&" */
-				ttyputmsg("'%s' should not have '&' in translation", se->english);
+				ttyputmsg(x_("'%s' should not have '&' in translation"), se->english);
 			}
 		}
 	}
 }
 
-void us_transmactounix(char *language)
+void us_transmactounix(CHAR *language)
 {
-	REGISTER char *macfile, *unixfile, *pt;
-	char buf[1000];
+	REGISTER CHAR *macfile, *unixfile;
+	CHAR buf[1000], *dummy;
 	REGISTER INTBIG lineno;
 	FILE *in, *out;
 
 	macfile = us_transgetfiles(language, 0);
-	in = fopen(macfile, "r");
+	in = xopen(macfile, el_filetypetext, 0, &dummy);
 	if (in == 0)
 	{
-		DiaMessageInDialog("Cannot read %s", macfile);
+		DiaMessageInDialog(x_("Cannot read %s"), macfile);
 		return;
 	}
 	unixfile = us_transgetfiles(language, 1);
-	out = fopen(unixfile, "w");
+	out = xcreate(unixfile, el_filetypetext, 0, 0);
 	if (out == 0)
 	{
-		DiaMessageInDialog("Cannot write %s", unixfile);
+		DiaMessageInDialog(x_("Cannot write %s"), unixfile);
 		return;
 	}
 	lineno = 0;
 	for(;;)
 	{
-		pt = fgets(buf, 999, in);
-		if (pt == 0) break;
+		if (xfgets(buf, 999, in)) break;
 		lineno++;
-		buf[strlen(buf)-1] = 0;
-		if (strncmp(buf, "msgstr \"", 8) != 0)
+		buf[estrlen(buf)] = 0;
+		if (estrncmp(buf, x_("msgstr \""), 8) != 0)
 		{
-			fprintf(out, "%s\n", buf);
+			efprintf(out, x_("%s\n"), buf);
 			continue;
 		}
 
 		/* found "msgstr", look for strange characters */
-		strcpy(&buf[7], us_convertmactoworld(&buf[7]));
-		fprintf(out, "%s\n", buf);
+		estrcpy(&buf[7], us_convertmactoworld(&buf[7]));
+		efprintf(out, x_("%s\n"), buf);
 		for(;;)
 		{
-			pt = fgets(buf, 999, in);
-			if (pt == 0) break;
+			if (xfgets(buf, 999, in)) break;
 			lineno++;
-			buf[strlen(buf)-1] = 0;
-			if (*pt == 0)
+			buf[estrlen(buf)] = 0;
+			if (buf[0] == 0)
 			{
-				fprintf(out, "\n");
+				efprintf(out, x_("\n"));
 				break;
 			}
-			strcpy(buf, us_convertmactoworld(buf));
-			fprintf(out, "%s\n", buf);
+			estrcpy(buf, us_convertmactoworld(buf));
+			efprintf(out, x_("%s\n"), buf);
 		}
 	}
 	fclose(in);
@@ -1164,16 +1162,16 @@ TRANSLATE us_trans_mactoworld[] =
  * encoded Macintosh-sytle) and return the buffer in international characters
  * encoded Windows/UNIX style.
  */
-char *us_convertmactoworld(char *buf)
+CHAR *us_convertmactoworld(CHAR *buf)
 {
-	char *pt;
+	CHAR *pt;
 	int i, len, thechar, outchar;
 
-	len = strlen(buf) * 2;
+	len = estrlen(buf) * 2;
 	if (len > us_translationsize)
 	{
-		if (us_translationsize > 0) efree((char *)us_translation);
-		us_translation = (char *)emalloc(len, us_tool->cluster);
+		if (us_translationsize > 0) efree((CHAR *)us_translation);
+		us_translation = (CHAR *)emalloc(len * SIZEOFCHAR, us_tool->cluster);
 		if (us_translation == 0) return(buf);
 		us_translationsize = len;
 	}
@@ -1216,16 +1214,16 @@ char *us_convertmactoworld(char *buf)
 	return(us_translation);
 }
 
-char *us_convertworldtomac(char *buf)
+CHAR *us_convertworldtomac(CHAR *buf)
 {
-	char *pt;
+	CHAR *pt;
 	int i, len, thechar, outchar;
 
-	len = strlen(buf);
+	len = estrlen(buf);
 	if (len > us_translationsize)
 	{
-		if (us_translationsize > 0) efree((char *)us_translation);
-		us_translation = (char *)emalloc(len, us_tool->cluster);
+		if (us_translationsize > 0) efree((CHAR *)us_translation);
+		us_translation = (CHAR *)emalloc(len * SIZEOFCHAR, us_tool->cluster);
 		if (us_translation == 0) return(buf);
 		us_translationsize = len;
 	}
