@@ -48,19 +48,21 @@ typedef struct Iredraw
 	{
 		NODEINST   *ni;
 		ARCINST    *ai;
+		PORTPROTO  *pp;
 		void       *blind;
 	} entryaddr;						/* object being re-drawn */
 	struct Iredraw *nextredraw;			/* next in list */
 } REDRAW;
 
-static REDRAW    *us_redrawfree = NOREDRAW;	/* free list of re-draw modules */
-static REDRAW    *us_firstredraw = NOREDRAW;	/* first in list of active re-draw modules */
-static REDRAW    *us_firstopaque = NOREDRAW;	/* first in list of active opaque re-draws */
-static REDRAW    *us_lastopaque = NOREDRAW;	/* last in list of active opaque re-draws */
-static REDRAW    *us_usedredraw = NOREDRAW;	/* first in list of used re-draw modules */
+static REDRAW   *us_redrawfree = NOREDRAW;	/* free list of re-draw modules */
+static REDRAW   *us_firstredraw = NOREDRAW;	/* first in list of active re-draw modules */
+static REDRAW   *us_firstopaque = NOREDRAW;	/* first in list of active opaque re-draws */
+static REDRAW   *us_firstexport = NOREDRAW;	/* first in list of export re-draws */
+static REDRAW   *us_lastopaque = NOREDRAW;	/* last in list of active opaque re-draws */
+static REDRAW   *us_usedredraw = NOREDRAW;	/* first in list of used re-draw modules */
 
 static REDRAW *us_allocredraw(void);
-static void us_freeredraw(REDRAW*);
+static void    us_freeredraw(REDRAW*);
 
 /***** 3D DISPLAY *****/
 
@@ -112,10 +114,9 @@ extern GRAPHICS us_ebox;
 
 /* prototypes for local routines */
 static INTBIG us_showin(WINDOWPART*, GEOM*, NODEPROTO*, XARRAY, INTBIG, INTBIG);
-static void us_queuevicinity(GEOM*, NODEPROTO*, XARRAY, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG);
+static void us_queuevicinity(WINDOWPART*, GEOM*, NODEPROTO*, XARRAY, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG);
 static void us_wanttodrawo(INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, WINDOWPART*, GRAPHICS*, INTBIG);
 static void us_drawextendedpolyline(POLYGON*, WINDOWPART*);
-static void us_writetext(INTBIG, INTBIG, INTBIG, INTBIG, GRAPHICS*, char*, UINTBIG*, WINDOWPART*, TECHNOLOGY*);
 static void us_reverse(POLYGON*);
 
 /*
@@ -131,7 +132,7 @@ void us_freewindowmemory(void)
 	{
 		r = us_redrawfree;
 		us_redrawfree = us_redrawfree->nextredraw;
-		efree((char *)r);
+		efree((CHAR *)r);
 	}
 
 	for(i=0; i<us_3dpolytotal; i++)
@@ -139,14 +140,14 @@ void us_freewindowmemory(void)
 		p3 = us_3dpolylist[i];
 		if (p3->total > 0)
 		{
-			efree((char *)p3->x);
-			efree((char *)p3->y);
-			efree((char *)p3->z);
+			efree((CHAR *)p3->x);
+			efree((CHAR *)p3->y);
+			efree((CHAR *)p3->z);
 		}
-		efree((char *)p3);
+		efree((CHAR *)p3);
 	}
 	if (us_3dpolytotal > 0)
-		efree((char *)us_3dpolylist);
+		efree((CHAR *)us_3dpolylist);
 }
 
 /******************** WINDOW DISPLAY ********************/
@@ -157,14 +158,14 @@ void us_clearwindow(WINDOWPART *w)
 	REGISTER INTBIG newstate;
 
 	startobjectchange((INTBIG)w, VWINDOWPART);
-	(void)setval((INTBIG)w, VWINDOWPART, "curnodeproto", (INTBIG)NONODEPROTO, VNODEPROTO);
-	newstate = (w->state & ~(GRIDON|WINDOWTYPE|WINDOWSIMULATING)) | DISPWINDOW;
-	(void)setval((INTBIG)w, VWINDOWPART, "state", newstate, VINTEGER);
-	(void)setval((INTBIG)w, VWINDOWPART, "buttonhandler", (INTBIG)DEFAULTBUTTONHANDLER, VADDRESS);
-	(void)setval((INTBIG)w, VWINDOWPART, "charhandler", (INTBIG)DEFAULTCHARHANDLER, VADDRESS);
-	(void)setval((INTBIG)w, VWINDOWPART, "changehandler", (INTBIG)DEFAULTCHANGEHANDLER, VADDRESS);
-	(void)setval((INTBIG)w, VWINDOWPART, "termhandler", (INTBIG)DEFAULTTERMHANDLER, VADDRESS);
-	(void)setval((INTBIG)w, VWINDOWPART, "redisphandler", (INTBIG)DEFAULTREDISPHANDLER, VADDRESS);
+	(void)setval((INTBIG)w, VWINDOWPART, x_("curnodeproto"), (INTBIG)NONODEPROTO, VNODEPROTO);
+	newstate = (w->state & ~(GRIDON|WINDOWTYPE|WINDOWMODE)) | DISPWINDOW;
+	(void)setval((INTBIG)w, VWINDOWPART, x_("state"), newstate, VINTEGER);
+	(void)setval((INTBIG)w, VWINDOWPART, x_("buttonhandler"), (INTBIG)DEFAULTBUTTONHANDLER, VADDRESS);
+	(void)setval((INTBIG)w, VWINDOWPART, x_("charhandler"), (INTBIG)DEFAULTCHARHANDLER, VADDRESS);
+	(void)setval((INTBIG)w, VWINDOWPART, x_("changehandler"), (INTBIG)DEFAULTCHANGEHANDLER, VADDRESS);
+	(void)setval((INTBIG)w, VWINDOWPART, x_("termhandler"), (INTBIG)DEFAULTTERMHANDLER, VADDRESS);
+	(void)setval((INTBIG)w, VWINDOWPART, x_("redisphandler"), (INTBIG)DEFAULTREDISPHANDLER, VADDRESS);
 	endobjectchange((INTBIG)w, VWINDOWPART);
 }
 
@@ -192,51 +193,42 @@ void us_erasewindow(WINDOWPART *w)
  * create a window for this facet, otherwise reuse the current one.
  */
 void us_switchtofacet(NODEPROTO *cur, INTBIG lx, INTBIG hx, INTBIG ly, INTBIG hy,
-	NODEINST *focusinst, PORTPROTO *facetinstport, BOOLEAN newframe, INTBIG pushpop)
+	NODEINST *focusinst, PORTPROTO *facetinstport, BOOLEAN newframe, BOOLEAN pushpop, BOOLEAN exact)
 {
 	HIGHLIGHT newhigh;
-	REGISTER INTBIG i, l, resethandlers, turnoffsim;
+	REGISTER INTBIG i, l, resethandlers, oldmode;
 	INTBIG dummy;
 	REGISTER VARIABLE *var;
-	char *one[1];
+	CHAR *one[1];
 	REGISTER INTBIG oldstate;
-	REGISTER char *thisline, *location;
+	REGISTER CHAR *thisline;
 	REGISTER EDITOR *ed;
 	WINDOWPART *neww, *oldw;
+	UINTBIG descript[TEXTDESCRIPTSIZE];
+	extern GRAPHICS us_hbox;
+	REGISTER void *infstr;
 
 	us_clearhighlightcount();
 	oldw = el_curwindowpart;
-	turnoffsim = 0;
 	if (oldw == NOWINDOWPART)
 	{
-		oldstate = DISPWINDOW;
-		location = "Entire";
+		/* no former window: force a new one to be created */
+		newframe = TRUE;
 	} else
 	{
+		/* if this is an explorer window, use the other partition (if there is one) */
 		if ((oldw->state&WINDOWTYPE) == EXPLORERWINDOW)
 		{
 			for(neww = el_topwindowpart; neww != NOWINDOWPART; neww = neww->nextwindowpart)
 				if (neww != oldw && neww->frame == oldw->frame) break;
 			if (neww != NOWINDOWPART) oldw = neww;
 		}
-		if (pushpop == 0 && (oldw->state&WINDOWSIMULATING) != 0) turnoffsim = 1;
-		if (turnoffsim != 0) us_setwindowsimulation(oldw, FALSE);
-		oldstate = oldw->state;
-		location = oldw->location;
 	}
+
+	/* start changes to the tool */
 	startobjectchange((INTBIG)us_tool, VTOOL);
 
-	if (!newframe)
-	{
-		/* delete current window and create a new window for this facet */
-		neww = newwindowpart(location, oldw);
-		if (neww == NOWINDOWPART) return;
-		if (oldw != NOWINDOWPART)
-		{
-			if (turnoffsim != 0) us_setwindowsimulation(oldw, TRUE);
-			killwindowpart(oldw);
-		}
-	} else
+	if (newframe)
 	{
 		/* just create a new window for this facet */
 		neww = us_wantnewwindow(0);
@@ -245,8 +237,18 @@ void us_switchtofacet(NODEPROTO *cur, INTBIG lx, INTBIG hx, INTBIG ly, INTBIG hy
 			us_abortcommand(_("Cannot create new window"));
 			return;
 		}
-		oldstate = DISPWINDOW;
-		location = "Entire";
+		oldmode = oldstate = DISPWINDOW;
+	} else
+	{
+		/* reuse the window */
+		oldmode = oldw->state;
+		if (pushpop == 0 && (oldw->state&WINDOWMODE) != 0)
+		{
+			/* was in a mode: turn that off */
+			us_setwindowmode(oldw, oldw->state, oldw->state & ~WINDOWMODE);
+		}
+		oldstate = oldw->state;
+		neww = oldw;
 	}
 	el_curwindowpart = neww;
 
@@ -260,16 +262,16 @@ void us_switchtofacet(NODEPROTO *cur, INTBIG lx, INTBIG hx, INTBIG ly, INTBIG hy
 		var = getvalkey((INTBIG)cur, VNODEPROTO, VSTRING|VISARRAY, el_facet_message_key);
 		if (var == NOVARIABLE)
 		{
-			one[0] = "";
+			one[0] = x_("");
 			var = setvalkey((INTBIG)cur, VNODEPROTO, el_facet_message_key, (INTBIG)one,
 				VSTRING|VISARRAY|(1<<VLENGTHSH));
 			if (var == NOVARIABLE) return;
 		}
 
 		ed = neww->editor;
-		ed->editobjaddr = (char *)cur;
+		ed->editobjaddr = (CHAR *)cur;
 		ed->editobjtype = VNODEPROTO;
-		ed->editobjqual = "FACET_message";
+		ed->editobjqual = x_("FACET_message");
 		ed->editobjvar = var;
 
 		/* load the text into the window */
@@ -277,7 +279,7 @@ void us_switchtofacet(NODEPROTO *cur, INTBIG lx, INTBIG hx, INTBIG ly, INTBIG hy
 		l = getlength(var);
 		for(i=0; i<l; i++)
 		{
-			thisline = ((char **)var->addr)[i];
+			thisline = ((CHAR **)var->addr)[i];
 			if (i == l-1 && *thisline == 0) continue;
 			us_addline(neww, i, thisline);
 		}
@@ -296,13 +298,19 @@ void us_switchtofacet(NODEPROTO *cur, INTBIG lx, INTBIG hx, INTBIG ly, INTBIG hy
 		resethandlers = 1;
 		if (pushpop != 0)
 		{
-			if ((neww->state&WINDOWSIMULATING) != 0 &&
+			if ((neww->state&WINDOWMODE) != 0 &&
 				((oldstate&WINDOWTYPE) == DISPWINDOW))
 			{
 				resethandlers = 0;
 			}
 		}
 
+		/* if editing a technology-edit facet, indicate so */
+		if ((cur->userbits&TECEDITFACET) != 0)
+		{
+			us_setwindowmode(neww, neww->state, neww->state | WINDOWTECEDMODE);
+		}
+
 		/* adjust window if it changed from display window to something else */
 		if ((neww->state&WINDOWTYPE) == DISPWINDOW && (oldstate&WINDOWTYPE) != DISPWINDOW)
 		{
@@ -340,7 +348,7 @@ void us_switchtofacet(NODEPROTO *cur, INTBIG lx, INTBIG hx, INTBIG ly, INTBIG hy
 			neww->redisphandler = DEFAULTREDISPHANDLER;
 		}
 
-		us_squarescreen(neww, NOWINDOWPART, FALSE, &lx, &hx, &ly, &hy, pushpop);
+		us_squarescreen(neww, NOWINDOWPART, FALSE, &lx, &hx, &ly, &hy, exact);
 		neww->screenlx = lx;
 		neww->screenhx = hx;
 		neww->screenly = ly;
@@ -363,10 +371,30 @@ void us_switchtofacet(NODEPROTO *cur, INTBIG lx, INTBIG hx, INTBIG ly, INTBIG hy
 		}
 	}
 
-	(void)setval((INTBIG)el_curlib, VLIBRARY, "curnodeproto", (INTBIG)cur, VNODEPROTO);
+	(void)setval((INTBIG)el_curlib, VLIBRARY, x_("curnodeproto"), (INTBIG)cur, VNODEPROTO);
 	endobjectchange((INTBIG)us_tool, VTOOL);
 	(void)setvalkey((INTBIG)us_tool, VTOOL, us_current_window_key, (INTBIG)neww,
 		VWINDOWPART|VDONTSAVE);
+	us_setfacetname(neww);
+	us_setfacetsize(neww);
+	us_setgridsize(neww);
+	if (neww->redisphandler != 0) (*neww->redisphandler)(neww);
+	if ((neww->state&WINDOWTECEDMODE) != 0 && (oldmode&WINDOWTECEDMODE) == 0)
+	{
+		TDCLEAR(descript);
+		TDSETSIZE(descript, TXTSETPOINTS(18));
+		us_hbox.col = HIGHLIT;
+		us_writetext(neww->uselx, neww->usehx, neww->usehy-30, neww->usehy, &us_hbox,
+			_("TECHNOLOGY EDIT MODE:"), descript, neww, NOTECHNOLOGY);
+		var = getval((INTBIG)us_tool, VTOOL, VSTRING, "USER_local_capg");
+		if (var != NOVARIABLE)
+		{
+			infstr = initinfstr();
+			formatinfstr(infstr, _("Use %s to make changes"), (CHAR *)var->addr);
+			us_writetext(neww->uselx, neww->usehx, neww->usehy-60, neww->usehy-30, &us_hbox,
+				returninfstr(infstr), descript, neww, NOTECHNOLOGY);
+		}
+	}
 }
 
 /*
@@ -374,7 +402,7 @@ void us_switchtofacet(NODEPROTO *cur, INTBIG lx, INTBIG hx, INTBIG ly, INTBIG hy
  * technology, otherwise determine technology from facet "facet".  If "always" is false,
  * only switch if the user has selected "auto-switching".
  */
-void us_ensurepropertechnology(NODEPROTO *facet, char *forcedtechnology, BOOLEAN always)
+void us_ensurepropertechnology(NODEPROTO *facet, CHAR *forcedtechnology, BOOLEAN always)
 {
 	REGISTER USERCOM *uc;
 	REGISTER TECHNOLOGY *tech;
@@ -393,9 +421,9 @@ void us_ensurepropertechnology(NODEPROTO *facet, char *forcedtechnology, BOOLEAN
 
 	/* switch technologies */
 	lastframe = getwindowframe(TRUE);
-	if (us_getmacro("pmtesetup") == NOVARIABLE) return;
+	if (us_getmacro(x_("pmtesetup")) == NOVARIABLE) return;
 	infstr = initinfstr();
-	formatinfstr(infstr, "pmtesetup \"%s\"", us_techname(facet));
+	formatinfstr(infstr, x_("pmtesetup \"%s\""), us_techname(facet));
 	uc = us_makecommand(returninfstr(infstr));
 	if (uc != NOUSERCOM)
 	{
@@ -426,6 +454,7 @@ void us_endchanges(WINDOWPART *which)
 	REGISTER REDRAW *r, *nextr;
 	REGISTER NODEINST *ni;
 	REGISTER ARCINST *ai;
+	REGISTER PORTPROTO *pp;
 	REGISTER INTBIG stopped;
 	REGISTER INTBIG ret;
 
@@ -436,7 +465,6 @@ void us_endchanges(WINDOWPART *which)
 		nextr = r->nextredraw;
 		r->nextredraw = us_usedredraw;
 		us_usedredraw = r;
-
 		if (stopped != 0) continue;
 
 		if (r->entryisnode)
@@ -512,7 +540,6 @@ void us_endchanges(WINDOWPART *which)
 		us_usedredraw = r;
 
 		if (stopped != 0) continue;
-
 		if (r->entryisnode)
 		{
 			ni = r->entryaddr.ni;
@@ -592,6 +619,37 @@ void us_endchanges(WINDOWPART *which)
 	}
 	us_usedredraw = NOREDRAW;
 
+	/* now re-draw the exports */
+	for(r = us_firstexport; r != NOREDRAW; r = nextr)
+	{
+		/* remember the next redraw module and queue this one for deletion */
+		nextr = r->nextredraw;
+		pp = r->entryaddr.pp;
+		us_freeredraw(r);
+		if (stopped != 0) continue;
+		makerot(pp->subnodeinst, rottrans);
+
+		if (which != NOWINDOWPART)
+		{
+			us_writeprotoname(pp, LAYERA, rottrans, LAYERO, el_colfacettxt, which, 0, 0, 0, 0,
+				(us_useroptions&EXPORTLABELS)>>EXPORTLABELSSH);
+			us_drawportprotovariables(pp, LAYERA, rottrans, which, FALSE);
+		} else
+		{
+			for(w = el_topwindowpart; w != NOWINDOWPART; w = w->nextwindowpart)
+			{
+				if ((w->state&WINDOWTYPE) != DISPWINDOW &&
+					(w->state&WINDOWTYPE) != DISP3DWINDOW) continue;
+				if (w->curnodeproto != pp->parent) continue;
+				us_writeprotoname(pp, LAYERA, rottrans, LAYERO, el_colfacettxt, w, 0, 0, 0, 0,
+					(us_useroptions&EXPORTLABELS)>>EXPORTLABELSSH);
+				us_drawportprotovariables(pp, LAYERA, rottrans, w, FALSE);
+			}
+		}
+	}
+	us_firstexport = NOREDRAW;
+
+	/* force all changes out */
 	flushscreen();
 }
 
@@ -605,11 +663,13 @@ INTBIG us_showin(WINDOWPART *w, GEOM *object, NODEPROTO *parnt, XARRAY trans, IN
 {
 	REGISTER NODEINST *ni;
 	XARRAY localtran, subrot, subtran;
+	REGISTER WINDOWPART *oldwin;
 	REGISTER INTBIG moretodo, res;
 	REGISTER INTBIG objlocal;
 
 	/* if the parent is the current facet in the window, draw the instance */
 	moretodo = 0;
+	oldwin = setvariablewindow(w);
 	if (parnt == w->curnodeproto)
 	{
 		if (object->entryisnode)
@@ -618,23 +678,36 @@ INTBIG us_showin(WINDOWPART *w, GEOM *object, NODEPROTO *parnt, XARRAY trans, IN
 			begintraversehierarchy();
 			res = us_drawnodeinst(ni, on, trans, layers, w);
 			endtraversehierarchy();
-			if (res == -2) return(-1);
+			if (res == -2)
+			{
+				(void)setvariablewindow(oldwin);
+				return(-1);
+			}
 			if (res < 0) res = 0;
 			moretodo |= res;
 		} else
 		{
 			res = us_drawarcinst(object->entryaddr.ai, on, trans, layers, w);
-			if (res < 0) return(-1);
+			if (res < 0)
+			{
+				(void)setvariablewindow(oldwin);
+				return(-1);
+			}
 			moretodo |= res;
 		}
 
 		/* if drawing the opaque layer, don't look for other things to draw */
-		if (on && layers == 2) return(moretodo);
+		if (on && layers == 2)
+		{
+			(void)setvariablewindow(oldwin);
+			return(moretodo);
+		}
 
 		/* queue re-drawing of objects in vicinity of this one */
 		if (object->entryisnode)
-			us_queuevicinity(object, parnt, trans, 0, 0, 0, 0, on); else
-				us_queuevicinity(object, parnt, trans, 0, 0, 0, 0, on);
+			us_queuevicinity(w, object, parnt, trans, 0, 0, 0, 0, on); else
+				us_queuevicinity(w, object, parnt, trans, 0, 0, 0, 0, on);
+		(void)setvariablewindow(oldwin);
 		return(moretodo);
 	}
 
@@ -657,17 +730,26 @@ INTBIG us_showin(WINDOWPART *w, GEOM *object, NODEPROTO *parnt, XARRAY trans, IN
 		if (ni->rotation == 0 && ni->transpose == 0)
 		{
 			res = us_showin(w, object, ni->parent, subrot, on, layers);
-			if (res < 0) return(-1);
+			if (res < 0)
+			{
+				(void)setvariablewindow(oldwin);
+				return(-1);
+			}
 			moretodo |= res;
 		} else
 		{
 			makerot(ni, localtran);
 			transmult(subrot, localtran, subtran);
 			res = us_showin(w, object, ni->parent, subtran, on, layers);
-			if (res < 0) return(-1);
+			if (res < 0)
+			{
+				(void)setvariablewindow(oldwin);
+				return(-1);
+			}
 			moretodo |= res;
 		}
 	}
+	(void)setvariablewindow(oldwin);
 	return(moretodo);
 }
 
@@ -771,6 +853,25 @@ void us_undisplayobject(GEOM *geom)
 	}
 }
 
+/*
+ * routine to queue object "p" to be re-drawn.
+ */
+void us_queueexport(PORTPROTO *pp)
+{
+	REGISTER REDRAW *r;
+
+	/* queue this object for being re-drawn */
+	r = us_allocredraw();
+	if (r == NOREDRAW)
+	{
+		ttyputnomemory();
+		return;
+	}
+	r->entryaddr.pp = pp;
+	r->nextredraw = us_firstexport;
+	us_firstexport = r;
+}
+
 /******************** HELPER ROUTINES ******************/
 
 /*
@@ -882,7 +983,7 @@ void us_freeredraw(REDRAW *r)
  * are to be drawn on if "on" is nonzero.  The transformation matrix
  * between the bounding box and the facet is in "trans".
  */
-void us_queuevicinity(GEOM *object, NODEPROTO *parnt, XARRAY trans, INTBIG lx,
+void us_queuevicinity(WINDOWPART *w, GEOM *object, NODEPROTO *parnt, XARRAY trans, INTBIG lx,
 	INTBIG hx, INTBIG ly, INTBIG hy, INTBIG on)
 {
 	REGISTER GEOM *look;
@@ -908,6 +1009,21 @@ void us_queuevicinity(GEOM *object, NODEPROTO *parnt, XARRAY trans, INTBIG lx,
 	xform(hx, hy, &ux, &uy, trans);
 	if (bx > ux) { i = bx;  bx = ux;  ux = i; }
 	if (by > uy) { i = by;  by = uy;  uy = i; }
+
+	/* extend by 1 screen pixel */
+	i = roundfloat(3.0f / w->scalex);
+	if (i <= 0) i = 1;
+	bx -= i;   hx += i;
+	by -= i;   hy += i;
+
+	/* clip search to visible area of window */
+	if (bx > w->screenhx || ux < w->screenlx ||
+		by > w->screenhy || uy < w->screenly) return;
+	if (bx < w->screenlx) bx = w->screenlx;
+	if (ux > w->screenhx) ux = w->screenhx;
+	if (by < w->screenly) by = w->screenly;
+	if (uy > w->screenhy) uy = w->screenhy;
+
 	slop = FARTEXTLIMIT * lambdaoffacet(parnt);
 	search = initsearch(bx-slop, ux+slop, by-slop, uy+slop, parnt);
 	if (object == NOGEOM) local = TRUE; else local = FALSE;
@@ -918,48 +1034,15 @@ void us_queuevicinity(GEOM *object, NODEPROTO *parnt, XARRAY trans, INTBIG lx,
 		/* don't re-draw the current object whose vicinity is being checked */
 		if (look == object) continue;
 
-#if 0
-		/* get the former inside factor (if it is a nodeinst) */
-		if (look->entryisnode) former = look->entryaddr.ni->userbits;
-#endif
-
 		/* see if the object really intersects the redraw area */
 		if (look->entryisnode)
 			us_getnodebounds(look->entryaddr.ni, &olx, &ohx, &oly, &ohy); else
 				us_getarcbounds(look->entryaddr.ai, &olx, &ohx, &oly, &ohy);
-		if (olx >= ux || ohx <= bx || oly >= uy || ohy <= by) continue;
+		if (olx > ux || ohx < bx || oly > uy || ohy < by) continue;
 
 		/* redraw all if object is going off, redraw opaque if going on */
 		if (on == LAYERN) us_queueredraw(look, local); else
 			us_queueopaque(look, local);
-#if 0
-		/* that's all if the object is an arcinst */
-		if (!look->entryisnode) continue;
-		ni = look->entryaddr.ni;
-
-		/* don't bother exploring if the nodeinst is already to be redrawn */
-		if ((former & REWANTN) != 0) continue;
-
-		/* explore the insides if the facet is expanded */
-		if (ni->proto->primindex != 0 || (ni->userbits&NEXPAND) == 0) continue;
-
-		/* explore the insides of this node and queue the pertinent parts */
-		maketransI(ni, localtran);
-		transmult(trans, localtran, xf);
-
-		/* this is the former contents if "makerotI", which I think is wrong...smr */
-		if (ni->transpose != 0) makeangle(ni->rotation, ni->transpose, localtran); else
-			makeangle((3600 - ni->rotation)%3600, 0, localtran);
-		localtran[2][0] = ni->proto->lowx + ni->proto->highx;
-		localtran[2][1] = ni->proto->lowy + ni->proto->highy;
-		xform(-localtran[2][0], -localtran[2][1], &localtran[2][0], &localtran[2][1], localtran);
-		localtran[2][0] /= 2;    localtran[2][1] /= 2;
-		transmult(xf, localtran, subrot);
-		us_queuevicinity(NOGEOM, ni->proto, subrot, lx, hx, ly, hy, on);
-
-		/* now flag this nodeinst so that it doesn't get completely redrawn */
-		ni->userbits = (ni->userbits & ~REWANTN) | RELOCLN;
-#endif
 	}
 
 	/* now queue things with "far text" */
@@ -1424,7 +1507,7 @@ void us_drawextendedpolyline(POLYGON *obj, WINDOWPART *w)
  * "initialfont" is the default size of text which will be reduced until it
  * can fit.
  */
-void us_writetext(INTBIG lx, INTBIG ux, INTBIG ly, INTBIG uy, GRAPHICS *desc, char *txt,
+void us_writetext(INTBIG lx, INTBIG ux, INTBIG ly, INTBIG uy, GRAPHICS *desc, CHAR *txt,
 	UINTBIG *initdescript, WINDOWPART *win, TECHNOLOGY *tech)
 {
 	REGISTER INTBIG stop, save, xabssize, yabssize, abssize, newsize, oldsize;
@@ -1465,7 +1548,7 @@ void us_writetext(INTBIG lx, INTBIG ux, INTBIG ly, INTBIG uy, GRAPHICS *desc, ch
 	/* truncate in X if possible */
 	if (six > ux-lx)
 	{
-		stop = (ux-lx) * strlen(txt);
+		stop = (ux-lx) * estrlen(txt);
 		stop /= six;
 		if (stop == 0) return;
 		save = txt[stop];   txt[stop] = 0;
@@ -1474,7 +1557,7 @@ void us_writetext(INTBIG lx, INTBIG ux, INTBIG ly, INTBIG uy, GRAPHICS *desc, ch
 
 	/* draw the text */
 	screendrawtext(win, lx+(ux-lx-six)/2, ly+(uy-ly-siy)/2, txt, desc);
-	if (stop >= 0) txt[stop] = (char)save;
+	if (stop >= 0) txt[stop] = (CHAR)save;
 }
 
 /******************** WINDOW PANNING ********************/
@@ -1491,8 +1574,8 @@ void us_slideup(INTBIG dist)
 
 	/* set the new window data */
 	startobjectchange((INTBIG)el_curwindowpart, VWINDOWPART);
-	(void)setval((INTBIG)el_curwindowpart, VWINDOWPART, "screenly", el_curwindowpart->screenly - dist, VINTEGER);
-	(void)setval((INTBIG)el_curwindowpart, VWINDOWPART, "screenhy", el_curwindowpart->screenhy - dist, VINTEGER);
+	(void)setval((INTBIG)el_curwindowpart, VWINDOWPART, x_("screenly"), el_curwindowpart->screenly - dist, VINTEGER);
+	(void)setval((INTBIG)el_curwindowpart, VWINDOWPART, x_("screenhy"), el_curwindowpart->screenhy - dist, VINTEGER);
 	endobjectchange((INTBIG)el_curwindowpart, VWINDOWPART);
 
 	/* restore highlighting */
@@ -1510,8 +1593,8 @@ void us_slideleft(INTBIG dist)
 	us_clearhighlightcount();
 
 	startobjectchange((INTBIG)el_curwindowpart, VWINDOWPART);
-	(void)setval((INTBIG)el_curwindowpart, VWINDOWPART, "screenlx", el_curwindowpart->screenlx + dist, VINTEGER);
-	(void)setval((INTBIG)el_curwindowpart, VWINDOWPART, "screenhx", el_curwindowpart->screenhx + dist, VINTEGER);
+	(void)setval((INTBIG)el_curwindowpart, VWINDOWPART, x_("screenlx"), el_curwindowpart->screenlx + dist, VINTEGER);
+	(void)setval((INTBIG)el_curwindowpart, VWINDOWPART, x_("screenhx"), el_curwindowpart->screenhx + dist, VINTEGER);
 	endobjectchange((INTBIG)el_curwindowpart, VWINDOWPART);
 
 	/* restore highlighting */
@@ -2287,7 +2370,7 @@ POLY3D *us_3dgetnextpoly(INTBIG count)
 			if (newlist[i] == 0) return(0);
 			newlist[i]->total = 0;
 		}
-		if (us_3dpolytotal > 0) efree((char *)us_3dpolylist);
+		if (us_3dpolytotal > 0) efree((CHAR *)us_3dpolylist);
 		us_3dpolylist = newlist;
 		us_3dpolytotal = newtotal;
 	}
@@ -2296,9 +2379,9 @@ POLY3D *us_3dgetnextpoly(INTBIG count)
 	{
 		if (poly3d->total > 0)
 		{
-			efree((char *)poly3d->x);
-			efree((char *)poly3d->y);
-			efree((char *)poly3d->z);
+			efree((CHAR *)poly3d->x);
+			efree((CHAR *)poly3d->y);
+			efree((CHAR *)poly3d->z);
 		}
 		poly3d->total = 0;
 		poly3d->x = (float *)emalloc(count * (sizeof (float)), us_tool->cluster);
