@@ -43,10 +43,10 @@ extern SYMBOLLIST	*vhdl_gsymbols;
 static IDENTTABLE	*vhdl_ident_ground, *vhdl_ident_power;
 
 /* prototypes for local routines */
-static BOOLEAN vhdl_addnetlist(LIBRARY*, char*);
-static void    vhdl_genfunction(char*, BOOLEAN, BOOLEAN, INTBIG);
-static void    vhdl_dumpfunction(char*, char**);
-static void    vhdl_genals_interface(DBINTERFACE*, char*);
+static BOOLEAN vhdl_addnetlist(LIBRARY*, CHAR*);
+static void    vhdl_genfunction(CHAR*, BOOLEAN, BOOLEAN, INTBIG);
+static void    vhdl_dumpfunction(CHAR*, CHAR**);
+static void    vhdl_genals_interface(DBINTERFACE*, CHAR*);
 static void    vhdl_genals_aport(void*, INTBIG*, DBNAME*);
 
 /*
@@ -61,141 +61,141 @@ Calling Sequence:  vhdl_genals(lib, basenp);
 */
 void vhdl_genals(LIBRARY *lib, NODEPROTO *basenp)
 {
-	char *gate;
+	CHAR *gate;
 	INTBIG total;
 	DBINTERFACE *top_interface, *interfacef;
 	UNRESLIST *ulist;
-	static char *power[] =
+	static CHAR *power[] =
 	{
-		"gate power(p)",
-		"set p=H@3",
-		"t: delta=0",
+		x_("gate power(p)"),
+		x_("set p=H@3"),
+		x_("t: delta=0"),
 		0
 	};
-	static char *ground[] =
+	static CHAR *ground[] =
 	{
-		"gate ground(g)",
-		"set g=L@3",
-		"t: delta=0",
+		x_("gate ground(g)"),
+		x_("set g=L@3"),
+		x_("t: delta=0"),
 		0
 	};
-	static char *pMOStran[] =
+	static CHAR *pMOStran[] =
 	{
-		"function PMOStran(g, a1, a2)",
-		"i: g, a1, a2",
-		"o: a1, a2",
-		"t: delta=1e-8",
+		x_("function PMOStran(g, a1, a2)"),
+		x_("i: g, a1, a2"),
+		x_("o: a1, a2"),
+		x_("t: delta=1e-8"),
 		0
 	};
-	static char *pMOStranWeak[] =
+	static CHAR *pMOStranWeak[] =
 	{
-		"function pMOStranWeak(g, a1, a2)",
-		"i: g, a1, a2",
-		"o: a1, a2",
-		"t: delta=1e-8",
+		x_("function pMOStranWeak(g, a1, a2)"),
+		x_("i: g, a1, a2"),
+		x_("o: a1, a2"),
+		x_("t: delta=1e-8"),
 		0
 	};
-	static char *nMOStran[] =
+	static CHAR *nMOStran[] =
 	{
-		"function nMOStran(g, a1, a2)",
-		"i: g, a1, a2",
-		"o: a1, a2",
-		"t: delta=1e-8",
+		x_("function nMOStran(g, a1, a2)"),
+		x_("i: g, a1, a2"),
+		x_("o: a1, a2"),
+		x_("t: delta=1e-8"),
 		0
 	};
-	static char *nMOStranWeak[] =
+	static CHAR *nMOStranWeak[] =
 	{
-		"function nMOStranWeak(g, a1, a2)",
-		"i: g, a1, a2",
-		"o: a1, a2",
-		"t: delta=1e-8",
+		x_("function nMOStranWeak(g, a1, a2)"),
+		x_("i: g, a1, a2"),
+		x_("o: a1, a2"),
+		x_("t: delta=1e-8"),
 		0
 	};
-	static char *inverter[] =
+	static CHAR *inverter[] =
 	{
-		"gate inverter(a,z)",
-		"t: delta=1.33e-9",		/* T3=1.33 */
-		"i: a=L o: z=H",
-		"t: delta=1.07e-9",		/* T1=1.07 */
-		"i: a=H o: z=L",
-		"t: delta=0",
-		"i: a=X o: z=X",
-		"load: a=1.0",
+		x_("gate inverter(a,z)"),
+		x_("t: delta=1.33e-9"),		/* T3=1.33 */
+		x_("i: a=L o: z=H"),
+		x_("t: delta=1.07e-9"),		/* T1=1.07 */
+		x_("i: a=H o: z=L"),
+		x_("t: delta=0"),
+		x_("i: a=X o: z=X"),
+		x_("load: a=1.0"),
 		0
 	};
-	static char *buffer[] =
+	static CHAR *buffer[] =
 	{
-		"gate buffer(in,out)",
-		"t: delta=0.56e-9",		/* T4*Cin=0.56 */
-		"i: in=H o: out=H",
-		"t: delta=0.41e-9",		/* T2*Cin=0.41 */
-		"i: in=L o: out=L",
-		"t: delta=0",
-		"i: in=X o: out=X",
+		x_("gate buffer(in,out)"),
+		x_("t: delta=0.56e-9"),		/* T4*Cin=0.56 */
+		x_("i: in=H o: out=H"),
+		x_("t: delta=0.41e-9"),		/* T2*Cin=0.41 */
+		x_("i: in=L o: out=L"),
+		x_("t: delta=0"),
+		x_("i: in=X o: out=X"),
 		0
 	};
-	static char *xor2[] =
+	static CHAR *xor2[] =
 	{
 		/* input a,b cap = 0.xx pF, Tphl = T1 + T2*Cin, Tplh = T3 + T4*Cin */
-		"model xor2(a,b,z)",
-		"g1: xor2fun(a,b,out)",
-		"g2: xor2buf(out,z)",
+		x_("model xor2(a,b,z)"),
+		x_("g1: xor2fun(a,b,out)"),
+		x_("g2: xor2buf(out,z)"),
 
-		"gate xor2fun(a,b,out)",
-		"t: delta=1.33e-9",		/* T3=1.33 */
-		"i: a=L b=H o: out=H",
-		"i: a=H b=L o: out=H",
-		"t: delta=1.07e-9",		/* T1=1.07 */
-		"i: a=L b=L o: out=L",
-		"i: a=H b=H o: out=L",
-		"t: delta=0",
-		"i:         o: out=X",
-		"load: a=1.0 b=1.0",
+		x_("gate xor2fun(a,b,out)"),
+		x_("t: delta=1.33e-9"),		/* T3=1.33 */
+		x_("i: a=L b=H o: out=H"),
+		x_("i: a=H b=L o: out=H"),
+		x_("t: delta=1.07e-9"),		/* T1=1.07 */
+		x_("i: a=L b=L o: out=L"),
+		x_("i: a=H b=H o: out=L"),
+		x_("t: delta=0"),
+		x_("i:         o: out=X"),
+		x_("load: a=1.0 b=1.0"),
 
-		"gate xor2buf(in,out)",
-		"t: delta=0.56e-9",		/* T4*Cin=0.56 */
-		"i: in=H    o: out=H",
-		"t: delta=0.41e-9",		/* T2*Cin=0.41 */
-		"i: in=L    o: out=L",
-		"t: delta=0",
-		"i: in=X    o: out=X",
+		x_("gate xor2buf(in,out)"),
+		x_("t: delta=0.56e-9"),		/* T4*Cin=0.56 */
+		x_("i: in=H    o: out=H"),
+		x_("t: delta=0.41e-9"),		/* T2*Cin=0.41 */
+		x_("i: in=L    o: out=L"),
+		x_("t: delta=0"),
+		x_("i: in=X    o: out=X"),
 		0
 	};
-	static char *JKFF[] =
+	static CHAR *JKFF[] =
 	{
-		"model jkff(j, k, clk, pr, clr, q, qbar)",
-		"n: JKFFLOP(clk, j, k, q, qbar)",
-		"function JKFFLOP(clk, j, k, q, qbar)",
-		"i: clk, j, k",
-		"o: q, qbar",
-		"t: delta=1e-8",
+		x_("model jkff(j, k, clk, pr, clr, q, qbar)"),
+		x_("n: JKFFLOP(clk, j, k, q, qbar)"),
+		x_("function JKFFLOP(clk, j, k, q, qbar)"),
+		x_("i: clk, j, k"),
+		x_("o: q, qbar"),
+		x_("t: delta=1e-8"),
 		0
 	};
-	static char *DFF[] =
+	static CHAR *DFF[] =
 	{
-		"model dsff(d, clk, pr, q)",
-		"n: DFFLOP(d, clk, q)",
-		"function DFFLOP(d, clk, q)",
-		"i: d, clk",
-		"o: q",
-		"t: delta=1e-8",
+		x_("model dsff(d, clk, pr, q)"),
+		x_("n: DFFLOP(d, clk, q)"),
+		x_("function DFFLOP(d, clk, q)"),
+		x_("i: d, clk"),
+		x_("o: q"),
+		x_("t: delta=1e-8"),
 		0
 	};
 
 	vhdl_freeunresolvedlist(&vhdl_unresolved_list);
-	vhdl_ident_ground = vhdl_findidentkey("ground");
-	vhdl_ident_power = vhdl_findidentkey("power");
+	vhdl_ident_ground = vhdl_findidentkey(x_("ground"));
+	vhdl_ident_power = vhdl_findidentkey(x_("power"));
 
 	/* print file header */
-	vhdl_printoneline("#*************************************************");
-	vhdl_printoneline("#  ALS Netlist file");
-	vhdl_printoneline("#");
+	vhdl_printoneline(x_("#*************************************************"));
+	vhdl_printoneline(x_("#  ALS Netlist file"));
+	vhdl_printoneline(x_("#"));
 	if ((us_useroptions&NODATEORVERSION) == 0)
 	{
-		vhdl_printoneline("#  File Creation:    %s", timetostring(getcurrenttime()));
+		vhdl_printoneline(x_("#  File Creation:    %s"), timetostring(getcurrenttime()));
 	}
-	vhdl_printoneline("#-------------------------------------------------");
-	vhdl_print("");
+	vhdl_printoneline(x_("#-------------------------------------------------"));
+	vhdl_print(x_(""));
 
 	/* determine top level cell which must be renamed from "basenp" */
 	top_interface = vhdl_findtopinterface(vhdl_units);
@@ -213,7 +213,7 @@ void vhdl_genals(LIBRARY *lib, NODEPROTO *basenp)
 	}
 
 	/* print closing line of output file */
-	vhdl_printoneline("#********* End of netlist *******************");
+	vhdl_printoneline(x_("#********* End of netlist *******************"));
 
 	/* scan unresolved references for reality inside of Electric */
 	total = 0;
@@ -242,77 +242,77 @@ void vhdl_genals(LIBRARY *lib, NODEPROTO *basenp)
 		}
 
 		/* now see if this is a reference to a function primitive */
-		if (strcmp(gate, "PMOStran") == 0)
+		if (estrcmp(gate, x_("PMOStran")) == 0)
 		{
 			vhdl_dumpfunction(gate, pMOStran);
 			ulist->numref = 0;
 			total--;
-		} else if (strcmp(gate, "pMOStranWeak") == 0)
+		} else if (estrcmp(gate, x_("pMOStranWeak")) == 0)
 		{
 			vhdl_dumpfunction(gate, pMOStranWeak);
 			ulist->numref = 0;
 			total--;
-		} else if (strcmp(gate, "nMOStran") == 0)
+		} else if (estrcmp(gate, x_("nMOStran")) == 0)
 		{
 			vhdl_dumpfunction(gate, nMOStran);
 			ulist->numref = 0;
 			total--;
-		} else if (strcmp(gate, "nMOStranWeak") == 0)
+		} else if (estrcmp(gate, x_("nMOStranWeak")) == 0)
 		{
 			vhdl_dumpfunction(gate, nMOStranWeak);
 			ulist->numref = 0;
 			total--;
-		} else if (strcmp(gate, "inverter") == 0)
+		} else if (estrcmp(gate, x_("inverter")) == 0)
 		{
 			vhdl_dumpfunction(gate, inverter);
 			ulist->numref = 0;
 			total--;
-		} else if (strcmp(gate, "buffer") == 0)
+		} else if (estrcmp(gate, x_("buffer")) == 0)
 		{
 			vhdl_dumpfunction(gate, buffer);
 			ulist->numref = 0;
 			total--;
-		} else if (strncmp(gate, "and", 3) == 0 && isdigit(gate[3]))
+		} else if (estrncmp(gate, x_("and"), 3) == 0 && isdigit(gate[3]))
 		{
-			vhdl_genfunction("and", TRUE, FALSE, atoi(&gate[3]));
+			vhdl_genfunction(x_("and"), TRUE, FALSE, eatoi(&gate[3]));
 			ulist->numref = 0;
 			total--;
-		} else if (strncmp(gate, "nand", 4) == 0 && isdigit(gate[4]))
+		} else if (estrncmp(gate, x_("nand"), 4) == 0 && isdigit(gate[4]))
 		{
-			vhdl_genfunction("and", TRUE, TRUE, atoi(&gate[4]));
+			vhdl_genfunction(x_("and"), TRUE, TRUE, eatoi(&gate[4]));
 			ulist->numref = 0;
 			total--;
-		} else if (strncmp(gate, "or", 2) == 0 && isdigit(gate[2]))
+		} else if (estrncmp(gate, x_("or"), 2) == 0 && isdigit(gate[2]))
 		{
-			vhdl_genfunction("or", FALSE, FALSE, atoi(&gate[2]));
+			vhdl_genfunction(x_("or"), FALSE, FALSE, eatoi(&gate[2]));
 			ulist->numref = 0;
 			total--;
-		} else if (strncmp(gate, "nor", 3) == 0 && isdigit(gate[3]))
+		} else if (estrncmp(gate, x_("nor"), 3) == 0 && isdigit(gate[3]))
 		{
-			vhdl_genfunction("or", FALSE, TRUE, atoi(&gate[3]));
+			vhdl_genfunction(x_("or"), FALSE, TRUE, eatoi(&gate[3]));
 			ulist->numref = 0;
 			total--;
-		} else if (strcmp(gate, "xor2") == 0)
+		} else if (estrcmp(gate, x_("xor2")) == 0)
 		{
 			vhdl_dumpfunction(gate, xor2);
 			ulist->numref = 0;
 			total--;
-		} else if (strcmp(gate, "power") == 0)
+		} else if (estrcmp(gate, x_("power")) == 0)
 		{
 			vhdl_dumpfunction(gate, power);
 			ulist->numref = 0;
 			total--;
-		} else if (strcmp(gate, "ground") == 0)
+		} else if (estrcmp(gate, x_("ground")) == 0)
 		{
 			vhdl_dumpfunction(gate, ground);
 			ulist->numref = 0;
 			total--;
-		} else if (strcmp(gate, "jkff") == 0)
+		} else if (estrcmp(gate, x_("jkff")) == 0)
 		{
 			vhdl_dumpfunction(gate, JKFF);
 			ulist->numref = 0;
 			total--;
-		} else if (strcmp(gate, "dsff") == 0)
+		} else if (estrcmp(gate, x_("dsff")) == 0)
 		{
 			vhdl_dumpfunction(gate, DFF);
 			ulist->numref = 0;
@@ -334,10 +334,10 @@ void vhdl_genals(LIBRARY *lib, NODEPROTO *basenp)
  * routine to search library "lib" for a netlist that matches "name".  If found,
  * add it to the current output netlist and return nonzero.  If not found, return false.
  */
-BOOLEAN vhdl_addnetlist(LIBRARY *lib, char *name)
+BOOLEAN vhdl_addnetlist(LIBRARY *lib, CHAR *name)
 {
 	REGISTER NODEPROTO *np;
-	REGISTER char *pn, *key;
+	REGISTER CHAR *pn, *key;
 	REGISTER VARIABLE *var;
 	REGISTER INTBIG len, i;
 	REGISTER void *infstr;
@@ -356,8 +356,8 @@ BOOLEAN vhdl_addnetlist(LIBRARY *lib, char *name)
 		var = getvalkey((INTBIG)np, VNODEPROTO, VSTRING|VISARRAY, el_facet_message_key);
 		if (var == NOVARIABLE) continue;
 		len = getlength(var);
-		vhdl_print("");
-		for(i=0; i<len; i++) vhdl_printoneline(((char **)var->addr)[i]);
+		vhdl_print(x_(""));
+		for(i=0; i<len; i++) vhdl_printoneline(((CHAR **)var->addr)[i]);
 		return(TRUE);
 	}
 	return(FALSE);
@@ -366,106 +366,107 @@ BOOLEAN vhdl_addnetlist(LIBRARY *lib, char *name)
 /*
  * inputs cap = 0.xx pF, Tphl = T1 + T2*Cin, Tplh = T3 + T4*Cin
  */
-void vhdl_genfunction(char *name, BOOLEAN isand, BOOLEAN isneg, INTBIG inputs)
+void vhdl_genfunction(CHAR *name, BOOLEAN isand, BOOLEAN isneg, INTBIG inputs)
 {
-	char modelname[20], line[20];
+	CHAR modelname[20], line[20];
 	REGISTER INTBIG i;
 	REGISTER void *infstr;
+	Q_UNUSED( name );
 
 	/* generate model name */
-	if (!isneg) modelname[0] = 0; else (void)strcpy(modelname, "n");
-	if (isand) (void)strcat(modelname, "and"); else (void)strcat(modelname, "or");
-	(void)sprintf(line, "%ld", inputs);
-	(void)strcat(modelname, line);
+	if (!isneg) modelname[0] = 0; else (void)estrcpy(modelname, x_("n"));
+	if (isand) (void)estrcat(modelname, x_("and")); else (void)estrcat(modelname, x_("or"));
+	(void)esnprintf(line, 20, x_("%ld"), inputs);
+	(void)estrcat(modelname, line);
 
-	vhdl_print("");
+	vhdl_print(x_(""));
 	infstr = initinfstr();
-	addstringtoinfstr(infstr, "# Built-in model for ");
+	addstringtoinfstr(infstr, x_("# Built-in model for "));
 	addstringtoinfstr(infstr, modelname);
 	vhdl_printoneline(returninfstr(infstr));
 
 	/* write header line */
 	infstr = initinfstr();
-	addstringtoinfstr(infstr, "model ");
+	addstringtoinfstr(infstr, x_("model "));
 	addstringtoinfstr(infstr, modelname);
-	addstringtoinfstr(infstr, "(");
+	addstringtoinfstr(infstr, x_("("));
 	for(i=1; i<=inputs; i++)
 	{
-		if (i > 1) addstringtoinfstr(infstr, ",");
-		(void)sprintf(line, "a%ld", i);
+		if (i > 1) addstringtoinfstr(infstr, x_(","));
+		(void)esnprintf(line, 20, x_("a%ld"), i);
 		addstringtoinfstr(infstr, line);
 	}
-	addstringtoinfstr(infstr, ",z)");
+	addstringtoinfstr(infstr, x_(",z)"));
 	vhdl_print(returninfstr(infstr));
 
 	/* write function line */
 	infstr = initinfstr();
-	addstringtoinfstr(infstr, "g1: ");
+	addstringtoinfstr(infstr, x_("g1: "));
 	addstringtoinfstr(infstr, modelname);
-	addstringtoinfstr(infstr, "fun(");
+	addstringtoinfstr(infstr, x_("fun("));
 	for(i=1; i<=inputs; i++)
 	{
-		if (i > 1) addstringtoinfstr(infstr, ",");
-		(void)sprintf(line, "a%ld", i);
+		if (i > 1) addstringtoinfstr(infstr, x_(","));
+		(void)esnprintf(line, 20, x_("a%ld"), i);
 		addstringtoinfstr(infstr, line);
 	}
-	if (!isneg) addstringtoinfstr(infstr, ",out)"); else
-		addstringtoinfstr(infstr, ",z)");
+	if (!isneg) addstringtoinfstr(infstr, x_(",out)")); else
+		addstringtoinfstr(infstr, x_(",z)"));
 	vhdl_print(returninfstr(infstr));
 
 	/* write buffer line if not negated */
 	if (!isneg)
 	{
 		infstr = initinfstr();
-		addstringtoinfstr(infstr, "g2: ");
+		addstringtoinfstr(infstr, x_("g2: "));
 		addstringtoinfstr(infstr, modelname);
-		addstringtoinfstr(infstr, "buf(out,z)");
+		addstringtoinfstr(infstr, x_("buf(out,z)"));
 		vhdl_print(returninfstr(infstr));
 	}
 
 	/* write function header */
 	infstr = initinfstr();
-	addstringtoinfstr(infstr, "gate ");
+	addstringtoinfstr(infstr, x_("gate "));
 	addstringtoinfstr(infstr, modelname);
-	addstringtoinfstr(infstr, "fun(");
+	addstringtoinfstr(infstr, x_("fun("));
 	for(i=1; i<=inputs; i++)
 	{
-		if (i > 1) addstringtoinfstr(infstr, ",");
-		(void)sprintf(line, "a%ld", i);
+		if (i > 1) addstringtoinfstr(infstr, x_(","));
+		(void)esnprintf(line, 20, x_("a%ld"), i);
 		addstringtoinfstr(infstr, line);
 	}
-	addstringtoinfstr(infstr, ",z)");
+	addstringtoinfstr(infstr, x_(",z)"));
 	vhdl_print(returninfstr(infstr));
-	vhdl_print("t: delta=1.33e-9");		/* T3=1.33 */
+	vhdl_print(x_("t: delta=1.33e-9"));		/* T3=1.33 */
 	for(i=1; i<=inputs; i++)
 	{
 		infstr = initinfstr();
-		(void)sprintf(line, "i: a%ld", i);
+		(void)esnprintf(line, 20, x_("i: a%ld"), i);
 		addstringtoinfstr(infstr, line);
-		if (isand) addstringtoinfstr(infstr, "=L o: z=H"); else
-			addstringtoinfstr(infstr, "=H o: z=L");
+		if (isand) addstringtoinfstr(infstr, x_("=L o: z=H")); else
+			addstringtoinfstr(infstr, x_("=H o: z=L"));
 		vhdl_print(returninfstr(infstr));
 	}
-	vhdl_print("t: delta=1.07e-9");		/* T1=1.07 */
+	vhdl_print(x_("t: delta=1.07e-9"));		/* T1=1.07 */
 	infstr = initinfstr();
-	addstringtoinfstr(infstr, "i:");
+	addstringtoinfstr(infstr, x_("i:"));
 	for(i=1; i<=inputs; i++)
 	{
-		if (isand) (void)sprintf(line, " a%ld=H", i); else
-			(void)sprintf(line, " a%ld=L", i);
+		if (isand) (void)esnprintf(line, 20, x_(" a%ld=H"), i); else
+			(void)esnprintf(line, 20, x_(" a%ld=L"), i);
 		addstringtoinfstr(infstr, line);
 	}
-	if (isand)  addstringtoinfstr(infstr, " o: z=L"); else
-		addstringtoinfstr(infstr, " o: z=H");
+	if (isand) addstringtoinfstr(infstr, x_(" o: z=L")); else
+		addstringtoinfstr(infstr, x_(" o: z=H"));
 	vhdl_print(returninfstr(infstr));
-	vhdl_print("t: delta=0");
-	vhdl_print("i: o: z=X");
+	vhdl_print(x_("t: delta=0"));
+	vhdl_print(x_("i: o: z=X"));
 
 	infstr = initinfstr();
-	addstringtoinfstr(infstr, "load:");
+	addstringtoinfstr(infstr, x_("load:"));
 	for(i=1; i<=inputs; i++)
 	{
-		(void)sprintf(line, " a%ld=1.0", i);
+		(void)esnprintf(line, 20, x_(" a%ld=1.0"), i);
 		addstringtoinfstr(infstr, line);
 	}
 	vhdl_print(returninfstr(infstr));
@@ -474,27 +475,27 @@ void vhdl_genfunction(char *name, BOOLEAN isand, BOOLEAN isneg, INTBIG inputs)
 	if (!isneg)
 	{
 		infstr = initinfstr();
-		addstringtoinfstr(infstr, "gate ");
+		addstringtoinfstr(infstr, x_("gate "));
 		addstringtoinfstr(infstr, modelname);
-		addstringtoinfstr(infstr, "buf(in,out)");
+		addstringtoinfstr(infstr, x_("buf(in,out)"));
 		vhdl_print(returninfstr(infstr));
-		vhdl_print("t: delta=0.56e-9");		/* T4*Cin=0.56 */
-		vhdl_print("i: in=H    o: out=L");
-		vhdl_print("t: delta=0.41e-9");		/* T2*Cin=0.41 */
-		vhdl_print("i: in=L    o: out=H");
-		vhdl_print("t: delta=0");
-		vhdl_print("i: in=X    o: out=X");
+		vhdl_print(x_("t: delta=0.56e-9"));		/* T4*Cin=0.56 */
+		vhdl_print(x_("i: in=H    o: out=L"));
+		vhdl_print(x_("t: delta=0.41e-9"));		/* T2*Cin=0.41 */
+		vhdl_print(x_("i: in=L    o: out=H"));
+		vhdl_print(x_("t: delta=0"));
+		vhdl_print(x_("i: in=X    o: out=X"));
 	}
 }
 
-void vhdl_dumpfunction(char *name, char **model)
+void vhdl_dumpfunction(CHAR *name, CHAR **model)
 {
 	REGISTER INTBIG i;
 	REGISTER void *infstr;
 
-	vhdl_print("");
+	vhdl_print(x_(""));
 	infstr = initinfstr();
-	addstringtoinfstr(infstr, "# Built-in model for ");
+	addstringtoinfstr(infstr, x_("# Built-in model for "));
 	addstringtoinfstr(infstr, name);
 	vhdl_printoneline(returninfstr(infstr));
 	for(i=0; model[i] != 0; i++) vhdl_printoneline(model[i]);
@@ -516,14 +517,14 @@ interfacef	*DBINTERFACE	Pointer to interface.
 name		*char			Pointer to string name of interface.
 ------------------------------------------------------------------------
 */
-void vhdl_genals_interface(DBINTERFACE *interfacef, char *name)
+void vhdl_genals_interface(DBINTERFACE *interfacef, CHAR *name)
 {
 	DBINSTANCE *inst;
 	SYMBOLTREE *symbol;
 	DBPORTLIST *port;
 	DBAPORTLIST *aport;
 	INTBIG first, generic, power_flag, ground_flag, i;
-	char temp[30], *pt;
+	CHAR temp[30], *pt;
 	IDENTTABLE *ident;
 	DBINDEXRANGE *irange;
 	DBDISCRETERANGE *drange;
@@ -576,13 +577,13 @@ void vhdl_genals_interface(DBINTERFACE *interfacef, char *name)
 	generic = 0;
 	power_flag = ground_flag = FALSE;
 	infstr = initinfstr();
-	addstringtoinfstr(infstr, "model ");
+	addstringtoinfstr(infstr, x_("model "));
 	for(pt = name; *pt != 0; pt++)
 		if (isalnum(*pt)) addtoinfstr(infstr, *pt); else
 	{
 		addtoinfstr(infstr, '_');
 	}
-	addstringtoinfstr(infstr, "(");
+	addstringtoinfstr(infstr, x_("("));
 
 	/* write port list of interface */
 	first = TRUE;
@@ -590,7 +591,7 @@ void vhdl_genals_interface(DBINTERFACE *interfacef, char *name)
 	{
 		if (port->type == NULL || port->type->type == DBTYPE_SINGLE)
 		{
-			if (!first) addstringtoinfstr(infstr, ", ");
+			if (!first) addstringtoinfstr(infstr, x_(", "));
 			addstringtoinfstr(infstr, port->name->string);
 			first = FALSE;
 		} else
@@ -601,9 +602,9 @@ void vhdl_genals_interface(DBINTERFACE *interfacef, char *name)
 			{
 				for (i = drange->start; i >= drange->end; i--)
 				{
-					if (!first) addstringtoinfstr(infstr, ", ");
+					if (!first) addstringtoinfstr(infstr, x_(", "));
 					addstringtoinfstr(infstr, port->name->string);
-					(void)sprintf(temp, "[%ld]", i);
+					(void)esnprintf(temp, 30, x_("[%ld]"), i);
 					addstringtoinfstr(infstr, temp);
 					first = FALSE;
 				}
@@ -611,16 +612,16 @@ void vhdl_genals_interface(DBINTERFACE *interfacef, char *name)
 			{
 				for (i = drange->start; i <= drange->end; i++)
 				{
-					if (!first) addstringtoinfstr(infstr, ", ");
+					if (!first) addstringtoinfstr(infstr, x_(", "));
 					addstringtoinfstr(infstr, port->name->string);
-					(void)sprintf(temp, "[%ld]", i);
+					(void)esnprintf(temp, 30, x_("[%ld]"), i);
 					addstringtoinfstr(infstr, temp);
 					first = FALSE;
 				}
 			}
 		}
 	}
-	addstringtoinfstr(infstr, ")");
+	addstringtoinfstr(infstr, x_(")"));
 	vhdl_print(returninfstr(infstr));
 
 	/* write all instances */
@@ -631,9 +632,9 @@ void vhdl_genals_interface(DBINTERFACE *interfacef, char *name)
 		{
 			infstr = initinfstr();
 			addstringtoinfstr(infstr, inst->name->string);
-			addstringtoinfstr(infstr, ": ");
+			addstringtoinfstr(infstr, x_(": "));
 			addstringtoinfstr(infstr, inst->compo->name->string);
-			addstringtoinfstr(infstr, "(");
+			addstringtoinfstr(infstr, x_("("));
 
 			/* print instance port list */
 			first = TRUE;
@@ -669,8 +670,8 @@ void vhdl_genals_interface(DBINTERFACE *interfacef, char *name)
 						{
 							for (i = drange->start; i >= drange->end; i--)
 							{
-								if (!first) addstringtoinfstr(infstr, ", ");
-								(void)sprintf(temp, "n%ld", generic++);
+								if (!first) addstringtoinfstr(infstr, x_(", "));
+								(void)esnprintf(temp, 30, x_("n%ld"), generic++);
 								addstringtoinfstr(infstr, temp);
 								first = FALSE;
 							}
@@ -678,30 +679,30 @@ void vhdl_genals_interface(DBINTERFACE *interfacef, char *name)
 						{
 							for (i = drange->start; i <= drange->end; i++)
 							{
-								if (!first) addstringtoinfstr(infstr, ", ");
-								(void)sprintf(temp, "n%ld", generic++);
+								if (!first) addstringtoinfstr(infstr, x_(", "));
+								(void)esnprintf(temp, 30, x_("n%ld"), generic++);
 								addstringtoinfstr(infstr, temp);
 								first = FALSE;
 							}
 						}
 					} else
 					{
-						if (!first) addstringtoinfstr(infstr, ", ");
-						(void)sprintf(temp, "n%ld", generic++);
+						if (!first) addstringtoinfstr(infstr, x_(", "));
+						(void)esnprintf(temp, 30, x_("n%ld"), generic++);
 						addstringtoinfstr(infstr, temp);
 						first = FALSE;
 					}
 				}
 			}
-			addstringtoinfstr(infstr, ")");
+			addstringtoinfstr(infstr, x_(")"));
 			vhdl_print(returninfstr(infstr));
 		}
 	}
 
 	/* check for power and ground flags */
-	if (power_flag) vhdl_print("set power = H@3");
-		else if (ground_flag) vhdl_print("set ground = L@3");
-	vhdl_print("");
+	if (power_flag) vhdl_print(x_("set power = H@3"));
+		else if (ground_flag) vhdl_print(x_("set ground = L@3"));
+	vhdl_print(x_(""));
 }
 
 /*
@@ -723,13 +724,13 @@ void vhdl_genals_aport(void *infstr, INTBIG *first, DBNAME *name)
 	DBINDEXRANGE *irange;
 	DBDISCRETERANGE *drange;
 	INTBIG i;
-	char temp[30];
+	CHAR temp[30];
 
 	if (name->type == DBNAME_INDEXED)
 	{
-		if (!(*first)) addstringtoinfstr(infstr, ", ");
+		if (!(*first)) addstringtoinfstr(infstr, x_(", "));
 		addstringtoinfstr(infstr, name->name->string);
-		(void)sprintf(temp, "[%ld]", ((DBEXPRLIST *)(name->pointer))->value);
+		(void)esnprintf(temp, 30, x_("[%ld]"), ((DBEXPRLIST *)(name->pointer))->value);
 		addstringtoinfstr(infstr, temp);
 		*first = FALSE;
 	} else
@@ -742,9 +743,9 @@ void vhdl_genals_aport(void *infstr, INTBIG *first, DBNAME *name)
 			{
 				for (i = drange->start; i >= drange->end; i--)
 				{
-					if (!(*first)) addstringtoinfstr(infstr, ", ");
+					if (!(*first)) addstringtoinfstr(infstr, x_(", "));
 					addstringtoinfstr(infstr, name->name->string);
-					(void)sprintf(temp, "[%ld]", i);
+					(void)esnprintf(temp, 30, x_("[%ld]"), i);
 					addstringtoinfstr(infstr, temp);
 					*first = FALSE;
 				}
@@ -752,16 +753,16 @@ void vhdl_genals_aport(void *infstr, INTBIG *first, DBNAME *name)
 			{
 				for (i = drange->start; i <= drange->end; i++)
 				{
-					if (!(*first)) addstringtoinfstr(infstr, ", ");
+					if (!(*first)) addstringtoinfstr(infstr, x_(", "));
 					addstringtoinfstr(infstr, name->name->string);
-					(void)sprintf(temp, "[%ld]", i);
+					(void)esnprintf(temp, 30, x_("[%ld]"), i);
 					addstringtoinfstr(infstr, temp);
 					*first = FALSE;
 				}
 			}
 		} else
 		{
-			if (!(*first)) addstringtoinfstr(infstr, ", ");
+			if (!(*first)) addstringtoinfstr(infstr, x_(", "));
 			addstringtoinfstr(infstr, name->name->string);
 			*first = FALSE;
 		}
