@@ -57,7 +57,7 @@ static INTBIG vhdl_evalprimary(PRIMARY*);
 static INTBIG vhdl_evalname(VNAME*);
 static BOOLEAN vhdl_indiscreterange(INTBIG, DBDISCRETERANGE*);
 static SINGLENAME *vhdl_parsesinglename(void);
-static INDEXEDNAME *vhdl_parseindexedname(INTBIG, char*);
+static INDEXEDNAME *vhdl_parseindexedname(INTBIG, CHAR*);
 static DBNAME *vhdl_semsinglename(SINGLENAME*);
 static DBNAME *vhdl_semconcatenatedname(CONCATENATEDNAME*);
 static DBNAME *vhdl_semindexedname(INDEXEDNAME*);
@@ -467,7 +467,7 @@ PRIMARY  *vhdl_parseprimary(void)
 {
 	PRIMARY *primary;
 	INTBIG type;
-	char *pointer;
+	CHAR *pointer;
 
 	type = NOPRIMARY;
 	primary = 0;
@@ -478,17 +478,17 @@ PRIMARY  *vhdl_parseprimary(void)
 		case TOKEN_STRING:
 		case TOKEN_BIT_STRING:
 			type = PRIMARY_LITERAL;
-			pointer = (char *)vhdl_parseliteral();
+			pointer = (CHAR *)vhdl_parseliteral();
 			break;
 		case TOKEN_IDENTIFIER:
 			type = PRIMARY_NAME;
-			pointer = (char *)vhdl_parsename();
+			pointer = (CHAR *)vhdl_parsename();
 			break;
 		case TOKEN_LEFTBRACKET:
 			/* should be an expression in brackets */
 			vhdl_getnexttoken();
 			type = PRIMARY_EXPRESSION;
-			pointer = (char *)vhdl_parseexpression();
+			pointer = (CHAR *)vhdl_parseexpression();
 
 			/* should be at right bracket */
 			if (vhdl_nexttoken->token != TOKEN_RIGHTBRACKET)
@@ -532,7 +532,7 @@ LITERAL  *vhdl_parseliteral(void)
 {
 	LITERAL *literal;
 	INTBIG type;
-	char *pointer;
+	CHAR *pointer;
 
 	literal = 0;
 	type = NOLITERAL;
@@ -540,7 +540,7 @@ LITERAL  *vhdl_parseliteral(void)
 	{
 		case TOKEN_DECIMAL:
 			type = LITERAL_NUMERIC;
-			pointer = (char *)vhdl_parsedecimal();
+			pointer = (CHAR *)vhdl_parsedecimal();
 			break;
 		case TOKEN_BASED:
 			/* type = LITERAL_NUMERIC;
@@ -588,7 +588,7 @@ INTBIG vhdl_parsedecimal(void)
 
 	value = 0;
 	/* only supports integers */
-	value = (INTBIG)atoi(vhdl_nexttoken->pointer);
+	value = (INTBIG)eatoi(vhdl_nexttoken->pointer);
 	vhdl_getnexttoken();
 	return(value);
 }
@@ -983,12 +983,12 @@ VNAME  *vhdl_parsename(void)
 {
 	VNAME *name;
 	INTBIG type;
-	char *pointer, *pointer2;
+	CHAR *pointer, *pointer2;
 	CONCATENATEDNAME *concat, *concat2;
 
 	name = NULL;
 	type = NONAME;
-	pointer = (char *)vhdl_parsesinglename();
+	pointer = (CHAR *)vhdl_parsesinglename();
 
 	switch (vhdl_nexttoken->token)
 	{
@@ -997,11 +997,11 @@ VNAME  *vhdl_parsename(void)
 			concat = (CONCATENATEDNAME *)emalloc((INTBIG)sizeof(CONCATENATEDNAME), vhdl_tool->cluster);
 			concat->name = (SINGLENAME *)pointer;
 			concat->next = NULL;
-			pointer = (char *)concat;
+			pointer = (CHAR *)concat;
 			while (vhdl_nexttoken->token == TOKEN_AMPERSAND)
 			{
 				vhdl_getnexttoken();
-				pointer2 = (char *)vhdl_parsesinglename();
+				pointer2 = (CHAR *)vhdl_parsesinglename();
 				concat2 = (CONCATENATEDNAME *)emalloc((INTBIG)sizeof(CONCATENATEDNAME), vhdl_tool->cluster);
 				concat->next = concat2;
 				concat2->name = (SINGLENAME *)pointer2;
@@ -1051,12 +1051,12 @@ SINGLENAME  *vhdl_parsesinglename(void)
 {
 	SINGLENAME *sname, *sname2;
 	INTBIG type;
-	char *pointer;
+	CHAR *pointer;
 	VNAME *nptr;
 
 	type = NOSINGLENAME;
 	sname = NULL;
-	pointer = (char *)vhdl_parsesimplename();
+	pointer = (CHAR *)vhdl_parsesimplename();
 
 	if (vhdl_nexttoken->last->space)
 	{
@@ -1075,10 +1075,10 @@ SINGLENAME  *vhdl_parsesinglename(void)
 				nptr = (VNAME *)emalloc((INTBIG)sizeof(VNAME), vhdl_tool->cluster);
 				nptr->type = NAME_SINGLE;
 				sname2 = (SINGLENAME *)emalloc((INTBIG)sizeof(SINGLENAME), vhdl_tool->cluster);
-				nptr->pointer = (char *)sname2;
+				nptr->pointer = (CHAR *)sname2;
 				sname2->type = SINGLENAME_SIMPLE;
 				sname2->pointer = pointer;
-				pointer = (char *)vhdl_parseindexedname((INTBIG)PREFIX_NAME, (char *)nptr);
+				pointer = (CHAR *)vhdl_parseindexedname((INTBIG)PREFIX_NAME, (CHAR *)nptr);
 				/* should be at right bracket */
 				if (vhdl_nexttoken->token != TOKEN_RIGHTBRACKET)
 				{
@@ -1154,7 +1154,7 @@ pre_ptr		*char			Pointer to prefix structure.
 pointer		*INDEXEDNAME	Returned pointer to indexed name.
 ------------------------------------------------------------------------
 */
-INDEXEDNAME  *vhdl_parseindexedname(INTBIG pre_type, char *pre_ptr)
+INDEXEDNAME  *vhdl_parseindexedname(INTBIG pre_type, CHAR *pre_ptr)
 {
 	PREFIX *prefix;
 	INDEXEDNAME *ind;
@@ -1464,7 +1464,7 @@ DBNAME  *vhdl_semconcatenatedname(CONCATENATEDNAME *name)
 		} else
 		{
 			end = newnl;
-			dbname->pointer = (char *)newnl;
+			dbname->pointer = (CHAR *)newnl;
 		}
 	}
 	return(dbname);
@@ -1538,7 +1538,7 @@ DBNAME  *vhdl_semindexedname(INDEXEDNAME *name)
 		}
 		indexr = indexr->next;
 	}
-	dbname->pointer = (char *)dbexpr;
+	dbname->pointer = (CHAR *)dbexpr;
 	return(dbname);
 }
 
