@@ -44,7 +44,7 @@ static IDENTTABLE	*vhdl_ident_ground, *vhdl_ident_power;
 static DBINTERFACE	*vhdl_top_interface;
 
 /* prototypes for local routines */
-static void vhdl_gennet_interface(DBINTERFACE*, char*);
+static void vhdl_gennet_interface(DBINTERFACE*, CHAR*);
 static void vhdl_gennet_aport(void*, DBNAME*);
 
 /*
@@ -61,25 +61,26 @@ void vhdl_gennet(INTBIG target)
 {
 	DBINTERFACE *interfacef;
 	UNRESLIST *ulist;
+	Q_UNUSED( target );
 
 	vhdl_freeunresolvedlist(&vhdl_unresolved_list);
-	vhdl_ident_ground = vhdl_findidentkey("ground");
-	vhdl_ident_power = vhdl_findidentkey("power");
+	vhdl_ident_ground = vhdl_findidentkey(x_("ground"));
+	vhdl_ident_power = vhdl_findidentkey(x_("power"));
 
 	/* print file header */
-	vhdl_printoneline(";*************************************************");
-	vhdl_printoneline(";  RNL Netlisp file");
-	vhdl_printoneline(";");
+	vhdl_printoneline(x_(";*************************************************"));
+	vhdl_printoneline(x_(";  RNL Netlisp file"));
+	vhdl_printoneline(x_(";"));
 	if ((us_useroptions&NODATEORVERSION) == 0)
-		vhdl_printoneline(";  File Creation:    %s", timetostring(getcurrenttime()));
-	vhdl_printoneline(";-------------------------------------------------");
-	vhdl_print("(load \"library.net\")");
+		vhdl_printoneline(x_(";  File Creation:    %s"), timetostring(getcurrenttime()));
+	vhdl_printoneline(x_(";-------------------------------------------------"));
+	vhdl_print(x_("(load \"library.net\")"));
 
 	/* determine top level cell which must be renamed main */
 	vhdl_top_interface = vhdl_findtopinterface(vhdl_units);
 	if (vhdl_top_interface == NULL)
 	{
-		ttyputmsg("ERROR - Cannot find top level interface.");
+		ttyputmsg(x_("ERROR - Cannot find top level interface."));
 	} else
 	{
 		/* clear written flag on all interfaces */
@@ -88,11 +89,11 @@ void vhdl_gennet(INTBIG target)
 		{
 			interfacef->flags &= ~ENTITY_WRITTEN;
 		}
-		vhdl_gennet_interface(vhdl_top_interface, "main");
+		vhdl_gennet_interface(vhdl_top_interface, x_("main"));
 	}
 
 	/* print closing line of output file */
-	vhdl_printoneline(";********* End of netlist file *******************");
+	vhdl_printoneline(x_(";********* End of netlist file *******************"));
 
 	/* print unresolved reference list is not empty */
 	if (vhdl_unresolved_list)
@@ -120,7 +121,7 @@ interfacef	*DBINTERFACE	Pointer to interface.
 name		*char			Pointer to string name of interface.
 ------------------------------------------------------------------------
 */
-void vhdl_gennet_interface(DBINTERFACE *interfacef, char *name)
+void vhdl_gennet_interface(DBINTERFACE *interfacef, CHAR *name)
 {
 	DBINSTANCE *inst;
 	SYMBOLTREE *symbol;
@@ -132,7 +133,7 @@ void vhdl_gennet_interface(DBINTERFACE *interfacef, char *name)
 	DBDISCRETERANGE *drange;
 	DBNAMELIST *cat;
 	DBSIGNALS *signal;
-	char temp[30];
+	CHAR temp[30];
 	REGISTER void *infstr;
 
 	/* go through interface's architectural body and call generate interfaces*/
@@ -183,11 +184,11 @@ void vhdl_gennet_interface(DBINTERFACE *interfacef, char *name)
 	generic = 0;
 	power_flag = ground_flag = FALSE;
 	infstr = initinfstr();
-	if (interfacef == vhdl_top_interface) addstringtoinfstr(infstr, "(node "); else
+	if (interfacef == vhdl_top_interface) addstringtoinfstr(infstr, x_("(node ")); else
 	{
-		addstringtoinfstr(infstr, "(macro ");
+		addstringtoinfstr(infstr, x_("(macro "));
 		addstringtoinfstr(infstr, name);
-		addstringtoinfstr(infstr, "(");
+		addstringtoinfstr(infstr, x_("("));
 	}
 
 	/* write port list of interface */
@@ -195,7 +196,7 @@ void vhdl_gennet_interface(DBINTERFACE *interfacef, char *name)
 	{
 		if (port->type == NULL || port->type->type == DBTYPE_SINGLE)
 		{
-			addstringtoinfstr(infstr, " ");
+			addstringtoinfstr(infstr, x_(" "));
 			addstringtoinfstr(infstr, port->name->string);
 		} else
 		{
@@ -205,39 +206,39 @@ void vhdl_gennet_interface(DBINTERFACE *interfacef, char *name)
 			{
 				for (i = drange->start; i >= drange->end; i--)
 				{
-					addstringtoinfstr(infstr, " ");
+					addstringtoinfstr(infstr, x_(" "));
 					addstringtoinfstr(infstr, port->name->string);
-					if (vhdl_target == TARGET_RSIM) (void)sprintf(temp, "_%ld", i); else
-						(void)sprintf(temp, "[%ld]", i);
+					if (vhdl_target == TARGET_RSIM) (void)esnprintf(temp, 30, x_("_%ld"), i); else
+						(void)esnprintf(temp, 30, x_("[%ld]"), i);
 					addstringtoinfstr(infstr, temp);
 				}
 			} else
 			{
 				for (i = drange->start; i <= drange->end; i++)
 				{
-					addstringtoinfstr(infstr, " ");
+					addstringtoinfstr(infstr, x_(" "));
 					addstringtoinfstr(infstr, port->name->string);
-					if (vhdl_target == TARGET_RSIM) (void)sprintf(temp, "_%ld", i); else
-						(void)sprintf(temp, "[%ld]", i);
+					if (vhdl_target == TARGET_RSIM) (void)esnprintf(temp, 30, x_("_%ld"), i); else
+						(void)esnprintf(temp, 30, x_("[%ld]"), i);
 					addstringtoinfstr(infstr, temp);
 				}
 			}
 		}
 	}
-	addstringtoinfstr(infstr, ")");
+	addstringtoinfstr(infstr, x_(")"));
 	vhdl_print(returninfstr(infstr));
 
 	/* Write out local node definitions */
 	infstr = initinfstr();
-	if (interfacef == vhdl_top_interface) addstringtoinfstr(infstr, "(node open_s");
-		else addstringtoinfstr(infstr, "(local open_s");
+	if (interfacef == vhdl_top_interface) addstringtoinfstr(infstr, x_("(node open_s"));
+		else addstringtoinfstr(infstr, x_("(local open_s"));
 	if (interfacef->bodies && interfacef->bodies->declare)
 	{
 		for (signal = interfacef->bodies->declare->bodysignals; signal; signal = signal->next)
 		{
 			if (signal->type == NULL || signal->type->type == DBTYPE_SINGLE)
 			{
-				addstringtoinfstr(infstr, " ");
+				addstringtoinfstr(infstr, x_(" "));
 				addstringtoinfstr(infstr, signal->name->string);
 			} else
 			{
@@ -247,27 +248,27 @@ void vhdl_gennet_interface(DBINTERFACE *interfacef, char *name)
 				{
 					for (i = drange->start; i >= drange->end; i--)
 					{
-						addstringtoinfstr(infstr, " ");
+						addstringtoinfstr(infstr, x_(" "));
 						addstringtoinfstr(infstr, signal->name->string);
-						if (vhdl_target == TARGET_RSIM) (void)sprintf(temp, "_%ld", i); else
-							(void)sprintf(temp, "[%ld]", i);
+						if (vhdl_target == TARGET_RSIM) (void)esnprintf(temp, 30, x_("_%ld"), i); else
+							(void)esnprintf(temp, 30, x_("[%ld]"), i);
 						addstringtoinfstr(infstr, temp);
 					}
 				} else
 				{
 					for (i = drange->start; i <= drange->end; i++)
 					{
-						addstringtoinfstr(infstr, " ");
+						addstringtoinfstr(infstr, x_(" "));
 						addstringtoinfstr(infstr, signal->name->string);
-						if (vhdl_target == TARGET_RSIM) (void)sprintf(temp, "_%ld", i); else
-							(void)sprintf(temp, "[%ld]", i);
+						if (vhdl_target == TARGET_RSIM) (void)esnprintf(temp, 30, x_("_%ld"), i); else
+							(void)esnprintf(temp, 30, x_("[%ld]"), i);
 						addstringtoinfstr(infstr, temp);
 					}
 				}
 			}
 		}
 	}
-	addstringtoinfstr(infstr, ")");
+	addstringtoinfstr(infstr, x_(")"));
 	vhdl_print(returninfstr(infstr));
 
 	/* write all instances */
@@ -276,9 +277,9 @@ void vhdl_gennet_interface(DBINTERFACE *interfacef, char *name)
 		for (inst = interfacef->bodies->statements->instances; inst != NULL; inst = inst->next)
 		{
 			infstr = initinfstr();
-			addstringtoinfstr(infstr, "(");
+			addstringtoinfstr(infstr, x_("("));
 			addstringtoinfstr(infstr, inst->compo->name->string);
-			addstringtoinfstr(infstr, " ");
+			addstringtoinfstr(infstr, x_(" "));
 
 			/* print instance port list */
 			for (aport = inst->ports; aport != NULL; aport = aport->next)
@@ -314,28 +315,28 @@ void vhdl_gennet_interface(DBINTERFACE *interfacef, char *name)
 						{
 							for (i = drange->start; i >= drange->end; i--)
 							{
-								addstringtoinfstr(infstr, " open_s.");
-								(void)sprintf(temp, "%ld", generic++);
+								addstringtoinfstr(infstr, x_(" open_s."));
+								(void)esnprintf(temp, 30, x_("%ld"), generic++);
 								addstringtoinfstr(infstr, temp);
 							}
 						} else
 						{
 							for (i = drange->start; i <= drange->end; i++)
 							{
-								addstringtoinfstr(infstr, " open_s.");
-								(void)sprintf(temp, "%ld", generic++);
+								addstringtoinfstr(infstr, x_(" open_s."));
+								(void)esnprintf(temp, 30, x_("%ld"), generic++);
 								addstringtoinfstr(infstr, temp);
 							}
 						}
 					} else
 					{
-						addstringtoinfstr(infstr, " open_s.");
-						(void)sprintf(temp, "%ld", generic++);
+						addstringtoinfstr(infstr, x_(" open_s."));
+						(void)esnprintf(temp, 30, x_("%ld"), generic++);
 						addstringtoinfstr(infstr, temp);
 					}
 				}
 			}
-			addstringtoinfstr(infstr, ")");
+			addstringtoinfstr(infstr, x_(")"));
 			vhdl_print(returninfstr(infstr));
 		}
 	}
@@ -343,12 +344,12 @@ void vhdl_gennet_interface(DBINTERFACE *interfacef, char *name)
 	/* check for power and ground flags */
 	if (power_flag)
 	{
-		vhdl_print("(connect power vdd)");
+		vhdl_print(x_("(connect power vdd)"));
 	} else if (ground_flag)
 	{
-		vhdl_print("(connect ground gnd)");
+		vhdl_print(x_("(connect ground gnd)"));
 	}
-	if (interfacef != vhdl_top_interface) vhdl_print(")");
+	if (interfacef != vhdl_top_interface) vhdl_print(x_(")"));
 }
 
 /*
@@ -369,15 +370,15 @@ void vhdl_gennet_aport(void *infstr, DBNAME *name)
 	DBINDEXRANGE *irange;
 	DBDISCRETERANGE *drange;
 	INTBIG i;
-	char temp[30];
+	CHAR temp[30];
 
 	if (name->type == DBNAME_INDEXED)
 	{
-		addstringtoinfstr(infstr, " ");
+		addstringtoinfstr(infstr, x_(" "));
 		addstringtoinfstr(infstr, name->name->string);
 		if (vhdl_target == TARGET_RSIM)
-			(void)sprintf(temp, "_%ld", ((DBEXPRLIST *)(name->pointer))->value); else
-				(void)sprintf(temp, "[%ld]", ((DBEXPRLIST *)(name->pointer))->value);
+			(void)esnprintf(temp, 30, x_("_%ld"), ((DBEXPRLIST *)(name->pointer))->value); else
+				(void)esnprintf(temp, 30, x_("[%ld]"), ((DBEXPRLIST *)(name->pointer))->value);
 		addstringtoinfstr(infstr, temp);
 	} else
 	{
@@ -389,26 +390,26 @@ void vhdl_gennet_aport(void *infstr, DBNAME *name)
 			{
 				for (i = drange->start; i >= drange->end; i--)
 				{
-					addstringtoinfstr(infstr, " ");
+					addstringtoinfstr(infstr, x_(" "));
 					addstringtoinfstr(infstr, name->name->string);
-					if (vhdl_target == TARGET_RSIM) (void)sprintf(temp, "_%ld", i); else
-						(void)sprintf(temp, "[%ld]", i);
+					if (vhdl_target == TARGET_RSIM) (void)esnprintf(temp, 30, x_("_%ld"), i); else
+						(void)esnprintf(temp, 30, x_("[%ld]"), i);
 					addstringtoinfstr(infstr, temp);
 				}
 			} else
 			{
 				for (i = drange->start; i <= drange->end; i++)
 				{
-					addstringtoinfstr(infstr, " ");
+					addstringtoinfstr(infstr, x_(" "));
 					addstringtoinfstr(infstr, name->name->string);
-					if (vhdl_target == TARGET_RSIM) (void)sprintf(temp, "_%ld", i); else
-						(void)sprintf(temp, "[%ld]", i);
+					if (vhdl_target == TARGET_RSIM) (void)esnprintf(temp, 30, x_("_%ld"), i); else
+						(void)esnprintf(temp, 30, x_("[%ld]"), i);
 					addstringtoinfstr(infstr, temp);
 				}
 			}
 		} else
 		{
-			addstringtoinfstr(infstr, " ");
+			addstringtoinfstr(infstr, x_(" "));
 			addstringtoinfstr(infstr, name->name->string);
 		}
 	}
