@@ -39,8 +39,8 @@
 
 #define MAXTEMP		10
 
-extern char		vhdl_delimiterstr[];
-extern char		vhdl_doubledelimiterstr[];
+extern CHAR		vhdl_delimiterstr[];
+extern CHAR		vhdl_doubledelimiterstr[];
 BOOLEAN			vhdl_err;
 PTREE			*vhdl_ptree = NULL;
 TOKENLIST		*vhdl_nexttoken;
@@ -104,7 +104,7 @@ tlist		*TOKENLIST	List of tokens.
 BOOLEAN vhdl_parser(TOKENLIST *tlist)
 {
 	INTBIG type;
-	char *pointer;
+	CHAR *pointer;
 	PTREE *newunit, *endunit;
 
 	/* start by clearing former parse information */
@@ -129,7 +129,7 @@ BOOLEAN vhdl_parser(TOKENLIST *tlist)
 					break;
 				case KEY_ENTITY:
 					type = UNIT_INTERFACE;
-					pointer = (char *)vhdl_parseinterface();
+					pointer = (CHAR *)vhdl_parseinterface();
 					break;
 #ifdef VHDL50
 				case KEY_ARCHITECTURAL:
@@ -137,21 +137,21 @@ BOOLEAN vhdl_parser(TOKENLIST *tlist)
 				case KEY_ARCHITECTURE:
 #endif
 					type = UNIT_BODY;
-					pointer = (char *)vhdl_parsebody((INTBIG)BODY_ARCHITECTURAL);
+					pointer = (CHAR *)vhdl_parsebody((INTBIG)BODY_ARCHITECTURAL);
 					break;
 				case KEY_PACKAGE:
 					type = UNIT_PACKAGE;
-					pointer = (char *)vhdl_parsepackage();
+					pointer = (CHAR *)vhdl_parsepackage();
 					break;
 #ifdef VHDL50
 				case KEY_WITH:
 					type = UNIT_WITH;
-					pointer = (char *)vhdl_parsewith();
+					pointer = (CHAR *)vhdl_parsewith();
 					break;
 #endif
 				case KEY_USE:
 					type = UNIT_USE;
-					pointer = (char *)vhdl_parseuse();
+					pointer = (CHAR *)vhdl_parseuse();
 					break;
 				default:
 					vhdl_reporterrormsg(vhdl_nexttoken, _("No entry keyword - entity, architectural, behavioral"));
@@ -182,10 +182,10 @@ BOOLEAN vhdl_parser(TOKENLIST *tlist)
 	return(vhdl_err);
 }
 
-void vhdl_reporterrormsg(TOKENLIST *tlist, char *err_msg)
+void vhdl_reporterrormsg(TOKENLIST *tlist, CHAR *err_msg)
 {
 	TOKENLIST *tstart;
-	char buffer[MAXVHDLLINE], stemp[MAXVHDLLINE], *sptr;
+	CHAR buffer[MAXVHDLLINE], stemp[MAXVHDLLINE], *sptr;
 	INTBIG pointer, i;
 
 	vhdl_err = TRUE;
@@ -211,57 +211,57 @@ void vhdl_reporterrormsg(TOKENLIST *tlist, char *err_msg)
 	for ( ; tstart != NOTOKENLIST && tstart->line_num == tlist->line_num;
 		tstart = tstart->next)
 	{
-		i = strlen(buffer);
+		i = estrlen(buffer);
 		if (i > MAXVHDLLINE/2) break;
 		if (tstart == tlist) pointer = i;
 		if (tstart->token < TOKEN_ARROW)
 		{
-			sprintf(stemp, "%c", vhdl_delimiterstr[tstart->token]);
-			strcat(buffer, stemp);
+			esnprintf(stemp, MAXVHDLLINE, x_("%c"), vhdl_delimiterstr[tstart->token]);
+			estrcat(buffer, stemp);
 		} else if (tstart->token < TOKEN_UNKNOWN)
 		{
 			sptr = &vhdl_doubledelimiterstr[2 * (tstart->token - TOKEN_ARROW)];
-			sprintf(stemp, "%c%c", sptr[0], sptr[1]);
-			strcat(buffer, stemp);
+			esnprintf(stemp, MAXVHDLLINE, x_("%c%c"), sptr[0], sptr[1]);
+			estrcat(buffer, stemp);
 		} else switch (tstart->token)
 		{
 			case TOKEN_STRING:
-				sprintf(stemp, "\"%s\" ", tstart->pointer);
-				strcat(buffer, stemp);
+				esnprintf(stemp, MAXVHDLLINE, x_("\"%s\" "), tstart->pointer);
+				estrcat(buffer, stemp);
 				break;
 			case TOKEN_KEYWORD:
-				sprintf(stemp, "%s", ((VKEYWORD *)(tstart->pointer))->name);
-				strcat(buffer, stemp);
+				esnprintf(stemp, MAXVHDLLINE, x_("%s"), ((VKEYWORD *)(tstart->pointer))->name);
+				estrcat(buffer, stemp);
 				break;
 			case TOKEN_IDENTIFIER:
-				sprintf(stemp, "%s",((IDENTTABLE *)(tstart->pointer))->string);
-				strcat(buffer, stemp);
+				esnprintf(stemp, MAXVHDLLINE, x_("%s"),((IDENTTABLE *)(tstart->pointer))->string);
+				estrcat(buffer, stemp);
 				break;
 			case TOKEN_CHAR:
-				sprintf(stemp, "%c", (char)((INTBIG)tstart->pointer));
-				strcat(buffer, stemp);
+				esnprintf(stemp, MAXVHDLLINE, x_("%c"), (CHAR)((INTBIG)tstart->pointer));
+				estrcat(buffer, stemp);
 			case TOKEN_DECIMAL:
-				sprintf(stemp, "%s", tstart->pointer);
-				strcat(buffer, stemp);
+				esnprintf(stemp, MAXVHDLLINE, x_("%s"), tstart->pointer);
+				estrcat(buffer, stemp);
 				break;
 			default:
 				if (tstart->pointer != 0)
 				{
-					sprintf(stemp, "%ld", (INTBIG)tstart->pointer);
-					strcat(buffer, stemp);
+					esnprintf(stemp, MAXVHDLLINE, x_("%ld"), (INTBIG)tstart->pointer);
+					estrcat(buffer, stemp);
 				}
 				break;
 		}
-		if (tstart->space) strcat(buffer, " ");
+		if (tstart->space) estrcat(buffer, x_(" "));
 	}
 
 	/* print out line */
-	ttyputmsg("%s", buffer);
+	ttyputmsg(x_("%s"), buffer);
 
 	/* print out pointer */
 	for (i = 0; i < pointer; i++) buffer[i] = ' ';
 	buffer[pointer] = 0;
-	ttyputmsg("%s^", buffer);
+	ttyputmsg(x_("%s^"), buffer);
 }
 
 /*
@@ -527,7 +527,7 @@ BODYDECLARE	*vhdl_parsebody_declare(void)
 {
 	BODYDECLARE *body, *endbody, *newbody;
 	INTBIG type;
-	char *pointer;
+	CHAR *pointer;
 
 	body = endbody = NULL;
 	while (!vhdl_keysame(vhdl_nexttoken, KEY_BEGIN))
@@ -536,7 +536,7 @@ BODYDECLARE	*vhdl_parsebody_declare(void)
 		if (vhdl_keysame(vhdl_nexttoken, KEY_COMPONENT))
 		{
 			type = BODYDECLARE_COMPONENT;
-			if ((pointer = (char *)vhdl_parsecomponent()) == (char *)PARSE_ERR)
+			if ((pointer = (CHAR *)vhdl_parsecomponent()) == (CHAR *)PARSE_ERR)
 			{
 				/* EMPTY */ 
 			}
@@ -559,7 +559,7 @@ BODYDECLARE	*vhdl_parsebody_declare(void)
 		else
 		{
 			type = BODYDECLARE_BASIC;
-			if ((pointer = (char *)vhdl_parsebasic_declare()) == (char *)PARSE_ERR)
+			if ((pointer = (CHAR *)vhdl_parsebasic_declare()) == (CHAR *)PARSE_ERR)
 			{
 				/* EMPTY */ 
 			}
@@ -706,14 +706,14 @@ BASICDECLARE  *vhdl_parsebasic_declare(void)
 {
 	BASICDECLARE *basic;
 	INTBIG type;
-	char *pointer;
+	CHAR *pointer;
 
 	basic = NULL;
 	type = NOBASICDECLARE;
 	if (vhdl_keysame(vhdl_nexttoken, KEY_TYPE))
 	{
 		type = BASICDECLARE_TYPE;
-		pointer = (char *)vhdl_parsetype();
+		pointer = (CHAR *)vhdl_parsetype();
 	}
 	else if (vhdl_keysame(vhdl_nexttoken, KEY_SUBTYPE))
 	{
@@ -730,7 +730,7 @@ BASICDECLARE  *vhdl_parsebasic_declare(void)
 	} else
 	{
 		type = BASICDECLARE_OBJECT;
-		pointer = (char *)vhdl_parseobject_declare();
+		pointer = (CHAR *)vhdl_parseobject_declare();
 	}
 	if (type != NOBASICDECLARE)
 	{
@@ -765,18 +765,18 @@ OBJECTDECLARE  *vhdl_parseobject_declare(void)
 {
 	OBJECTDECLARE *object;
 	INTBIG type;
-	char *pointer;
+	CHAR *pointer;
 
 	object = NULL;
 	type = NOOBJECTDECLARE;
 	if (vhdl_keysame(vhdl_nexttoken, KEY_CONSTANT))
 	{
 		type = OBJECTDECLARE_CONSTANT;
-		pointer = (char *)vhdl_parseconstant_declare();
+		pointer = (CHAR *)vhdl_parseconstant_declare();
 	} else if (vhdl_keysame(vhdl_nexttoken, KEY_SIGNAL))
 	{
 		type = OBJECTDECLARE_SIGNAL;
-		pointer = (char *)vhdl_parsesignal_declare();
+		pointer = (CHAR *)vhdl_parsesignal_declare();
 	} else if (vhdl_keysame(vhdl_nexttoken, KEY_VARIABLE))
 	{
 		/* EMPTY */ 
@@ -1038,7 +1038,7 @@ STATEMENTS	*vhdl_parseset_of_statements(void)
 {
 	STATEMENTS *statements, *endstate, *newstate;
 	INTBIG type;
-	char *pointer;
+	CHAR *pointer;
 	TOKENLIST *label;
 
 	statements = endstate = NULL;
@@ -1053,14 +1053,14 @@ STATEMENTS	*vhdl_parseset_of_statements(void)
 		{
 			/* could be architectural if or if generate scheme */
 			type = ARCHSTATE_GENERATE;
-			pointer = (char *)vhdl_parsegenerate(NULL, (INTBIG)GENSCHEME_IF);
+			pointer = (CHAR *)vhdl_parsegenerate(NULL, (INTBIG)GENSCHEME_IF);
 		}
 
 		/* check for generate statement */
 		else if (vhdl_keysame(vhdl_nexttoken, KEY_FOR))
 		{
 			type = ARCHSTATE_GENERATE;
-			pointer = (char *)vhdl_parsegenerate(NULL, (INTBIG)GENSCHEME_FOR);
+			pointer = (CHAR *)vhdl_parsegenerate(NULL, (INTBIG)GENSCHEME_FOR);
 		}
 
 		else
@@ -1096,19 +1096,19 @@ STATEMENTS	*vhdl_parseset_of_statements(void)
 			if (vhdl_keysame(vhdl_nexttoken, KEY_IF))
 			{
 				type = ARCHSTATE_GENERATE;
-				pointer = (char *)vhdl_parsegenerate(label, (INTBIG)GENSCHEME_IF);
+				pointer = (CHAR *)vhdl_parsegenerate(label, (INTBIG)GENSCHEME_IF);
 			}
 			else if (vhdl_keysame(vhdl_nexttoken, KEY_FOR))
 			{
 				type = ARCHSTATE_GENERATE;
-				pointer = (char *)vhdl_parsegenerate(label, (INTBIG)GENSCHEME_FOR);
+				pointer = (CHAR *)vhdl_parsegenerate(label, (INTBIG)GENSCHEME_FOR);
 			}
 			/* should be component_instantiation_declaration */
 			else
 			{
 				vhdl_nexttoken = label;
 				type = ARCHSTATE_INSTANCE;
-				pointer = (char *)vhdl_parseinstance();
+				pointer = (CHAR *)vhdl_parseinstance();
 			}
 		}
 
@@ -1119,7 +1119,7 @@ STATEMENTS	*vhdl_parseset_of_statements(void)
 			vhdl_nexttoken->next->token == TOKEN_LEFTBRACKET)
 		{
 			type = ARCHSTATE_INSTANCE;
-			pointer = (char *)vhdl_parseinstance();
+			pointer = (CHAR *)vhdl_parseinstance();
 		}
 #endif
 
@@ -1329,7 +1329,7 @@ DISCRETERANGE  *vhdl_parsediscrete_range(void)
 	drange = (DISCRETERANGE *)emalloc((INTBIG)sizeof(DISCRETERANGE), vhdl_tool->cluster);
 	/* currently only support ranege option */
 	drange->type = DISCRETERANGE_RANGE;
-	drange->pointer = (char *)vhdl_parserange();
+	drange->pointer = (CHAR *)vhdl_parserange();
 	return(drange);
 }
 
@@ -1359,7 +1359,7 @@ RANGE  *vhdl_parserange(void)
 	range = (RANGE *)emalloc((INTBIG)sizeof(RANGE), vhdl_tool->cluster);
 	/* currently support only simple expression range option */
 	range->type = RANGE_SIMPLE_EXPR;
-	range->pointer = (char *)vhdl_parserange_simple();
+	range->pointer = (CHAR *)vhdl_parserange_simple();
 	return(range);
 }
 
@@ -1680,11 +1680,11 @@ APORTLIST  *vhdl_parseactual_port_list(void)
 		} else
 #endif
 		{
-			aplist->pointer = (char *)vhdl_parsename();
+			aplist->pointer = (CHAR *)vhdl_parsename();
 			if (vhdl_nexttoken->token == TOKEN_ARROW)
 			{
 				vhdl_getnexttoken();
-				aplist->pointer = (char *)vhdl_parsename();
+				aplist->pointer = (CHAR *)vhdl_parsename();
 			}
 		}
 
@@ -1716,11 +1716,11 @@ APORTLIST  *vhdl_parseactual_port_list(void)
 			} else
 #endif
 			{
-				newport->pointer = (char *)vhdl_parsename();
+				newport->pointer = (CHAR *)vhdl_parsename();
 				if (vhdl_nexttoken->token == TOKEN_ARROW)
 				{
 					vhdl_getnexttoken();
-					newport->pointer = (char *)vhdl_parsename();
+					newport->pointer = (CHAR *)vhdl_parsename();
 				}
 			}
 		}
@@ -2166,11 +2166,11 @@ void vhdl_freeparsermemory(void)
 			case UNIT_INTERFACE:
 				interfacef = (VINTERFACE *)par->pointer;
 				vhdl_freeports(interfacef->ports);
-				efree((char *)interfacef);
+				efree((CHAR *)interfacef);
 				break;
 			case UNIT_BODY:
 				body = (BODY *)par->pointer;
-				if (body->entity != NULL) efree((char *)body->entity);
+				if (body->entity != NULL) efree((CHAR *)body->entity);
 				for(bodydec = body->body_declare; bodydec != NULL; bodydec = nextbodydec)
 				{
 					nextbodydec = bodydec->next;
@@ -2179,16 +2179,16 @@ void vhdl_freeparsermemory(void)
 						case BODYDECLARE_COMPONENT:
 							compo = (VCOMPONENT *)bodydec->pointer;
 							vhdl_freeports(compo->ports);
-							efree((char *)compo);
+							efree((CHAR *)compo);
 							break;
 						case BODYDECLARE_BASIC:
 							vhdl_freebasicdeclare((BASICDECLARE *)bodydec->pointer);
 							break;
 					}
-					efree((char *)bodydec);
+					efree((CHAR *)bodydec);
 				}
 				vhdl_freesetofstatements(body->statements);
-				efree((char *)body);
+				efree((CHAR *)body);
 				break;
 			case UNIT_PACKAGE:
 				package = (PACKAGE *)par->pointer;
@@ -2198,16 +2198,16 @@ void vhdl_freeparsermemory(void)
 				{
 					nextdpart = dpart->next;
 					vhdl_freebasicdeclare((BASICDECLARE *)dpart->item);
-					efree((char *)dpart);
+					efree((CHAR *)dpart);
 				}
-				efree((char *)package);
+				efree((CHAR *)package);
 				break;
 #ifdef VHDL50
 			case UNIT_WITH:
 				for(with = (WITH *)par->pointer; with != NULL; with = nextwith)
 				{
 					nextwith = with->next;
-					efree((char *)with);
+					efree((CHAR *)with);
 				}
 				break;
 #endif
@@ -2215,11 +2215,11 @@ void vhdl_freeparsermemory(void)
 				for(use = (USE *)par->pointer; use != NULL; use = nextuse)
 				{
 					nextuse = use->next;
-					efree((char *)use);
+					efree((CHAR *)use);
 				}
 				break;
 		}
-		efree((char *)par);
+		efree((CHAR *)par);
 	}
 	vhdl_ptree = NULL;
 }
@@ -2234,7 +2234,7 @@ void vhdl_freeports(FPORTLIST *ports)
 		nextports = ports->next;
 		vhdl_freeidentlist(ports->names);
 		vhdl_freename(ports->type);
-		efree((char *)ports);
+		efree((CHAR *)ports);
 	}
 }
 
@@ -2246,7 +2246,7 @@ void vhdl_freeidentlist(IDENTLIST *ilist)
 	for(; ilist != NULL; ilist = nextilist)
 	{
 		nextilist = ilist->next;
-		efree((char *)ilist);
+		efree((CHAR *)ilist);
 	}
 }
 
@@ -2260,9 +2260,9 @@ void vhdl_freesimpleexpr(SIMPLEEXPR *sexpr)
 	{
 		nextmore = more->next;
 		vhdl_freeterm(more->term);
-		efree((char *)more);
+		efree((CHAR *)more);
 	}
-	efree((char *)sexpr);
+	efree((CHAR *)sexpr);
 }
 
 /* free structure created by vhdl_parseterm() */
@@ -2275,9 +2275,9 @@ void vhdl_freeterm(TERM *term)
 	{
 		nextmore = more->next;
 		vhdl_freefactor(more->factor);
-		efree((char *)more);
+		efree((CHAR *)more);
 	}
-	efree((char *)term);
+	efree((CHAR *)term);
 }
 
 /* free structure created by vhdl_parsefactor() */
@@ -2286,7 +2286,7 @@ void vhdl_freefactor(FACTOR *factor)
 	vhdl_freeprimary(factor->primary);
 	if (factor->misc_operator == MISCOP_POWER)
 		vhdl_freeprimary(factor->primary2);
-	efree((char *)factor);
+	efree((CHAR *)factor);
 }
 
 /* free structure created by vhdl_parseprimary() */
@@ -2296,7 +2296,7 @@ void vhdl_freeprimary(PRIMARY *primary)
 	switch (primary->type)
 	{
 		case PRIMARY_LITERAL:
-			if (primary->pointer != 0) efree((char *)primary->pointer);
+			if (primary->pointer != 0) efree((CHAR *)primary->pointer);
 			break;
 		case PRIMARY_NAME:
 			vhdl_freename((VNAME *)primary->pointer);
@@ -2305,7 +2305,7 @@ void vhdl_freeprimary(PRIMARY *primary)
 			vhdl_freeexpression((EXPRESSION *)primary->pointer);
 			break;
 	}
-	efree((char *)primary);
+	efree((CHAR *)primary);
 }
 
 /* free structure created by "vhdl_parsename()" */
@@ -2320,10 +2320,10 @@ void vhdl_freename(VNAME *name)
 		{
 			nextconcat = concat->next;
 			vhdl_freesinglename(concat->name);
-			efree((char *)concat);
+			efree((CHAR *)concat);
 		}
 	} else vhdl_freesinglename((SINGLENAME *)name->pointer);
-	efree((char *)name);
+	efree((CHAR *)name);
 }
 
 /* free structure created by "vhdl_parsesinglename()" */
@@ -2341,15 +2341,15 @@ void vhdl_freesinglename(SINGLENAME *sname)
 		prefix = in->prefix;
 		nptr = (VNAME *)prefix->pointer;
 		sname2 = (SINGLENAME *)nptr->pointer;
-		if (sname2->pointer != 0) efree((char *)sname2->pointer);
-		efree((char *)sname2);
-		efree((char *)nptr);
+		if (sname2->pointer != 0) efree((CHAR *)sname2->pointer);
+		efree((CHAR *)sname2);
+		efree((CHAR *)nptr);
 		vhdl_freeindexedname(in);
 	} else
 	{
-		if (sname->pointer != 0) efree((char *)sname->pointer);
+		if (sname->pointer != 0) efree((CHAR *)sname->pointer);
 	}
-	efree((char *)sname);
+	efree((CHAR *)sname);
 }
 
 /* free structure created by "vhdl_parseindexedname()" */
@@ -2357,21 +2357,21 @@ void vhdl_freeindexedname(INDEXEDNAME *ind)
 {
 	EXPRLIST *elist, *nextelist;
 
-	efree((char *)ind->prefix);
+	efree((CHAR *)ind->prefix);
 	for(elist = ind->expr_list; elist != NULL; elist = nextelist)
 	{
 		nextelist = elist->next;
 		vhdl_freeexpression(elist->expression);
-		efree((char *)elist);
+		efree((CHAR *)elist);
 	}
-	efree((char *)ind);
+	efree((CHAR *)ind);
 }
 
 /* free structure created by "vhdl_parsesubtype_indication()" */
 void vhdl_freesubtypeind(SUBTYPEIND *subtypeind)
 {
 	vhdl_freename(subtypeind->type);
-	efree((char *)subtypeind);
+	efree((CHAR *)subtypeind);
 }
 
 /* free the structure created by "vhdl_parseexpression()" */
@@ -2384,9 +2384,9 @@ void vhdl_freeexpression(EXPRESSION *exp)
 	{
 		nextmore = more->next;
 		vhdl_freerelation(more->relation);
-		efree((char *)more);
+		efree((CHAR *)more);
 	}
-	efree((char *)exp);
+	efree((CHAR *)exp);
 }
 
 /* free the structure created by "vhdl_parserelation()" */
@@ -2394,7 +2394,7 @@ void vhdl_freerelation(RELATION *rel)
 {
 	vhdl_freesimpleexpr(rel->simple_expr);
 	if (rel->simple_expr2 != 0) vhdl_freesimpleexpr(rel->simple_expr2);
-	efree((char *)rel);
+	efree((CHAR *)rel);
 }
 
 /* free the structure created by "vhdl_parsebasic_declare()" */
@@ -2438,22 +2438,22 @@ void vhdl_freebasicdeclare(BASICDECLARE *basic)
 								srange = (RANGESIMPLE *)range->pointer;
 								vhdl_freesimpleexpr(srange->start);
 								vhdl_freesimpleexpr(srange->end);
-								efree((char *)srange);
-								efree((char *)range);
-								efree((char *)drange);
-								efree((char *)icon);
+								efree((CHAR *)srange);
+								efree((CHAR *)range);
+								efree((CHAR *)drange);
+								efree((CHAR *)icon);
 							}
 							subtypeind = (SUBTYPEIND *)constr->subtype;
 							vhdl_freename(subtypeind->type);
-							efree((char *)subtypeind);
-							efree((char *)array->pointer);
-							efree((char *)array);
+							efree((CHAR *)subtypeind);
+							efree((CHAR *)array->pointer);
+							efree((CHAR *)array);
 						}
 					}
-					efree((char *)compos);
+					efree((CHAR *)compos);
 				}
 			}
-			efree((char *)type);
+			efree((CHAR *)type);
 		}
 	} else if (basic->type == BASICDECLARE_OBJECT)
 	{
@@ -2466,19 +2466,19 @@ void vhdl_freebasicdeclare(BASICDECLARE *basic)
 					constant = (CONSTANTDECLARE *)objdec->pointer;
 					vhdl_freesubtypeind(constant->subtype);
 					vhdl_freeexpression(constant->expression);
-					efree((char *)constant);
+					efree((CHAR *)constant);
 					break;
 				case OBJECTDECLARE_SIGNAL:
 					sigdecl = (SIGNALDECLARE *)objdec->pointer;
 					vhdl_freesubtypeind(sigdecl->subtype);
 					vhdl_freeidentlist(sigdecl->names);
-					efree((char *)sigdecl);
+					efree((CHAR *)sigdecl);
 					break;
 			}
-			efree((char *)objdec);
+			efree((CHAR *)objdec);
 		}
 	}
-	efree((char *)basic);
+	efree((CHAR *)basic);
 }
 
 /* free structure created by vhdl_parseset_of_statements() */
@@ -2508,31 +2508,31 @@ void vhdl_freesetofstatements(STATEMENTS *statements)
 					srange = (RANGESIMPLE *)range->pointer;
 					vhdl_freesimpleexpr(srange->start);
 					vhdl_freesimpleexpr(srange->end);
-					efree((char *)srange);
-					efree((char *)range);
-					efree((char *)drange);
+					efree((CHAR *)srange);
+					efree((CHAR *)range);
+					efree((CHAR *)drange);
 				} else
 				{
 					vhdl_freeexpression(scheme->condition);
 				}
 				vhdl_freesetofstatements(gen->statements);
-				efree((char *)scheme);
-				efree((char *)gen);
+				efree((CHAR *)scheme);
+				efree((CHAR *)gen);
 				break;
 			case ARCHSTATE_INSTANCE:
 				inst = (VINSTANCE *)statements->pointer;
 				if (inst == NULL) break;
-				if (inst->entity != NULL) efree((char *)inst->entity);
+				if (inst->entity != NULL) efree((CHAR *)inst->entity);
 				for(aplist = inst->ports; aplist != NULL; aplist = nextaplist)
 				{
 					nextaplist = aplist->next;
 					if (aplist->pointer != NULL) vhdl_freename((VNAME *)aplist->pointer);
-					efree((char *)aplist);
+					efree((CHAR *)aplist);
 				}
-				efree((char *)inst);
+				efree((CHAR *)inst);
 				break;
 		}
-		efree((char *)statements);
+		efree((CHAR *)statements);
 	}
 }
 
