@@ -63,8 +63,8 @@ typedef struct Iqnode
 
 typedef struct Iqport
 {
-	char			*instname;	/* name of instance */
-	char			*portname;	/* name of port */
+	CHAR			*instname;	/* name of instance */
+	CHAR			*portname;	/* name of port */
 	BOOLEAN          namealloc;	/* true if port name is allocated */
 	struct Iqport	*next;		/* next in port list */
 } QPORT;
@@ -76,7 +76,7 @@ static void vhdl_genquisc_interface(DBINTERFACE*);
 static INTBIG vhdl_querysize(DBNAME*);
 static void vhdl_addidentaport(DBNAME*, DBPORTLIST*, INTBIG, DBINSTANCE*, QNODE**);
 static void vhdl_addindexedaport(DBNAME*, DBPORTLIST*, INTBIG, DBINSTANCE*, QNODE**);
-static QPORT *vhdl_createqport(char*, DBPORTLIST*, INTBIG);
+static QPORT *vhdl_createqport(CHAR*, DBPORTLIST*, INTBIG);
 static void vhdl_addporttonode(QPORT*, IDENTTABLE*, INTBIG, INTBIG, QNODE**);
 
 /*
@@ -91,7 +91,7 @@ Calling Sequence:  vhdl_genquisc();
 */
 void vhdl_genquisc(void)
 {
-	char *pn, *key;
+	CHAR *pn, *key;
 	INTBIG total;
 	REGISTER LIBRARY *celllib;
 	REGISTER CELL *cell;
@@ -100,17 +100,17 @@ void vhdl_genquisc(void)
 	REGISTER void *infstr;
 
 	vhdl_freeunresolvedlist(&vhdl_unresolved_list);
-	vhdl_ident_ground = vhdl_findidentkey("ground");
-	vhdl_ident_power = vhdl_findidentkey("power");
+	vhdl_ident_ground = vhdl_findidentkey(x_("ground"));
+	vhdl_ident_power = vhdl_findidentkey(x_("power"));
 
 	/* print file header */
-	vhdl_printoneline("!*************************************************");
-	vhdl_printoneline("!  QUISC Command file");
-	vhdl_printoneline("!");
+	vhdl_printoneline(x_("!*************************************************"));
+	vhdl_printoneline(x_("!  QUISC Command file"));
+	vhdl_printoneline(x_("!"));
 	if ((us_useroptions&NODATEORVERSION) == 0)
-		vhdl_printoneline("!  File Creation:    %s", timetostring(getcurrenttime()));
-	vhdl_printoneline("!-------------------------------------------------");
-	vhdl_print("");
+		vhdl_printoneline(x_("!  File Creation:    %s"), timetostring(getcurrenttime()));
+	vhdl_printoneline(x_("!-------------------------------------------------"));
+	vhdl_print(x_(""));
 
 	/* determine top level cell */
 	top_interface = vhdl_findtopinterface(vhdl_units);
@@ -124,10 +124,10 @@ void vhdl_genquisc(void)
 	}
 
 	/* print closing line of output file */
-	vhdl_printoneline("!********* End of command file *******************");
+	vhdl_printoneline(x_("!********* End of command file *******************"));
 
 	/* scan unresolved references for reality inside of Electric */
-	celllib = (LIBRARY *)asktool(sc_tool, "cell-lib");
+	celllib = (LIBRARY *)asktool(sc_tool, x_("cell-lib"));
 	if (celllib == 0) celllib = NOLIBRARY;
 	total = 0;
 	for (ulist = vhdl_unresolved_list; ulist != NULL; ulist = ulist->next)
@@ -200,7 +200,7 @@ void vhdl_genquisc_interface(DBINTERFACE *interfacef)
 	DBINDEXRANGE *irange;
 	DBDISCRETERANGE *drange;
 	DBNAMELIST *cat;
-	char buff[256], *inout;
+	CHAR buff[256], *inout;
 
 	/* go through interface's architectural body and call generate interface */
 	/* for any interface called by an instance which has not been already */
@@ -235,13 +235,13 @@ void vhdl_genquisc_interface(DBINTERFACE *interfacef)
 	}
 
 	/* write this entity */
-	vhdl_print("create cell %s", (INTBIG)interfacef->name->string);
+	vhdl_print(x_("create cell %s"), (INTBIG)interfacef->name->string);
 
 	/* write out instances as components */
 	if (interfacef->bodies && interfacef->bodies->statements)
 	{
 		for (inst = interfacef->bodies->statements->instances; inst != NULL; inst = inst->next)
-			vhdl_print("create instance %s %s", (INTBIG)inst->name->string,
+			vhdl_print(x_("create instance %s %s"), (INTBIG)inst->name->string,
 				(INTBIG)inst->compo->name->string);
 	}
 
@@ -432,17 +432,17 @@ void vhdl_genquisc_interface(DBINTERFACE *interfacef)
 			{
 				for (qport2 = qport->next; qport2; qport2 = qport2->next)
 				{
-					vhdl_print("connect %s %s %s %s", (INTBIG)qport->instname,
+					vhdl_print(x_("connect %s %s %s %s"), (INTBIG)qport->instname,
 						(INTBIG)qport->portname, (INTBIG)qport2->instname,(INTBIG)qport2->portname);
 				}
 				if (newnode->flags & QNODE_POWER)
 				{
-					vhdl_print("connect %s %s power", (INTBIG)qport->instname,
+					vhdl_print(x_("connect %s %s power"), (INTBIG)qport->instname,
 						(INTBIG)qport->portname);
 				}
 				if (newnode->flags & QNODE_GROUND)
 				{
-					vhdl_print("connect %s %s ground", (INTBIG)qport->instname,
+					vhdl_print(x_("connect %s %s ground"), (INTBIG)qport->instname,
 						(INTBIG)qport->portname);
 				}
 			}
@@ -455,7 +455,7 @@ void vhdl_genquisc_interface(DBINTERFACE *interfacef)
 				{
 					for (qport2 = qport->next; qport2; qport2 = qport2->next)
 					{
-						vhdl_print("connect %s %s %s %s", (INTBIG)qport->instname,
+						vhdl_print(x_("connect %s %s %s %s"), (INTBIG)qport->instname,
 							(INTBIG)qport->portname, (INTBIG)qport2->instname,
 								(INTBIG)qport2->portname);
 					}
@@ -476,15 +476,15 @@ void vhdl_genquisc_interface(DBINTERFACE *interfacef)
 				{
 					switch (newnode->mode)
 					{
-						case DBMODE_IN:  inout = " input";    break;
-						case DBMODE_OUT: inout = " output";   break;
-						default:         inout = "";          break;
+						case DBMODE_IN:  inout = x_(" input");    break;
+						case DBMODE_OUT: inout = x_(" output");   break;
+						default:         inout = x_("");          break;
 					}
-					vhdl_print("export %s %s %s%s", (INTBIG)qport->instname,
+					vhdl_print(x_("export %s %s %s%s"), (INTBIG)qport->instname,
 						(INTBIG)qport->portname, (INTBIG)newnode->name->string, inout);
 				} else
 				{
-					sprintf(buff, "%s", newnode->name->string);
+					esnprintf(buff, 256, x_("%s"), newnode->name->string);
 					ttyputmsg(_("ERROR - no export for %s"), buff);
 				}
 			} else
@@ -503,16 +503,16 @@ void vhdl_genquisc_interface(DBINTERFACE *interfacef)
 					{
 						switch (newnode->mode)
 						{
-							case DBMODE_IN:  inout = " input";    break;
-							case DBMODE_OUT: inout = " output";   break;
-							default:         inout = "";          break;
+							case DBMODE_IN:  inout = x_(" input");    break;
+							case DBMODE_OUT: inout = x_(" output");   break;
+							default:         inout = x_("");          break;
 						}
-						vhdl_print("export %s %s %s[%ld]%s", (INTBIG)qport->instname,
+						vhdl_print(x_("export %s %s %s[%ld]%s"), (INTBIG)qport->instname,
 							(INTBIG)qport->portname, (INTBIG)newnode->name->string,
 								(INTBIG)indexc, inout);
 					} else
 					{
-						sprintf(buff, "%s[%ld]", newnode->name->string, (INTBIG)indexc);
+						esnprintf(buff, 256, x_("%s[%ld]"), newnode->name->string, (INTBIG)indexc);
 						ttyputmsg(_("ERROR - no export for %s"), buff);
 					}
 				}
@@ -521,7 +521,7 @@ void vhdl_genquisc_interface(DBINTERFACE *interfacef)
 	}
 
 	/* extract entity */
-	vhdl_print("extract");
+	vhdl_print(x_("extract"));
 
 	/* print out non-exported node name assignments */
 	for (newnode = qnodes; newnode; newnode = newnode->next)
@@ -533,7 +533,7 @@ void vhdl_genquisc_interface(DBINTERFACE *interfacef)
 				qport = newnode->ports;
 				if (qport)
 				{
-					vhdl_print("set node-name %s %s %s", (INTBIG)qport->instname,
+					vhdl_print(x_("set node-name %s %s %s"), (INTBIG)qport->instname,
 						(INTBIG)qport->portname, (INTBIG)newnode->name->string);
 				}
 			} else
@@ -550,7 +550,7 @@ void vhdl_genquisc_interface(DBINTERFACE *interfacef)
 					qport = newnode->table[i];
 					if (qport)
 					{
-						vhdl_print("set node-name %s %s %s[%ld]",
+						vhdl_print(x_("set node-name %s %s %s[%ld]"),
 							(INTBIG)qport->instname, (INTBIG)qport->portname,
 								(INTBIG)newnode->name->string, (INTBIG)indexc);
 					}
@@ -559,7 +559,7 @@ void vhdl_genquisc_interface(DBINTERFACE *interfacef)
 		}
 	}
 
-	vhdl_print("");
+	vhdl_print(x_(""));
 
 
 	/* deallocate QNODEs */
@@ -573,19 +573,19 @@ void vhdl_genquisc_interface(DBINTERFACE *interfacef)
 			{
 				qport = lastnode->table[i];
 				lastnode->table[i] = qport->next;
-				if (qport->namealloc) efree((char *)qport->portname);
-				efree((char *)qport);
+				if (qport->namealloc) efree((CHAR *)qport->portname);
+				efree((CHAR *)qport);
 			}
 		}
-		if (lastnode->size > 0) efree((char *)lastnode->table);
+		if (lastnode->size > 0) efree((CHAR *)lastnode->table);
 		while (lastnode->ports != 0)
 		{
 			qport = lastnode->ports;
 			lastnode->ports = qport->next;
-			if (qport->namealloc) efree((char *)qport->portname);
-			efree((char *)qport);
+			if (qport->namealloc) efree((CHAR *)qport->portname);
+			efree((CHAR *)qport);
 		}
-		efree((char *)lastnode);
+		efree((CHAR *)lastnode);
 	}
 }
 
@@ -763,17 +763,17 @@ offset		INTBIG		Offset if array.
 qport		*QPORT		Address of created QPORT.
 ------------------------------------------------------------------------
 */
-QPORT *vhdl_createqport(char *iname, DBPORTLIST *port, INTBIG offset)
+QPORT *vhdl_createqport(CHAR *iname, DBPORTLIST *port, INTBIG offset)
 {
 	QPORT *newport;
-	char buff[80];
+	CHAR buff[80];
 
 	newport = (QPORT *)emalloc(sizeof(QPORT), vhdl_tool->cluster);
 	newport->instname = iname;
 	newport->next = NULL;
 	if (port->type && port->type->type == DBTYPE_ARRAY)
 	{
-		sprintf(buff, "%s[%ld]", port->name->string, (INTBIG)offset);
+		esnprintf(buff, 80, x_("%s[%ld]"), port->name->string, (INTBIG)offset);
 		(void)allocstring(&(newport->portname), buff, vhdl_tool->cluster);
 		newport->namealloc = TRUE;
 	} else
