@@ -43,7 +43,7 @@ extern TOKENLIST *vhdl_nexttoken;
 SYMBOLLIST		*vhdl_symbols = 0, *vhdl_gsymbols = 0;
 SYMBOLLIST      *vhdl_symbollists = 0;
 DBUNITS			*vhdl_units = 0;
-static char		vhdl_default_name[80];
+static CHAR		vhdl_default_name[80];
 #ifdef VHDL50
   static INTBIG	vhdl_default_num;
 #else
@@ -72,15 +72,15 @@ static DBSTATEMENTS    *vhdl_semgenerate(GENERATE*);
 static void             vhdl_semuse(USE*);
 static SYMBOLTREE      *vhdl_searchfsymbol(IDENTTABLE*, SYMBOLLIST*);
 static SYMBOLTREE      *vhdl_searchsymboltree(IDENTTABLE*, SYMBOLTREE*);
-static SYMBOLTREE      *vhdl_addsymbol(IDENTTABLE*, INTBIG, char*, SYMBOLLIST*);
-static SYMBOLTREE      *vhdl_addsymboltree(IDENTTABLE*, INTBIG, char*, SYMBOLTREE*);
+static SYMBOLTREE      *vhdl_addsymbol(IDENTTABLE*, INTBIG, CHAR*, SYMBOLLIST*);
+static SYMBOLTREE      *vhdl_addsymboltree(IDENTTABLE*, INTBIG, CHAR*, SYMBOLTREE*);
 static SYMBOLLIST      *vhdl_pushsymbols(SYMBOLLIST*);
 static SYMBOLLIST      *vhdl_popsymbols(SYMBOLLIST*);
 static void             vhdl_semaport_check(VNAME*);
 static void             vhdl_semaport_check_single_name(SINGLENAME*);
-static char            *vhdl_parsescalar_type(void);
+static CHAR            *vhdl_parsescalar_type(void);
 static COMPOSITE       *vhdl_parsecomposite_type(void);
-static char            *vhdl_parserecord_type(void);
+static CHAR            *vhdl_parserecord_type(void);
 static ARRAY           *vhdl_parsearray_type(void);
 static void             vhdl_semtype_declare(TYPE*);
 static DBLTYPE         *vhdl_semcomposite_type(COMPOSITE*);
@@ -118,9 +118,9 @@ void vhdl_freesemantic(void)
 		{
 			port = intf->ports;
 			intf->ports = intf->ports->next;
-			efree((char *)port);
+			efree((CHAR *)port);
 		}
-		efree((char *)intf);
+		efree((CHAR *)intf);
 	}
 	while (vhdl_units->bodies != 0)
 	{
@@ -137,17 +137,17 @@ void vhdl_freesemantic(void)
 				{
 					port = comp->ports;
 					comp->ports = comp->ports->next;
-					efree((char *)port);
+					efree((CHAR *)port);
 				}
-				efree((char *)comp);
+				efree((CHAR *)comp);
 			}
 			while (bodydecl->bodysignals != 0)
 			{
 				signals = bodydecl->bodysignals;
 				bodydecl->bodysignals = bodydecl->bodysignals->next;
-				efree((char *)signals);
+				efree((CHAR *)signals);
 			}
-			efree((char *)bodydecl);
+			efree((CHAR *)bodydecl);
 
 			if (body->statements != 0)
 			{
@@ -165,21 +165,21 @@ void vhdl_freesemantic(void)
 							while (aport->name->pointer != 0)
 							{
 								expr = (DBEXPRLIST *)aport->name->pointer;
-								aport->name->pointer = (char *)expr->next;
-								efree((char *)expr);
+								aport->name->pointer = (CHAR *)expr->next;
+								efree((CHAR *)expr);
 							}
-							efree((char *)aport->name);
+							efree((CHAR *)aport->name);
 						}
-						efree((char *)aport);
+						efree((CHAR *)aport);
 					}
-					efree((char *)inst);
+					efree((CHAR *)inst);
 				}
-				efree((char *)state);
+				efree((CHAR *)state);
 			}
 		}
-		efree((char *)body);
+		efree((CHAR *)body);
 	}
-	efree((char *)vhdl_units);
+	efree((CHAR *)vhdl_units);
 	vhdl_units = 0;
 
 	for(sym = vhdl_symbollists; sym != 0; sym = sym->next)
@@ -192,7 +192,7 @@ void vhdl_freesemantic(void)
 		{
 			if (lastsym == 0) vhdl_symbollists = sym->next; else
 				lastsym->next = sym->next;
-			efree((char *)sym);
+			efree((CHAR *)sym);
 			continue;
 		}
 		lastsym = sym;
@@ -209,7 +209,7 @@ void vhdl_freesemantic(void)
 			vhdl_freesymboltree(sym->root);
 			sym->root = 0;
 		}
-		efree((char *)sym);
+		efree((CHAR *)sym);
 	}
 	vhdl_gsymbols = vhdl_symbols = 0;
 }
@@ -225,24 +225,24 @@ void vhdl_freesymboltree(SYMBOLTREE *tree)
 		{
 			case SYMBOL_PACKAGE:
 				if (vhdl_freeinggsymbols != 0)
-					efree((char *)tree->pointer);
+					efree((CHAR *)tree->pointer);
 				break;
 			case SYMBOL_TYPE:
 				dbtype = (DBLTYPE *)tree->pointer;
 				while (dbtype->pointer != 0)
 				{
 					range = (DBINDEXRANGE *)dbtype->pointer;
-					dbtype->pointer = (char *)range->next;
-					if (range->drange != 0) efree((char *)range->drange);
-					efree((char *)range);
+					dbtype->pointer = (CHAR *)range->next;
+					if (range->drange != 0) efree((CHAR *)range->drange);
+					efree((CHAR *)range);
 				}
-				efree((char *)dbtype);
+				efree((CHAR *)dbtype);
 				break;
 		}
 	}
 	if (tree->lptr != 0) vhdl_freesymboltree(tree->lptr);
 	if (tree->rptr != 0) vhdl_freesymboltree(tree->rptr);
-	efree((char *)tree);
+	efree((CHAR *)tree);
 }
 
 /*
@@ -263,7 +263,7 @@ BOOLEAN vhdl_semantic(void)
 	SYMBOLLIST *ssymbols;
 
 	vhdl_err = FALSE;
-	strcpy(vhdl_default_name, "default");
+	estrcpy(vhdl_default_name, x_("default"));
 #ifdef VHDL50
 	vhdl_default_num = 0;
 #endif
@@ -349,27 +349,25 @@ symbols		*SYMBOLLIST	Pointer to current symbol list.
 void vhdl_createdefaulttype(SYMBOLLIST *symbols)
 {
 	IDENTTABLE *ikey;
-	char *bitname;
+	CHAR *bitname;
 
 	/* type BIT */
-	bitname = (char *)emalloc(4, vhdl_tool->cluster);
-	(void)strcpy(bitname, "BIT");
+	allocstring(&bitname, x_("BIT"), vhdl_tool->cluster);
 	if ((ikey = vhdl_findidentkey(bitname)) == 0)
 	{
 		ikey = vhdl_makeidentkey(bitname);
 		if (ikey == 0) return;
 	} else efree(bitname);
-	vhdl_addsymbol(ikey, (INTBIG)SYMBOL_TYPE, (char *)0, symbols);
+	vhdl_addsymbol(ikey, (INTBIG)SYMBOL_TYPE, (CHAR *)0, symbols);
 
 	/* type "std_logic" */
-	bitname = (char *)emalloc(10, vhdl_tool->cluster);
-	(void)strcpy(bitname, "std_logic");
+	allocstring(&bitname, x_("std_logic"), vhdl_tool->cluster);
 	if ((ikey = vhdl_findidentkey(bitname)) == 0)
 	{
 		ikey = vhdl_makeidentkey(bitname);
 		if (ikey == 0) return;
 	} else efree(bitname);
-	vhdl_addsymbol(ikey, (INTBIG)SYMBOL_TYPE, (char *)0, symbols);
+	vhdl_addsymbol(ikey, (INTBIG)SYMBOL_TYPE, (CHAR *)0, symbols);
 }
 
 /*
@@ -402,7 +400,7 @@ void vhdl_sempackage(PACKAGE *package)
 		dbpackage = (DBPACKAGE *)emalloc((INTBIG)sizeof(DBPACKAGE), vhdl_tool->cluster);
 		dbpackage->name = (IDENTTABLE *)package->name->pointer;
 		dbpackage->root = 0;
-		vhdl_addsymbol(dbpackage->name, (INTBIG)SYMBOL_PACKAGE, (char *)dbpackage, vhdl_gsymbols);
+		vhdl_addsymbol(dbpackage->name, (INTBIG)SYMBOL_PACKAGE, (CHAR *)dbpackage, vhdl_gsymbols);
 	}
 
 	/* check package parts */
@@ -451,7 +449,7 @@ DBINTERFACE  *vhdl_seminterface(VINTERFACE *interfacef)
 		dbinter->bodies = 0;
 		dbinter->symbols = 0;
 		dbinter->next = 0;
-		vhdl_addsymbol(dbinter->name, (INTBIG)SYMBOL_ENTITY, (char *)dbinter, vhdl_gsymbols);
+		vhdl_addsymbol(dbinter->name, (INTBIG)SYMBOL_ENTITY, (CHAR *)dbinter, vhdl_gsymbols);
 		vhdl_symbols = vhdl_pushsymbols(vhdl_symbols);
 		dbinter->ports = vhdl_semformal_port_list(interfacef->ports);
 
@@ -505,7 +503,7 @@ DBBODY *vhdl_sembody(BODY *body)
 	dbbody->parent = 0;
 	dbbody->same_parent = 0;
 	dbbody->next = 0;
-	vhdl_addsymbol(dbbody->name, (INTBIG)SYMBOL_BODY, (char *)dbbody, vhdl_gsymbols);
+	vhdl_addsymbol(dbbody->name, (INTBIG)SYMBOL_BODY, (CHAR *)dbbody, vhdl_gsymbols);
 
 	/* check if interface declared */
 	if ((symbol = vhdl_searchsymbol((IDENTTABLE *)body->entity->identifier->pointer,
@@ -629,7 +627,7 @@ DBPORTLIST *vhdl_semformal_port_list(FPORTLIST *port)
 					endport->next = newport;
 					endport = newport;
 				}
-				vhdl_addsymbol(newport->name, (INTBIG)SYMBOL_FPORT, (char *)newport, vhdl_symbols);
+				vhdl_addsymbol(newport->name, (INTBIG)SYMBOL_FPORT, (CHAR *)newport, vhdl_symbols);
 			}
 		}
 	}
@@ -738,7 +736,7 @@ DBCOMPONENTS *vhdl_semcomponent(VCOMPONENT *compo)
 	dbcomp->name = (IDENTTABLE *)compo->name->pointer;
 	dbcomp->ports = 0;
 	dbcomp->next = 0;
-	vhdl_addsymbol(dbcomp->name, (INTBIG)SYMBOL_COMPONENT, (char *)dbcomp, vhdl_symbols);
+	vhdl_addsymbol(dbcomp->name, (INTBIG)SYMBOL_COMPONENT, (CHAR *)dbcomp, vhdl_symbols);
 	vhdl_symbols = vhdl_pushsymbols(vhdl_symbols);
 	dbcomp->ports = vhdl_semformal_port_list(compo->ports);
 	vhdl_symbols = vhdl_popsymbols(vhdl_symbols);
@@ -869,7 +867,7 @@ DBSIGNALS *vhdl_semsignal_declare(SIGNALDECLARE *signal)
 			}
 			newsignal->next = signals;
 			signals = newsignal;
-			vhdl_addsymbol(newsignal->name, (INTBIG)SYMBOL_SIGNAL, (char *)newsignal, vhdl_symbols);
+			vhdl_addsymbol(newsignal->name, (INTBIG)SYMBOL_SIGNAL, (CHAR *)newsignal, vhdl_symbols);
 		}
 	}
 
@@ -903,7 +901,7 @@ void vhdl_semconstant_declare(CONSTANTDECLARE *constant)
 	{
 		value = vhdl_evalexpression(constant->expression);
 		vhdl_addsymbol((IDENTTABLE *)constant->identifier->pointer, (INTBIG)SYMBOL_CONSTANT,
-			(char *)value, vhdl_symbols);
+			(CHAR *)value, vhdl_symbols);
 	}
 }
 
@@ -961,7 +959,7 @@ DBSTATEMENTS *vhdl_semset_of_statements(STATEMENTS *state)
 							endinstance = newinstance;
 						}
 					}
-					efree((char *)newstate);
+					efree((CHAR *)newstate);
 				}
 				break;
 			case ARCHSTATE_SIG_ASSIGN:
@@ -996,12 +994,12 @@ DBINSTANCE *vhdl_seminstance(VINSTANCE *inst)
 	INTBIG iport_num, cport_num;
 	APORTLIST *aplist;
 	DBPORTLIST *plist;
-	char sbuffer[80], *sptr;
+	CHAR sbuffer[80], *sptr;
 	IDENTTABLE *ikey;
 	DBAPORTLIST *dbaport, *enddbaport;
 #ifndef VHDL50
 	INTBIG i;
-	char temp[20];
+	CHAR temp[20];
 #endif
 
 	dbinst = 0;
@@ -1014,19 +1012,19 @@ DBINSTANCE *vhdl_seminstance(VINSTANCE *inst)
 			ttyputmsg(_("WARNING - no name for node instance, adding default"));
 
 		/* create instance name */
-		sprintf(sbuffer, "%s_%ld", vhdl_default_name, vhdl_default_num++);
+		esnprintf(sbuffer, 80, x_("%s_%ld"), vhdl_default_name, vhdl_default_num++);
 #else
 	/* If inside a "for generate" make unique instance name
 	 * from instance label and vhdl_for_tags[]
 	 */
 	if (vhdl_for_level > 0)
 	{
-		if (!inst->name) strcpy(sbuffer, "no_name"); else
-			strcpy(sbuffer,((IDENTTABLE *)(inst->name->pointer))->string);
+		if (!inst->name) estrcpy(sbuffer, x_("no_name")); else
+			estrcpy(sbuffer,((IDENTTABLE *)(inst->name->pointer))->string);
 		for (i=1; i<=vhdl_for_level; ++i)
 		{
-			sprintf(temp, "_%ld", (INTBIG)vhdl_for_tags[i]);
-			strcat(sbuffer,temp);
+			esnprintf(temp, 20, x_("_%ld"), (INTBIG)vhdl_for_tags[i]);
+			estrcat(sbuffer,temp);
 		}
 #endif
 		/* add to global name space */
@@ -1050,7 +1048,7 @@ DBINSTANCE *vhdl_seminstance(VINSTANCE *inst)
 		vhdl_reporterrormsg(inst->name, _("Instance name previously defined"));
 	} else
 	{
-		vhdl_addsymbol(dbinst->name, (INTBIG)SYMBOL_INSTANCE, (char *)dbinst, vhdl_symbols);
+		vhdl_addsymbol(dbinst->name, (INTBIG)SYMBOL_INSTANCE, (CHAR *)dbinst, vhdl_symbols);
 	}
 
 	/* check that instance entity is among component list */
@@ -1167,9 +1165,9 @@ DBSTATEMENTS *vhdl_semgenerate(GENERATE *gen)
 			vhdl_reporterrormsg(gen->label, _("Symbol previously defined"));
 		} else
 		{
-			vhdl_addsymbol((IDENTTABLE *)gen->label->pointer, (INTBIG)SYMBOL_LABEL, (char *)0,
+			vhdl_addsymbol((IDENTTABLE *)gen->label->pointer, (INTBIG)SYMBOL_LABEL, (CHAR *)0,
 				vhdl_symbols);
-			strcpy(vhdl_default_name, ((IDENTTABLE *)(gen->label->pointer))->string);
+			estrcpy(vhdl_default_name, ((IDENTTABLE *)(gen->label->pointer))->string);
 #ifdef VHDL50
 			vhdl_default_num = 0;
 #endif
@@ -1193,7 +1191,7 @@ DBSTATEMENTS *vhdl_semgenerate(GENERATE *gen)
 
 			/* add identifier as a variable symbol */
 			symbol = vhdl_addsymbol((IDENTTABLE *)scheme->identifier->pointer, (INTBIG)SYMBOL_VARIABLE,
-				(char *)0, vhdl_symbols);
+				(CHAR *)0, vhdl_symbols);
 
 			/* determine direction of discrete range (ascending or descending) */
 			drange = vhdl_semdiscrete_range(scheme->range);
@@ -1206,7 +1204,7 @@ DBSTATEMENTS *vhdl_semgenerate(GENERATE *gen)
 			oldstates = 0;
 			for (temp = drange->start; temp <= drange->end; temp++)
 			{
-				symbol->pointer = (char *)temp;
+				symbol->pointer = (CHAR *)temp;
 				dbstates = vhdl_semset_of_statements(gen->statements);
 #ifndef VHDL50
 				++vhdl_for_tags[vhdl_for_level];
@@ -1237,11 +1235,11 @@ DBSTATEMENTS *vhdl_semgenerate(GENERATE *gen)
 								endinst = inst;
 							}
 						}
-						efree((char *)dbstates);
+						efree((CHAR *)dbstates);
 					}
 				}
 			}
-			efree((char *)drange);
+			efree((CHAR *)drange);
 			dbstates = oldstates;
 
 			/* restore old symbol table */
@@ -1466,7 +1464,7 @@ sym_list	*SYMBOLLIST	Pointer to symbol list.
 symbol		*SYMBOLTREE	Pointer to created symbol.
 ------------------------------------------------------------------------
 */
-SYMBOLTREE *vhdl_addsymbol(IDENTTABLE *value, INTBIG type, char *pointer, SYMBOLLIST *sym_list)
+SYMBOLTREE *vhdl_addsymbol(IDENTTABLE *value, INTBIG type, CHAR *pointer, SYMBOLLIST *sym_list)
 {
 	SYMBOLTREE *symbol;
 
@@ -1504,7 +1502,7 @@ nptr		*SYMBOLTREE	Pointer to current tree node.
 symbol		*SYMBOLTREE	Pointer to created symbol.
 ------------------------------------------------------------------------
 */
-SYMBOLTREE *vhdl_addsymboltree(IDENTTABLE *value, INTBIG type, char *pointer, SYMBOLTREE *nptr)
+SYMBOLTREE *vhdl_addsymboltree(IDENTTABLE *value, INTBIG type, CHAR *pointer, SYMBOLTREE *nptr)
 {
 	SYMBOLTREE **tptr, *newnode;
 
@@ -1701,7 +1699,7 @@ TYPE *vhdl_parsetype(void)
 	TYPE *type;
 	TOKENLIST *ident;
 	INTBIG type_define;
-	char *pointer;
+	CHAR *pointer;
 
 	type = NULL;
 
@@ -1737,11 +1735,11 @@ TYPE *vhdl_parsetype(void)
 	if (vhdl_keysame(vhdl_nexttoken, KEY_ARRAY))
 	{
 		type_define = TYPE_COMPOSITE;
-		pointer = (char *)vhdl_parsecomposite_type();
+		pointer = (CHAR *)vhdl_parsecomposite_type();
 	} else if (vhdl_keysame(vhdl_nexttoken, KEY_RECORD))
 	{
 		type_define = TYPE_COMPOSITE;
-		pointer = (char *)vhdl_parsecomposite_type();
+		pointer = (CHAR *)vhdl_parsecomposite_type();
 	} else if (vhdl_keysame(vhdl_nexttoken, KEY_RANGE))
 	{
 		type_define = TYPE_SCALAR;
@@ -1774,7 +1772,7 @@ TYPE *vhdl_parsetype(void)
 	return(type);
 }
 
-char *vhdl_parsescalar_type(void) { return((char *)NULL); }
+CHAR *vhdl_parsescalar_type(void) { return((CHAR *)NULL); }
 
 /*
 Module:  vhdl_parsecomposite_type
@@ -1791,7 +1789,7 @@ COMPOSITE *vhdl_parsecomposite_type(void)
 {
 	COMPOSITE *compo;
 	INTBIG type;
-	char *pointer;
+	CHAR *pointer;
 
 	compo = NULL;
 
@@ -1799,7 +1797,7 @@ COMPOSITE *vhdl_parsecomposite_type(void)
 	if (vhdl_keysame(vhdl_nexttoken, KEY_ARRAY))
 	{
 		type = COMPOSITE_ARRAY;
-		pointer = (char *)vhdl_parsearray_type();
+		pointer = (CHAR *)vhdl_parsearray_type();
 	} else if (vhdl_keysame(vhdl_nexttoken, KEY_RECORD))
 	{
 		type = COMPOSITE_RECORD;
@@ -1818,7 +1816,7 @@ COMPOSITE *vhdl_parsecomposite_type(void)
 	return(compo);
 }
 
-char *vhdl_parserecord_type() { return((char *)NULL); }
+CHAR *vhdl_parserecord_type() { return((CHAR *)NULL); }
 
 /*
 Module:  vhdl_parsearray_type
@@ -1918,7 +1916,7 @@ ARRAY *vhdl_parsearray_type(void)
 	array = (ARRAY *)emalloc((INTBIG)sizeof(ARRAY), vhdl_tool->cluster);
 	array->type = ARRAY_CONSTRAINED;
 	constr = (CONSTRAINED *)emalloc((INTBIG)sizeof(CONSTRAINED), vhdl_tool->cluster);
-	array->pointer = (char *)constr;
+	array->pointer = (CHAR *)constr;
 	constr->constraint = iconstraint;
 	constr->subtype = subtype;
 
@@ -1968,7 +1966,7 @@ void vhdl_semtype_declare(TYPE *type)
 	if (dbtype)
 	{
 		dbtype->name = (IDENTTABLE *)type->identifier->pointer;
-		vhdl_addsymbol(dbtype->name, (INTBIG)SYMBOL_TYPE, (char *)dbtype, vhdl_symbols);
+		vhdl_addsymbol(dbtype->name, (INTBIG)SYMBOL_TYPE, (CHAR *)dbtype, vhdl_symbols);
 	}
 }
 
@@ -2076,7 +2074,7 @@ DBLTYPE *vhdl_semconstrained_array(CONSTRAINED *constr)
 		if (endrange == NULL)
 		{
 			endrange = newrange;
-			dbtype->pointer = (char *)newrange;
+			dbtype->pointer = (CHAR *)newrange;
 		} else
 		{
 			endrange->next = newrange;
