@@ -43,7 +43,7 @@ extern SYMBOLLIST	*vhdl_gsymbols;
 static DBINTERFACE  *vhdl_top_interface;
 
 /* prototypes for local routines */
-static void vhdl_gensilos_interface(DBINTERFACE*, char*);
+static void vhdl_gensilos_interface(DBINTERFACE*, CHAR*);
 static void vhdl_gensilos_aport(void*, DBINTERFACE*, DBNAME*);
 static BOOLEAN vhdl_gensilos_isport(DBINTERFACE*, DBNAME*);
 
@@ -63,23 +63,23 @@ void vhdl_gensilos(void)
 	UNRESLIST *ulist;
 
 	vhdl_freeunresolvedlist(&vhdl_unresolved_list);
-	(void)vhdl_findidentkey("ground");
-	(void)vhdl_findidentkey("power");
+	(void)vhdl_findidentkey(x_("ground"));
+	(void)vhdl_findidentkey(x_("power"));
 
 	/* print file header */
-	vhdl_printoneline("$*************************************************");
-	vhdl_printoneline("$  SILOS Netlist file");
-	vhdl_printoneline("$");
+	vhdl_printoneline(x_("$*************************************************"));
+	vhdl_printoneline(x_("$  SILOS Netlist file"));
+	vhdl_printoneline(x_("$"));
 	if ((us_useroptions&NODATEORVERSION) == 0)
-		vhdl_printoneline("$  File Creation:    %s", timetostring(getcurrenttime()));
-	vhdl_printoneline("$-------------------------------------------------");
-	vhdl_print("");
+		vhdl_printoneline(x_("$  File Creation:    %s"), timetostring(getcurrenttime()));
+	vhdl_printoneline(x_("$-------------------------------------------------"));
+	vhdl_print(x_(""));
 
 	/* determine top level cell */
 	vhdl_top_interface = vhdl_findtopinterface(vhdl_units);
 	if (vhdl_top_interface == NULL)
 	{
-		ttyputmsg("ERROR - Cannot find top entity");
+		ttyputmsg(x_("ERROR - Cannot find top entity"));
 	} else
 	{
 		/* clear written flag on all interfaces */
@@ -88,12 +88,12 @@ void vhdl_gensilos(void)
 		{
 			interfacef->flags &= ~ENTITY_WRITTEN;
 		}
-		vhdl_print(".TITLE %s", vhdl_top_interface->name->string);
+		vhdl_print(x_(".TITLE %s"), vhdl_top_interface->name->string);
 		vhdl_gensilos_interface(vhdl_top_interface, vhdl_top_interface->name->string);
 	}
 
 	/* print closing line of output file */
-	vhdl_printoneline("$********* End of netlist file *******************");
+	vhdl_printoneline(x_("$********* End of netlist file *******************"));
 
 	/* print unresolved reference list is not empty */
 	if (vhdl_unresolved_list)
@@ -121,7 +121,7 @@ interfacef	*DBINTERFACE	Pointer to interface.
 name		*char			Pointer to string name of interface.
 ------------------------------------------------------------------------
 */
-void vhdl_gensilos_interface(DBINTERFACE *interfacef, char *name)
+void vhdl_gensilos_interface(DBINTERFACE *interfacef, CHAR *name)
 {
 	DBINSTANCE *inst;
 	SYMBOLTREE *symbol;
@@ -131,7 +131,7 @@ void vhdl_gensilos_interface(DBINTERFACE *interfacef, char *name)
 	DBINDEXRANGE *irange;
 	DBDISCRETERANGE *drange;
 	DBNAMELIST *cat;
-	char temp[30];
+	CHAR temp[30];
 	REGISTER void *infstr;
 
 	/* go through interface's architectural body and call generate interfaces*/
@@ -180,11 +180,11 @@ void vhdl_gensilos_interface(DBINTERFACE *interfacef, char *name)
 
 	/* write this interface , unless this is the top level, in that case
 	   only write the instances. */
-	vhdl_print("");
+	vhdl_print(x_(""));
 	if (interfacef != vhdl_top_interface)
 	{
 		infstr = initinfstr();
-		addstringtoinfstr(infstr, ".MACRO  ");
+		addstringtoinfstr(infstr, x_(".MACRO  "));
 		addstringtoinfstr(infstr, name);
 
 		/* write port list of interface */
@@ -192,7 +192,7 @@ void vhdl_gensilos_interface(DBINTERFACE *interfacef, char *name)
 		{
 			if (port->type == NULL || port->type->type == DBTYPE_SINGLE)
 			{
-				addstringtoinfstr(infstr, " ");
+				addstringtoinfstr(infstr, x_(" "));
 				addstringtoinfstr(infstr, port->name->string);
 			} else
 			{
@@ -202,18 +202,18 @@ void vhdl_gensilos_interface(DBINTERFACE *interfacef, char *name)
 				{
 					for (i = drange->start; i >= drange->end; i--)
 					{
-						addstringtoinfstr(infstr, " ");
+						addstringtoinfstr(infstr, x_(" "));
 						addstringtoinfstr(infstr, port->name->string);
-						(void)sprintf(temp, "__%ld", i);
+						(void)esnprintf(temp, 30, x_("__%ld"), i);
 						addstringtoinfstr(infstr, temp);
 					}
 				} else
 				{
 					for (i = drange->start; i <= drange->end; i++)
 					{
-						addstringtoinfstr(infstr, " ");
+						addstringtoinfstr(infstr, x_(" "));
 						addstringtoinfstr(infstr, port->name->string);
-						(void)sprintf(temp, "__%ld", i);
+						(void)esnprintf(temp, 30, x_("__%ld"), i);
 						addstringtoinfstr(infstr, temp);
 					}
 				}
@@ -228,9 +228,9 @@ void vhdl_gensilos_interface(DBINTERFACE *interfacef, char *name)
 		for (inst = interfacef->bodies->statements->instances; inst != NULL; inst = inst->next)
 		{
 			infstr = initinfstr();
-			addstringtoinfstr(infstr, "(");
+			addstringtoinfstr(infstr, x_("("));
 			addstringtoinfstr(infstr, inst->name->string);
-			addstringtoinfstr(infstr, " ");
+			addstringtoinfstr(infstr, x_(" "));
 			addstringtoinfstr(infstr, inst->compo->name->string);
 
 			/* print instance port list */
@@ -259,21 +259,21 @@ void vhdl_gensilos_interface(DBINTERFACE *interfacef, char *name)
 						if (drange->start > drange->end)
 						{
 							for (i = drange->start; i >= drange->end; i--)
-								addstringtoinfstr(infstr, " .SKIP");
+								addstringtoinfstr(infstr, x_(" .SKIP"));
 						} else
 						{
 							for (i = drange->start; i <= drange->end; i++)
-								addstringtoinfstr(infstr, " .SKIP");
+								addstringtoinfstr(infstr, x_(" .SKIP"));
 						}
-					} else addstringtoinfstr(infstr, " .SKIP");
+					} else addstringtoinfstr(infstr, x_(" .SKIP"));
 				}
 			}
 			vhdl_print(returninfstr(infstr));
 		}
 	}
 
-	if (interfacef != vhdl_top_interface) vhdl_print(".EOM"); else
-		vhdl_print("");
+	if (interfacef != vhdl_top_interface) vhdl_print(x_(".EOM")); else
+		vhdl_print(x_(""));
 }
 
 /*
@@ -299,15 +299,15 @@ void vhdl_gensilos_aport(void *infstr, DBINTERFACE *interfacef, DBNAME *name)
 	DBINDEXRANGE *irange;
 	DBDISCRETERANGE *drange;
 	INTBIG i;
-	char temp[30];
+	CHAR temp[30];
 
 	if (name->type == DBNAME_INDEXED)
 	{
-		addstringtoinfstr(infstr, " ");
+		addstringtoinfstr(infstr, x_(" "));
 		addstringtoinfstr(infstr, name->name->string);
 		if (vhdl_gensilos_isport(interfacef, name))
-			(void)sprintf(temp, "__%ld", ((DBEXPRLIST *)(name->pointer))->value); else
-				(void)sprintf(temp, "[%ld]", ((DBEXPRLIST *)(name->pointer))->value);
+			(void)esnprintf(temp, 30, x_("__%ld"), ((DBEXPRLIST *)(name->pointer))->value); else
+				(void)esnprintf(temp, 30, x_("[%ld]"), ((DBEXPRLIST *)(name->pointer))->value);
 		addstringtoinfstr(infstr, temp);
 	} else
 	{
@@ -319,26 +319,28 @@ void vhdl_gensilos_aport(void *infstr, DBINTERFACE *interfacef, DBNAME *name)
 			{
 				for (i = drange->start; i >= drange->end; i--)
 				{
-					addstringtoinfstr(infstr, " ");
+					addstringtoinfstr(infstr, x_(" "));
 					addstringtoinfstr(infstr, name->name->string);
-					if (vhdl_gensilos_isport(interfacef, name)) (void)sprintf(temp, "__%ld", i);
-						else (void)sprintf(temp, "[%ld]", i);
+					if (vhdl_gensilos_isport(interfacef, name))
+						(void)esnprintf(temp, 30, x_("__%ld"), i); else
+							(void)esnprintf(temp, 30, x_("[%ld]"), i);
 					addstringtoinfstr(infstr, temp);
 				}
 			} else
 			{
 				for (i = drange->start; i <= drange->end; i++)
 				{
-					addstringtoinfstr(infstr, " ");
+					addstringtoinfstr(infstr, x_(" "));
 					addstringtoinfstr(infstr, name->name->string);
-					if (vhdl_gensilos_isport(interfacef, name)) (void)sprintf(temp, "__%ld", i);
-						else (void)sprintf(temp, "[%ld]", i);
+					if (vhdl_gensilos_isport(interfacef, name))
+						(void)esnprintf(temp, 30, x_("__%ld"), i); else
+							(void)esnprintf(temp, 30, x_("[%ld]"), i);
 					addstringtoinfstr(infstr, temp);
 				}
 			}
 		} else
 		{
-			addstringtoinfstr(infstr, " ");
+			addstringtoinfstr(infstr, x_(" "));
 			addstringtoinfstr(infstr, name->name->string);
 		}
 	}
